#line 1 "ad_aarch64.cpp"
//
// Copyright (c) 2003, 2021, Oracle and/or its affiliates. All rights reserved.
// Copyright (c) 2014, 2021, Red Hat, Inc. All rights reserved.
// DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
//
// This code is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License version 2 only, as
// published by the Free Software Foundation.
//
// This code is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// version 2 for more details (a copy is included in the LICENSE file that
// accompanied this code).
//
// You should have received a copy of the GNU General Public License version
// 2 along with this work; if not, write to the Free Software Foundation,
// Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
// or visit www.oracle.com if you need additional information or have any
// questions.
//
//

// Machine Generated File.  Do Not Edit!

#include "precompiled.hpp"
#include "adfiles/adGlobals_aarch64.hpp"
#include "adfiles/ad_aarch64.hpp"
#include "memory/allocation.inline.hpp"
#include "code/codeCache.hpp"
#include "code/compiledIC.hpp"
#include "code/nativeInst.hpp"
#include "code/vmreg.inline.hpp"
#include "gc/shared/collectedHeap.inline.hpp"
#include "oops/compiledICHolder.hpp"
#include "oops/compressedOops.hpp"
#include "oops/markWord.hpp"
#include "oops/method.hpp"
#include "oops/oop.inline.hpp"
#include "opto/c2_MacroAssembler.hpp"
#include "opto/cfgnode.hpp"
#include "opto/intrinsicnode.hpp"
#include "opto/locknode.hpp"
#include "opto/opcodes.hpp"
#include "opto/regalloc.hpp"
#include "opto/regmask.hpp"
#include "opto/runtime.hpp"
#include "runtime/biasedLocking.hpp"
#include "runtime/safepointMechanism.hpp"
#include "runtime/sharedRuntime.hpp"
#include "runtime/stubRoutines.hpp"
#include "utilities/growableArray.hpp"
#include "utilities/powerOfTwo.hpp"

//SourceForm

#line 1318 "src/hotspot/cpu/aarch64/aarch64.ad"


  // Derived RegMask with conditionally allocatable registers

  void PhaseOutput::pd_perform_mach_node_analysis() {
  }

  int MachNode::pd_alignment_required() const {
    return 1;
  }

  int MachNode::compute_padding(int current_offset) const {
    return 0;
  }

  RegMask _ANY_REG32_mask;
  RegMask _ANY_REG_mask;
  RegMask _PTR_REG_mask;
  RegMask _NO_SPECIAL_REG32_mask;
  RegMask _NO_SPECIAL_REG_mask;
  RegMask _NO_SPECIAL_PTR_REG_mask;

  void reg_mask_init() {
    // We derive below RegMask(s) from the ones which are auto-generated from
    // adlc register classes to make AArch64 rheapbase (r27) and rfp (r29)
    // registers conditionally reserved.

    _ANY_REG32_mask = _ALL_REG32_mask;
    _ANY_REG32_mask.Remove(OptoReg::as_OptoReg(r31_sp->as_VMReg()));

    _ANY_REG_mask = _ALL_REG_mask;

    _PTR_REG_mask = _ALL_REG_mask;

    _NO_SPECIAL_REG32_mask = _ALL_REG32_mask;
    _NO_SPECIAL_REG32_mask.SUBTRACT(_NON_ALLOCATABLE_REG32_mask);

    _NO_SPECIAL_REG_mask = _ALL_REG_mask;
    _NO_SPECIAL_REG_mask.SUBTRACT(_NON_ALLOCATABLE_REG_mask);

    _NO_SPECIAL_PTR_REG_mask = _ALL_REG_mask;
    _NO_SPECIAL_PTR_REG_mask.SUBTRACT(_NON_ALLOCATABLE_REG_mask);

    // r27 is not allocatable when compressed oops is on and heapbase is not
    // zero, compressed klass pointers doesn't use r27 after JDK-8234794
    if (UseCompressedOops && (CompressedOops::ptrs_base() != NULL)) {
      _NO_SPECIAL_REG32_mask.Remove(OptoReg::as_OptoReg(r27->as_VMReg()));
      _NO_SPECIAL_REG_mask.SUBTRACT(_HEAPBASE_REG_mask);
      _NO_SPECIAL_PTR_REG_mask.SUBTRACT(_HEAPBASE_REG_mask);
    }

    // r29 is not allocatable when PreserveFramePointer is on
    if (PreserveFramePointer) {
      _NO_SPECIAL_REG32_mask.Remove(OptoReg::as_OptoReg(r29->as_VMReg()));
      _NO_SPECIAL_REG_mask.SUBTRACT(_FP_REG_mask);
      _NO_SPECIAL_PTR_REG_mask.SUBTRACT(_FP_REG_mask);
    }
  }

  // Optimizaton of volatile gets and puts
  // -------------------------------------
  //
  // AArch64 has ldar<x> and stlr<x> instructions which we can safely
  // use to implement volatile reads and writes. For a volatile read
  // we simply need
  //
  //   ldar<x>
  //
  // and for a volatile write we need
  //
  //   stlr<x>
  //
  // Alternatively, we can implement them by pairing a normal
  // load/store with a memory barrier. For a volatile read we need
  //
  //   ldr<x>
  //   dmb ishld
  //
  // for a volatile write
  //
  //   dmb ish
  //   str<x>
  //   dmb ish
  //
  // We can also use ldaxr and stlxr to implement compare and swap CAS
  // sequences. These are normally translated to an instruction
  // sequence like the following
  //
  //   dmb      ish
  // retry:
  //   ldxr<x>   rval raddr
  //   cmp       rval rold
  //   b.ne done
  //   stlxr<x>  rval, rnew, rold
  //   cbnz      rval retry
  // done:
  //   cset      r0, eq
  //   dmb ishld
  //
  // Note that the exclusive store is already using an stlxr
  // instruction. That is required to ensure visibility to other
  // threads of the exclusive write (assuming it succeeds) before that
  // of any subsequent writes.
  //
  // The following instruction sequence is an improvement on the above
  //
  // retry:
  //   ldaxr<x>  rval raddr
  //   cmp       rval rold
  //   b.ne done
  //   stlxr<x>  rval, rnew, rold
  //   cbnz      rval retry
  // done:
  //   cset      r0, eq
  //
  // We don't need the leading dmb ish since the stlxr guarantees
  // visibility of prior writes in the case that the swap is
  // successful. Crucially we don't have to worry about the case where
  // the swap is not successful since no valid program should be
  // relying on visibility of prior changes by the attempting thread
  // in the case where the CAS fails.
  //
  // Similarly, we don't need the trailing dmb ishld if we substitute
  // an ldaxr instruction since that will provide all the guarantees we
  // require regarding observation of changes made by other threads
  // before any change to the CAS address observed by the load.
  //
  // In order to generate the desired instruction sequence we need to
  // be able to identify specific 'signature' ideal graph node
  // sequences which i) occur as a translation of a volatile reads or
  // writes or CAS operations and ii) do not occur through any other
  // translation or graph transformation. We can then provide
  // alternative aldc matching rules which translate these node
  // sequences to the desired machine code sequences. Selection of the
  // alternative rules can be implemented by predicates which identify
  // the relevant node sequences.
  //
  // The ideal graph generator translates a volatile read to the node
  // sequence
  //
  //   LoadX[mo_acquire]
  //   MemBarAcquire
  //
  // As a special case when using the compressed oops optimization we
  // may also see this variant
  //
  //   LoadN[mo_acquire]
  //   DecodeN
  //   MemBarAcquire
  //
  // A volatile write is translated to the node sequence
  //
  //   MemBarRelease
  //   StoreX[mo_release] {CardMark}-optional
  //   MemBarVolatile
  //
  // n.b. the above node patterns are generated with a strict
  // 'signature' configuration of input and output dependencies (see
  // the predicates below for exact details). The card mark may be as
  // simple as a few extra nodes or, in a few GC configurations, may
  // include more complex control flow between the leading and
  // trailing memory barriers. However, whatever the card mark
  // configuration these signatures are unique to translated volatile
  // reads/stores -- they will not appear as a result of any other
  // bytecode translation or inlining nor as a consequence of
  // optimizing transforms.
  //
  // We also want to catch inlined unsafe volatile gets and puts and
  // be able to implement them using either ldar<x>/stlr<x> or some
  // combination of ldr<x>/stlr<x> and dmb instructions.
  //
  // Inlined unsafe volatiles puts manifest as a minor variant of the
  // normal volatile put node sequence containing an extra cpuorder
  // membar
  //
  //   MemBarRelease
  //   MemBarCPUOrder
  //   StoreX[mo_release] {CardMark}-optional
  //   MemBarCPUOrder
  //   MemBarVolatile
  //
  // n.b. as an aside, a cpuorder membar is not itself subject to
  // matching and translation by adlc rules.  However, the rule
  // predicates need to detect its presence in order to correctly
  // select the desired adlc rules.
  //
  // Inlined unsafe volatile gets manifest as a slightly different
  // node sequence to a normal volatile get because of the
  // introduction of some CPUOrder memory barriers to bracket the
  // Load. However, but the same basic skeleton of a LoadX feeding a
  // MemBarAcquire, possibly thorugh an optional DecodeN, is still
  // present
  //
  //   MemBarCPUOrder
  //        ||       \\
  //   MemBarCPUOrder LoadX[mo_acquire]
  //        ||            |
  //        ||       {DecodeN} optional
  //        ||       /
  //     MemBarAcquire
  //
  // In this case the acquire membar does not directly depend on the
  // load. However, we can be sure that the load is generated from an
  // inlined unsafe volatile get if we see it dependent on this unique
  // sequence of membar nodes. Similarly, given an acquire membar we
  // can know that it was added because of an inlined unsafe volatile
  // get if it is fed and feeds a cpuorder membar and if its feed
  // membar also feeds an acquiring load.
  //
  // Finally an inlined (Unsafe) CAS operation is translated to the
  // following ideal graph
  //
  //   MemBarRelease
  //   MemBarCPUOrder
  //   CompareAndSwapX {CardMark}-optional
  //   MemBarCPUOrder
  //   MemBarAcquire
  //
  // So, where we can identify these volatile read and write
  // signatures we can choose to plant either of the above two code
  // sequences. For a volatile read we can simply plant a normal
  // ldr<x> and translate the MemBarAcquire to a dmb. However, we can
  // also choose to inhibit translation of the MemBarAcquire and
  // inhibit planting of the ldr<x>, instead planting an ldar<x>.
  //
  // When we recognise a volatile store signature we can choose to
  // plant at a dmb ish as a translation for the MemBarRelease, a
  // normal str<x> and then a dmb ish for the MemBarVolatile.
  // Alternatively, we can inhibit translation of the MemBarRelease
  // and MemBarVolatile and instead plant a simple stlr<x>
  // instruction.
  //
  // when we recognise a CAS signature we can choose to plant a dmb
  // ish as a translation for the MemBarRelease, the conventional
  // macro-instruction sequence for the CompareAndSwap node (which
  // uses ldxr<x>) and then a dmb ishld for the MemBarAcquire.
  // Alternatively, we can elide generation of the dmb instructions
  // and plant the alternative CompareAndSwap macro-instruction
  // sequence (which uses ldaxr<x>).
  //
  // Of course, the above only applies when we see these signature
  // configurations. We still want to plant dmb instructions in any
  // other cases where we may see a MemBarAcquire, MemBarRelease or
  // MemBarVolatile. For example, at the end of a constructor which
  // writes final/volatile fields we will see a MemBarRelease
  // instruction and this needs a 'dmb ish' lest we risk the
  // constructed object being visible without making the
  // final/volatile field writes visible.
  //
  // n.b. the translation rules below which rely on detection of the
  // volatile signatures and insert ldar<x> or stlr<x> are failsafe.
  // If we see anything other than the signature configurations we
  // always just translate the loads and stores to ldr<x> and str<x>
  // and translate acquire, release and volatile membars to the
  // relevant dmb instructions.
  //

  // is_CAS(int opcode, bool maybe_volatile)
  //
  // return true if opcode is one of the possible CompareAndSwapX
  // values otherwise false.

  bool is_CAS(int opcode, bool maybe_volatile)
  {
    switch(opcode) {
      // We handle these
    case Op_CompareAndSwapI:
    case Op_CompareAndSwapL:
    case Op_CompareAndSwapP:
    case Op_CompareAndSwapN:
    case Op_ShenandoahCompareAndSwapP:
    case Op_ShenandoahCompareAndSwapN:
    case Op_CompareAndSwapB:
    case Op_CompareAndSwapS:
    case Op_GetAndSetI:
    case Op_GetAndSetL:
    case Op_GetAndSetP:
    case Op_GetAndSetN:
    case Op_GetAndAddI:
    case Op_GetAndAddL:
      return true;
    case Op_CompareAndExchangeI:
    case Op_CompareAndExchangeN:
    case Op_CompareAndExchangeB:
    case Op_CompareAndExchangeS:
    case Op_CompareAndExchangeL:
    case Op_CompareAndExchangeP:
    case Op_WeakCompareAndSwapB:
    case Op_WeakCompareAndSwapS:
    case Op_WeakCompareAndSwapI:
    case Op_WeakCompareAndSwapL:
    case Op_WeakCompareAndSwapP:
    case Op_WeakCompareAndSwapN:
    case Op_ShenandoahWeakCompareAndSwapP:
    case Op_ShenandoahWeakCompareAndSwapN:
    case Op_ShenandoahCompareAndExchangeP:
    case Op_ShenandoahCompareAndExchangeN:
      return maybe_volatile;
    default:
      return false;
    }
  }

  // helper to determine the maximum number of Phi nodes we may need to
  // traverse when searching from a card mark membar for the merge mem
  // feeding a trailing membar or vice versa

// predicates controlling emit of ldr<x>/ldar<x>

bool unnecessary_acquire(const Node *barrier)
{
  assert(barrier->is_MemBar(), "expecting a membar");

  MemBarNode* mb = barrier->as_MemBar();

  if (mb->trailing_load()) {
    return true;
  }

  if (mb->trailing_load_store()) {
    Node* load_store = mb->in(MemBarNode::Precedent);
    assert(load_store->is_LoadStore(), "unexpected graph shape");
    return is_CAS(load_store->Opcode(), true);
  }

  return false;
}

bool needs_acquiring_load(const Node *n)
{
  assert(n->is_Load(), "expecting a load");
  LoadNode *ld = n->as_Load();
  return ld->is_acquire();
}

bool unnecessary_release(const Node *n)
{
  assert((n->is_MemBar() &&
          n->Opcode() == Op_MemBarRelease),
         "expecting a release membar");

  MemBarNode *barrier = n->as_MemBar();
  if (!barrier->leading()) {
    return false;
  } else {
    Node* trailing = barrier->trailing_membar();
    MemBarNode* trailing_mb = trailing->as_MemBar();
    assert(trailing_mb->trailing(), "Not a trailing membar?");
    assert(trailing_mb->leading_membar() == n, "inconsistent leading/trailing membars");

    Node* mem = trailing_mb->in(MemBarNode::Precedent);
    if (mem->is_Store()) {
      assert(mem->as_Store()->is_release(), "");
      assert(trailing_mb->Opcode() == Op_MemBarVolatile, "");
      return true;
    } else {
      assert(mem->is_LoadStore(), "");
      assert(trailing_mb->Opcode() == Op_MemBarAcquire, "");
      return is_CAS(mem->Opcode(), true);
    }
  }
  return false;
}

bool unnecessary_volatile(const Node *n)
{
  // assert n->is_MemBar();
  MemBarNode *mbvol = n->as_MemBar();

  bool release = mbvol->trailing_store();
  assert(!release || (mbvol->in(MemBarNode::Precedent)->is_Store() && mbvol->in(MemBarNode::Precedent)->as_Store()->is_release()), "");
#ifdef ASSERT
  if (release) {
    Node* leading = mbvol->leading_membar();
    assert(leading->Opcode() == Op_MemBarRelease, "");
    assert(leading->as_MemBar()->leading_store(), "");
    assert(leading->as_MemBar()->trailing_membar() == mbvol, "");
  }
#endif

  return release;
}

// predicates controlling emit of str<x>/stlr<x>

bool needs_releasing_store(const Node *n)
{
  // assert n->is_Store();
  StoreNode *st = n->as_Store();
  return st->trailing_membar() != NULL;
}

// predicate controlling translation of CAS
//
// returns true if CAS needs to use an acquiring load otherwise false

bool needs_acquiring_load_exclusive(const Node *n)
{
  assert(is_CAS(n->Opcode(), true), "expecting a compare and swap");
  LoadStoreNode* ldst = n->as_LoadStore();
  if (is_CAS(n->Opcode(), false)) {
    assert(ldst->trailing_membar() != NULL, "expected trailing membar");
  } else {
    return ldst->trailing_membar() != NULL;
  }

  // so we can just return true here
  return true;
}

#define __ _masm.

// advance declarations for helper functions to convert register
// indices to register objects

// the ad file has to provide implementations of certain methods
// expected by the generic code
//
// REQUIRED FUNCTIONALITY

//=============================================================================

// !!!!! Special hack to get all types of calls to specify the byte offset
//       from the start of the call to the point where the return address
//       will point.

int MachCallStaticJavaNode::ret_addr_offset()
{
  // call should be a simple bl
  int off = 4;
  return off;
}

int MachCallDynamicJavaNode::ret_addr_offset()
{
  return 16; // movz, movk, movk, bl
}

int MachCallRuntimeNode::ret_addr_offset() {
  // for generated stubs the call will be
  //   bl(addr)
  // or with far branches
  //   bl(trampoline_stub)
  // for real runtime callouts it will be six instructions
  // see aarch64_enc_java_to_runtime
  //   adr(rscratch2, retaddr)
  //   lea(rscratch1, RuntimeAddress(addr)
  //   stp(zr, rscratch2, Address(__ pre(sp, -2 * wordSize)))
  //   blr(rscratch1)
  CodeBlob *cb = CodeCache::find_blob(_entry_point);
  if (cb) {
    return 1 * NativeInstruction::instruction_size;
  } else {
    return 6 * NativeInstruction::instruction_size;
  }
}

int MachCallNativeNode::ret_addr_offset() {
  // This is implemented using aarch64_enc_java_to_runtime as above.
  CodeBlob *cb = CodeCache::find_blob(_entry_point);
  if (cb) {
    return 1 * NativeInstruction::instruction_size;
  } else {
    return 6 * NativeInstruction::instruction_size;
  }
}

//=============================================================================

#ifndef PRODUCT
void MachBreakpointNode::format(PhaseRegAlloc *ra_, outputStream *st) const {
  st->print("BREAKPOINT");
}
#endif

void MachBreakpointNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  C2_MacroAssembler _masm(&cbuf);
  __ brk(0);
}

uint MachBreakpointNode::size(PhaseRegAlloc *ra_) const {
  return MachNode::size(ra_);
}

//=============================================================================

#ifndef PRODUCT
  void MachNopNode::format(PhaseRegAlloc*, outputStream* st) const {
    st->print("nop \t# %d bytes pad for loops and calls", _count);
  }
#endif

  void MachNopNode::emit(CodeBuffer &cbuf, PhaseRegAlloc*) const {
    C2_MacroAssembler _masm(&cbuf);
    for (int i = 0; i < _count; i++) {
      __ nop();
    }
  }

  uint MachNopNode::size(PhaseRegAlloc*) const {
    return _count * NativeInstruction::instruction_size;
  }

//=============================================================================
const RegMask& MachConstantBaseNode::_out_RegMask = RegMask::Empty;

int ConstantTable::calculate_table_base_offset() const {
  return 0;  // absolute addressing, no offset
}

bool MachConstantBaseNode::requires_postalloc_expand() const { return false; }
void MachConstantBaseNode::postalloc_expand(GrowableArray <Node *> *nodes, PhaseRegAlloc *ra_) {
  ShouldNotReachHere();
}

void MachConstantBaseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  // Empty encoding
}

uint MachConstantBaseNode::size(PhaseRegAlloc* ra_) const {
  return 0;
}

#ifndef PRODUCT
void MachConstantBaseNode::format(PhaseRegAlloc* ra_, outputStream* st) const {
  st->print("-- \t// MachConstantBaseNode (empty encoding)");
}
#endif

#ifndef PRODUCT
void MachPrologNode::format(PhaseRegAlloc *ra_, outputStream *st) const {
  Compile* C = ra_->C;

  int framesize = C->output()->frame_slots() << LogBytesPerInt;

  if (C->output()->need_stack_bang(framesize))
    st->print("# stack bang size=%d\n\t", framesize);

  if (framesize < ((1 << 9) + 2 * wordSize)) {
    st->print("sub  sp, sp, #%d\n\t", framesize);
    st->print("stp  rfp, lr, [sp, #%d]", framesize - 2 * wordSize);
    if (PreserveFramePointer) st->print("\n\tadd  rfp, sp, #%d", framesize - 2 * wordSize);
  } else {
    st->print("stp  lr, rfp, [sp, #%d]!\n\t", -(2 * wordSize));
    if (PreserveFramePointer) st->print("mov  rfp, sp\n\t");
    st->print("mov  rscratch1, #%d\n\t", framesize - 2 * wordSize);
    st->print("sub  sp, sp, rscratch1");
  }
  if (C->stub_function() == NULL && BarrierSet::barrier_set()->barrier_set_nmethod() != NULL) {
    st->print("\n\t");
    st->print("ldr  rscratch1, [guard]\n\t");
    st->print("dmb ishld\n\t");
    st->print("ldr  rscratch2, [rthread, #thread_disarmed_offset]\n\t");
    st->print("cmp  rscratch1, rscratch2\n\t");
    st->print("b.eq skip");
    st->print("\n\t");
    st->print("blr #nmethod_entry_barrier_stub\n\t");
    st->print("b skip\n\t");
    st->print("guard: int\n\t");
    st->print("\n\t");
    st->print("skip:\n\t");
  }
}
#endif

void MachPrologNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  Compile* C = ra_->C;
  C2_MacroAssembler _masm(&cbuf);

  // n.b. frame size includes space for return pc and rfp
  const int framesize = C->output()->frame_size_in_bytes();

  // insert a nop at the start of the prolog so we can patch in a
  // branch if we need to invalidate the method later
  __ nop();

  if (C->clinit_barrier_on_entry()) {
    assert(!C->method()->holder()->is_not_initialized(), "initialization should have been started");

    Label L_skip_barrier;

    __ mov_metadata(rscratch2, C->method()->holder()->constant_encoding());
    __ clinit_barrier(rscratch2, rscratch1, &L_skip_barrier);
    __ far_jump(RuntimeAddress(SharedRuntime::get_handle_wrong_method_stub()));
    __ bind(L_skip_barrier);
  }

  if (C->max_vector_size() >= 16) {
    __ reinitialize_ptrue();
  }

  int bangsize = C->output()->bang_size_in_bytes();
  if (C->output()->need_stack_bang(bangsize))
    __ generate_stack_overflow_check(bangsize);

  __ build_frame(framesize);

  if (C->stub_function() == NULL) {
    BarrierSetAssembler* bs = BarrierSet::barrier_set()->barrier_set_assembler();
    bs->nmethod_entry_barrier(&_masm);
  }

  if (VerifyStackAtCalls) {
    Unimplemented();
  }

  C->output()->set_frame_complete(cbuf.insts_size());

  if (C->has_mach_constant_base_node()) {
    // NOTE: We set the table base offset here because users might be
    // emitted before MachConstantBaseNode.
    ConstantTable& constant_table = C->output()->constant_table();
    constant_table.set_table_base_offset(constant_table.calculate_table_base_offset());
  }
}

uint MachPrologNode::size(PhaseRegAlloc* ra_) const
{
  return MachNode::size(ra_); // too many variables; just compute it
                              // the hard way
}

int MachPrologNode::reloc() const
{
  return 0;
}

//=============================================================================

#ifndef PRODUCT
void MachEpilogNode::format(PhaseRegAlloc *ra_, outputStream *st) const {
  Compile* C = ra_->C;
  int framesize = C->output()->frame_slots() << LogBytesPerInt;

  st->print("# pop frame %d\n\t",framesize);

  if (framesize == 0) {
    st->print("ldp  lr, rfp, [sp],#%d\n\t", (2 * wordSize));
  } else if (framesize < ((1 << 9) + 2 * wordSize)) {
    st->print("ldp  lr, rfp, [sp,#%d]\n\t", framesize - 2 * wordSize);
    st->print("add  sp, sp, #%d\n\t", framesize);
  } else {
    st->print("mov  rscratch1, #%d\n\t", framesize - 2 * wordSize);
    st->print("add  sp, sp, rscratch1\n\t");
    st->print("ldp  lr, rfp, [sp],#%d\n\t", (2 * wordSize));
  }

  if (do_polling() && C->is_method_compilation()) {
    st->print("# test polling word\n\t");
    st->print("ldr  rscratch1, [rthread],#%d\n\t", in_bytes(JavaThread::polling_word_offset()));
    st->print("cmp  sp, rscratch1\n\t");
    st->print("bhi #slow_path");
  }
}
#endif

void MachEpilogNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  Compile* C = ra_->C;
  C2_MacroAssembler _masm(&cbuf);
  int framesize = C->output()->frame_slots() << LogBytesPerInt;

  __ remove_frame(framesize);

  if (StackReservedPages > 0 && C->has_reserved_stack_access()) {
    __ reserved_stack_check();
  }

  if (do_polling() && C->is_method_compilation()) {
    Label dummy_label;
    Label* code_stub = &dummy_label;
    if (!C->output()->in_scratch_emit_size()) {
      code_stub = &C->output()->safepoint_poll_table()->add_safepoint(__ offset());
    }
    __ relocate(relocInfo::poll_return_type);
    __ safepoint_poll(*code_stub, true /* at_return */, false /* acquire */, true /* in_nmethod */);
  }
}

uint MachEpilogNode::size(PhaseRegAlloc *ra_) const {
  // Variable size. Determine dynamically.
  return MachNode::size(ra_);
}

int MachEpilogNode::reloc() const {
  // Return number of relocatable values contained in this instruction.
  return 1; // 1 for polling page.
}

const Pipeline * MachEpilogNode::pipeline() const {
  return MachNode::pipeline_class();
}

//=============================================================================

// Figure out which register class each belongs in: rc_int, rc_float or
// rc_stack.
enum RC { rc_bad, rc_int, rc_float, rc_predicate, rc_stack };

static enum RC rc_class(OptoReg::Name reg) {

  if (reg == OptoReg::Bad) {
    return rc_bad;
  }

  // we have 32 int registers * 2 halves
  int slots_of_int_registers = RegisterImpl::max_slots_per_register * RegisterImpl::number_of_registers;

  if (reg < slots_of_int_registers) {
    return rc_int;
  }

  // we have 32 float register * 8 halves
  int slots_of_float_registers = FloatRegisterImpl::max_slots_per_register * FloatRegisterImpl::number_of_registers;
  if (reg < slots_of_int_registers + slots_of_float_registers) {
    return rc_float;
  }

  int slots_of_predicate_registers = PRegisterImpl::max_slots_per_register * PRegisterImpl::number_of_registers;
  if (reg < slots_of_int_registers + slots_of_float_registers + slots_of_predicate_registers) {
    return rc_predicate;
  }

  // Between predicate regs & stack is the flags.
  assert(OptoReg::is_stack(reg), "blow up if spilling flags");

  return rc_stack;
}

uint MachSpillCopyNode::implementation(CodeBuffer *cbuf, PhaseRegAlloc *ra_, bool do_size, outputStream *st) const {
  Compile* C = ra_->C;

  // Get registers to move.
  OptoReg::Name src_hi = ra_->get_reg_second(in(1));
  OptoReg::Name src_lo = ra_->get_reg_first(in(1));
  OptoReg::Name dst_hi = ra_->get_reg_second(this);
  OptoReg::Name dst_lo = ra_->get_reg_first(this);

  enum RC src_hi_rc = rc_class(src_hi);
  enum RC src_lo_rc = rc_class(src_lo);
  enum RC dst_hi_rc = rc_class(dst_hi);
  enum RC dst_lo_rc = rc_class(dst_lo);

  assert(src_lo != OptoReg::Bad && dst_lo != OptoReg::Bad, "must move at least 1 register");

  if (src_hi != OptoReg::Bad) {
    assert((src_lo&1)==0 && src_lo+1==src_hi &&
           (dst_lo&1)==0 && dst_lo+1==dst_hi,
           "expected aligned-adjacent pairs");
  }

  if (src_lo == dst_lo && src_hi == dst_hi) {
    return 0;            // Self copy, no move.
  }

  bool is64 = (src_lo & 1) == 0 && src_lo + 1 == src_hi &&
              (dst_lo & 1) == 0 && dst_lo + 1 == dst_hi;
  int src_offset = ra_->reg2offset(src_lo);
  int dst_offset = ra_->reg2offset(dst_lo);

  if (bottom_type()->isa_vect() != NULL) {
    uint ireg = ideal_reg();
    if (ireg == Op_VecA && cbuf) {
      C2_MacroAssembler _masm(cbuf);
      int sve_vector_reg_size_in_bytes = Matcher::scalable_vector_reg_size(T_BYTE);
      if (src_lo_rc == rc_stack && dst_lo_rc == rc_stack) {
        // stack->stack
        __ spill_copy_sve_vector_stack_to_stack(src_offset, dst_offset,
                                                sve_vector_reg_size_in_bytes);
      } else if (src_lo_rc == rc_float && dst_lo_rc == rc_stack) {
        __ spill_sve_vector(as_FloatRegister(Matcher::_regEncode[src_lo]), ra_->reg2offset(dst_lo),
                            sve_vector_reg_size_in_bytes);
      } else if (src_lo_rc == rc_stack && dst_lo_rc == rc_float) {
        __ unspill_sve_vector(as_FloatRegister(Matcher::_regEncode[dst_lo]), ra_->reg2offset(src_lo),
                              sve_vector_reg_size_in_bytes);
      } else if (src_lo_rc == rc_float && dst_lo_rc == rc_float) {
        __ sve_orr(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                   as_FloatRegister(Matcher::_regEncode[src_lo]),
                   as_FloatRegister(Matcher::_regEncode[src_lo]));
      } else {
        ShouldNotReachHere();
      }
    } else if (cbuf) {
      assert(ireg == Op_VecD || ireg == Op_VecX, "must be 64 bit or 128 bit vector");
      C2_MacroAssembler _masm(cbuf);
      assert((src_lo_rc != rc_int && dst_lo_rc != rc_int), "sanity");
      if (src_lo_rc == rc_stack && dst_lo_rc == rc_stack) {
        // stack->stack
        assert((src_offset & 7) == 0 && (dst_offset & 7) == 0, "unaligned stack offset");
        if (ireg == Op_VecD) {
          __ unspill(rscratch1, true, src_offset);
          __ spill(rscratch1, true, dst_offset);
        } else {
          __ spill_copy128(src_offset, dst_offset);
        }
      } else if (src_lo_rc == rc_float && dst_lo_rc == rc_float) {
        __ mov(as_FloatRegister(Matcher::_regEncode[dst_lo]),
               ireg == Op_VecD ? __ T8B : __ T16B,
               as_FloatRegister(Matcher::_regEncode[src_lo]));
      } else if (src_lo_rc == rc_float && dst_lo_rc == rc_stack) {
        __ spill(as_FloatRegister(Matcher::_regEncode[src_lo]),
                 ireg == Op_VecD ? __ D : __ Q,
                 ra_->reg2offset(dst_lo));
      } else if (src_lo_rc == rc_stack && dst_lo_rc == rc_float) {
        __ unspill(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                   ireg == Op_VecD ? __ D : __ Q,
                   ra_->reg2offset(src_lo));
      } else {
        ShouldNotReachHere();
      }
    }
  } else if (cbuf) {
    C2_MacroAssembler _masm(cbuf);
    switch (src_lo_rc) {
    case rc_int:
      if (dst_lo_rc == rc_int) {  // gpr --> gpr copy
        if (is64) {
            __ mov(as_Register(Matcher::_regEncode[dst_lo]),
                   as_Register(Matcher::_regEncode[src_lo]));
        } else {
            C2_MacroAssembler _masm(cbuf);
            __ movw(as_Register(Matcher::_regEncode[dst_lo]),
                    as_Register(Matcher::_regEncode[src_lo]));
        }
      } else if (dst_lo_rc == rc_float) { // gpr --> fpr copy
        if (is64) {
            __ fmovd(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                     as_Register(Matcher::_regEncode[src_lo]));
        } else {
            __ fmovs(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                     as_Register(Matcher::_regEncode[src_lo]));
        }
      } else {                    // gpr --> stack spill
        assert(dst_lo_rc == rc_stack, "spill to bad register class");
        __ spill(as_Register(Matcher::_regEncode[src_lo]), is64, dst_offset);
      }
      break;
    case rc_float:
      if (dst_lo_rc == rc_int) {  // fpr --> gpr copy
        if (is64) {
            __ fmovd(as_Register(Matcher::_regEncode[dst_lo]),
                     as_FloatRegister(Matcher::_regEncode[src_lo]));
        } else {
            __ fmovs(as_Register(Matcher::_regEncode[dst_lo]),
                     as_FloatRegister(Matcher::_regEncode[src_lo]));
        }
      } else if (dst_lo_rc == rc_float) { // fpr --> fpr copy
          if (cbuf) {
            __ fmovd(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                     as_FloatRegister(Matcher::_regEncode[src_lo]));
        } else {
            __ fmovs(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                     as_FloatRegister(Matcher::_regEncode[src_lo]));
        }
      } else {                    // fpr --> stack spill
        assert(dst_lo_rc == rc_stack, "spill to bad register class");
        __ spill(as_FloatRegister(Matcher::_regEncode[src_lo]),
                 is64 ? __ D : __ S, dst_offset);
      }
      break;
    case rc_stack:
      if (dst_lo_rc == rc_int) {  // stack --> gpr load
        __ unspill(as_Register(Matcher::_regEncode[dst_lo]), is64, src_offset);
      } else if (dst_lo_rc == rc_float) { // stack --> fpr load
        __ unspill(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                   is64 ? __ D : __ S, src_offset);
      } else {                    // stack --> stack copy
        assert(dst_lo_rc == rc_stack, "spill to bad register class");
        __ unspill(rscratch1, is64, src_offset);
        __ spill(rscratch1, is64, dst_offset);
      }
      break;
    default:
      assert(false, "bad rc_class for spill");
      ShouldNotReachHere();
    }
  }

  if (st) {
    st->print("spill ");
    if (src_lo_rc == rc_stack) {
      st->print("[sp, #%d] -> ", ra_->reg2offset(src_lo));
    } else {
      st->print("%s -> ", Matcher::regName[src_lo]);
    }
    if (dst_lo_rc == rc_stack) {
      st->print("[sp, #%d]", ra_->reg2offset(dst_lo));
    } else {
      st->print("%s", Matcher::regName[dst_lo]);
    }
    if (bottom_type()->isa_vect() != NULL) {
      int vsize = 0;
      switch (ideal_reg()) {
      case Op_VecD:
        vsize = 64;
        break;
      case Op_VecX:
        vsize = 128;
        break;
      case Op_VecA:
        vsize = Matcher::scalable_vector_reg_size(T_BYTE) * 8;
        break;
      default:
        assert(false, "bad register type for spill");
        ShouldNotReachHere();
      }
      st->print("\t# vector spill size = %d", vsize);
    } else {
      st->print("\t# spill size = %d", is64 ? 64 : 32);
    }
  }

  return 0;

}

#ifndef PRODUCT
void MachSpillCopyNode::format(PhaseRegAlloc *ra_, outputStream *st) const {
  if (!ra_)
    st->print("N%d = SpillCopy(N%d)", _idx, in(1)->_idx);
  else
    implementation(NULL, ra_, false, st);
}
#endif

void MachSpillCopyNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  implementation(&cbuf, ra_, false, NULL);
}

uint MachSpillCopyNode::size(PhaseRegAlloc *ra_) const {
  return MachNode::size(ra_);
}

//=============================================================================

#ifndef PRODUCT
void BoxLockNode::format(PhaseRegAlloc *ra_, outputStream *st) const {
  int offset = ra_->reg2offset(in_RegMask(0).find_first_elem());
  int reg = ra_->get_reg_first(this);
  st->print("add %s, rsp, #%d]\t# box lock",
            Matcher::regName[reg], offset);
}
#endif

void BoxLockNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  C2_MacroAssembler _masm(&cbuf);

  int offset = ra_->reg2offset(in_RegMask(0).find_first_elem());
  int reg    = ra_->get_encode(this);

  // This add will handle any 24-bit signed offset. 24 bits allows an
  // 8 megabyte stack frame.
  __ add(as_Register(reg), sp, offset);
}

uint BoxLockNode::size(PhaseRegAlloc *ra_) const {
  // BoxLockNode is not a MachNode, so we can't just call MachNode::size(ra_).
  int offset = ra_->reg2offset(in_RegMask(0).find_first_elem());

  if (Assembler::operand_valid_for_add_sub_immediate(offset)) {
    return NativeInstruction::instruction_size;
  } else {
    return 2 * NativeInstruction::instruction_size;
  }
}

//=============================================================================

#ifndef PRODUCT
void MachUEPNode::format(PhaseRegAlloc* ra_, outputStream* st) const
{
  st->print_cr("# MachUEPNode");
  if (UseCompressedClassPointers) {
    st->print_cr("\tldrw rscratch1, j_rarg0 + oopDesc::klass_offset_in_bytes()]\t# compressed klass");
    if (CompressedKlassPointers::shift() != 0) {
      st->print_cr("\tdecode_klass_not_null rscratch1, rscratch1");
    }
  } else {
   st->print_cr("\tldr rscratch1, j_rarg0 + oopDesc::klass_offset_in_bytes()]\t# compressed klass");
  }
  st->print_cr("\tcmp r0, rscratch1\t # Inline cache check");
  st->print_cr("\tbne, SharedRuntime::_ic_miss_stub");
}
#endif

void MachUEPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const
{
  // This is the unverified entry point.
  C2_MacroAssembler _masm(&cbuf);

  __ cmp_klass(j_rarg0, rscratch2, rscratch1);
  Label skip;
  // TODO
  // can we avoid this skip and still use a reloc?
  __ br(Assembler::EQ, skip);
  __ far_jump(RuntimeAddress(SharedRuntime::get_ic_miss_stub()));
  __ bind(skip);
}

uint MachUEPNode::size(PhaseRegAlloc* ra_) const
{
  return MachNode::size(ra_);
}

// REQUIRED EMIT CODE

//=============================================================================

// Emit exception handler code.
int HandlerImpl::emit_exception_handler(CodeBuffer& cbuf)
{
  // mov rscratch1 #exception_blob_entry_point
  // br rscratch1
  // Note that the code buffer's insts_mark is always relative to insts.
  // That's why we must use the macroassembler to generate a handler.
  C2_MacroAssembler _masm(&cbuf);
  address base = __ start_a_stub(size_exception_handler());
  if (base == NULL) {
    ciEnv::current()->record_failure("CodeCache is full");
    return 0;  // CodeBuffer::expand failed
  }
  int offset = __ offset();
  __ far_jump(RuntimeAddress(OptoRuntime::exception_blob()->entry_point()));
  assert(__ offset() - offset <= (int) size_exception_handler(), "overflow");
  __ end_a_stub();
  return offset;
}

// Emit deopt handler code.
int HandlerImpl::emit_deopt_handler(CodeBuffer& cbuf)
{
  // Note that the code buffer's insts_mark is always relative to insts.
  // That's why we must use the macroassembler to generate a handler.
  C2_MacroAssembler _masm(&cbuf);
  address base = __ start_a_stub(size_deopt_handler());
  if (base == NULL) {
    ciEnv::current()->record_failure("CodeCache is full");
    return 0;  // CodeBuffer::expand failed
  }
  int offset = __ offset();

  __ adr(lr, __ pc());
  __ far_jump(RuntimeAddress(SharedRuntime::deopt_blob()->unpack()));

  assert(__ offset() - offset <= (int) size_deopt_handler(), "overflow");
  __ end_a_stub();
  return offset;
}

// REQUIRED MATCHER CODE

//=============================================================================

const bool Matcher::match_rule_supported(int opcode) {
  if (!has_match_rule(opcode))
    return false;

  bool ret_value = true;
  switch (opcode) {
    case Op_OnSpinWait:
      return VM_Version::supports_on_spin_wait();
    case Op_CacheWB:
    case Op_CacheWBPreSync:
    case Op_CacheWBPostSync:
      if (!VM_Version::supports_data_cache_line_flush()) {
        ret_value = false;
      }
      break;
  }

  return ret_value; // Per default match rules are supported.
}

// Identify extra cases that we might want to provide match rules for vector nodes and
// other intrinsics guarded with vector length (vlen) and element type (bt).
const bool Matcher::match_rule_supported_vector(int opcode, int vlen, BasicType bt) {
  if (!match_rule_supported(opcode) || !vector_size_supported(bt, vlen)) {
    return false;
  }
  int bit_size = vlen * type2aelembytes(bt) * 8;
  if (UseSVE == 0 && bit_size > 128) {
    return false;
  }
  if (UseSVE > 0) {
    return op_sve_supported(opcode);
  } else { // NEON
    // Special cases
    switch (opcode) {
    case Op_VectorMaskCmp:
    // We don't have VectorReinterpret with bit_size less than 64 support for
    // now, even for byte type. To be refined with fully VectorCast support.
    case Op_VectorReinterpret:
      if (vlen < 2 || bit_size < 64) {
        return false;
      }
      break;
    case Op_MulAddVS2VI:
      if (bit_size < 128) {
        return false;
      }
      break;
    case Op_MulVL:
      return false;
    case Op_VectorLoadShuffle:
    case Op_VectorRearrange:
      if (vlen < 4) {
        return false;
      }
      break;
    // Some types of VectorCast are not implemented for now.
    case Op_VectorCastI2X:
      if (bt == T_BYTE) {
        return false;
      }
      break;
    case Op_VectorCastS2X:
      if (vlen < 4 || bit_size < 64) {
        return false;
      }
      break;
    case Op_VectorCastF2X:
    case Op_VectorCastD2X:
      if (bt == T_INT || bt == T_SHORT || bt == T_BYTE || bt == T_LONG) {
        return false;
      }
      break;
    default:
      break;
    }
  }
  return true; // Per default match rules are supported.
}

const RegMask* Matcher::predicate_reg_mask(void) {
  return &_PR_REG_mask;
}

const TypeVect* Matcher::predicate_reg_type(const Type* elemTy, int length) {
  return new TypeVectMask(elemTy, length);
}

// Vector calling convention not yet implemented.
const bool Matcher::supports_vector_calling_convention(void) {
  return false;
}

OptoRegPair Matcher::vector_return_value(uint ideal_reg) {
  Unimplemented();
  return OptoRegPair(0, 0);
}

const int Matcher::float_pressure(int default_pressure_threshold) {
  return default_pressure_threshold;
}

// Is this branch offset short enough that a short branch can be used?
//
// NOTE: If the platform does not provide any short branch variants, then
//       this method should return false for offset 0.
bool Matcher::is_short_branch_offset(int rule, int br_size, int offset) {
  // The passed offset is relative to address of the branch.

  return (-32768 <= offset && offset < 32768);
}

// Vector width in bytes.
const int Matcher::vector_width_in_bytes(BasicType bt) {
  // The MaxVectorSize should have been set by detecting SVE max vector register size.
  int size = MIN2((UseSVE > 0) ? 256 : 16, (int)MaxVectorSize);
  // Minimum 2 values in vector
  if (size < 2*type2aelembytes(bt)) size = 0;
  // But never < 4
  if (size < 4) size = 0;
  return size;
}

// Limits on vector size (number of elements) loaded into vector.
const int Matcher::max_vector_size(const BasicType bt) {
  return vector_width_in_bytes(bt)/type2aelembytes(bt);
}
const int Matcher::min_vector_size(const BasicType bt) {
  int max_size = max_vector_size(bt);
  if ((UseSVE > 0) && (MaxVectorSize >= 16)) {
    // Currently vector length less than SVE vector register size is not supported.
    return max_size;
  } else { // NEON
    // Limit the vector size to 8 bytes
    int size = 8 / type2aelembytes(bt);
    if (bt == T_BYTE) {
      // To support vector api shuffle/rearrange.
      size = 4;
    } else if (bt == T_BOOLEAN) {
      // To support vector api load/store mask.
      size = 2;
    }
    if (size < 2) size = 2;
    return MIN2(size,max_size);
  }
}

// Actual max scalable vector register length.
const int Matcher::scalable_vector_reg_size(const BasicType bt) {
  return Matcher::max_vector_size(bt);
}

// Vector ideal reg.
const uint Matcher::vector_ideal_reg(int len) {
  if (UseSVE > 0 && 16 <= len && len <= 256) {
    return Op_VecA;
  }
  switch(len) {
    // For 16-bit/32-bit mask vector, reuse VecD.
    case  2:
    case  4:
    case  8: return Op_VecD;
    case 16: return Op_VecX;
  }
  ShouldNotReachHere();
  return 0;
}

MachOper* Matcher::pd_specialize_generic_vector_operand(MachOper* original_opnd, uint ideal_reg, bool is_temp) {
  ShouldNotReachHere(); // generic vector operands not supported
  return NULL;
}

bool Matcher::is_generic_reg2reg_move(MachNode* m) {
  ShouldNotReachHere();  // generic vector operands not supported
  return false;
}

bool Matcher::is_generic_vector(MachOper* opnd)  {
  ShouldNotReachHere();  // generic vector operands not supported
  return false;
}

// Return whether or not this register is ever used as an argument.
// This function is used on startup to build the trampoline stubs in
// generateOptoStub.  Registers not mentioned will be killed by the VM
// call in the trampoline, and arguments in those registers not be
// available to the callee.
bool Matcher::can_be_java_arg(int reg)
{
  return
    reg ==  R0_num || reg == R0_H_num ||
    reg ==  R1_num || reg == R1_H_num ||
    reg ==  R2_num || reg == R2_H_num ||
    reg ==  R3_num || reg == R3_H_num ||
    reg ==  R4_num || reg == R4_H_num ||
    reg ==  R5_num || reg == R5_H_num ||
    reg ==  R6_num || reg == R6_H_num ||
    reg ==  R7_num || reg == R7_H_num ||
    reg ==  V0_num || reg == V0_H_num ||
    reg ==  V1_num || reg == V1_H_num ||
    reg ==  V2_num || reg == V2_H_num ||
    reg ==  V3_num || reg == V3_H_num ||
    reg ==  V4_num || reg == V4_H_num ||
    reg ==  V5_num || reg == V5_H_num ||
    reg ==  V6_num || reg == V6_H_num ||
    reg ==  V7_num || reg == V7_H_num;
}

bool Matcher::is_spillable_arg(int reg)
{
  return can_be_java_arg(reg);
}

bool Matcher::use_asm_for_ldiv_by_con(jlong divisor) {
  return false;
}

RegMask Matcher::divI_proj_mask() {
  ShouldNotReachHere();
  return RegMask();
}

// Register for MODI projection of divmodI.
RegMask Matcher::modI_proj_mask() {
  ShouldNotReachHere();
  return RegMask();
}

// Register for DIVL projection of divmodL.
RegMask Matcher::divL_proj_mask() {
  ShouldNotReachHere();
  return RegMask();
}

// Register for MODL projection of divmodL.
RegMask Matcher::modL_proj_mask() {
  ShouldNotReachHere();
  return RegMask();
}

const RegMask Matcher::method_handle_invoke_SP_save_mask() {
  return FP_REG_mask();
}

bool size_fits_all_mem_uses(AddPNode* addp, int shift) {
  for (DUIterator_Fast imax, i = addp->fast_outs(imax); i < imax; i++) {
    Node* u = addp->fast_out(i);
    if (u->is_LoadStore()) {
      // On AArch64, LoadStoreNodes (i.e. compare and swap
      // instructions) only take register indirect as an operand, so
      // any attempt to use an AddPNode as an input to a LoadStoreNode
      // must fail.
      return false;
    }
    if (u->is_Mem()) {
      int opsize = u->as_Mem()->memory_size();
      assert(opsize > 0, "unexpected memory operand size");
      if (u->as_Mem()->memory_size() != (1<<shift)) {
        return false;
      }
    }
  }
  return true;
}

// Should the matcher clone input 'm' of node 'n'?
bool Matcher::pd_clone_node(Node* n, Node* m, Matcher::MStack& mstack) {
  if (is_vshift_con_pattern(n, m)) { // ShiftV src (ShiftCntV con)
    mstack.push(m, Visit);           // m = ShiftCntV
    return true;
  }
  return false;
}

// Should the Matcher clone shifts on addressing modes, expecting them
// to be subsumed into complex addressing expressions or compute them
// into registers?
bool Matcher::pd_clone_address_expressions(AddPNode* m, Matcher::MStack& mstack, VectorSet& address_visited) {
  if (clone_base_plus_offset_address(m, mstack, address_visited)) {
    return true;
  }

  Node *off = m->in(AddPNode::Offset);
  if (off->Opcode() == Op_LShiftL && off->in(2)->is_Con() &&
      size_fits_all_mem_uses(m, off->in(2)->get_int()) &&
      // Are there other uses besides address expressions?
      !is_visited(off)) {
    address_visited.set(off->_idx); // Flag as address_visited
    mstack.push(off->in(2), Visit);
    Node *conv = off->in(1);
    if (conv->Opcode() == Op_ConvI2L &&
        // Are there other uses besides address expressions?
        !is_visited(conv)) {
      address_visited.set(conv->_idx); // Flag as address_visited
      mstack.push(conv->in(1), Pre_Visit);
    } else {
      mstack.push(conv, Pre_Visit);
    }
    address_visited.test_set(m->_idx); // Flag as address_visited
    mstack.push(m->in(AddPNode::Address), Pre_Visit);
    mstack.push(m->in(AddPNode::Base), Pre_Visit);
    return true;
  } else if (off->Opcode() == Op_ConvI2L &&
             // Are there other uses besides address expressions?
             !is_visited(off)) {
    address_visited.test_set(m->_idx); // Flag as address_visited
    address_visited.set(off->_idx); // Flag as address_visited
    mstack.push(off->in(1), Pre_Visit);
    mstack.push(m->in(AddPNode::Address), Pre_Visit);
    mstack.push(m->in(AddPNode::Base), Pre_Visit);
    return true;
  }
  return false;
}

#define MOV_VOLATILE(REG, BASE, INDEX, SCALE, DISP, SCRATCH, INSN)      \
  C2_MacroAssembler _masm(&cbuf);                                       \
  {                                                                     \
    guarantee(INDEX == -1, "mode not permitted for volatile");          \
    guarantee(DISP == 0, "mode not permitted for volatile");            \
    guarantee(SCALE == 0, "mode not permitted for volatile");           \
    __ INSN(REG, as_Register(BASE));                                    \
  }


static Address mem2address(int opcode, Register base, int index, int size, int disp)
  {
    Address::extend scale;

    // Hooboy, this is fugly.  We need a way to communicate to the
    // encoder that the index needs to be sign extended, so we have to
    // enumerate all the cases.
    switch (opcode) {
    case INDINDEXSCALEDI2L:
    case INDINDEXSCALEDI2LN:
    case INDINDEXI2L:
    case INDINDEXI2LN:
      scale = Address::sxtw(size);
      break;
    default:
      scale = Address::lsl(size);
    }

    if (index == -1) {
      return Address(base, disp);
    } else {
      assert(disp == 0, "unsupported address mode: disp = %d", disp);
      return Address(base, as_Register(index), scale);
    }
  }


typedef void (MacroAssembler::* mem_insn)(Register Rt, const Address &adr);
typedef void (MacroAssembler::* mem_insn2)(Register Rt, Register adr);
typedef void (MacroAssembler::* mem_float_insn)(FloatRegister Rt, const Address &adr);
typedef void (MacroAssembler::* mem_vector_insn)(FloatRegister Rt,
                                  MacroAssembler::SIMD_RegVariant T, const Address &adr);

  // Used for all non-volatile memory accesses.  The use of
  // $mem->opcode() to discover whether this pattern uses sign-extended
  // offsets is something of a kludge.
  static void loadStore(C2_MacroAssembler masm, mem_insn insn,
                        Register reg, int opcode,
                        Register base, int index, int scale, int disp,
                        int size_in_memory)
  {
    Address addr = mem2address(opcode, base, index, scale, disp);
    if (addr.getMode() == Address::base_plus_offset) {
      /* If we get an out-of-range offset it is a bug in the compiler,
         so we assert here. */
      assert(Address::offset_ok_for_immed(addr.offset(), exact_log2(size_in_memory)),
             "c2 compiler bug");
      /* Fix up any out-of-range offsets. */
      assert_different_registers(rscratch1, base);
      assert_different_registers(rscratch1, reg);
      addr = masm.legitimize_address(addr, size_in_memory, rscratch1);
    }
    (masm.*insn)(reg, addr);
  }

  static void loadStore(C2_MacroAssembler masm, mem_float_insn insn,
                        FloatRegister reg, int opcode,
                        Register base, int index, int size, int disp,
                        int size_in_memory)
  {
    Address::extend scale;

    switch (opcode) {
    case INDINDEXSCALEDI2L:
    case INDINDEXSCALEDI2LN:
      scale = Address::sxtw(size);
      break;
    default:
      scale = Address::lsl(size);
    }

    if (index == -1) {
      /* If we get an out-of-range offset it is a bug in the compiler,
         so we assert here. */
      assert(Address::offset_ok_for_immed(disp, exact_log2(size_in_memory)), "c2 compiler bug");
      /* Fix up any out-of-range offsets. */
      assert_different_registers(rscratch1, base);
      Address addr = Address(base, disp);
      addr = masm.legitimize_address(addr, size_in_memory, rscratch1);
      (masm.*insn)(reg, addr);
    } else {
      assert(disp == 0, "unsupported address mode: disp = %d", disp);
      (masm.*insn)(reg, Address(base, as_Register(index), scale));
    }
  }

  static void loadStore(C2_MacroAssembler masm, mem_vector_insn insn,
                        FloatRegister reg, MacroAssembler::SIMD_RegVariant T,
                        int opcode, Register base, int index, int size, int disp)
  {
    if (index == -1) {
      (masm.*insn)(reg, T, Address(base, disp));
    } else {
      assert(disp == 0, "unsupported address mode");
      (masm.*insn)(reg, T, Address(base, as_Register(index), Address::lsl(size)));
    }
  }


#line 1538 "ad_aarch64.cpp"


//SourceForm

#line 89 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

  static inline BasicType vector_element_basic_type(const MachNode* n) {
    const TypeVect* vt = n->bottom_type()->is_vect();
    return vt->element_basic_type();
  }

  static inline BasicType vector_element_basic_type(const MachNode* use, const MachOper* opnd) {
    int def_idx = use->operand_index(opnd);
    Node* def = use->in(def_idx);
    const TypeVect* vt = def->bottom_type()->is_vect();
    return vt->element_basic_type();
  }

  static Assembler::SIMD_RegVariant elemBytes_to_regVariant(int esize) {
    switch(esize) {
      case 1:
        return Assembler::B;
      case 2:
        return Assembler::H;
      case 4:
        return Assembler::S;
      case 8:
        return Assembler::D;
      default:
        assert(false, "unsupported");
        ShouldNotReachHere();
    }
    return Assembler::INVALID;
  }

  static Assembler::SIMD_RegVariant elemType_to_regVariant(BasicType bt) {
    return elemBytes_to_regVariant(type2aelembytes(bt));
  }

  typedef void (C2_MacroAssembler::* sve_mem_insn_predicate)(FloatRegister Rt, Assembler::SIMD_RegVariant T,
                                                             PRegister Pg, const Address &adr);

  // Predicated load/store, with optional ptrue to all elements of given predicate register.
  static void loadStoreA_predicate(C2_MacroAssembler masm, bool is_store,
                                   FloatRegister reg, PRegister pg, BasicType bt,
                                   int opcode, Register base, int index, int size, int disp) {
    sve_mem_insn_predicate insn;
    Assembler::SIMD_RegVariant type;
    int esize = type2aelembytes(bt);
    if (index == -1) {
      assert(size == 0, "unsupported address mode: scale size = %d", size);
      switch(esize) {
      case 1:
        insn = is_store ? &C2_MacroAssembler::sve_st1b : &C2_MacroAssembler::sve_ld1b;
        type = Assembler::B;
        break;
      case 2:
        insn = is_store ? &C2_MacroAssembler::sve_st1h : &C2_MacroAssembler::sve_ld1h;
        type = Assembler::H;
        break;
      case 4:
        insn = is_store ? &C2_MacroAssembler::sve_st1w : &C2_MacroAssembler::sve_ld1w;
        type = Assembler::S;
        break;
      case 8:
        insn = is_store ? &C2_MacroAssembler::sve_st1d : &C2_MacroAssembler::sve_ld1d;
        type = Assembler::D;
        break;
      default:
        assert(false, "unsupported");
        ShouldNotReachHere();
      }
      (masm.*insn)(reg, type, pg, Address(base, disp / Matcher::scalable_vector_reg_size(T_BYTE)));
    } else {
      assert(false, "unimplemented");
      ShouldNotReachHere();
    }
  }

  bool op_sve_supported(int opcode) {
    switch (opcode) {
      case Op_MulAddVS2VI:
        // No multiply reduction instructions
      case Op_MulReductionVD:
      case Op_MulReductionVF:
      case Op_MulReductionVI:
      case Op_MulReductionVL:
        // Others
      case Op_Extract:
      case Op_ExtractB:
      case Op_ExtractC:
      case Op_ExtractD:
      case Op_ExtractF:
      case Op_ExtractI:
      case Op_ExtractL:
      case Op_ExtractS:
      case Op_ExtractUB:
      // Vector API specific
      case Op_AndReductionV:
      case Op_OrReductionV:
      case Op_XorReductionV:
      case Op_MaxReductionV:
      case Op_MinReductionV:
      case Op_LoadVectorGather:
      case Op_StoreVectorScatter:
      case Op_VectorBlend:
      case Op_VectorCast:
      case Op_VectorCastB2X:
      case Op_VectorCastD2X:
      case Op_VectorCastF2X:
      case Op_VectorCastI2X:
      case Op_VectorCastL2X:
      case Op_VectorCastS2X:
      case Op_VectorInsert:
      case Op_VectorLoadConst:
      case Op_VectorLoadMask:
      case Op_VectorLoadShuffle:
      case Op_VectorMaskCmp:
      case Op_VectorRearrange:
      case Op_VectorReinterpret:
      case Op_VectorStoreMask:
      case Op_VectorTest:
        return false;
      default:
        return true;
    }
  }

#line 1667 "ad_aarch64.cpp"


//SourceForm

#line 32 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"


static void z_load_barrier(MacroAssembler& _masm, const MachNode* node, Address ref_addr, Register ref, Register tmp, uint8_t barrier_data) {
  if (barrier_data == ZLoadBarrierElided) {
    return;
  }
  ZLoadBarrierStubC2* const stub = ZLoadBarrierStubC2::create(node, ref_addr, ref, tmp, barrier_data);
  __ ldr(tmp, Address(rthread, ZThreadLocalData::address_bad_mask_offset()));
  __ andr(tmp, tmp, ref);
  __ cbnz(tmp, *stub->entry());
  __ bind(*stub->continuation());
}

static void z_load_barrier_slow_path(MacroAssembler& _masm, const MachNode* node, Address ref_addr, Register ref, Register tmp) {
  ZLoadBarrierStubC2* const stub = ZLoadBarrierStubC2::create(node, ref_addr, ref, tmp, ZLoadBarrierStrong);
  __ b(*stub->entry());
  __ bind(*stub->continuation());
}


#line 1693 "ad_aarch64.cpp"


#ifndef PRODUCT
void Compile::adlc_verification() {

  // Following assertions generated from definition section
  assert( INSN_COST == 100, "Expect (100) to equal 100");
  assert( BRANCH_COST == 200, "Expect (2 * INSN_COST) to equal 200");
  assert( CALL_COST == 200, "Expect (2 * INSN_COST) to equal 200");
  assert( VOLATILE_REF_COST == 1000, "Expect (10 * INSN_COST) to equal 1000");
  assert( SVE_COST == 200, "Expect (200) to equal 200");
}
#endif

// Map from machine-independent register number to register_save_policy
const        char register_save_policy[] = {
  'C', // R10
  'C', // R10_H
  'C', // R11
  'C', // R11_H
  'C', // R12
  'C', // R12_H
  'C', // R13
  'C', // R13_H
  'C', // R14
  'C', // R14_H
  'C', // R15
  'C', // R15_H
  'C', // R16
  'C', // R16_H
  'C', // R17
  'C', // R17_H
  'C', // R18
  'C', // R18_H
  'C', // R0
  'C', // R0_H
  'C', // R1
  'C', // R1_H
  'C', // R2
  'C', // R2_H
  'C', // R3
  'C', // R3_H
  'C', // R4
  'C', // R4_H
  'C', // R5
  'C', // R5_H
  'C', // R6
  'C', // R6_H
  'C', // R7
  'C', // R7_H
  'C', // R19
  'C', // R19_H
  'C', // R20
  'C', // R20_H
  'C', // R21
  'C', // R21_H
  'C', // R22
  'C', // R22_H
  'C', // R23
  'C', // R23_H
  'C', // R24
  'C', // R24_H
  'C', // R25
  'C', // R25_H
  'C', // R26
  'C', // R26_H
  'C', // R27
  'C', // R27_H
  'N', // R28
  'N', // R28_H
  'N', // R29
  'N', // R29_H
  'N', // R30
  'N', // R30_H
  'N', // R31
  'N', // R31_H
  'N', // R8
  'N', // R8_H
  'N', // R9
  'N', // R9_H
  'C', // V16
  'C', // V16_H
  'C', // V16_J
  'C', // V16_K
  'C', // V16_L
  'C', // V16_M
  'C', // V16_N
  'C', // V16_O
  'C', // V17
  'C', // V17_H
  'C', // V17_J
  'C', // V17_K
  'C', // V17_L
  'C', // V17_M
  'C', // V17_N
  'C', // V17_O
  'C', // V18
  'C', // V18_H
  'C', // V18_J
  'C', // V18_K
  'C', // V18_L
  'C', // V18_M
  'C', // V18_N
  'C', // V18_O
  'C', // V19
  'C', // V19_H
  'C', // V19_J
  'C', // V19_K
  'C', // V19_L
  'C', // V19_M
  'C', // V19_N
  'C', // V19_O
  'C', // V20
  'C', // V20_H
  'C', // V20_J
  'C', // V20_K
  'C', // V20_L
  'C', // V20_M
  'C', // V20_N
  'C', // V20_O
  'C', // V21
  'C', // V21_H
  'C', // V21_J
  'C', // V21_K
  'C', // V21_L
  'C', // V21_M
  'C', // V21_N
  'C', // V21_O
  'C', // V22
  'C', // V22_H
  'C', // V22_J
  'C', // V22_K
  'C', // V22_L
  'C', // V22_M
  'C', // V22_N
  'C', // V22_O
  'C', // V23
  'C', // V23_H
  'C', // V23_J
  'C', // V23_K
  'C', // V23_L
  'C', // V23_M
  'C', // V23_N
  'C', // V23_O
  'C', // V24
  'C', // V24_H
  'C', // V24_J
  'C', // V24_K
  'C', // V24_L
  'C', // V24_M
  'C', // V24_N
  'C', // V24_O
  'C', // V25
  'C', // V25_H
  'C', // V25_J
  'C', // V25_K
  'C', // V25_L
  'C', // V25_M
  'C', // V25_N
  'C', // V25_O
  'C', // V26
  'C', // V26_H
  'C', // V26_J
  'C', // V26_K
  'C', // V26_L
  'C', // V26_M
  'C', // V26_N
  'C', // V26_O
  'C', // V27
  'C', // V27_H
  'C', // V27_J
  'C', // V27_K
  'C', // V27_L
  'C', // V27_M
  'C', // V27_N
  'C', // V27_O
  'C', // V28
  'C', // V28_H
  'C', // V28_J
  'C', // V28_K
  'C', // V28_L
  'C', // V28_M
  'C', // V28_N
  'C', // V28_O
  'C', // V29
  'C', // V29_H
  'C', // V29_J
  'C', // V29_K
  'C', // V29_L
  'C', // V29_M
  'C', // V29_N
  'C', // V29_O
  'C', // V30
  'C', // V30_H
  'C', // V30_J
  'C', // V30_K
  'C', // V30_L
  'C', // V30_M
  'C', // V30_N
  'C', // V30_O
  'C', // V31
  'C', // V31_H
  'C', // V31_J
  'C', // V31_K
  'C', // V31_L
  'C', // V31_M
  'C', // V31_N
  'C', // V31_O
  'C', // V0
  'C', // V0_H
  'C', // V0_J
  'C', // V0_K
  'C', // V0_L
  'C', // V0_M
  'C', // V0_N
  'C', // V0_O
  'C', // V1
  'C', // V1_H
  'C', // V1_J
  'C', // V1_K
  'C', // V1_L
  'C', // V1_M
  'C', // V1_N
  'C', // V1_O
  'C', // V2
  'C', // V2_H
  'C', // V2_J
  'C', // V2_K
  'C', // V2_L
  'C', // V2_M
  'C', // V2_N
  'C', // V2_O
  'C', // V3
  'C', // V3_H
  'C', // V3_J
  'C', // V3_K
  'C', // V3_L
  'C', // V3_M
  'C', // V3_N
  'C', // V3_O
  'C', // V4
  'C', // V4_H
  'C', // V4_J
  'C', // V4_K
  'C', // V4_L
  'C', // V4_M
  'C', // V4_N
  'C', // V4_O
  'C', // V5
  'C', // V5_H
  'C', // V5_J
  'C', // V5_K
  'C', // V5_L
  'C', // V5_M
  'C', // V5_N
  'C', // V5_O
  'C', // V6
  'C', // V6_H
  'C', // V6_J
  'C', // V6_K
  'C', // V6_L
  'C', // V6_M
  'C', // V6_N
  'C', // V6_O
  'C', // V7
  'C', // V7_H
  'C', // V7_J
  'C', // V7_K
  'C', // V7_L
  'C', // V7_M
  'C', // V7_N
  'C', // V7_O
  'C', // V8
  'C', // V8_H
  'C', // V8_J
  'C', // V8_K
  'C', // V8_L
  'C', // V8_M
  'C', // V8_N
  'C', // V8_O
  'C', // V9
  'C', // V9_H
  'C', // V9_J
  'C', // V9_K
  'C', // V9_L
  'C', // V9_M
  'C', // V9_N
  'C', // V9_O
  'C', // V10
  'C', // V10_H
  'C', // V10_J
  'C', // V10_K
  'C', // V10_L
  'C', // V10_M
  'C', // V10_N
  'C', // V10_O
  'C', // V11
  'C', // V11_H
  'C', // V11_J
  'C', // V11_K
  'C', // V11_L
  'C', // V11_M
  'C', // V11_N
  'C', // V11_O
  'C', // V12
  'C', // V12_H
  'C', // V12_J
  'C', // V12_K
  'C', // V12_L
  'C', // V12_M
  'C', // V12_N
  'C', // V12_O
  'C', // V13
  'C', // V13_H
  'C', // V13_J
  'C', // V13_K
  'C', // V13_L
  'C', // V13_M
  'C', // V13_N
  'C', // V13_O
  'C', // V14
  'C', // V14_H
  'C', // V14_J
  'C', // V14_K
  'C', // V14_L
  'C', // V14_M
  'C', // V14_N
  'C', // V14_O
  'C', // V15
  'C', // V15_H
  'C', // V15_J
  'C', // V15_K
  'C', // V15_L
  'C', // V15_M
  'C', // V15_N
  'C', // V15_O
  'C', // P0
  'C', // P1
  'C', // P2
  'C', // P3
  'C', // P4
  'C', // P5
  'C', // P6
  'C', // P7
  'C', // P8
  'C', // P9
  'C', // P10
  'C', // P11
  'C', // P12
  'C', // P13
  'C', // P14
  'C', // P15
  'C' // no trailing comma // RFLAGS
};

// Map from machine-independent register number to c_reg_save_policy
const        char c_reg_save_policy[] = {
  'C', // R10
  'C', // R10_H
  'C', // R11
  'C', // R11_H
  'C', // R12
  'C', // R12_H
  'C', // R13
  'C', // R13_H
  'C', // R14
  'C', // R14_H
  'C', // R15
  'C', // R15_H
  'C', // R16
  'C', // R16_H
  'C', // R17
  'C', // R17_H
  'C', // R18
  'C', // R18_H
  'C', // R0
  'C', // R0_H
  'C', // R1
  'C', // R1_H
  'C', // R2
  'C', // R2_H
  'C', // R3
  'C', // R3_H
  'C', // R4
  'C', // R4_H
  'C', // R5
  'C', // R5_H
  'C', // R6
  'C', // R6_H
  'C', // R7
  'C', // R7_H
  'E', // R19
  'E', // R19_H
  'E', // R20
  'E', // R20_H
  'E', // R21
  'E', // R21_H
  'E', // R22
  'E', // R22_H
  'E', // R23
  'E', // R23_H
  'E', // R24
  'E', // R24_H
  'E', // R25
  'E', // R25_H
  'E', // R26
  'E', // R26_H
  'E', // R27
  'E', // R27_H
  'E', // R28
  'E', // R28_H
  'N', // R29
  'N', // R29_H
  'N', // R30
  'N', // R30_H
  'N', // R31
  'N', // R31_H
  'C', // R8
  'C', // R8_H
  'C', // R9
  'C', // R9_H
  'C', // V16
  'C', // V16_H
  'C', // V16_J
  'C', // V16_K
  'C', // V16_L
  'C', // V16_M
  'C', // V16_N
  'C', // V16_O
  'C', // V17
  'C', // V17_H
  'C', // V17_J
  'C', // V17_K
  'C', // V17_L
  'C', // V17_M
  'C', // V17_N
  'C', // V17_O
  'C', // V18
  'C', // V18_H
  'C', // V18_J
  'C', // V18_K
  'C', // V18_L
  'C', // V18_M
  'C', // V18_N
  'C', // V18_O
  'C', // V19
  'C', // V19_H
  'C', // V19_J
  'C', // V19_K
  'C', // V19_L
  'C', // V19_M
  'C', // V19_N
  'C', // V19_O
  'C', // V20
  'C', // V20_H
  'C', // V20_J
  'C', // V20_K
  'C', // V20_L
  'C', // V20_M
  'C', // V20_N
  'C', // V20_O
  'C', // V21
  'C', // V21_H
  'C', // V21_J
  'C', // V21_K
  'C', // V21_L
  'C', // V21_M
  'C', // V21_N
  'C', // V21_O
  'C', // V22
  'C', // V22_H
  'C', // V22_J
  'C', // V22_K
  'C', // V22_L
  'C', // V22_M
  'C', // V22_N
  'C', // V22_O
  'C', // V23
  'C', // V23_H
  'C', // V23_J
  'C', // V23_K
  'C', // V23_L
  'C', // V23_M
  'C', // V23_N
  'C', // V23_O
  'C', // V24
  'C', // V24_H
  'C', // V24_J
  'C', // V24_K
  'C', // V24_L
  'C', // V24_M
  'C', // V24_N
  'C', // V24_O
  'C', // V25
  'C', // V25_H
  'C', // V25_J
  'C', // V25_K
  'C', // V25_L
  'C', // V25_M
  'C', // V25_N
  'C', // V25_O
  'C', // V26
  'C', // V26_H
  'C', // V26_J
  'C', // V26_K
  'C', // V26_L
  'C', // V26_M
  'C', // V26_N
  'C', // V26_O
  'C', // V27
  'C', // V27_H
  'C', // V27_J
  'C', // V27_K
  'C', // V27_L
  'C', // V27_M
  'C', // V27_N
  'C', // V27_O
  'C', // V28
  'C', // V28_H
  'C', // V28_J
  'C', // V28_K
  'C', // V28_L
  'C', // V28_M
  'C', // V28_N
  'C', // V28_O
  'C', // V29
  'C', // V29_H
  'C', // V29_J
  'C', // V29_K
  'C', // V29_L
  'C', // V29_M
  'C', // V29_N
  'C', // V29_O
  'C', // V30
  'C', // V30_H
  'C', // V30_J
  'C', // V30_K
  'C', // V30_L
  'C', // V30_M
  'C', // V30_N
  'C', // V30_O
  'C', // V31
  'C', // V31_H
  'C', // V31_J
  'C', // V31_K
  'C', // V31_L
  'C', // V31_M
  'C', // V31_N
  'C', // V31_O
  'C', // V0
  'C', // V0_H
  'C', // V0_J
  'C', // V0_K
  'C', // V0_L
  'C', // V0_M
  'C', // V0_N
  'C', // V0_O
  'C', // V1
  'C', // V1_H
  'C', // V1_J
  'C', // V1_K
  'C', // V1_L
  'C', // V1_M
  'C', // V1_N
  'C', // V1_O
  'C', // V2
  'C', // V2_H
  'C', // V2_J
  'C', // V2_K
  'C', // V2_L
  'C', // V2_M
  'C', // V2_N
  'C', // V2_O
  'C', // V3
  'C', // V3_H
  'C', // V3_J
  'C', // V3_K
  'C', // V3_L
  'C', // V3_M
  'C', // V3_N
  'C', // V3_O
  'C', // V4
  'C', // V4_H
  'C', // V4_J
  'C', // V4_K
  'C', // V4_L
  'C', // V4_M
  'C', // V4_N
  'C', // V4_O
  'C', // V5
  'C', // V5_H
  'C', // V5_J
  'C', // V5_K
  'C', // V5_L
  'C', // V5_M
  'C', // V5_N
  'C', // V5_O
  'C', // V6
  'C', // V6_H
  'C', // V6_J
  'C', // V6_K
  'C', // V6_L
  'C', // V6_M
  'C', // V6_N
  'C', // V6_O
  'C', // V7
  'C', // V7_H
  'C', // V7_J
  'C', // V7_K
  'C', // V7_L
  'C', // V7_M
  'C', // V7_N
  'C', // V7_O
  'E', // V8
  'E', // V8_H
  'C', // V8_J
  'C', // V8_K
  'C', // V8_L
  'C', // V8_M
  'C', // V8_N
  'C', // V8_O
  'E', // V9
  'E', // V9_H
  'C', // V9_J
  'C', // V9_K
  'C', // V9_L
  'C', // V9_M
  'C', // V9_N
  'C', // V9_O
  'E', // V10
  'E', // V10_H
  'C', // V10_J
  'C', // V10_K
  'C', // V10_L
  'C', // V10_M
  'C', // V10_N
  'C', // V10_O
  'E', // V11
  'E', // V11_H
  'C', // V11_J
  'C', // V11_K
  'C', // V11_L
  'C', // V11_M
  'C', // V11_N
  'C', // V11_O
  'E', // V12
  'E', // V12_H
  'C', // V12_J
  'C', // V12_K
  'C', // V12_L
  'C', // V12_M
  'C', // V12_N
  'C', // V12_O
  'E', // V13
  'E', // V13_H
  'C', // V13_J
  'C', // V13_K
  'C', // V13_L
  'C', // V13_M
  'C', // V13_N
  'C', // V13_O
  'E', // V14
  'E', // V14_H
  'C', // V14_J
  'C', // V14_K
  'C', // V14_L
  'C', // V14_M
  'C', // V14_N
  'C', // V14_O
  'E', // V15
  'E', // V15_H
  'C', // V15_J
  'C', // V15_K
  'C', // V15_L
  'C', // V15_M
  'C', // V15_N
  'C', // V15_O
  'C', // P0
  'C', // P1
  'C', // P2
  'C', // P3
  'C', // P4
  'C', // P5
  'C', // P6
  'C', // P7
  'C', // P8
  'C', // P9
  'C', // P10
  'C', // P11
  'C', // P12
  'C', // P13
  'C', // P14
  'C', // P15
  'C' // no trailing comma // RFLAGS
};

// Map from machine-independent register number to register_save_type
const        int register_save_type[] = {
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  0 // no trailing comma
};


const        int   reduceOp[] = {
  /*    0 */  0,
  /*    1 */  0,
  /*    2 */  0,
  /*    3 */  0,
  /*    4 */  0,
  /*    5 */  0,
  /*    6 */  0,
  /*    7 */  0,
  /*    8 */  immI_rule,
  /*    9 */  immI0_rule,
  /*   10 */  immI_1_rule,
  /*   11 */  immI_M1_rule,
  /*   12 */  immIExt_rule,
  /*   13 */  immI_le_4_rule,
  /*   14 */  immI_31_rule,
  /*   15 */  immI_2_rule,
  /*   16 */  immI_4_rule,
  /*   17 */  immI_8_rule,
  /*   18 */  immI_16_rule,
  /*   19 */  immI_24_rule,
  /*   20 */  immI_32_rule,
  /*   21 */  immI_48_rule,
  /*   22 */  immI_56_rule,
  /*   23 */  immI_63_rule,
  /*   24 */  immI_64_rule,
  /*   25 */  immI_255_rule,
  /*   26 */  immI_65535_rule,
  /*   27 */  immL_255_rule,
  /*   28 */  immL_65535_rule,
  /*   29 */  immL_4294967295_rule,
  /*   30 */  immL_bitmask_rule,
  /*   31 */  immI_bitmask_rule,
  /*   32 */  immL_positive_bitmaskI_rule,
  /*   33 */  immIScale_rule,
  /*   34 */  immI26_rule,
  /*   35 */  immI19_rule,
  /*   36 */  immIU12_rule,
  /*   37 */  immLU12_rule,
  /*   38 */  immIOffset_rule,
  /*   39 */  immIOffset1_rule,
  /*   40 */  immIOffset2_rule,
  /*   41 */  immIOffset4_rule,
  /*   42 */  immIOffset8_rule,
  /*   43 */  immIOffset16_rule,
  /*   44 */  immLoffset_rule,
  /*   45 */  immLoffset1_rule,
  /*   46 */  immLoffset2_rule,
  /*   47 */  immLoffset4_rule,
  /*   48 */  immLoffset8_rule,
  /*   49 */  immLoffset16_rule,
  /*   50 */  immI8_rule,
  /*   51 */  immI8_shift8_rule,
  /*   52 */  immL8_shift8_rule,
  /*   53 */  immIAddSub_rule,
  /*   54 */  immILog_rule,
  /*   55 */  immL_rule,
  /*   56 */  immL0_rule,
  /*   57 */  immL_1_rule,
  /*   58 */  immL_M1_rule,
  /*   59 */  immL_pc_off_rule,
  /*   60 */  immLAddSub_rule,
  /*   61 */  immLLog_rule,
  /*   62 */  immL_32bits_rule,
  /*   63 */  immP_rule,
  /*   64 */  immP0_rule,
  /*   65 */  immP_1_rule,
  /*   66 */  immByteMapBase_rule,
  /*   67 */  immP_M1_rule,
  /*   68 */  immP_M2_rule,
  /*   69 */  immD_rule,
  /*   70 */  immD0_rule,
  /*   71 */  immDPacked_rule,
  /*   72 */  immF_rule,
  /*   73 */  immF0_rule,
  /*   74 */  immFPacked_rule,
  /*   75 */  immN_rule,
  /*   76 */  immN0_rule,
  /*   77 */  immNKlass_rule,
  /*   78 */  iRegI_rule,
  /*   79 */  iRegINoSp_rule,
  /*   80 */  iRegL_rule,
  /*   81 */  iRegLNoSp_rule,
  /*   82 */  iRegP_rule,
  /*   83 */  iRegPNoSp_rule,
  /*   84 */  iRegP_R0_rule,
  /*   85 */  iRegP_R1_rule,
  /*   86 */  iRegP_R2_rule,
  /*   87 */  iRegP_R3_rule,
  /*   88 */  iRegP_R4_rule,
  /*   89 */  iRegP_R5_rule,
  /*   90 */  iRegP_R10_rule,
  /*   91 */  iRegL_R0_rule,
  /*   92 */  iRegL_R2_rule,
  /*   93 */  iRegL_R3_rule,
  /*   94 */  iRegL_R11_rule,
  /*   95 */  iRegP_FP_rule,
  /*   96 */  iRegI_R0_rule,
  /*   97 */  iRegI_R2_rule,
  /*   98 */  iRegI_R3_rule,
  /*   99 */  iRegI_R4_rule,
  /*  100 */  iRegN_rule,
  /*  101 */  iRegN_R0_rule,
  /*  102 */  iRegN_R2_rule,
  /*  103 */  iRegN_R3_rule,
  /*  104 */  iRegNNoSp_rule,
  /*  105 */  iRegIHeapbase_rule,
  /*  106 */  vRegF_rule,
  /*  107 */  vRegD_rule,
  /*  108 */  vReg_rule,
  /*  109 */  vecD_rule,
  /*  110 */  vecX_rule,
  /*  111 */  vRegD_V0_rule,
  /*  112 */  vRegD_V1_rule,
  /*  113 */  vRegD_V2_rule,
  /*  114 */  vRegD_V3_rule,
  /*  115 */  vRegD_V4_rule,
  /*  116 */  vRegD_V5_rule,
  /*  117 */  vRegD_V6_rule,
  /*  118 */  vRegD_V7_rule,
  /*  119 */  vRegD_V8_rule,
  /*  120 */  vRegD_V9_rule,
  /*  121 */  vRegD_V10_rule,
  /*  122 */  vRegD_V11_rule,
  /*  123 */  vRegD_V12_rule,
  /*  124 */  vRegD_V13_rule,
  /*  125 */  vRegD_V14_rule,
  /*  126 */  vRegD_V15_rule,
  /*  127 */  vRegD_V16_rule,
  /*  128 */  vRegD_V17_rule,
  /*  129 */  vRegD_V18_rule,
  /*  130 */  vRegD_V19_rule,
  /*  131 */  vRegD_V20_rule,
  /*  132 */  vRegD_V21_rule,
  /*  133 */  vRegD_V22_rule,
  /*  134 */  vRegD_V23_rule,
  /*  135 */  vRegD_V24_rule,
  /*  136 */  vRegD_V25_rule,
  /*  137 */  vRegD_V26_rule,
  /*  138 */  vRegD_V27_rule,
  /*  139 */  vRegD_V28_rule,
  /*  140 */  vRegD_V29_rule,
  /*  141 */  vRegD_V30_rule,
  /*  142 */  vRegD_V31_rule,
  /*  143 */  pRegGov_rule,
  /*  144 */  rFlagsReg_rule,
  /*  145 */  rFlagsRegU_rule,
  /*  146 */  inline_cache_RegP_rule,
  /*  147 */  thread_RegP_rule,
  /*  148 */  lr_RegP_rule,
  /*  149 */  indirect_rule,
  /*  150 */  indIndexScaledI2L_rule,
  /*  151 */  indIndexScaled_rule,
  /*  152 */  indIndexI2L_rule,
  /*  153 */  indIndex_rule,
  /*  154 */  indOffI_rule,
  /*  155 */  indOffI1_rule,
  /*  156 */  indOffI2_rule,
  /*  157 */  indOffI4_rule,
  /*  158 */  indOffI8_rule,
  /*  159 */  indOffI16_rule,
  /*  160 */  indOffL_rule,
  /*  161 */  indOffL1_rule,
  /*  162 */  indOffL2_rule,
  /*  163 */  indOffL4_rule,
  /*  164 */  indOffL8_rule,
  /*  165 */  indOffL16_rule,
  /*  166 */  indirectN_rule,
  /*  167 */  indIndexScaledI2LN_rule,
  /*  168 */  indIndexScaledN_rule,
  /*  169 */  indIndexI2LN_rule,
  /*  170 */  indIndexN_rule,
  /*  171 */  indOffIN_rule,
  /*  172 */  indOffLN_rule,
  /*  173 */  thread_anchor_pc_rule,
  /*  174 */  stackSlotP_rule,
  /*  175 */  stackSlotI_rule,
  /*  176 */  stackSlotF_rule,
  /*  177 */  stackSlotD_rule,
  /*  178 */  stackSlotL_rule,
  /*  179 */  cmpOp_rule,
  /*  180 */  cmpOpU_rule,
  /*  181 */  cmpOpEqNe_rule,
  /*  182 */  cmpOpLtGe_rule,
  /*  183 */  cmpOpUEqNeLtGe_rule,
  /*  184 */  iRegL2I_rule,
  /*  185 */  vmemA_immIOffset4_rule,
  /*  186 */  vmemA_immLOffset4_rule,
  /*  187 */  vmemA_indOffI4_rule,
  /*  188 */  vmemA_indOffL4_rule,
  // last operand
  /*  189 */  vmem2_rule,
  /*  190 */  vmem4_rule,
  /*  191 */  vmem8_rule,
  /*  192 */  vmem16_rule,
  /*  193 */  memory1_rule,
  /*  194 */  memory2_rule,
  /*  195 */  memory4_rule,
  /*  196 */  memory8_rule,
  /*  197 */  memory_rule,
  /*  198 */  iRegIorL2I_rule,
  /*  199 */  vmemA_rule,
  // last operand class
  /*  200 */  _ConvI2L_iRegI__rule,
  /*  201 */  _LShiftL__ConvI2L_iRegI__immIScale_rule,
  /*  202 */  _LShiftL_iRegL_immIScale_rule,
  /*  203 */  _DecodeN_iRegN__rule,
  /*  204 */  _LoadB_memory1__rule,
  /*  205 */  _LoadUB_memory1__rule,
  /*  206 */  _LoadS_memory2__rule,
  /*  207 */  _LoadUS_memory2__rule,
  /*  208 */  _LoadI_memory4__rule,
  /*  209 */  _ConvI2L__LoadI_memory4___rule,
  /*  210 */  _LoadB_indirect__rule,
  /*  211 */  _LoadUB_indirect__rule,
  /*  212 */  _LoadUS_indirect__rule,
  /*  213 */  _LoadS_indirect__rule,
  /*  214 */  _LoadI_indirect__rule,
  /*  215 */  _ConvI2L__LoadI_indirect___rule,
  /*  216 */  _LoadL_memory8__rule,
  /*  217 */  _CastP2X_iRegP__rule,
  /*  218 */  _CastP2X__DecodeN_iRegN___rule,
  /*  219 */  _Binary_iRegP_iRegP_rule,
  /*  220 */  _Binary_iRegLNoSp_iRegLNoSp_rule,
  /*  221 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  222 */  _Binary_iRegNNoSp_iRegNNoSp_rule,
  /*  223 */  _Binary_iRegI_iRegI_rule,
  /*  224 */  _Binary_iRegL_iRegL_rule,
  /*  225 */  _Binary_iRegN_iRegN_rule,
  /*  226 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  227 */  _Binary_iRegIorL2I_iRegIorL2I_rule,
  /*  228 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  229 */  _Binary_immI0_iRegIorL2I_rule,
  /*  230 */  _Binary_iRegIorL2I_immI0_rule,
  /*  231 */  _Binary_immI_1_immI0_rule,
  /*  232 */  _Binary_iRegL_immL0_rule,
  /*  233 */  _Binary_immL0_iRegL_rule,
  /*  234 */  _Binary_iRegP_immP0_rule,
  /*  235 */  _Binary_immP0_iRegP_rule,
  /*  236 */  _Binary_iRegN_immN0_rule,
  /*  237 */  _Binary_immN0_iRegN_rule,
  /*  238 */  _Binary_vRegF_vRegF_rule,
  /*  239 */  _Binary_vRegD_vRegD_rule,
  /*  240 */  _ConvL2I_iRegL__rule,
  /*  241 */  _ConvI2L_iRegIorL2I__rule,
  /*  242 */  _LShiftL__ConvI2L_iRegIorL2I__immIScale_rule,
  /*  243 */  _MulI_iRegIorL2I_iRegIorL2I_rule,
  /*  244 */  _SubI_immI0_iRegIorL2I_rule,
  /*  245 */  _MulL_iRegL_iRegL_rule,
  /*  246 */  _SubL_immL0_iRegL_rule,
  /*  247 */  _MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I__rule,
  /*  248 */  _SubL_immL0__ConvI2L_iRegIorL2I__rule,
  /*  249 */  _XorI_iRegIorL2I_immI_M1_rule,
  /*  250 */  _XorL_iRegL_immL_M1_rule,
  /*  251 */  _XorI_iRegIorL2I_iRegIorL2I_rule,
  /*  252 */  _XorL_iRegL_iRegL_rule,
  /*  253 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  254 */  _XorI__URShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  255 */  _URShiftL_iRegL_immI_rule,
  /*  256 */  _XorL__URShiftL_iRegL_immI_immL_M1_rule,
  /*  257 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  258 */  _XorI__RShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  259 */  _RShiftL_iRegL_immI_rule,
  /*  260 */  _XorL__RShiftL_iRegL_immI_immL_M1_rule,
  /*  261 */  _RotateRight_iRegIorL2I_immI_rule,
  /*  262 */  _XorI__RotateRight_iRegIorL2I_immI_immI_M1_rule,
  /*  263 */  _RotateRight_iRegL_immI_rule,
  /*  264 */  _XorL__RotateRight_iRegL_immI_immL_M1_rule,
  /*  265 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  266 */  _XorI__LShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  267 */  _LShiftL_iRegL_immI_rule,
  /*  268 */  _XorL__LShiftL_iRegL_immI_immL_M1_rule,
  /*  269 */  _XorI__URShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  270 */  _XorI_iRegIorL2I__URShiftI_iRegIorL2I_immI_rule,
  /*  271 */  _XorL__URShiftL_iRegL_immI_iRegL_rule,
  /*  272 */  _XorL_iRegL__URShiftL_iRegL_immI_rule,
  /*  273 */  _XorI__RShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  274 */  _XorI_iRegIorL2I__RShiftI_iRegIorL2I_immI_rule,
  /*  275 */  _XorL__RShiftL_iRegL_immI_iRegL_rule,
  /*  276 */  _XorL_iRegL__RShiftL_iRegL_immI_rule,
  /*  277 */  _XorI__RotateRight_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  278 */  _XorI_iRegIorL2I__RotateRight_iRegIorL2I_immI_rule,
  /*  279 */  _XorL__RotateRight_iRegL_immI_iRegL_rule,
  /*  280 */  _XorL_iRegL__RotateRight_iRegL_immI_rule,
  /*  281 */  _XorI__LShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  282 */  _XorI_iRegIorL2I__LShiftI_iRegIorL2I_immI_rule,
  /*  283 */  _XorL__LShiftL_iRegL_immI_iRegL_rule,
  /*  284 */  _XorL_iRegL__LShiftL_iRegL_immI_rule,
  /*  285 */  _AndI__URShiftI_iRegIorL2I_immI_immI_bitmask_rule,
  /*  286 */  _AndI_iRegIorL2I_immI_bitmask_rule,
  /*  287 */  _AndL_iRegL_immL_bitmask_rule,
  /*  288 */  _LShiftI__AndI_iRegIorL2I_immI_bitmask_immI_rule,
  /*  289 */  _AndL_iRegL_immL_positive_bitmaskI_rule,
  /*  290 */  _LShiftL__AndL_iRegL_immL_positive_bitmaskI_immI_rule,
  /*  291 */  _ConvI2L__AndI_iRegIorL2I_immI_bitmask__rule,
  /*  292 */  _ConvL2I__AndL_iRegL_immL_positive_bitmaskI__rule,
  /*  293 */  _AndI_iRegI_immI_bitmask_rule,
  /*  294 */  _LShiftI_iRegIorL2I_immI_16_rule,
  /*  295 */  _RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_rule,
  /*  296 */  _LShiftI_iRegIorL2I_immI_24_rule,
  /*  297 */  _RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /*  298 */  _URShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /*  299 */  _LShiftL_iRegL_immI_48_rule,
  /*  300 */  _RShiftL__LShiftL_iRegL_immI_48_immI_48_rule,
  /*  301 */  _LShiftL_iRegL_immI_32_rule,
  /*  302 */  _RShiftL__LShiftL_iRegL_immI_32_immI_32_rule,
  /*  303 */  _LShiftL_iRegL_immI_56_rule,
  /*  304 */  _RShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /*  305 */  _URShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /*  306 */  _AndI_iRegIorL2I_immI_255_rule,
  /*  307 */  _AndI_iRegIorL2I_immI_65535_rule,
  /*  308 */  _AndL_iRegL_immL_255_rule,
  /*  309 */  _AndL_iRegL_immL_65535_rule,
  /*  310 */  _AndL_iRegL_immL_4294967295_rule,
  /*  311 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_56_immI_56_immIExt_rule,
  /*  312 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_48_immI_48_immIExt_rule,
  /*  313 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_32_immI_32_immIExt_rule,
  /*  314 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_immIExt_rule,
  /*  315 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_immIExt_rule,
  /*  316 */  _LShiftL__ConvI2L_iRegIorL2I__immIExt_rule,
  /*  317 */  _LShiftL__AndL_iRegL_immL_255_immIExt_rule,
  /*  318 */  _LShiftL__AndL_iRegL_immL_65535_immIExt_rule,
  /*  319 */  _LShiftL__AndL_iRegL_immL_4294967295_immIExt_rule,
  /*  320 */  _LShiftI__AndI_iRegIorL2I_immI_255_immIExt_rule,
  /*  321 */  _LShiftI__AndI_iRegIorL2I_immI_65535_immIExt_rule,
  /*  322 */  _NegF_vRegF__rule,
  /*  323 */  _Binary__NegF_vRegF__vRegF_rule,
  /*  324 */  _Binary_vRegF__NegF_vRegF__rule,
  /*  325 */  _NegD_vRegD__rule,
  /*  326 */  _Binary__NegD_vRegD__vRegD_rule,
  /*  327 */  _Binary_vRegD__NegD_vRegD__rule,
  /*  328 */  _SubF_vRegF_vRegF_rule,
  /*  329 */  _SubD_vRegD_vRegD_rule,
  /*  330 */  _OverflowMulI_iRegIorL2I_iRegIorL2I_rule,
  /*  331 */  _OverflowMulL_iRegL_iRegL_rule,
  /*  332 */  _CmpI_iRegIorL2I_immI0_rule,
  /*  333 */  _CmpL_iRegL_immL0_rule,
  /*  334 */  _CmpP_iRegP_immP0_rule,
  /*  335 */  _CmpN_iRegN_immN0_rule,
  /*  336 */  _CmpP__DecodeN_iRegN__immP0_rule,
  /*  337 */  _CmpU_iRegIorL2I_immI0_rule,
  /*  338 */  _CmpUL_iRegL_immL0_rule,
  /*  339 */  _AndL_iRegL_immL_rule,
  /*  340 */  _CmpL__AndL_iRegL_immL_immL0_rule,
  /*  341 */  _AndI_iRegIorL2I_immI_rule,
  /*  342 */  _CmpI__AndI_iRegIorL2I_immI_immI0_rule,
  /*  343 */  _AndL_iRegL_iRegL_rule,
  /*  344 */  _AndI_iRegIorL2I_iRegIorL2I_rule,
  /*  345 */  _PartialSubtypeCheck_iRegP_R4_iRegP_R0_rule,
  /*  346 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /*  347 */  _Binary_iRegP_R3_iRegI_R4_rule,
  /*  348 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /*  349 */  _Binary_iRegP_R3_iRegI_R2_rule,
  /*  350 */  _Binary_iRegP_R3_immI_le_4_rule,
  /*  351 */  _Binary_iRegP_R3_immI_1_rule,
  /*  352 */  _Binary_iRegP_R1_iRegP_R3_rule,
  /*  353 */  _Binary_iRegP_R1_iRegI_R3_rule,
  /*  354 */  _Binary_vecD_iRegIorL2I_rule,
  /*  355 */  _Binary_vecX_iRegIorL2I_rule,
  /*  356 */  _Binary_vecX_iRegL_rule,
  /*  357 */  _Binary_vecD_vRegF_rule,
  /*  358 */  _Binary_vecX_vRegF_rule,
  /*  359 */  _Binary_vecX_vRegD_rule,
  /*  360 */  _Binary_vecD_vecD_rule,
  /*  361 */  _Binary_vecX_vecX_rule,
  /*  362 */  _ReplicateB_immI_M1__rule,
  /*  363 */  _ReplicateS_immI_M1__rule,
  /*  364 */  _ReplicateI_immI_M1__rule,
  /*  365 */  _ReplicateL_immL_M1__rule,
  /*  366 */  _XorV_vecD__ReplicateB_immI_M1__rule,
  /*  367 */  _XorV__ReplicateB_immI_M1__vecD_rule,
  /*  368 */  _XorV_vecD__ReplicateS_immI_M1__rule,
  /*  369 */  _XorV__ReplicateS_immI_M1__vecD_rule,
  /*  370 */  _XorV_vecD__ReplicateI_immI_M1__rule,
  /*  371 */  _XorV__ReplicateI_immI_M1__vecD_rule,
  /*  372 */  _XorV_vecX__ReplicateB_immI_M1__rule,
  /*  373 */  _XorV__ReplicateB_immI_M1__vecX_rule,
  /*  374 */  _XorV_vecX__ReplicateS_immI_M1__rule,
  /*  375 */  _XorV__ReplicateS_immI_M1__vecX_rule,
  /*  376 */  _XorV_vecX__ReplicateI_immI_M1__rule,
  /*  377 */  _XorV__ReplicateI_immI_M1__vecX_rule,
  /*  378 */  _XorV_vecX__ReplicateL_immL_M1__rule,
  /*  379 */  _XorV__ReplicateL_immL_M1__vecX_rule,
  /*  380 */  _SubVF_vecD_vecD_rule,
  /*  381 */  _SubVF_vecX_vecX_rule,
  /*  382 */  _SubVD_vecX_vecX_rule,
  /*  383 */  _MulVS_vecD_vecD_rule,
  /*  384 */  _MulVS_vecX_vecX_rule,
  /*  385 */  _MulVI_vecD_vecD_rule,
  /*  386 */  _MulVI_vecX_vecX_rule,
  /*  387 */  _NegVF_vecD__rule,
  /*  388 */  _Binary__NegVF_vecD__vecD_rule,
  /*  389 */  _Binary_vecD__NegVF_vecD__rule,
  /*  390 */  _NegVF_vecX__rule,
  /*  391 */  _Binary__NegVF_vecX__vecX_rule,
  /*  392 */  _Binary_vecX__NegVF_vecX__rule,
  /*  393 */  _NegVD_vecX__rule,
  /*  394 */  _Binary__NegVD_vecX__vecX_rule,
  /*  395 */  _Binary_vecX__NegVD_vecX__rule,
  /*  396 */  _LShiftCntV_immI__rule,
  /*  397 */  _RShiftCntV_immI__rule,
  /*  398 */  _RShiftVB_vecD__RShiftCntV_immI__rule,
  /*  399 */  _RShiftVB_vecX__RShiftCntV_immI__rule,
  /*  400 */  _RShiftVS_vecD__RShiftCntV_immI__rule,
  /*  401 */  _RShiftVS_vecX__RShiftCntV_immI__rule,
  /*  402 */  _RShiftVI_vecD__RShiftCntV_immI__rule,
  /*  403 */  _RShiftVI_vecX__RShiftCntV_immI__rule,
  /*  404 */  _RShiftVL_vecX__RShiftCntV_immI__rule,
  /*  405 */  _URShiftVB_vecD__RShiftCntV_immI__rule,
  /*  406 */  _URShiftVB_vecX__RShiftCntV_immI__rule,
  /*  407 */  _URShiftVS_vecD__RShiftCntV_immI__rule,
  /*  408 */  _URShiftVS_vecX__RShiftCntV_immI__rule,
  /*  409 */  _URShiftVI_vecD__RShiftCntV_immI__rule,
  /*  410 */  _URShiftVI_vecX__RShiftCntV_immI__rule,
  /*  411 */  _URShiftVL_vecX__RShiftCntV_immI__rule,
  /*  412 */  _XorV_vReg__ReplicateB_immI_M1__rule,
  /*  413 */  _XorV__ReplicateB_immI_M1__vReg_rule,
  /*  414 */  _XorV_vReg__ReplicateS_immI_M1__rule,
  /*  415 */  _XorV__ReplicateS_immI_M1__vReg_rule,
  /*  416 */  _XorV_vReg__ReplicateI_immI_M1__rule,
  /*  417 */  _XorV__ReplicateI_immI_M1__vReg_rule,
  /*  418 */  _XorV_vReg__ReplicateL_immL_M1__rule,
  /*  419 */  _XorV__ReplicateL_immL_M1__vReg_rule,
  /*  420 */  _Binary_vReg_vReg_rule,
  /*  421 */  _NegVF_vReg__rule,
  /*  422 */  _Binary__NegVF_vReg__vReg_rule,
  /*  423 */  _Binary_vReg__NegVF_vReg__rule,
  /*  424 */  _NegVD_vReg__rule,
  /*  425 */  _Binary__NegVD_vReg__vReg_rule,
  /*  426 */  _Binary_vReg__NegVD_vReg__rule,
  /*  427 */  _MulVB_vReg_vReg_rule,
  /*  428 */  _MulVS_vReg_vReg_rule,
  /*  429 */  _MulVI_vReg_vReg_rule,
  /*  430 */  _MulVL_vReg_vReg_rule,
  // last internally defined operand
  /*  431 */  iRegINoSp_rule,
  /*  432 */  iRegLNoSp_rule,
  /*  433 */  iRegPNoSp_rule,
  /*  434 */  iRegPNoSp_rule,
  /*  435 */  iRegPNoSp_rule,
  /*  436 */  iRegPNoSp_rule,
  /*  437 */  iRegNNoSp_rule,
  /*  438 */  iRegNNoSp_rule,
  /*  439 */  iRegNNoSp_rule,
  /*  440 */  vRegF_rule,
  /*  441 */  vRegF_rule,
  /*  442 */  vRegD_rule,
  /*  443 */  vRegD_rule,
  /*  444 */  iRegINoSp_rule,
  /*  445 */  iRegINoSp_rule,
  /*  446 */  iRegINoSp_rule,
  /*  447 */  iRegINoSp_rule,
  /*  448 */  iRegPNoSp_rule,
  /*  449 */  iRegLNoSp_rule,
  /*  450 */  iRegPNoSp_rule,
  /*  451 */  iRegPNoSp_rule,
  /*  452 */  iRegI_rule,
  /*  453 */  iRegL_rule,
  /*  454 */  vRegF_rule,
  /*  455 */  vRegD_rule,
  /*  456 */  vecD_rule,
  /*  457 */  vecX_rule,
  /*  458 */  vReg_rule,
  /*  459 */  rFlagsReg_rule,
  /*  460 */  rFlagsReg_rule,
  /*  461 */  rFlagsReg_rule,
  /*  462 */  vRegF_rule,
  /*  463 */  vRegD_rule,
  /*  464 */  vRegF_rule,
  /*  465 */  vRegD_rule,
  /*  466 */  iRegINoSp_rule,
  /*  467 */  vRegF_rule,
  /*  468 */  iRegLNoSp_rule,
  /*  469 */  vRegD_rule,
  /*  470 */  iRegINoSp_rule,
  /*  471 */  vRegF_rule,
  /*  472 */  iRegLNoSp_rule,
  /*  473 */  vRegD_rule,
  /*  474 */  rFlagsReg_rule,
  /*  475 */  rFlagsReg_rule,
  /*  476 */  rFlagsReg_rule,
  /*  477 */  rFlagsReg_rule,
  /*  478 */  rFlagsReg_rule,
  /*  479 */  rFlagsReg_rule,
  /*  480 */  rFlagsReg_rule,
  /*  481 */  rFlagsReg_rule,
  /*  482 */  rFlagsReg_rule,
  /*  483 */  rFlagsReg_rule,
  /*  484 */  rFlagsReg_rule,
  /*  485 */  rFlagsReg_rule,
  /*  486 */  rFlagsReg_rule,
  /*  487 */  rFlagsReg_rule,
  /*  488 */  rFlagsReg_rule,
  /*  489 */  rFlagsReg_rule,
  /*  490 */  rFlagsRegU_rule,
  /*  491 */  rFlagsRegU_rule,
  /*  492 */  rFlagsRegU_rule,
  /*  493 */  rFlagsRegU_rule,
  /*  494 */  rFlagsReg_rule,
  /*  495 */  rFlagsReg_rule,
  /*  496 */  rFlagsReg_rule,
  /*  497 */  rFlagsReg_rule,
  /*  498 */  rFlagsRegU_rule,
  /*  499 */  rFlagsRegU_rule,
  /*  500 */  rFlagsRegU_rule,
  /*  501 */  rFlagsRegU_rule,
  /*  502 */  rFlagsRegU_rule,
  /*  503 */  rFlagsRegU_rule,
  /*  504 */  rFlagsRegU_rule,
  /*  505 */  rFlagsRegU_rule,
  /*  506 */  rFlagsReg_rule,
  /*  507 */  rFlagsReg_rule,
  /*  508 */  rFlagsReg_rule,
  /*  509 */  rFlagsReg_rule,
  /*  510 */  rFlagsReg_rule,
  /*  511 */  rFlagsReg_rule,
  /*  512 */  rFlagsReg_rule,
  /*  513 */  rFlagsReg_rule,
  /*  514 */  rFlagsReg_rule,
  /*  515 */  rFlagsReg_rule,
  /*  516 */  rFlagsReg_rule,
  /*  517 */  thread_RegP_rule,
  /*  518 */  vecD_rule,
  /*  519 */  vecX_rule,
  /*  520 */  vecX_rule,
  /*  521 */  vecD_rule,
  /*  522 */  vecD_rule,
  /*  523 */  vecX_rule,
  /*  524 */  vecD_rule,
  /*  525 */  vecD_rule,
  /*  526 */  vecX_rule,
  /*  527 */  vecD_rule,
  /*  528 */  vecX_rule,
  /*  529 */  vecD_rule,
  /*  530 */  vecX_rule,
  /*  531 */  vecD_rule,
  /*  532 */  vecX_rule,
  /*  533 */  vecX_rule,
  /*  534 */  vecX_rule,
  /*  535 */  vecD_rule,
  /*  536 */  vecX_rule,
  /*  537 */  vecX_rule,
  /*  538 */  vecX_rule,
  /*  539 */  vecD_rule,
  /*  540 */  vecD_rule,
  /*  541 */  vecD_rule,
  /*  542 */  vecX_rule,
  /*  543 */  vecD_rule,
  /*  544 */  vecX_rule,
  /*  545 */  vecD_rule,
  /*  546 */  vecX_rule,
  /*  547 */  vecX_rule,
  /*  548 */  vecD_rule,
  /*  549 */  vecX_rule,
  /*  550 */  vecD_rule,
  /*  551 */  vecX_rule,
  /*  552 */  vecD_rule,
  /*  553 */  vecX_rule,
  /*  554 */  vecD_rule,
  /*  555 */  vecX_rule,
  /*  556 */  vecX_rule,
  /*  557 */  vecD_rule,
  /*  558 */  vecX_rule,
  /*  559 */  vecD_rule,
  /*  560 */  vecX_rule,
  /*  561 */  vecD_rule,
  /*  562 */  vecX_rule,
  /*  563 */  vecX_rule,
  /*  564 */  vecD_rule,
  /*  565 */  vecX_rule,
  /*  566 */  vecX_rule,
  /*  567 */  vecD_rule,
  /*  568 */  vecX_rule,
  /*  569 */  vecX_rule,
  /*  570 */  vecD_rule,
  /*  571 */  vecX_rule,
  /*  572 */  vecX_rule,
  /*  573 */  vecD_rule,
  /*  574 */  vecD_rule,
  /*  575 */  vecX_rule,
  /*  576 */  vecX_rule,
  /*  577 */  vecX_rule,
  /*  578 */  vecD_rule,
  /*  579 */  vReg_rule,
  /*  580 */  vReg_rule,
  /*  581 */  vReg_rule,
  /*  582 */  vReg_rule,
  /*  583 */  vReg_rule,
  /*  584 */  vReg_rule,
  /*  585 */  vReg_rule,
  /*  586 */  vReg_rule,
  /*  587 */  vReg_rule,
  /*  588 */  vReg_rule,
  /*  589 */  vReg_rule,
  /*  590 */  vReg_rule,
  /*  591 */  vReg_rule,
  /*  592 */  vReg_rule,
  /*  593 */  vReg_rule,
  /*  594 */  vReg_rule,
  /*  595 */  vReg_rule,
  /*  596 */  vReg_rule,
  /*  597 */  vReg_rule,
  /*  598 */  vReg_rule,
  /*  599 */  iRegINoSp_rule,
  /*  600 */  iRegLNoSp_rule,
  /*  601 */  iRegINoSp_rule,
  /*  602 */  iRegLNoSp_rule,
  /*  603 */  iRegINoSp_rule,
  /*  604 */  iRegLNoSp_rule,
  /*  605 */  iRegINoSp_rule,
  /*  606 */  iRegLNoSp_rule,
  /*  607 */  iRegINoSp_rule,
  /*  608 */  iRegLNoSp_rule,
  /*  609 */  iRegLNoSp_rule,
  /*  610 */  iRegLNoSp_rule,
  /*  611 */  iRegINoSp_rule,
  /*  612 */  iRegPNoSp_rule,
  /*  613 */  iRegNNoSp_rule,
  /*  614 */  iRegPNoSp_rule,
  /*  615 */  iRegNNoSp_rule,
  /*  616 */  vRegF_rule,
  /*  617 */  vRegD_rule,
  /*  618 */  Universe_rule,
  /*  619 */  Universe_rule,
  /*  620 */  Universe_rule,
  /*  621 */  Universe_rule,
  /*  622 */  Universe_rule,
  /*  623 */  Universe_rule,
  /*  624 */  Universe_rule,
  /*  625 */  Universe_rule,
  /*  626 */  Universe_rule,
  /*  627 */  Universe_rule,
  /*  628 */  Universe_rule,
  /*  629 */  Universe_rule,
  /*  630 */  Universe_rule,
  /*  631 */  Universe_rule,
  /*  632 */  Universe_rule,
  /*  633 */  Universe_rule,
  /*  634 */  Universe_rule,
  /*  635 */  Universe_rule,
  /*  636 */  iRegINoSp_rule,
  /*  637 */  iRegLNoSp_rule,
  /*  638 */  iRegINoSp_rule,
  /*  639 */  iRegLNoSp_rule,
  /*  640 */  iRegINoSp_rule,
  /*  641 */  iRegINoSp_rule,
  /*  642 */  iRegLNoSp_rule,
  /*  643 */  iRegLNoSp_rule,
  /*  644 */  iRegINoSp_rule,
  /*  645 */  iRegLNoSp_rule,
  /*  646 */  iRegLNoSp_rule,
  /*  647 */  iRegPNoSp_rule,
  /*  648 */  iRegNNoSp_rule,
  /*  649 */  vRegF_rule,
  /*  650 */  vRegD_rule,
  /*  651 */  Universe_rule,
  /*  652 */  Universe_rule,
  /*  653 */  Universe_rule,
  /*  654 */  Universe_rule,
  /*  655 */  Universe_rule,
  /*  656 */  Universe_rule,
  /*  657 */  Universe_rule,
  /*  658 */  Universe_rule,
  /*  659 */  Universe_rule,
  /*  660 */  Universe_rule,
  /*  661 */  Universe_rule,
  /*  662 */  iRegINoSp_rule,
  /*  663 */  iRegLNoSp_rule,
  /*  664 */  iRegINoSp_rule,
  /*  665 */  iRegINoSp_rule,
  /*  666 */  iRegINoSp_rule,
  /*  667 */  iRegINoSp_rule,
  /*  668 */  iRegINoSp_rule,
  /*  669 */  iRegINoSp_rule,
  /*  670 */  Universe_rule,
  /*  671 */  Universe_rule,
  /*  672 */  Universe_rule,
  /*  673 */  Universe_rule,
  /*  674 */  Universe_rule,
  /*  675 */  Universe_rule,
  /*  676 */  Universe_rule,
  /*  677 */  Universe_rule,
  /*  678 */  Universe_rule,
  /*  679 */  Universe_rule,
  /*  680 */  Universe_rule,
  /*  681 */  iRegINoSp_rule,
  /*  682 */  iRegINoSp_rule,
  /*  683 */  iRegNNoSp_rule,
  /*  684 */  iRegNNoSp_rule,
  /*  685 */  iRegPNoSp_rule,
  /*  686 */  iRegPNoSp_rule,
  /*  687 */  iRegNNoSp_rule,
  /*  688 */  iRegPNoSp_rule,
  /*  689 */  iRegPNoSp_rule,
  /*  690 */  iRegINoSp_rule,
  /*  691 */  iRegINoSp_rule,
  /*  692 */  iRegINoSp_rule,
  /*  693 */  iRegINoSp_rule,
  /*  694 */  iRegINoSp_rule,
  /*  695 */  iRegINoSp_rule,
  /*  696 */  iRegINoSp_rule,
  /*  697 */  iRegINoSp_rule,
  /*  698 */  iRegINoSp_rule,
  /*  699 */  iRegINoSp_rule,
  /*  700 */  iRegINoSp_rule,
  /*  701 */  iRegINoSp_rule,
  /*  702 */  iRegINoSp_rule,
  /*  703 */  iRegINoSp_rule,
  /*  704 */  iRegINoSp_rule,
  /*  705 */  iRegLNoSp_rule,
  /*  706 */  iRegNNoSp_rule,
  /*  707 */  iRegPNoSp_rule,
  /*  708 */  iRegINoSp_rule,
  /*  709 */  iRegINoSp_rule,
  /*  710 */  iRegINoSp_rule,
  /*  711 */  iRegLNoSp_rule,
  /*  712 */  iRegNNoSp_rule,
  /*  713 */  iRegPNoSp_rule,
  /*  714 */  iRegINoSp_rule,
  /*  715 */  iRegINoSp_rule,
  /*  716 */  iRegINoSp_rule,
  /*  717 */  iRegINoSp_rule,
  /*  718 */  iRegINoSp_rule,
  /*  719 */  iRegINoSp_rule,
  /*  720 */  iRegINoSp_rule,
  /*  721 */  iRegINoSp_rule,
  /*  722 */  iRegINoSp_rule,
  /*  723 */  iRegINoSp_rule,
  /*  724 */  iRegINoSp_rule,
  /*  725 */  iRegINoSp_rule,
  /*  726 */  iRegINoSp_rule,
  /*  727 */  iRegLNoSp_rule,
  /*  728 */  iRegINoSp_rule,
  /*  729 */  iRegPNoSp_rule,
  /*  730 */  iRegINoSp_rule,
  /*  731 */  iRegLNoSp_rule,
  /*  732 */  iRegINoSp_rule,
  /*  733 */  iRegPNoSp_rule,
  /*  734 */  iRegLNoSp_rule,
  /*  735 */  Universe_rule,
  /*  736 */  iRegLNoSp_rule,
  /*  737 */  Universe_rule,
  /*  738 */  iRegINoSp_rule,
  /*  739 */  Universe_rule,
  /*  740 */  iRegINoSp_rule,
  /*  741 */  Universe_rule,
  /*  742 */  iRegLNoSp_rule,
  /*  743 */  Universe_rule,
  /*  744 */  iRegLNoSp_rule,
  /*  745 */  Universe_rule,
  /*  746 */  iRegINoSp_rule,
  /*  747 */  Universe_rule,
  /*  748 */  iRegINoSp_rule,
  /*  749 */  Universe_rule,
  /*  750 */  iRegINoSp_rule,
  /*  751 */  iRegINoSp_rule,
  /*  752 */  iRegINoSp_rule,
  /*  753 */  iRegINoSp_rule,
  /*  754 */  iRegINoSp_rule,
  /*  755 */  iRegINoSp_rule,
  /*  756 */  iRegINoSp_rule,
  /*  757 */  iRegINoSp_rule,
  /*  758 */  iRegINoSp_rule,
  /*  759 */  iRegINoSp_rule,
  /*  760 */  iRegLNoSp_rule,
  /*  761 */  iRegLNoSp_rule,
  /*  762 */  iRegLNoSp_rule,
  /*  763 */  iRegLNoSp_rule,
  /*  764 */  iRegLNoSp_rule,
  /*  765 */  iRegLNoSp_rule,
  /*  766 */  iRegPNoSp_rule,
  /*  767 */  iRegPNoSp_rule,
  /*  768 */  iRegPNoSp_rule,
  /*  769 */  iRegPNoSp_rule,
  /*  770 */  iRegPNoSp_rule,
  /*  771 */  iRegPNoSp_rule,
  /*  772 */  iRegNNoSp_rule,
  /*  773 */  iRegNNoSp_rule,
  /*  774 */  iRegNNoSp_rule,
  /*  775 */  iRegNNoSp_rule,
  /*  776 */  iRegNNoSp_rule,
  /*  777 */  iRegNNoSp_rule,
  /*  778 */  vRegF_rule,
  /*  779 */  vRegF_rule,
  /*  780 */  vRegD_rule,
  /*  781 */  vRegD_rule,
  /*  782 */  iRegINoSp_rule,
  /*  783 */  iRegINoSp_rule,
  /*  784 */  iRegINoSp_rule,
  /*  785 */  iRegPNoSp_rule,
  /*  786 */  iRegPNoSp_rule,
  /*  787 */  iRegPNoSp_rule,
  /*  788 */  iRegPNoSp_rule,
  /*  789 */  iRegLNoSp_rule,
  /*  790 */  iRegPNoSp_rule,
  /*  791 */  iRegLNoSp_rule,
  /*  792 */  iRegLNoSp_rule,
  /*  793 */  iRegINoSp_rule,
  /*  794 */  iRegINoSp_rule,
  /*  795 */  iRegLNoSp_rule,
  /*  796 */  iRegLNoSp_rule,
  /*  797 */  iRegINoSp_rule,
  /*  798 */  iRegLNoSp_rule,
  /*  799 */  iRegINoSp_rule,
  /*  800 */  iRegLNoSp_rule,
  /*  801 */  iRegLNoSp_rule,
  /*  802 */  iRegLNoSp_rule,
  /*  803 */  iRegLNoSp_rule,
  /*  804 */  iRegINoSp_rule,
  /*  805 */  iRegINoSp_rule,
  /*  806 */  iRegINoSp_rule,
  /*  807 */  iRegINoSp_rule,
  /*  808 */  iRegINoSp_rule,
  /*  809 */  iRegINoSp_rule,
  /*  810 */  iRegINoSp_rule,
  /*  811 */  iRegLNoSp_rule,
  /*  812 */  iRegLNoSp_rule,
  /*  813 */  iRegLNoSp_rule,
  /*  814 */  iRegLNoSp_rule,
  /*  815 */  iRegLNoSp_rule,
  /*  816 */  iRegLNoSp_rule,
  /*  817 */  iRegLNoSp_rule,
  /*  818 */  iRegLNoSp_rule,
  /*  819 */  iRegLNoSp_rule,
  /*  820 */  iRegLNoSp_rule,
  /*  821 */  iRegLNoSp_rule,
  /*  822 */  iRegLNoSp_rule,
  /*  823 */  iRegLNoSp_rule,
  /*  824 */  iRegLNoSp_rule,
  /*  825 */  iRegLNoSp_rule,
  /*  826 */  iRegLNoSp_rule,
  /*  827 */  iRegLNoSp_rule,
  /*  828 */  iRegINoSp_rule,
  /*  829 */  iRegINoSp_rule,
  /*  830 */  iRegLNoSp_rule,
  /*  831 */  iRegINoSp_rule,
  /*  832 */  iRegLNoSp_rule,
  /*  833 */  iRegINoSp_rule,
  /*  834 */  iRegINoSp_rule,
  /*  835 */  iRegINoSp_rule,
  /*  836 */  iRegINoSp_rule,
  /*  837 */  iRegINoSp_rule,
  /*  838 */  iRegINoSp_rule,
  /*  839 */  iRegLNoSp_rule,
  /*  840 */  iRegLNoSp_rule,
  /*  841 */  iRegLNoSp_rule,
  /*  842 */  iRegLNoSp_rule,
  /*  843 */  iRegLNoSp_rule,
  /*  844 */  iRegLNoSp_rule,
  /*  845 */  iRegLNoSp_rule,
  /*  846 */  iRegLNoSp_rule,
  /*  847 */  iRegINoSp_rule,
  /*  848 */  iRegINoSp_rule,
  /*  849 */  iRegINoSp_rule,
  /*  850 */  iRegLNoSp_rule,
  /*  851 */  iRegLNoSp_rule,
  /*  852 */  iRegINoSp_rule,
  /*  853 */  iRegINoSp_rule,
  /*  854 */  iRegLNoSp_rule,
  /*  855 */  iRegLNoSp_rule,
  /*  856 */  iRegINoSp_rule,
  /*  857 */  iRegINoSp_rule,
  /*  858 */  iRegLNoSp_rule,
  /*  859 */  iRegLNoSp_rule,
  /*  860 */  iRegINoSp_rule,
  /*  861 */  iRegINoSp_rule,
  /*  862 */  iRegLNoSp_rule,
  /*  863 */  iRegLNoSp_rule,
  /*  864 */  iRegINoSp_rule,
  /*  865 */  iRegINoSp_rule,
  /*  866 */  iRegLNoSp_rule,
  /*  867 */  iRegLNoSp_rule,
  /*  868 */  iRegINoSp_rule,
  /*  869 */  iRegINoSp_rule,
  /*  870 */  iRegLNoSp_rule,
  /*  871 */  iRegLNoSp_rule,
  /*  872 */  iRegINoSp_rule,
  /*  873 */  iRegINoSp_rule,
  /*  874 */  iRegLNoSp_rule,
  /*  875 */  iRegLNoSp_rule,
  /*  876 */  iRegINoSp_rule,
  /*  877 */  iRegINoSp_rule,
  /*  878 */  iRegINoSp_rule,
  /*  879 */  iRegINoSp_rule,
  /*  880 */  iRegLNoSp_rule,
  /*  881 */  iRegLNoSp_rule,
  /*  882 */  iRegLNoSp_rule,
  /*  883 */  iRegLNoSp_rule,
  /*  884 */  iRegINoSp_rule,
  /*  885 */  iRegINoSp_rule,
  /*  886 */  iRegINoSp_rule,
  /*  887 */  iRegINoSp_rule,
  /*  888 */  iRegLNoSp_rule,
  /*  889 */  iRegLNoSp_rule,
  /*  890 */  iRegLNoSp_rule,
  /*  891 */  iRegLNoSp_rule,
  /*  892 */  iRegINoSp_rule,
  /*  893 */  iRegINoSp_rule,
  /*  894 */  iRegINoSp_rule,
  /*  895 */  iRegINoSp_rule,
  /*  896 */  iRegLNoSp_rule,
  /*  897 */  iRegLNoSp_rule,
  /*  898 */  iRegLNoSp_rule,
  /*  899 */  iRegLNoSp_rule,
  /*  900 */  iRegINoSp_rule,
  /*  901 */  iRegINoSp_rule,
  /*  902 */  iRegINoSp_rule,
  /*  903 */  iRegINoSp_rule,
  /*  904 */  iRegLNoSp_rule,
  /*  905 */  iRegLNoSp_rule,
  /*  906 */  iRegLNoSp_rule,
  /*  907 */  iRegLNoSp_rule,
  /*  908 */  iRegINoSp_rule,
  /*  909 */  iRegINoSp_rule,
  /*  910 */  iRegLNoSp_rule,
  /*  911 */  iRegLNoSp_rule,
  /*  912 */  iRegINoSp_rule,
  /*  913 */  iRegINoSp_rule,
  /*  914 */  iRegLNoSp_rule,
  /*  915 */  iRegLNoSp_rule,
  /*  916 */  iRegINoSp_rule,
  /*  917 */  iRegINoSp_rule,
  /*  918 */  iRegLNoSp_rule,
  /*  919 */  iRegLNoSp_rule,
  /*  920 */  iRegINoSp_rule,
  /*  921 */  iRegINoSp_rule,
  /*  922 */  iRegLNoSp_rule,
  /*  923 */  iRegLNoSp_rule,
  /*  924 */  iRegINoSp_rule,
  /*  925 */  iRegINoSp_rule,
  /*  926 */  iRegLNoSp_rule,
  /*  927 */  iRegLNoSp_rule,
  /*  928 */  iRegINoSp_rule,
  /*  929 */  iRegINoSp_rule,
  /*  930 */  iRegLNoSp_rule,
  /*  931 */  iRegLNoSp_rule,
  /*  932 */  iRegINoSp_rule,
  /*  933 */  iRegINoSp_rule,
  /*  934 */  iRegLNoSp_rule,
  /*  935 */  iRegLNoSp_rule,
  /*  936 */  iRegINoSp_rule,
  /*  937 */  iRegINoSp_rule,
  /*  938 */  iRegLNoSp_rule,
  /*  939 */  iRegLNoSp_rule,
  /*  940 */  iRegINoSp_rule,
  /*  941 */  iRegINoSp_rule,
  /*  942 */  iRegLNoSp_rule,
  /*  943 */  iRegLNoSp_rule,
  /*  944 */  iRegINoSp_rule,
  /*  945 */  iRegINoSp_rule,
  /*  946 */  iRegLNoSp_rule,
  /*  947 */  iRegLNoSp_rule,
  /*  948 */  iRegINoSp_rule,
  /*  949 */  iRegINoSp_rule,
  /*  950 */  iRegLNoSp_rule,
  /*  951 */  iRegLNoSp_rule,
  /*  952 */  iRegINoSp_rule,
  /*  953 */  iRegINoSp_rule,
  /*  954 */  iRegLNoSp_rule,
  /*  955 */  iRegLNoSp_rule,
  /*  956 */  iRegINoSp_rule,
  /*  957 */  iRegINoSp_rule,
  /*  958 */  iRegLNoSp_rule,
  /*  959 */  iRegLNoSp_rule,
  /*  960 */  iRegINoSp_rule,
  /*  961 */  iRegINoSp_rule,
  /*  962 */  iRegLNoSp_rule,
  /*  963 */  iRegLNoSp_rule,
  /*  964 */  iRegINoSp_rule,
  /*  965 */  iRegINoSp_rule,
  /*  966 */  iRegLNoSp_rule,
  /*  967 */  iRegLNoSp_rule,
  /*  968 */  iRegINoSp_rule,
  /*  969 */  iRegINoSp_rule,
  /*  970 */  iRegLNoSp_rule,
  /*  971 */  iRegLNoSp_rule,
  /*  972 */  iRegINoSp_rule,
  /*  973 */  iRegINoSp_rule,
  /*  974 */  iRegLNoSp_rule,
  /*  975 */  iRegLNoSp_rule,
  /*  976 */  iRegINoSp_rule,
  /*  977 */  iRegINoSp_rule,
  /*  978 */  iRegLNoSp_rule,
  /*  979 */  iRegLNoSp_rule,
  /*  980 */  iRegINoSp_rule,
  /*  981 */  iRegINoSp_rule,
  /*  982 */  iRegLNoSp_rule,
  /*  983 */  iRegLNoSp_rule,
  /*  984 */  iRegINoSp_rule,
  /*  985 */  iRegLNoSp_rule,
  /*  986 */  iRegINoSp_rule,
  /*  987 */  iRegLNoSp_rule,
  /*  988 */  iRegINoSp_rule,
  /*  989 */  iRegLNoSp_rule,
  /*  990 */  iRegLNoSp_rule,
  /*  991 */  iRegINoSp_rule,
  /*  992 */  iRegLNoSp_rule,
  /*  993 */  iRegINoSp_rule,
  /*  994 */  iRegINoSp_rule,
  /*  995 */  iRegLNoSp_rule,
  /*  996 */  iRegLNoSp_rule,
  /*  997 */  iRegINoSp_rule,
  /*  998 */  iRegLNoSp_rule,
  /*  999 */  iRegLNoSp_rule,
  /* 1000 */  iRegINoSp_rule,
  /* 1001 */  iRegLNoSp_rule,
  /* 1002 */  iRegINoSp_rule,
  /* 1003 */  iRegLNoSp_rule,
  /* 1004 */  iRegLNoSp_rule,
  /* 1005 */  iRegLNoSp_rule,
  /* 1006 */  iRegINoSp_rule,
  /* 1007 */  iRegINoSp_rule,
  /* 1008 */  iRegLNoSp_rule,
  /* 1009 */  iRegLNoSp_rule,
  /* 1010 */  iRegINoSp_rule,
  /* 1011 */  iRegINoSp_rule,
  /* 1012 */  iRegINoSp_rule,
  /* 1013 */  iRegLNoSp_rule,
  /* 1014 */  iRegINoSp_rule,
  /* 1015 */  iRegLNoSp_rule,
  /* 1016 */  iRegINoSp_rule,
  /* 1017 */  iRegLNoSp_rule,
  /* 1018 */  iRegLNoSp_rule,
  /* 1019 */  iRegLNoSp_rule,
  /* 1020 */  iRegLNoSp_rule,
  /* 1021 */  iRegINoSp_rule,
  /* 1022 */  iRegINoSp_rule,
  /* 1023 */  iRegINoSp_rule,
  /* 1024 */  iRegINoSp_rule,
  /* 1025 */  iRegINoSp_rule,
  /* 1026 */  iRegINoSp_rule,
  /* 1027 */  iRegLNoSp_rule,
  /* 1028 */  iRegLNoSp_rule,
  /* 1029 */  iRegLNoSp_rule,
  /* 1030 */  iRegLNoSp_rule,
  /* 1031 */  iRegLNoSp_rule,
  /* 1032 */  iRegLNoSp_rule,
  /* 1033 */  iRegLNoSp_rule,
  /* 1034 */  iRegLNoSp_rule,
  /* 1035 */  iRegINoSp_rule,
  /* 1036 */  iRegINoSp_rule,
  /* 1037 */  iRegINoSp_rule,
  /* 1038 */  iRegINoSp_rule,
  /* 1039 */  iRegLNoSp_rule,
  /* 1040 */  iRegLNoSp_rule,
  /* 1041 */  iRegLNoSp_rule,
  /* 1042 */  iRegLNoSp_rule,
  /* 1043 */  iRegLNoSp_rule,
  /* 1044 */  iRegLNoSp_rule,
  /* 1045 */  iRegINoSp_rule,
  /* 1046 */  iRegINoSp_rule,
  /* 1047 */  iRegLNoSp_rule,
  /* 1048 */  iRegLNoSp_rule,
  /* 1049 */  iRegLNoSp_rule,
  /* 1050 */  iRegLNoSp_rule,
  /* 1051 */  iRegLNoSp_rule,
  /* 1052 */  iRegLNoSp_rule,
  /* 1053 */  iRegLNoSp_rule,
  /* 1054 */  iRegLNoSp_rule,
  /* 1055 */  iRegLNoSp_rule,
  /* 1056 */  iRegLNoSp_rule,
  /* 1057 */  iRegLNoSp_rule,
  /* 1058 */  iRegLNoSp_rule,
  /* 1059 */  iRegINoSp_rule,
  /* 1060 */  iRegINoSp_rule,
  /* 1061 */  iRegINoSp_rule,
  /* 1062 */  iRegINoSp_rule,
  /* 1063 */  iRegINoSp_rule,
  /* 1064 */  iRegINoSp_rule,
  /* 1065 */  iRegLNoSp_rule,
  /* 1066 */  iRegLNoSp_rule,
  /* 1067 */  iRegLNoSp_rule,
  /* 1068 */  iRegLNoSp_rule,
  /* 1069 */  iRegLNoSp_rule,
  /* 1070 */  iRegLNoSp_rule,
  /* 1071 */  iRegLNoSp_rule,
  /* 1072 */  iRegLNoSp_rule,
  /* 1073 */  iRegLNoSp_rule,
  /* 1074 */  iRegLNoSp_rule,
  /* 1075 */  iRegLNoSp_rule,
  /* 1076 */  iRegLNoSp_rule,
  /* 1077 */  iRegINoSp_rule,
  /* 1078 */  iRegINoSp_rule,
  /* 1079 */  iRegINoSp_rule,
  /* 1080 */  iRegINoSp_rule,
  /* 1081 */  iRegINoSp_rule,
  /* 1082 */  iRegINoSp_rule,
  /* 1083 */  vRegF_rule,
  /* 1084 */  vRegD_rule,
  /* 1085 */  vRegF_rule,
  /* 1086 */  vRegD_rule,
  /* 1087 */  vRegF_rule,
  /* 1088 */  vRegD_rule,
  /* 1089 */  vRegF_rule,
  /* 1090 */  vRegD_rule,
  /* 1091 */  vRegF_rule,
  /* 1092 */  vRegF_rule,
  /* 1093 */  vRegD_rule,
  /* 1094 */  vRegD_rule,
  /* 1095 */  vRegF_rule,
  /* 1096 */  vRegF_rule,
  /* 1097 */  vRegD_rule,
  /* 1098 */  vRegD_rule,
  /* 1099 */  vRegF_rule,
  /* 1100 */  vRegD_rule,
  /* 1101 */  vRegF_rule,
  /* 1102 */  vRegF_rule,
  /* 1103 */  vRegD_rule,
  /* 1104 */  vRegD_rule,
  /* 1105 */  vRegF_rule,
  /* 1106 */  vRegD_rule,
  /* 1107 */  iRegINoSp_rule,
  /* 1108 */  iRegLNoSp_rule,
  /* 1109 */  vRegF_rule,
  /* 1110 */  vRegD_rule,
  /* 1111 */  vRegD_rule,
  /* 1112 */  vRegF_rule,
  /* 1113 */  vRegD_rule,
  /* 1114 */  vRegD_rule,
  /* 1115 */  vRegF_rule,
  /* 1116 */  vRegD_rule,
  /* 1117 */  vRegF_rule,
  /* 1118 */  Universe_rule,
  /* 1119 */  iRegINoSp_rule,
  /* 1120 */  iRegINoSp_rule,
  /* 1121 */  iRegINoSp_rule,
  /* 1122 */  iRegINoSp_rule,
  /* 1123 */  iRegINoSp_rule,
  /* 1124 */  iRegINoSp_rule,
  /* 1125 */  iRegLNoSp_rule,
  /* 1126 */  iRegLNoSp_rule,
  /* 1127 */  iRegLNoSp_rule,
  /* 1128 */  iRegLNoSp_rule,
  /* 1129 */  iRegLNoSp_rule,
  /* 1130 */  iRegLNoSp_rule,
  /* 1131 */  iRegLNoSp_rule,
  /* 1132 */  iRegLNoSp_rule,
  /* 1133 */  iRegINoSp_rule,
  /* 1134 */  iRegINoSp_rule,
  /* 1135 */  iRegINoSp_rule,
  /* 1136 */  vRegF_rule,
  /* 1137 */  vRegD_rule,
  /* 1138 */  iRegINoSp_rule,
  /* 1139 */  iRegLNoSp_rule,
  /* 1140 */  vRegF_rule,
  /* 1141 */  vRegF_rule,
  /* 1142 */  iRegINoSp_rule,
  /* 1143 */  iRegLNoSp_rule,
  /* 1144 */  vRegD_rule,
  /* 1145 */  vRegD_rule,
  /* 1146 */  stackSlotI_rule,
  /* 1147 */  stackSlotF_rule,
  /* 1148 */  stackSlotL_rule,
  /* 1149 */  stackSlotD_rule,
  /* 1150 */  Universe_rule,
  /* 1151 */  Universe_rule,
  /* 1152 */  Universe_rule,
  /* 1153 */  Universe_rule,
  /* 1154 */  iRegINoSp_rule,
  /* 1155 */  iRegINoSp_rule,
  /* 1156 */  iRegINoSp_rule,
  /* 1157 */  iRegINoSp_rule,
  /* 1158 */  iRegINoSp_rule,
  /* 1159 */  iRegINoSp_rule,
  /* 1160 */  0,
  /* 1161 */  iRegINoSp_rule,
  /* 1162 */  0,
  /* 1163 */  iRegINoSp_rule,
  /* 1164 */  Universe_rule,
  /* 1165 */  Universe_rule,
  /* 1166 */  Universe_rule,
  /* 1167 */  Universe_rule,
  /* 1168 */  Universe_rule,
  /* 1169 */  Universe_rule,
  /* 1170 */  Universe_rule,
  /* 1171 */  Universe_rule,
  /* 1172 */  Universe_rule,
  /* 1173 */  Universe_rule,
  /* 1174 */  Universe_rule,
  /* 1175 */  Universe_rule,
  /* 1176 */  Universe_rule,
  /* 1177 */  Universe_rule,
  /* 1178 */  Universe_rule,
  /* 1179 */  Universe_rule,
  /* 1180 */  Universe_rule,
  /* 1181 */  Universe_rule,
  /* 1182 */  Universe_rule,
  /* 1183 */  Universe_rule,
  /* 1184 */  Universe_rule,
  /* 1185 */  Universe_rule,
  /* 1186 */  Universe_rule,
  /* 1187 */  Universe_rule,
  /* 1188 */  Universe_rule,
  /* 1189 */  Universe_rule,
  /* 1190 */  Universe_rule,
  /* 1191 */  Universe_rule,
  /* 1192 */  Universe_rule,
  /* 1193 */  iRegP_R0_rule,
  /* 1194 */  Universe_rule,
  /* 1195 */  Universe_rule,
  /* 1196 */  Universe_rule,
  /* 1197 */  iRegP_R5_rule,
  /* 1198 */  iRegI_R0_rule,
  /* 1199 */  iRegI_R0_rule,
  /* 1200 */  iRegI_R0_rule,
  /* 1201 */  iRegI_R0_rule,
  /* 1202 */  iRegI_R0_rule,
  /* 1203 */  iRegI_R0_rule,
  /* 1204 */  iRegI_R0_rule,
  /* 1205 */  iRegI_R0_rule,
  /* 1206 */  iRegI_R0_rule,
  /* 1207 */  iRegI_R0_rule,
  /* 1208 */  iRegI_R0_rule,
  /* 1209 */  iRegI_R0_rule,
  /* 1210 */  iRegI_R0_rule,
  /* 1211 */  iRegI_R0_rule,
  /* 1212 */  iRegI_R0_rule,
  /* 1213 */  iRegI_R0_rule,
  /* 1214 */  iRegI_R0_rule,
  /* 1215 */  iRegI_R0_rule,
  /* 1216 */  Universe_rule,
  /* 1217 */  iRegI_R0_rule,
  /* 1218 */  vecD_rule,
  /* 1219 */  vecD_rule,
  /* 1220 */  vecD_rule,
  /* 1221 */  vecX_rule,
  /* 1222 */  Universe_rule,
  /* 1223 */  Universe_rule,
  /* 1224 */  Universe_rule,
  /* 1225 */  Universe_rule,
  /* 1226 */  iRegINoSp_rule,
  /* 1227 */  iRegINoSp_rule,
  /* 1228 */  iRegINoSp_rule,
  /* 1229 */  iRegINoSp_rule,
  /* 1230 */  iRegLNoSp_rule,
  /* 1231 */  iRegINoSp_rule,
  /* 1232 */  iRegINoSp_rule,
  /* 1233 */  iRegINoSp_rule,
  /* 1234 */  iRegINoSp_rule,
  /* 1235 */  iRegLNoSp_rule,
  /* 1236 */  iRegINoSp_rule,
  /* 1237 */  iRegINoSp_rule,
  /* 1238 */  iRegINoSp_rule,
  /* 1239 */  iRegINoSp_rule,
  /* 1240 */  iRegINoSp_rule,
  /* 1241 */  iRegINoSp_rule,
  /* 1242 */  iRegINoSp_rule,
  /* 1243 */  iRegINoSp_rule,
  /* 1244 */  iRegINoSp_rule,
  /* 1245 */  iRegINoSp_rule,
  /* 1246 */  iRegINoSp_rule,
  /* 1247 */  iRegINoSp_rule,
  /* 1248 */  iRegLNoSp_rule,
  /* 1249 */  iRegLNoSp_rule,
  /* 1250 */  vRegF_rule,
  /* 1251 */  vRegF_rule,
  /* 1252 */  vRegD_rule,
  /* 1253 */  vRegF_rule,
  /* 1254 */  vRegF_rule,
  /* 1255 */  vRegD_rule,
  /* 1256 */  iRegINoSp_rule,
  /* 1257 */  iRegINoSp_rule,
  /* 1258 */  iRegINoSp_rule,
  /* 1259 */  iRegINoSp_rule,
  /* 1260 */  iRegINoSp_rule,
  /* 1261 */  iRegINoSp_rule,
  /* 1262 */  iRegINoSp_rule,
  /* 1263 */  iRegINoSp_rule,
  /* 1264 */  iRegINoSp_rule,
  /* 1265 */  iRegINoSp_rule,
  /* 1266 */  iRegINoSp_rule,
  /* 1267 */  iRegINoSp_rule,
  /* 1268 */  iRegINoSp_rule,
  /* 1269 */  iRegINoSp_rule,
  /* 1270 */  iRegINoSp_rule,
  /* 1271 */  iRegINoSp_rule,
  /* 1272 */  iRegINoSp_rule,
  /* 1273 */  iRegINoSp_rule,
  /* 1274 */  iRegLNoSp_rule,
  /* 1275 */  iRegLNoSp_rule,
  /* 1276 */  iRegLNoSp_rule,
  /* 1277 */  vecD_rule,
  /* 1278 */  vecX_rule,
  /* 1279 */  vecD_rule,
  /* 1280 */  vecX_rule,
  /* 1281 */  vecD_rule,
  /* 1282 */  vecX_rule,
  /* 1283 */  vecX_rule,
  /* 1284 */  vecD_rule,
  /* 1285 */  vecX_rule,
  /* 1286 */  vecX_rule,
  /* 1287 */  iRegINoSp_rule,
  /* 1288 */  iRegINoSp_rule,
  /* 1289 */  iRegINoSp_rule,
  /* 1290 */  iRegINoSp_rule,
  /* 1291 */  iRegINoSp_rule,
  /* 1292 */  iRegINoSp_rule,
  /* 1293 */  iRegLNoSp_rule,
  /* 1294 */  vRegF_rule,
  /* 1295 */  vRegF_rule,
  /* 1296 */  vRegD_rule,
  /* 1297 */  vecD_rule,
  /* 1298 */  vecX_rule,
  /* 1299 */  vecX_rule,
  /* 1300 */  vecD_rule,
  /* 1301 */  vecD_rule,
  /* 1302 */  vecD_rule,
  /* 1303 */  vecD_rule,
  /* 1304 */  vecD_rule,
  /* 1305 */  vecD_rule,
  /* 1306 */  vecX_rule,
  /* 1307 */  vecX_rule,
  /* 1308 */  vecX_rule,
  /* 1309 */  vecX_rule,
  /* 1310 */  vecX_rule,
  /* 1311 */  vecX_rule,
  /* 1312 */  vecX_rule,
  /* 1313 */  vecX_rule,
  /* 1314 */  vecD_rule,
  /* 1315 */  vecD_rule,
  /* 1316 */  vecD_rule,
  /* 1317 */  vecD_rule,
  /* 1318 */  vecD_rule,
  /* 1319 */  vecD_rule,
  /* 1320 */  vecD_rule,
  /* 1321 */  vecD_rule,
  /* 1322 */  vecD_rule,
  /* 1323 */  vecD_rule,
  /* 1324 */  vecD_rule,
  /* 1325 */  vecD_rule,
  /* 1326 */  vecX_rule,
  /* 1327 */  vecX_rule,
  /* 1328 */  vecX_rule,
  /* 1329 */  vecX_rule,
  /* 1330 */  vecX_rule,
  /* 1331 */  vecX_rule,
  /* 1332 */  vecX_rule,
  /* 1333 */  vecX_rule,
  /* 1334 */  vecX_rule,
  /* 1335 */  vecX_rule,
  /* 1336 */  vecX_rule,
  /* 1337 */  vecX_rule,
  /* 1338 */  vecX_rule,
  /* 1339 */  vecX_rule,
  /* 1340 */  vecX_rule,
  /* 1341 */  vecX_rule,
  /* 1342 */  vecD_rule,
  /* 1343 */  vecX_rule,
  /* 1344 */  vecD_rule,
  /* 1345 */  vecX_rule,
  /* 1346 */  vecD_rule,
  /* 1347 */  vecX_rule,
  /* 1348 */  vecD_rule,
  /* 1349 */  vecX_rule,
  /* 1350 */  vecD_rule,
  /* 1351 */  vecX_rule,
  /* 1352 */  vecD_rule,
  /* 1353 */  vecX_rule,
  /* 1354 */  vecX_rule,
  /* 1355 */  vecX_rule,
  /* 1356 */  vecD_rule,
  /* 1357 */  vecX_rule,
  /* 1358 */  vecD_rule,
  /* 1359 */  vecX_rule,
  /* 1360 */  vecD_rule,
  /* 1361 */  vecD_rule,
  /* 1362 */  vecD_rule,
  /* 1363 */  vecD_rule,
  /* 1364 */  vecD_rule,
  /* 1365 */  vecD_rule,
  /* 1366 */  vecX_rule,
  /* 1367 */  vecD_rule,
  /* 1368 */  vecX_rule,
  /* 1369 */  vecX_rule,
  /* 1370 */  iRegINoSp_rule,
  /* 1371 */  iRegINoSp_rule,
  /* 1372 */  iRegINoSp_rule,
  /* 1373 */  iRegINoSp_rule,
  /* 1374 */  vecD_rule,
  /* 1375 */  vecX_rule,
  /* 1376 */  vecX_rule,
  /* 1377 */  vecD_rule,
  /* 1378 */  vecX_rule,
  /* 1379 */  vecD_rule,
  /* 1380 */  vecX_rule,
  /* 1381 */  vecD_rule,
  /* 1382 */  vecX_rule,
  /* 1383 */  vecD_rule,
  /* 1384 */  vecX_rule,
  /* 1385 */  vecD_rule,
  /* 1386 */  vecX_rule,
  /* 1387 */  vecD_rule,
  /* 1388 */  vecX_rule,
  /* 1389 */  vecX_rule,
  /* 1390 */  vecX_rule,
  /* 1391 */  vecD_rule,
  /* 1392 */  vecX_rule,
  /* 1393 */  vecX_rule,
  /* 1394 */  iRegINoSp_rule,
  /* 1395 */  iRegINoSp_rule,
  /* 1396 */  iRegINoSp_rule,
  /* 1397 */  iRegINoSp_rule,
  /* 1398 */  vRegF_rule,
  /* 1399 */  vRegF_rule,
  /* 1400 */  vRegF_rule,
  /* 1401 */  vRegF_rule,
  /* 1402 */  vRegD_rule,
  /* 1403 */  vRegD_rule,
  /* 1404 */  vecD_rule,
  /* 1405 */  vecX_rule,
  /* 1406 */  vecD_rule,
  /* 1407 */  vecX_rule,
  /* 1408 */  vecD_rule,
  /* 1409 */  vecX_rule,
  /* 1410 */  vecX_rule,
  /* 1411 */  vecD_rule,
  /* 1412 */  vecX_rule,
  /* 1413 */  vecX_rule,
  /* 1414 */  vecD_rule,
  /* 1415 */  vecX_rule,
  /* 1416 */  vecD_rule,
  /* 1417 */  vecX_rule,
  /* 1418 */  vecD_rule,
  /* 1419 */  vecX_rule,
  /* 1420 */  vecX_rule,
  /* 1421 */  vecD_rule,
  /* 1422 */  vecX_rule,
  /* 1423 */  vecX_rule,
  /* 1424 */  vecD_rule,
  /* 1425 */  vecX_rule,
  /* 1426 */  vecD_rule,
  /* 1427 */  vecX_rule,
  /* 1428 */  vecD_rule,
  /* 1429 */  vecX_rule,
  /* 1430 */  vecD_rule,
  /* 1431 */  vecX_rule,
  /* 1432 */  vecX_rule,
  /* 1433 */  vecD_rule,
  /* 1434 */  vecD_rule,
  /* 1435 */  vecX_rule,
  /* 1436 */  vecX_rule,
  /* 1437 */  vecD_rule,
  /* 1438 */  vecD_rule,
  /* 1439 */  vecX_rule,
  /* 1440 */  vecX_rule,
  /* 1441 */  vecD_rule,
  /* 1442 */  vecX_rule,
  /* 1443 */  vecX_rule,
  /* 1444 */  vecD_rule,
  /* 1445 */  vecX_rule,
  /* 1446 */  vecD_rule,
  /* 1447 */  vecX_rule,
  /* 1448 */  vecD_rule,
  /* 1449 */  vecD_rule,
  /* 1450 */  vecX_rule,
  /* 1451 */  vecX_rule,
  /* 1452 */  vecX_rule,
  /* 1453 */  vecX_rule,
  /* 1454 */  vecX_rule,
  /* 1455 */  vecD_rule,
  /* 1456 */  vecX_rule,
  /* 1457 */  vecX_rule,
  /* 1458 */  vecD_rule,
  /* 1459 */  vecX_rule,
  /* 1460 */  vecD_rule,
  /* 1461 */  vecX_rule,
  /* 1462 */  vecD_rule,
  /* 1463 */  vecX_rule,
  /* 1464 */  vecD_rule,
  /* 1465 */  vecX_rule,
  /* 1466 */  vecD_rule,
  /* 1467 */  vecX_rule,
  /* 1468 */  vecD_rule,
  /* 1469 */  vecX_rule,
  /* 1470 */  vecD_rule,
  /* 1471 */  vecX_rule,
  /* 1472 */  vecD_rule,
  /* 1473 */  vecX_rule,
  /* 1474 */  vecD_rule,
  /* 1475 */  vecX_rule,
  /* 1476 */  vecD_rule,
  /* 1477 */  vecX_rule,
  /* 1478 */  vecD_rule,
  /* 1479 */  vecX_rule,
  /* 1480 */  vecD_rule,
  /* 1481 */  vecX_rule,
  /* 1482 */  vecD_rule,
  /* 1483 */  vecX_rule,
  /* 1484 */  vecD_rule,
  /* 1485 */  vecX_rule,
  /* 1486 */  vecD_rule,
  /* 1487 */  vecX_rule,
  /* 1488 */  vecD_rule,
  /* 1489 */  vecX_rule,
  /* 1490 */  vecD_rule,
  /* 1491 */  vecX_rule,
  /* 1492 */  vecD_rule,
  /* 1493 */  vecX_rule,
  /* 1494 */  vecD_rule,
  /* 1495 */  vecX_rule,
  /* 1496 */  vecD_rule,
  /* 1497 */  vecX_rule,
  /* 1498 */  vecD_rule,
  /* 1499 */  vecX_rule,
  /* 1500 */  vecX_rule,
  /* 1501 */  vecX_rule,
  /* 1502 */  vecX_rule,
  /* 1503 */  vecX_rule,
  /* 1504 */  vecX_rule,
  /* 1505 */  vecX_rule,
  /* 1506 */  vecD_rule,
  /* 1507 */  vecD_rule,
  /* 1508 */  vecX_rule,
  /* 1509 */  vecX_rule,
  /* 1510 */  vecD_rule,
  /* 1511 */  vecD_rule,
  /* 1512 */  vecX_rule,
  /* 1513 */  vecX_rule,
  /* 1514 */  vecD_rule,
  /* 1515 */  vecD_rule,
  /* 1516 */  vecX_rule,
  /* 1517 */  vecX_rule,
  /* 1518 */  vecX_rule,
  /* 1519 */  vecX_rule,
  /* 1520 */  vecD_rule,
  /* 1521 */  vecD_rule,
  /* 1522 */  vecX_rule,
  /* 1523 */  vecX_rule,
  /* 1524 */  vecD_rule,
  /* 1525 */  vecD_rule,
  /* 1526 */  vecX_rule,
  /* 1527 */  vecX_rule,
  /* 1528 */  vecD_rule,
  /* 1529 */  vecD_rule,
  /* 1530 */  vecX_rule,
  /* 1531 */  vecX_rule,
  /* 1532 */  vecX_rule,
  /* 1533 */  vecX_rule,
  /* 1534 */  vecD_rule,
  /* 1535 */  vecX_rule,
  /* 1536 */  vecX_rule,
  /* 1537 */  vecD_rule,
  /* 1538 */  vecX_rule,
  /* 1539 */  vecX_rule,
  /* 1540 */  vecX_rule,
  /* 1541 */  vReg_rule,
  /* 1542 */  Universe_rule,
  /* 1543 */  vReg_rule,
  /* 1544 */  vReg_rule,
  /* 1545 */  vReg_rule,
  /* 1546 */  vReg_rule,
  /* 1547 */  vReg_rule,
  /* 1548 */  vReg_rule,
  /* 1549 */  vReg_rule,
  /* 1550 */  vReg_rule,
  /* 1551 */  vReg_rule,
  /* 1552 */  vReg_rule,
  /* 1553 */  vReg_rule,
  /* 1554 */  vReg_rule,
  /* 1555 */  vReg_rule,
  /* 1556 */  vReg_rule,
  /* 1557 */  vReg_rule,
  /* 1558 */  vReg_rule,
  /* 1559 */  vReg_rule,
  /* 1560 */  vReg_rule,
  /* 1561 */  vReg_rule,
  /* 1562 */  vReg_rule,
  /* 1563 */  vReg_rule,
  /* 1564 */  vReg_rule,
  /* 1565 */  vReg_rule,
  /* 1566 */  vReg_rule,
  /* 1567 */  vReg_rule,
  /* 1568 */  vReg_rule,
  /* 1569 */  vReg_rule,
  /* 1570 */  vReg_rule,
  /* 1571 */  vReg_rule,
  /* 1572 */  vReg_rule,
  /* 1573 */  vReg_rule,
  /* 1574 */  vReg_rule,
  /* 1575 */  vReg_rule,
  /* 1576 */  vReg_rule,
  /* 1577 */  vReg_rule,
  /* 1578 */  vReg_rule,
  /* 1579 */  vReg_rule,
  /* 1580 */  vReg_rule,
  /* 1581 */  vReg_rule,
  /* 1582 */  vReg_rule,
  /* 1583 */  vReg_rule,
  /* 1584 */  vReg_rule,
  /* 1585 */  vReg_rule,
  /* 1586 */  vReg_rule,
  /* 1587 */  vReg_rule,
  /* 1588 */  vReg_rule,
  /* 1589 */  vReg_rule,
  /* 1590 */  vReg_rule,
  /* 1591 */  vReg_rule,
  /* 1592 */  vReg_rule,
  /* 1593 */  vReg_rule,
  /* 1594 */  vReg_rule,
  /* 1595 */  vReg_rule,
  /* 1596 */  vReg_rule,
  /* 1597 */  vReg_rule,
  /* 1598 */  vReg_rule,
  /* 1599 */  vReg_rule,
  /* 1600 */  vReg_rule,
  /* 1601 */  vReg_rule,
  /* 1602 */  vReg_rule,
  /* 1603 */  vReg_rule,
  /* 1604 */  vReg_rule,
  /* 1605 */  vReg_rule,
  /* 1606 */  vReg_rule,
  /* 1607 */  vReg_rule,
  /* 1608 */  vReg_rule,
  /* 1609 */  vReg_rule,
  /* 1610 */  iRegINoSp_rule,
  /* 1611 */  iRegINoSp_rule,
  /* 1612 */  iRegINoSp_rule,
  /* 1613 */  iRegLNoSp_rule,
  /* 1614 */  vRegF_rule,
  /* 1615 */  vRegD_rule,
  /* 1616 */  vRegF_rule,
  /* 1617 */  vRegD_rule,
  /* 1618 */  vRegF_rule,
  /* 1619 */  vRegD_rule,
  /* 1620 */  vReg_rule,
  /* 1621 */  vReg_rule,
  /* 1622 */  vReg_rule,
  /* 1623 */  vReg_rule,
  /* 1624 */  vReg_rule,
  /* 1625 */  vReg_rule,
  /* 1626 */  vReg_rule,
  /* 1627 */  vReg_rule,
  /* 1628 */  vReg_rule,
  /* 1629 */  vReg_rule,
  /* 1630 */  vReg_rule,
  /* 1631 */  vReg_rule,
  /* 1632 */  vReg_rule,
  /* 1633 */  vReg_rule,
  /* 1634 */  vReg_rule,
  /* 1635 */  vReg_rule,
  /* 1636 */  vReg_rule,
  /* 1637 */  vReg_rule,
  /* 1638 */  vReg_rule,
  /* 1639 */  vReg_rule,
  /* 1640 */  vReg_rule,
  /* 1641 */  vReg_rule,
  /* 1642 */  vReg_rule,
  /* 1643 */  vReg_rule,
  /* 1644 */  vReg_rule,
  /* 1645 */  vReg_rule,
  /* 1646 */  vReg_rule,
  /* 1647 */  vReg_rule,
  /* 1648 */  vReg_rule,
  /* 1649 */  vReg_rule,
  /* 1650 */  vReg_rule,
  /* 1651 */  vReg_rule,
  /* 1652 */  vReg_rule,
  /* 1653 */  vReg_rule,
  /* 1654 */  vReg_rule,
  /* 1655 */  vReg_rule,
  /* 1656 */  vReg_rule,
  /* 1657 */  vReg_rule,
  /* 1658 */  vReg_rule,
  /* 1659 */  vReg_rule,
  /* 1660 */  vReg_rule,
  /* 1661 */  iRegINoSp_rule,
  /* 1662 */  iRegINoSp_rule,
  /* 1663 */  iRegINoSp_rule,
  /* 1664 */  iRegINoSp_rule,
  /* 1665 */  iRegNNoSp_rule,
  /* 1666 */  iRegPNoSp_rule,
  /* 1667 */  iRegNNoSp_rule,
  /* 1668 */  iRegPNoSp_rule,
  /* 1669 */  iRegINoSp_rule,
  /* 1670 */  iRegINoSp_rule,
  /* 1671 */  iRegINoSp_rule,
  /* 1672 */  iRegINoSp_rule,
  /* 1673 */  iRegPNoSp_rule,
  /* 1674 */  iRegPNoSp_rule,
  /* 1675 */  iRegINoSp_rule,
  /* 1676 */  iRegINoSp_rule,
  /* 1677 */  iRegINoSp_rule,
  /* 1678 */  iRegINoSp_rule,
  /* 1679 */  iRegPNoSp_rule,
  /* 1680 */  iRegPNoSp_rule,
  /* 1681 */  iRegPNoSp_rule,
  /* 1682 */  iRegPNoSp_rule,
  // last instruction
  0 // no trailing comma
};

const        int   leftOp[] = {
  /*    0 */  0,
  /*    1 */  0,
  /*    2 */  0,
  /*    3 */  0,
  /*    4 */  0,
  /*    5 */  0,
  /*    6 */  0,
  /*    7 */  0,
  /*    8 */  0,
  /*    9 */  0,
  /*   10 */  0,
  /*   11 */  0,
  /*   12 */  0,
  /*   13 */  0,
  /*   14 */  0,
  /*   15 */  0,
  /*   16 */  0,
  /*   17 */  0,
  /*   18 */  0,
  /*   19 */  0,
  /*   20 */  0,
  /*   21 */  0,
  /*   22 */  0,
  /*   23 */  0,
  /*   24 */  0,
  /*   25 */  0,
  /*   26 */  0,
  /*   27 */  0,
  /*   28 */  0,
  /*   29 */  0,
  /*   30 */  0,
  /*   31 */  0,
  /*   32 */  0,
  /*   33 */  0,
  /*   34 */  0,
  /*   35 */  0,
  /*   36 */  0,
  /*   37 */  0,
  /*   38 */  0,
  /*   39 */  0,
  /*   40 */  0,
  /*   41 */  0,
  /*   42 */  0,
  /*   43 */  0,
  /*   44 */  0,
  /*   45 */  0,
  /*   46 */  0,
  /*   47 */  0,
  /*   48 */  0,
  /*   49 */  0,
  /*   50 */  0,
  /*   51 */  0,
  /*   52 */  0,
  /*   53 */  0,
  /*   54 */  0,
  /*   55 */  0,
  /*   56 */  0,
  /*   57 */  0,
  /*   58 */  0,
  /*   59 */  0,
  /*   60 */  0,
  /*   61 */  0,
  /*   62 */  0,
  /*   63 */  0,
  /*   64 */  0,
  /*   65 */  0,
  /*   66 */  0,
  /*   67 */  0,
  /*   68 */  0,
  /*   69 */  0,
  /*   70 */  0,
  /*   71 */  0,
  /*   72 */  0,
  /*   73 */  0,
  /*   74 */  0,
  /*   75 */  0,
  /*   76 */  0,
  /*   77 */  0,
  /*   78 */  0,
  /*   79 */  0,
  /*   80 */  0,
  /*   81 */  0,
  /*   82 */  0,
  /*   83 */  0,
  /*   84 */  0,
  /*   85 */  0,
  /*   86 */  0,
  /*   87 */  0,
  /*   88 */  0,
  /*   89 */  0,
  /*   90 */  0,
  /*   91 */  0,
  /*   92 */  0,
  /*   93 */  0,
  /*   94 */  0,
  /*   95 */  0,
  /*   96 */  0,
  /*   97 */  0,
  /*   98 */  0,
  /*   99 */  0,
  /*  100 */  0,
  /*  101 */  0,
  /*  102 */  0,
  /*  103 */  0,
  /*  104 */  0,
  /*  105 */  0,
  /*  106 */  0,
  /*  107 */  0,
  /*  108 */  0,
  /*  109 */  0,
  /*  110 */  0,
  /*  111 */  0,
  /*  112 */  0,
  /*  113 */  0,
  /*  114 */  0,
  /*  115 */  0,
  /*  116 */  0,
  /*  117 */  0,
  /*  118 */  0,
  /*  119 */  0,
  /*  120 */  0,
  /*  121 */  0,
  /*  122 */  0,
  /*  123 */  0,
  /*  124 */  0,
  /*  125 */  0,
  /*  126 */  0,
  /*  127 */  0,
  /*  128 */  0,
  /*  129 */  0,
  /*  130 */  0,
  /*  131 */  0,
  /*  132 */  0,
  /*  133 */  0,
  /*  134 */  0,
  /*  135 */  0,
  /*  136 */  0,
  /*  137 */  0,
  /*  138 */  0,
  /*  139 */  0,
  /*  140 */  0,
  /*  141 */  0,
  /*  142 */  0,
  /*  143 */  0,
  /*  144 */  0,
  /*  145 */  0,
  /*  146 */  0,
  /*  147 */  0,
  /*  148 */  0,
  /*  149 */  0,
  /*  150 */  iRegP_rule,
  /*  151 */  iRegP_rule,
  /*  152 */  iRegP_rule,
  /*  153 */  iRegP_rule,
  /*  154 */  iRegP_rule,
  /*  155 */  iRegP_rule,
  /*  156 */  iRegP_rule,
  /*  157 */  iRegP_rule,
  /*  158 */  iRegP_rule,
  /*  159 */  iRegP_rule,
  /*  160 */  iRegP_rule,
  /*  161 */  iRegP_rule,
  /*  162 */  iRegP_rule,
  /*  163 */  iRegP_rule,
  /*  164 */  iRegP_rule,
  /*  165 */  iRegP_rule,
  /*  166 */  iRegN_rule,
  /*  167 */  _DecodeN_iRegN__rule,
  /*  168 */  _DecodeN_iRegN__rule,
  /*  169 */  _DecodeN_iRegN__rule,
  /*  170 */  _DecodeN_iRegN__rule,
  /*  171 */  _DecodeN_iRegN__rule,
  /*  172 */  _DecodeN_iRegN__rule,
  /*  173 */  thread_RegP_rule,
  /*  174 */  0,
  /*  175 */  0,
  /*  176 */  0,
  /*  177 */  0,
  /*  178 */  0,
  /*  179 */  0,
  /*  180 */  0,
  /*  181 */  0,
  /*  182 */  0,
  /*  183 */  0,
  /*  184 */  iRegL_rule,
  /*  185 */  0,
  /*  186 */  0,
  /*  187 */  iRegP_rule,
  /*  188 */  iRegP_rule,
  // last operand
  /*  189 */  0,
  /*  190 */  0,
  /*  191 */  0,
  /*  192 */  0,
  /*  193 */  0,
  /*  194 */  0,
  /*  195 */  0,
  /*  196 */  0,
  /*  197 */  0,
  /*  198 */  0,
  /*  199 */  0,
  // last operand class
  /*  200 */  iRegI_rule,
  /*  201 */  _ConvI2L_iRegI__rule,
  /*  202 */  iRegL_rule,
  /*  203 */  iRegN_rule,
  /*  204 */  memory1_rule,
  /*  205 */  memory1_rule,
  /*  206 */  memory2_rule,
  /*  207 */  memory2_rule,
  /*  208 */  memory4_rule,
  /*  209 */  _LoadI_memory4__rule,
  /*  210 */  indirect_rule,
  /*  211 */  indirect_rule,
  /*  212 */  indirect_rule,
  /*  213 */  indirect_rule,
  /*  214 */  indirect_rule,
  /*  215 */  _LoadI_indirect__rule,
  /*  216 */  memory8_rule,
  /*  217 */  iRegP_rule,
  /*  218 */  _DecodeN_iRegN__rule,
  /*  219 */  iRegP_rule,
  /*  220 */  iRegLNoSp_rule,
  /*  221 */  iRegINoSp_rule,
  /*  222 */  iRegNNoSp_rule,
  /*  223 */  iRegI_rule,
  /*  224 */  iRegL_rule,
  /*  225 */  iRegN_rule,
  /*  226 */  cmpOp_rule,
  /*  227 */  iRegIorL2I_rule,
  /*  228 */  cmpOpU_rule,
  /*  229 */  immI0_rule,
  /*  230 */  iRegIorL2I_rule,
  /*  231 */  immI_1_rule,
  /*  232 */  iRegL_rule,
  /*  233 */  immL0_rule,
  /*  234 */  iRegP_rule,
  /*  235 */  immP0_rule,
  /*  236 */  iRegN_rule,
  /*  237 */  immN0_rule,
  /*  238 */  vRegF_rule,
  /*  239 */  vRegD_rule,
  /*  240 */  iRegL_rule,
  /*  241 */  iRegIorL2I_rule,
  /*  242 */  _ConvI2L_iRegIorL2I__rule,
  /*  243 */  iRegIorL2I_rule,
  /*  244 */  immI0_rule,
  /*  245 */  iRegL_rule,
  /*  246 */  immL0_rule,
  /*  247 */  _ConvI2L_iRegIorL2I__rule,
  /*  248 */  immL0_rule,
  /*  249 */  iRegIorL2I_rule,
  /*  250 */  iRegL_rule,
  /*  251 */  iRegIorL2I_rule,
  /*  252 */  iRegL_rule,
  /*  253 */  iRegIorL2I_rule,
  /*  254 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  255 */  iRegL_rule,
  /*  256 */  _URShiftL_iRegL_immI_rule,
  /*  257 */  iRegIorL2I_rule,
  /*  258 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  259 */  iRegL_rule,
  /*  260 */  _RShiftL_iRegL_immI_rule,
  /*  261 */  iRegIorL2I_rule,
  /*  262 */  _RotateRight_iRegIorL2I_immI_rule,
  /*  263 */  iRegL_rule,
  /*  264 */  _RotateRight_iRegL_immI_rule,
  /*  265 */  iRegIorL2I_rule,
  /*  266 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  267 */  iRegL_rule,
  /*  268 */  _LShiftL_iRegL_immI_rule,
  /*  269 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  270 */  iRegIorL2I_rule,
  /*  271 */  _URShiftL_iRegL_immI_rule,
  /*  272 */  iRegL_rule,
  /*  273 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  274 */  iRegIorL2I_rule,
  /*  275 */  _RShiftL_iRegL_immI_rule,
  /*  276 */  iRegL_rule,
  /*  277 */  _RotateRight_iRegIorL2I_immI_rule,
  /*  278 */  iRegIorL2I_rule,
  /*  279 */  _RotateRight_iRegL_immI_rule,
  /*  280 */  iRegL_rule,
  /*  281 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  282 */  iRegIorL2I_rule,
  /*  283 */  _LShiftL_iRegL_immI_rule,
  /*  284 */  iRegL_rule,
  /*  285 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  286 */  iRegIorL2I_rule,
  /*  287 */  iRegL_rule,
  /*  288 */  _AndI_iRegIorL2I_immI_bitmask_rule,
  /*  289 */  iRegL_rule,
  /*  290 */  _AndL_iRegL_immL_positive_bitmaskI_rule,
  /*  291 */  _AndI_iRegIorL2I_immI_bitmask_rule,
  /*  292 */  _AndL_iRegL_immL_positive_bitmaskI_rule,
  /*  293 */  iRegI_rule,
  /*  294 */  iRegIorL2I_rule,
  /*  295 */  _LShiftI_iRegIorL2I_immI_16_rule,
  /*  296 */  iRegIorL2I_rule,
  /*  297 */  _LShiftI_iRegIorL2I_immI_24_rule,
  /*  298 */  _LShiftI_iRegIorL2I_immI_24_rule,
  /*  299 */  iRegL_rule,
  /*  300 */  _LShiftL_iRegL_immI_48_rule,
  /*  301 */  iRegL_rule,
  /*  302 */  _LShiftL_iRegL_immI_32_rule,
  /*  303 */  iRegL_rule,
  /*  304 */  _LShiftL_iRegL_immI_56_rule,
  /*  305 */  _LShiftL_iRegL_immI_56_rule,
  /*  306 */  iRegIorL2I_rule,
  /*  307 */  iRegIorL2I_rule,
  /*  308 */  iRegL_rule,
  /*  309 */  iRegL_rule,
  /*  310 */  iRegL_rule,
  /*  311 */  _RShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /*  312 */  _RShiftL__LShiftL_iRegL_immI_48_immI_48_rule,
  /*  313 */  _RShiftL__LShiftL_iRegL_immI_32_immI_32_rule,
  /*  314 */  _RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /*  315 */  _RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_rule,
  /*  316 */  _ConvI2L_iRegIorL2I__rule,
  /*  317 */  _AndL_iRegL_immL_255_rule,
  /*  318 */  _AndL_iRegL_immL_65535_rule,
  /*  319 */  _AndL_iRegL_immL_4294967295_rule,
  /*  320 */  _AndI_iRegIorL2I_immI_255_rule,
  /*  321 */  _AndI_iRegIorL2I_immI_65535_rule,
  /*  322 */  vRegF_rule,
  /*  323 */  _NegF_vRegF__rule,
  /*  324 */  vRegF_rule,
  /*  325 */  vRegD_rule,
  /*  326 */  _NegD_vRegD__rule,
  /*  327 */  vRegD_rule,
  /*  328 */  vRegF_rule,
  /*  329 */  vRegD_rule,
  /*  330 */  iRegIorL2I_rule,
  /*  331 */  iRegL_rule,
  /*  332 */  iRegIorL2I_rule,
  /*  333 */  iRegL_rule,
  /*  334 */  iRegP_rule,
  /*  335 */  iRegN_rule,
  /*  336 */  _DecodeN_iRegN__rule,
  /*  337 */  iRegIorL2I_rule,
  /*  338 */  iRegL_rule,
  /*  339 */  iRegL_rule,
  /*  340 */  _AndL_iRegL_immL_rule,
  /*  341 */  iRegIorL2I_rule,
  /*  342 */  _AndI_iRegIorL2I_immI_rule,
  /*  343 */  iRegL_rule,
  /*  344 */  iRegIorL2I_rule,
  /*  345 */  iRegP_R4_rule,
  /*  346 */  iRegP_R1_rule,
  /*  347 */  iRegP_R3_rule,
  /*  348 */  iRegP_R1_rule,
  /*  349 */  iRegP_R3_rule,
  /*  350 */  iRegP_R3_rule,
  /*  351 */  iRegP_R3_rule,
  /*  352 */  iRegP_R1_rule,
  /*  353 */  iRegP_R1_rule,
  /*  354 */  vecD_rule,
  /*  355 */  vecX_rule,
  /*  356 */  vecX_rule,
  /*  357 */  vecD_rule,
  /*  358 */  vecX_rule,
  /*  359 */  vecX_rule,
  /*  360 */  vecD_rule,
  /*  361 */  vecX_rule,
  /*  362 */  immI_M1_rule,
  /*  363 */  immI_M1_rule,
  /*  364 */  immI_M1_rule,
  /*  365 */  immL_M1_rule,
  /*  366 */  vecD_rule,
  /*  367 */  _ReplicateB_immI_M1__rule,
  /*  368 */  vecD_rule,
  /*  369 */  _ReplicateS_immI_M1__rule,
  /*  370 */  vecD_rule,
  /*  371 */  _ReplicateI_immI_M1__rule,
  /*  372 */  vecX_rule,
  /*  373 */  _ReplicateB_immI_M1__rule,
  /*  374 */  vecX_rule,
  /*  375 */  _ReplicateS_immI_M1__rule,
  /*  376 */  vecX_rule,
  /*  377 */  _ReplicateI_immI_M1__rule,
  /*  378 */  vecX_rule,
  /*  379 */  _ReplicateL_immL_M1__rule,
  /*  380 */  vecD_rule,
  /*  381 */  vecX_rule,
  /*  382 */  vecX_rule,
  /*  383 */  vecD_rule,
  /*  384 */  vecX_rule,
  /*  385 */  vecD_rule,
  /*  386 */  vecX_rule,
  /*  387 */  vecD_rule,
  /*  388 */  _NegVF_vecD__rule,
  /*  389 */  vecD_rule,
  /*  390 */  vecX_rule,
  /*  391 */  _NegVF_vecX__rule,
  /*  392 */  vecX_rule,
  /*  393 */  vecX_rule,
  /*  394 */  _NegVD_vecX__rule,
  /*  395 */  vecX_rule,
  /*  396 */  immI_rule,
  /*  397 */  immI_rule,
  /*  398 */  vecD_rule,
  /*  399 */  vecX_rule,
  /*  400 */  vecD_rule,
  /*  401 */  vecX_rule,
  /*  402 */  vecD_rule,
  /*  403 */  vecX_rule,
  /*  404 */  vecX_rule,
  /*  405 */  vecD_rule,
  /*  406 */  vecX_rule,
  /*  407 */  vecD_rule,
  /*  408 */  vecX_rule,
  /*  409 */  vecD_rule,
  /*  410 */  vecX_rule,
  /*  411 */  vecX_rule,
  /*  412 */  vReg_rule,
  /*  413 */  _ReplicateB_immI_M1__rule,
  /*  414 */  vReg_rule,
  /*  415 */  _ReplicateS_immI_M1__rule,
  /*  416 */  vReg_rule,
  /*  417 */  _ReplicateI_immI_M1__rule,
  /*  418 */  vReg_rule,
  /*  419 */  _ReplicateL_immL_M1__rule,
  /*  420 */  vReg_rule,
  /*  421 */  vReg_rule,
  /*  422 */  _NegVF_vReg__rule,
  /*  423 */  vReg_rule,
  /*  424 */  vReg_rule,
  /*  425 */  _NegVD_vReg__rule,
  /*  426 */  vReg_rule,
  /*  427 */  vReg_rule,
  /*  428 */  vReg_rule,
  /*  429 */  vReg_rule,
  /*  430 */  vReg_rule,
  // last internally defined operand
  /*  431 */  immI_rule,
  /*  432 */  immL_rule,
  /*  433 */  immP_rule,
  /*  434 */  immP0_rule,
  /*  435 */  immP_1_rule,
  /*  436 */  immByteMapBase_rule,
  /*  437 */  immN_rule,
  /*  438 */  immN0_rule,
  /*  439 */  immNKlass_rule,
  /*  440 */  immFPacked_rule,
  /*  441 */  immF_rule,
  /*  442 */  immDPacked_rule,
  /*  443 */  immD_rule,
  /*  444 */  iRegIorL2I_rule,
  /*  445 */  iRegL_rule,
  /*  446 */  iRegIorL2I_rule,
  /*  447 */  iRegL_rule,
  /*  448 */  iRegL_rule,
  /*  449 */  iRegP_rule,
  /*  450 */  iRegPNoSp_rule,
  /*  451 */  iRegPNoSp_rule,
  /*  452 */  iRegI_rule,
  /*  453 */  iRegL_rule,
  /*  454 */  vRegF_rule,
  /*  455 */  vRegD_rule,
  /*  456 */  vecD_rule,
  /*  457 */  vecX_rule,
  /*  458 */  vReg_rule,
  /*  459 */  memory8_rule,
  /*  460 */  indirect_rule,
  /*  461 */  indirect_rule,
  /*  462 */  vRegF_rule,
  /*  463 */  vRegD_rule,
  /*  464 */  vRegF_rule,
  /*  465 */  vRegD_rule,
  /*  466 */  stackSlotF_rule,
  /*  467 */  stackSlotI_rule,
  /*  468 */  stackSlotD_rule,
  /*  469 */  stackSlotL_rule,
  /*  470 */  vRegF_rule,
  /*  471 */  iRegI_rule,
  /*  472 */  vRegD_rule,
  /*  473 */  iRegL_rule,
  /*  474 */  iRegIorL2I_rule,
  /*  475 */  iRegIorL2I_rule,
  /*  476 */  iRegL_rule,
  /*  477 */  iRegL_rule,
  /*  478 */  iRegIorL2I_rule,
  /*  479 */  iRegIorL2I_rule,
  /*  480 */  iRegL_rule,
  /*  481 */  iRegL_rule,
  /*  482 */  immI0_rule,
  /*  483 */  immI0_rule,
  /*  484 */  iRegIorL2I_rule,
  /*  485 */  iRegL_rule,
  /*  486 */  iRegI_rule,
  /*  487 */  iRegI_rule,
  /*  488 */  iRegI_rule,
  /*  489 */  iRegI_rule,
  /*  490 */  iRegI_rule,
  /*  491 */  iRegI_rule,
  /*  492 */  iRegI_rule,
  /*  493 */  iRegI_rule,
  /*  494 */  iRegL_rule,
  /*  495 */  iRegL_rule,
  /*  496 */  iRegL_rule,
  /*  497 */  iRegL_rule,
  /*  498 */  iRegL_rule,
  /*  499 */  iRegL_rule,
  /*  500 */  iRegL_rule,
  /*  501 */  iRegL_rule,
  /*  502 */  iRegP_rule,
  /*  503 */  iRegN_rule,
  /*  504 */  iRegP_rule,
  /*  505 */  iRegN_rule,
  /*  506 */  vRegF_rule,
  /*  507 */  vRegF_rule,
  /*  508 */  vRegD_rule,
  /*  509 */  vRegD_rule,
  /*  510 */  _AndL_iRegL_immL_rule,
  /*  511 */  _AndI_iRegIorL2I_immI_rule,
  /*  512 */  _AndL_iRegL_iRegL_rule,
  /*  513 */  _AndI_iRegIorL2I_iRegIorL2I_rule,
  /*  514 */  iRegP_rule,
  /*  515 */  iRegP_rule,
  /*  516 */  _PartialSubtypeCheck_iRegP_R4_iRegP_R0_rule,
  /*  517 */  0,
  /*  518 */  vecD_rule,
  /*  519 */  vecX_rule,
  /*  520 */  vecD_rule,
  /*  521 */  vecX_rule,
  /*  522 */  vecD_rule,
  /*  523 */  vecD_rule,
  /*  524 */  vecD_rule,
  /*  525 */  vecX_rule,
  /*  526 */  vecD_rule,
  /*  527 */  vecX_rule,
  /*  528 */  vecD_rule,
  /*  529 */  vecX_rule,
  /*  530 */  vecD_rule,
  /*  531 */  vecX_rule,
  /*  532 */  vecD_rule,
  /*  533 */  vecD_rule,
  /*  534 */  vecD_rule,
  /*  535 */  vecD_rule,
  /*  536 */  vecX_rule,
  /*  537 */  vecX_rule,
  /*  538 */  vecD_rule,
  /*  539 */  vecX_rule,
  /*  540 */  vecX_rule,
  /*  541 */  vecD_rule,
  /*  542 */  vecX_rule,
  /*  543 */  vecD_rule,
  /*  544 */  vecD_rule,
  /*  545 */  vecD_rule,
  /*  546 */  vecD_rule,
  /*  547 */  vecD_rule,
  /*  548 */  vecD_rule,
  /*  549 */  vecX_rule,
  /*  550 */  immI0_rule,
  /*  551 */  immI0_rule,
  /*  552 */  vecD_rule,
  /*  553 */  vecX_rule,
  /*  554 */  vecD_rule,
  /*  555 */  vecD_rule,
  /*  556 */  vecD_rule,
  /*  557 */  vecD_rule,
  /*  558 */  vecX_rule,
  /*  559 */  vecD_rule,
  /*  560 */  vecX_rule,
  /*  561 */  vecD_rule,
  /*  562 */  vecX_rule,
  /*  563 */  vecX_rule,
  /*  564 */  vecD_rule,
  /*  565 */  vecX_rule,
  /*  566 */  vecX_rule,
  /*  567 */  vecD_rule,
  /*  568 */  vecX_rule,
  /*  569 */  vecX_rule,
  /*  570 */  vecD_rule,
  /*  571 */  vecX_rule,
  /*  572 */  vecX_rule,
  /*  573 */  iRegIorL2I_rule,
  /*  574 */  iRegIorL2I_rule,
  /*  575 */  iRegIorL2I_rule,
  /*  576 */  iRegIorL2I_rule,
  /*  577 */  vecX_rule,
  /*  578 */  vecD_rule,
  /*  579 */  vReg_rule,
  /*  580 */  vReg_rule,
  /*  581 */  vReg_rule,
  /*  582 */  vReg_rule,
  /*  583 */  vReg_rule,
  /*  584 */  vReg_rule,
  /*  585 */  vReg_rule,
  /*  586 */  vReg_rule,
  /*  587 */  vReg_rule,
  /*  588 */  iRegIorL2I_rule,
  /*  589 */  iRegIorL2I_rule,
  /*  590 */  iRegIorL2I_rule,
  /*  591 */  iRegIorL2I_rule,
  /*  592 */  iRegIorL2I_rule,
  /*  593 */  iRegIorL2I_rule,
  /*  594 */  iRegIorL2I_rule,
  /*  595 */  iRegIorL2I_rule,
  /*  596 */  vReg_rule,
  /*  597 */  vReg_rule,
  /*  598 */  vReg_rule,
  /*  599 */  memory1_rule,
  /*  600 */  _LoadB_memory1__rule,
  /*  601 */  memory1_rule,
  /*  602 */  _LoadUB_memory1__rule,
  /*  603 */  memory2_rule,
  /*  604 */  _LoadS_memory2__rule,
  /*  605 */  memory2_rule,
  /*  606 */  _LoadUS_memory2__rule,
  /*  607 */  memory4_rule,
  /*  608 */  _LoadI_memory4__rule,
  /*  609 */  _ConvI2L__LoadI_memory4___rule,
  /*  610 */  memory8_rule,
  /*  611 */  memory4_rule,
  /*  612 */  memory8_rule,
  /*  613 */  memory4_rule,
  /*  614 */  memory8_rule,
  /*  615 */  memory4_rule,
  /*  616 */  memory4_rule,
  /*  617 */  memory8_rule,
  /*  618 */  memory1_rule,
  /*  619 */  memory1_rule,
  /*  620 */  memory1_rule,
  /*  621 */  memory1_rule,
  /*  622 */  memory2_rule,
  /*  623 */  memory2_rule,
  /*  624 */  memory4_rule,
  /*  625 */  memory4_rule,
  /*  626 */  memory8_rule,
  /*  627 */  memory8_rule,
  /*  628 */  memory8_rule,
  /*  629 */  memory8_rule,
  /*  630 */  memory4_rule,
  /*  631 */  memory4_rule,
  /*  632 */  memory4_rule,
  /*  633 */  memory8_rule,
  /*  634 */  memory4_rule,
  /*  635 */  memory8_rule,
  /*  636 */  indirect_rule,
  /*  637 */  _LoadB_indirect__rule,
  /*  638 */  indirect_rule,
  /*  639 */  _LoadUB_indirect__rule,
  /*  640 */  indirect_rule,
  /*  641 */  indirect_rule,
  /*  642 */  _LoadUS_indirect__rule,
  /*  643 */  _LoadS_indirect__rule,
  /*  644 */  indirect_rule,
  /*  645 */  _ConvI2L__LoadI_indirect___rule,
  /*  646 */  indirect_rule,
  /*  647 */  indirect_rule,
  /*  648 */  indirect_rule,
  /*  649 */  indirect_rule,
  /*  650 */  indirect_rule,
  /*  651 */  indirect_rule,
  /*  652 */  indirect_rule,
  /*  653 */  indirect_rule,
  /*  654 */  indirect_rule,
  /*  655 */  indirect_rule,
  /*  656 */  indirect_rule,
  /*  657 */  indirect_rule,
  /*  658 */  indirect_rule,
  /*  659 */  indirect_rule,
  /*  660 */  0,
  /*  661 */  0,
  /*  662 */  iRegIorL2I_rule,
  /*  663 */  iRegL_rule,
  /*  664 */  iRegIorL2I_rule,
  /*  665 */  iRegIorL2I_rule,
  /*  666 */  iRegIorL2I_rule,
  /*  667 */  _LoadI_memory4__rule,
  /*  668 */  iRegL_rule,
  /*  669 */  _LoadL_memory8__rule,
  /*  670 */  0,
  /*  671 */  0,
  /*  672 */  0,
  /*  673 */  0,
  /*  674 */  0,
  /*  675 */  0,
  /*  676 */  0,
  /*  677 */  0,
  /*  678 */  0,
  /*  679 */  0,
  /*  680 */  0,
  /*  681 */  _CastP2X_iRegP__rule,
  /*  682 */  _CastP2X__DecodeN_iRegN___rule,
  /*  683 */  iRegP_rule,
  /*  684 */  iRegP_rule,
  /*  685 */  iRegN_rule,
  /*  686 */  iRegN_rule,
  /*  687 */  iRegP_rule,
  /*  688 */  iRegN_rule,
  /*  689 */  indirect_rule,
  /*  690 */  indirect_rule,
  /*  691 */  indirect_rule,
  /*  692 */  indirect_rule,
  /*  693 */  indirect_rule,
  /*  694 */  indirect_rule,
  /*  695 */  indirect_rule,
  /*  696 */  indirect_rule,
  /*  697 */  indirect_rule,
  /*  698 */  indirect_rule,
  /*  699 */  indirect_rule,
  /*  700 */  indirect_rule,
  /*  701 */  indirect_rule,
  /*  702 */  indirect_rule,
  /*  703 */  indirect_rule,
  /*  704 */  indirect_rule,
  /*  705 */  indirect_rule,
  /*  706 */  indirect_rule,
  /*  707 */  indirect_rule,
  /*  708 */  indirect_rule,
  /*  709 */  indirect_rule,
  /*  710 */  indirect_rule,
  /*  711 */  indirect_rule,
  /*  712 */  indirect_rule,
  /*  713 */  indirect_rule,
  /*  714 */  indirect_rule,
  /*  715 */  indirect_rule,
  /*  716 */  indirect_rule,
  /*  717 */  indirect_rule,
  /*  718 */  indirect_rule,
  /*  719 */  indirect_rule,
  /*  720 */  indirect_rule,
  /*  721 */  indirect_rule,
  /*  722 */  indirect_rule,
  /*  723 */  indirect_rule,
  /*  724 */  indirect_rule,
  /*  725 */  indirect_rule,
  /*  726 */  indirect_rule,
  /*  727 */  indirect_rule,
  /*  728 */  indirect_rule,
  /*  729 */  indirect_rule,
  /*  730 */  indirect_rule,
  /*  731 */  indirect_rule,
  /*  732 */  indirect_rule,
  /*  733 */  indirect_rule,
  /*  734 */  indirect_rule,
  /*  735 */  indirect_rule,
  /*  736 */  indirect_rule,
  /*  737 */  indirect_rule,
  /*  738 */  indirect_rule,
  /*  739 */  indirect_rule,
  /*  740 */  indirect_rule,
  /*  741 */  indirect_rule,
  /*  742 */  indirect_rule,
  /*  743 */  indirect_rule,
  /*  744 */  indirect_rule,
  /*  745 */  indirect_rule,
  /*  746 */  indirect_rule,
  /*  747 */  indirect_rule,
  /*  748 */  indirect_rule,
  /*  749 */  indirect_rule,
  /*  750 */  iRegL_rule,
  /*  751 */  iRegL_rule,
  /*  752 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  753 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  754 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  755 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  756 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  757 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  758 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  759 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  760 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  761 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  762 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  763 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  764 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  765 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  766 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  767 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  768 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  769 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  770 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  771 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  772 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  773 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  774 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  775 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  776 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  777 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  778 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  779 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  780 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  781 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  782 */  iRegIorL2I_rule,
  /*  783 */  iRegIorL2I_rule,
  /*  784 */  _ConvL2I_iRegL__rule,
  /*  785 */  iRegP_rule,
  /*  786 */  iRegP_rule,
  /*  787 */  iRegP_rule,
  /*  788 */  iRegP_rule,
  /*  789 */  _ConvI2L_iRegIorL2I__rule,
  /*  790 */  iRegP_rule,
  /*  791 */  iRegL_rule,
  /*  792 */  iRegL_rule,
  /*  793 */  iRegIorL2I_rule,
  /*  794 */  iRegIorL2I_rule,
  /*  795 */  iRegL_rule,
  /*  796 */  iRegL_rule,
  /*  797 */  immI0_rule,
  /*  798 */  immL0_rule,
  /*  799 */  iRegIorL2I_rule,
  /*  800 */  _ConvI2L_iRegIorL2I__rule,
  /*  801 */  _ConvI2L_iRegIorL2I__rule,
  /*  802 */  iRegL_rule,
  /*  803 */  iRegL_rule,
  /*  804 */  iRegIorL2I_rule,
  /*  805 */  _MulI_iRegIorL2I_iRegIorL2I_rule,
  /*  806 */  iRegIorL2I_rule,
  /*  807 */  _SubI_immI0_iRegIorL2I_rule,
  /*  808 */  iRegIorL2I_rule,
  /*  809 */  iRegIorL2I_rule,
  /*  810 */  _SubI_immI0_iRegIorL2I_rule,
  /*  811 */  iRegL_rule,
  /*  812 */  _MulL_iRegL_iRegL_rule,
  /*  813 */  iRegL_rule,
  /*  814 */  _SubL_immL0_iRegL_rule,
  /*  815 */  iRegL_rule,
  /*  816 */  iRegL_rule,
  /*  817 */  _SubL_immL0_iRegL_rule,
  /*  818 */  iRegLNoSp_rule,
  /*  819 */  _MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I__rule,
  /*  820 */  iRegLNoSp_rule,
  /*  821 */  _MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I__rule,
  /*  822 */  iRegLNoSp_rule,
  /*  823 */  iRegLNoSp_rule,
  /*  824 */  _SubL_immL0__ConvI2L_iRegIorL2I__rule,
  /*  825 */  _ConvI2L_iRegIorL2I__rule,
  /*  826 */  _ConvI2L_iRegIorL2I__rule,
  /*  827 */  _SubL_immL0__ConvI2L_iRegIorL2I__rule,
  /*  828 */  _Binary_iRegIorL2I_iRegIorL2I_rule,
  /*  829 */  iRegIorL2I_rule,
  /*  830 */  iRegL_rule,
  /*  831 */  iRegIorL2I_rule,
  /*  832 */  iRegL_rule,
  /*  833 */  iRegIorL2I_rule,
  /*  834 */  iRegIorL2I_rule,
  /*  835 */  iRegIorL2I_rule,
  /*  836 */  iRegIorL2I_rule,
  /*  837 */  iRegIorL2I_rule,
  /*  838 */  iRegIorL2I_rule,
  /*  839 */  iRegL_rule,
  /*  840 */  iRegL_rule,
  /*  841 */  iRegL_rule,
  /*  842 */  iRegL_rule,
  /*  843 */  _CastP2X_iRegP__rule,
  /*  844 */  iRegL_rule,
  /*  845 */  iRegL_rule,
  /*  846 */  iRegL_rule,
  /*  847 */  iRegIorL2I_rule,
  /*  848 */  iRegIorL2I_rule,
  /*  849 */  _XorI_iRegIorL2I_immI_M1_rule,
  /*  850 */  iRegL_rule,
  /*  851 */  _XorL_iRegL_immL_M1_rule,
  /*  852 */  iRegIorL2I_rule,
  /*  853 */  _XorI_iRegIorL2I_immI_M1_rule,
  /*  854 */  iRegL_rule,
  /*  855 */  _XorL_iRegL_immL_M1_rule,
  /*  856 */  immI_M1_rule,
  /*  857 */  _XorI_iRegIorL2I_iRegIorL2I_rule,
  /*  858 */  immL_M1_rule,
  /*  859 */  _XorL_iRegL_iRegL_rule,
  /*  860 */  iRegIorL2I_rule,
  /*  861 */  _XorI__URShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  862 */  iRegL_rule,
  /*  863 */  _XorL__URShiftL_iRegL_immI_immL_M1_rule,
  /*  864 */  iRegIorL2I_rule,
  /*  865 */  _XorI__RShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  866 */  iRegL_rule,
  /*  867 */  _XorL__RShiftL_iRegL_immI_immL_M1_rule,
  /*  868 */  iRegIorL2I_rule,
  /*  869 */  _XorI__RotateRight_iRegIorL2I_immI_immI_M1_rule,
  /*  870 */  iRegL_rule,
  /*  871 */  _XorL__RotateRight_iRegL_immI_immL_M1_rule,
  /*  872 */  iRegIorL2I_rule,
  /*  873 */  _XorI__LShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  874 */  iRegL_rule,
  /*  875 */  _XorL__LShiftL_iRegL_immI_immL_M1_rule,
  /*  876 */  immI_M1_rule,
  /*  877 */  _XorI__URShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  878 */  immI_M1_rule,
  /*  879 */  _XorI_iRegIorL2I__URShiftI_iRegIorL2I_immI_rule,
  /*  880 */  immL_M1_rule,
  /*  881 */  _XorL__URShiftL_iRegL_immI_iRegL_rule,
  /*  882 */  immL_M1_rule,
  /*  883 */  _XorL_iRegL__URShiftL_iRegL_immI_rule,
  /*  884 */  immI_M1_rule,
  /*  885 */  _XorI__RShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  886 */  immI_M1_rule,
  /*  887 */  _XorI_iRegIorL2I__RShiftI_iRegIorL2I_immI_rule,
  /*  888 */  immL_M1_rule,
  /*  889 */  _XorL__RShiftL_iRegL_immI_iRegL_rule,
  /*  890 */  immL_M1_rule,
  /*  891 */  _XorL_iRegL__RShiftL_iRegL_immI_rule,
  /*  892 */  immI_M1_rule,
  /*  893 */  _XorI__RotateRight_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  894 */  immI_M1_rule,
  /*  895 */  _XorI_iRegIorL2I__RotateRight_iRegIorL2I_immI_rule,
  /*  896 */  immL_M1_rule,
  /*  897 */  _XorL__RotateRight_iRegL_immI_iRegL_rule,
  /*  898 */  immL_M1_rule,
  /*  899 */  _XorL_iRegL__RotateRight_iRegL_immI_rule,
  /*  900 */  immI_M1_rule,
  /*  901 */  _XorI__LShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  902 */  immI_M1_rule,
  /*  903 */  _XorI_iRegIorL2I__LShiftI_iRegIorL2I_immI_rule,
  /*  904 */  immL_M1_rule,
  /*  905 */  _XorL__LShiftL_iRegL_immI_iRegL_rule,
  /*  906 */  immL_M1_rule,
  /*  907 */  _XorL_iRegL__LShiftL_iRegL_immI_rule,
  /*  908 */  iRegIorL2I_rule,
  /*  909 */  _XorI__URShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  910 */  iRegL_rule,
  /*  911 */  _XorL__URShiftL_iRegL_immI_immL_M1_rule,
  /*  912 */  iRegIorL2I_rule,
  /*  913 */  _XorI__RShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  914 */  iRegL_rule,
  /*  915 */  _XorL__RShiftL_iRegL_immI_immL_M1_rule,
  /*  916 */  iRegIorL2I_rule,
  /*  917 */  _XorI__RotateRight_iRegIorL2I_immI_immI_M1_rule,
  /*  918 */  iRegL_rule,
  /*  919 */  _XorL__RotateRight_iRegL_immI_immL_M1_rule,
  /*  920 */  iRegIorL2I_rule,
  /*  921 */  _XorI__LShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  922 */  iRegL_rule,
  /*  923 */  _XorL__LShiftL_iRegL_immI_immL_M1_rule,
  /*  924 */  iRegIorL2I_rule,
  /*  925 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  926 */  iRegL_rule,
  /*  927 */  _URShiftL_iRegL_immI_rule,
  /*  928 */  iRegIorL2I_rule,
  /*  929 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  930 */  iRegL_rule,
  /*  931 */  _RShiftL_iRegL_immI_rule,
  /*  932 */  iRegIorL2I_rule,
  /*  933 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  934 */  iRegL_rule,
  /*  935 */  _LShiftL_iRegL_immI_rule,
  /*  936 */  iRegIorL2I_rule,
  /*  937 */  _RotateRight_iRegIorL2I_immI_rule,
  /*  938 */  iRegL_rule,
  /*  939 */  _RotateRight_iRegL_immI_rule,
  /*  940 */  iRegIorL2I_rule,
  /*  941 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  942 */  iRegL_rule,
  /*  943 */  _URShiftL_iRegL_immI_rule,
  /*  944 */  iRegIorL2I_rule,
  /*  945 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  946 */  iRegL_rule,
  /*  947 */  _RShiftL_iRegL_immI_rule,
  /*  948 */  iRegIorL2I_rule,
  /*  949 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  950 */  iRegL_rule,
  /*  951 */  _LShiftL_iRegL_immI_rule,
  /*  952 */  iRegIorL2I_rule,
  /*  953 */  _RotateRight_iRegIorL2I_immI_rule,
  /*  954 */  iRegL_rule,
  /*  955 */  _RotateRight_iRegL_immI_rule,
  /*  956 */  iRegIorL2I_rule,
  /*  957 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  958 */  iRegL_rule,
  /*  959 */  _URShiftL_iRegL_immI_rule,
  /*  960 */  iRegIorL2I_rule,
  /*  961 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  962 */  iRegL_rule,
  /*  963 */  _RShiftL_iRegL_immI_rule,
  /*  964 */  iRegIorL2I_rule,
  /*  965 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  966 */  iRegL_rule,
  /*  967 */  _LShiftL_iRegL_immI_rule,
  /*  968 */  iRegIorL2I_rule,
  /*  969 */  _RotateRight_iRegIorL2I_immI_rule,
  /*  970 */  iRegL_rule,
  /*  971 */  _RotateRight_iRegL_immI_rule,
  /*  972 */  iRegIorL2I_rule,
  /*  973 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  974 */  iRegL_rule,
  /*  975 */  _URShiftL_iRegL_immI_rule,
  /*  976 */  iRegIorL2I_rule,
  /*  977 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  978 */  iRegL_rule,
  /*  979 */  _RShiftL_iRegL_immI_rule,
  /*  980 */  iRegIorL2I_rule,
  /*  981 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  982 */  iRegL_rule,
  /*  983 */  _LShiftL_iRegL_immI_rule,
  /*  984 */  iRegIorL2I_rule,
  /*  985 */  iRegL_rule,
  /*  986 */  iRegIorL2I_rule,
  /*  987 */  iRegL_rule,
  /*  988 */  iRegIorL2I_rule,
  /*  989 */  iRegL_rule,
  /*  990 */  _LShiftL_iRegL_immI_rule,
  /*  991 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  992 */  _LShiftL_iRegL_immI_rule,
  /*  993 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  994 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  995 */  _URShiftL_iRegL_immI_rule,
  /*  996 */  _AndI__URShiftI_iRegIorL2I_immI_immI_bitmask_rule,
  /*  997 */  _AndI_iRegIorL2I_immI_bitmask_rule,
  /*  998 */  _AndL_iRegL_immL_bitmask_rule,
  /*  999 */  _LShiftI__AndI_iRegIorL2I_immI_bitmask_immI_rule,
  /* 1000 */  _LShiftL__AndL_iRegL_immL_positive_bitmaskI_immI_rule,
  /* 1001 */  _ConvI2L__AndI_iRegIorL2I_immI_bitmask__rule,
  /* 1002 */  _ConvL2I__AndL_iRegL_immL_positive_bitmaskI__rule,
  /* 1003 */  _AndI_iRegI_immI_bitmask_rule,
  /* 1004 */  _LShiftL_iRegL_immI_rule,
  /* 1005 */  _URShiftL_iRegL_immI_rule,
  /* 1006 */  _LShiftI_iRegIorL2I_immI_rule,
  /* 1007 */  _URShiftI_iRegIorL2I_immI_rule,
  /* 1008 */  _LShiftL_iRegL_immI_rule,
  /* 1009 */  _URShiftL_iRegL_immI_rule,
  /* 1010 */  _LShiftI_iRegIorL2I_immI_rule,
  /* 1011 */  _URShiftI_iRegIorL2I_immI_rule,
  /* 1012 */  iRegI_rule,
  /* 1013 */  iRegL_rule,
  /* 1014 */  iRegI_rule,
  /* 1015 */  iRegL_rule,
  /* 1016 */  iRegI_rule,
  /* 1017 */  iRegL_rule,
  /* 1018 */  iRegL_rule,
  /* 1019 */  _ConvI2L_iRegIorL2I__rule,
  /* 1020 */  iRegL_rule,
  /* 1021 */  iRegIorL2I_rule,
  /* 1022 */  _RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_rule,
  /* 1023 */  iRegIorL2I_rule,
  /* 1024 */  _RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /* 1025 */  iRegIorL2I_rule,
  /* 1026 */  _URShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /* 1027 */  iRegL_rule,
  /* 1028 */  _RShiftL__LShiftL_iRegL_immI_48_immI_48_rule,
  /* 1029 */  iRegL_rule,
  /* 1030 */  _RShiftL__LShiftL_iRegL_immI_32_immI_32_rule,
  /* 1031 */  iRegL_rule,
  /* 1032 */  _RShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /* 1033 */  iRegL_rule,
  /* 1034 */  _URShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /* 1035 */  iRegIorL2I_rule,
  /* 1036 */  _AndI_iRegIorL2I_immI_255_rule,
  /* 1037 */  iRegIorL2I_rule,
  /* 1038 */  _AndI_iRegIorL2I_immI_65535_rule,
  /* 1039 */  iRegL_rule,
  /* 1040 */  _AndL_iRegL_immL_255_rule,
  /* 1041 */  iRegL_rule,
  /* 1042 */  _AndL_iRegL_immL_65535_rule,
  /* 1043 */  iRegL_rule,
  /* 1044 */  _AndL_iRegL_immL_4294967295_rule,
  /* 1045 */  iRegIorL2I_rule,
  /* 1046 */  iRegIorL2I_rule,
  /* 1047 */  iRegL_rule,
  /* 1048 */  iRegL_rule,
  /* 1049 */  iRegL_rule,
  /* 1050 */  iRegL_rule,
  /* 1051 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_56_immI_56_immIExt_rule,
  /* 1052 */  iRegL_rule,
  /* 1053 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_48_immI_48_immIExt_rule,
  /* 1054 */  iRegL_rule,
  /* 1055 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_32_immI_32_immIExt_rule,
  /* 1056 */  iRegL_rule,
  /* 1057 */  iRegL_rule,
  /* 1058 */  iRegL_rule,
  /* 1059 */  iRegIorL2I_rule,
  /* 1060 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_immIExt_rule,
  /* 1061 */  iRegIorL2I_rule,
  /* 1062 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_immIExt_rule,
  /* 1063 */  iRegIorL2I_rule,
  /* 1064 */  iRegIorL2I_rule,
  /* 1065 */  iRegL_rule,
  /* 1066 */  _LShiftL__ConvI2L_iRegIorL2I__immIExt_rule,
  /* 1067 */  iRegL_rule,
  /* 1068 */  iRegL_rule,
  /* 1069 */  _LShiftL__AndL_iRegL_immL_255_immIExt_rule,
  /* 1070 */  iRegL_rule,
  /* 1071 */  _LShiftL__AndL_iRegL_immL_65535_immIExt_rule,
  /* 1072 */  iRegL_rule,
  /* 1073 */  _LShiftL__AndL_iRegL_immL_4294967295_immIExt_rule,
  /* 1074 */  iRegL_rule,
  /* 1075 */  iRegL_rule,
  /* 1076 */  iRegL_rule,
  /* 1077 */  iRegIorL2I_rule,
  /* 1078 */  _LShiftI__AndI_iRegIorL2I_immI_255_immIExt_rule,
  /* 1079 */  iRegIorL2I_rule,
  /* 1080 */  _LShiftI__AndI_iRegIorL2I_immI_65535_immIExt_rule,
  /* 1081 */  iRegIorL2I_rule,
  /* 1082 */  iRegIorL2I_rule,
  /* 1083 */  vRegF_rule,
  /* 1084 */  vRegD_rule,
  /* 1085 */  vRegF_rule,
  /* 1086 */  vRegD_rule,
  /* 1087 */  vRegF_rule,
  /* 1088 */  vRegD_rule,
  /* 1089 */  vRegF_rule,
  /* 1090 */  vRegD_rule,
  /* 1091 */  vRegF_rule,
  /* 1092 */  vRegF_rule,
  /* 1093 */  vRegD_rule,
  /* 1094 */  vRegD_rule,
  /* 1095 */  _NegF_vRegF__rule,
  /* 1096 */  _NegF_vRegF__rule,
  /* 1097 */  _NegD_vRegD__rule,
  /* 1098 */  _NegD_vRegD__rule,
  /* 1099 */  _NegF_vRegF__rule,
  /* 1100 */  _NegD_vRegD__rule,
  /* 1101 */  vRegF_rule,
  /* 1102 */  vRegF_rule,
  /* 1103 */  vRegD_rule,
  /* 1104 */  vRegD_rule,
  /* 1105 */  vRegF_rule,
  /* 1106 */  vRegD_rule,
  /* 1107 */  iRegIorL2I_rule,
  /* 1108 */  iRegL_rule,
  /* 1109 */  _SubF_vRegF_vRegF_rule,
  /* 1110 */  _SubD_vRegD_vRegD_rule,
  /* 1111 */  vRegD_rule,
  /* 1112 */  vRegF_rule,
  /* 1113 */  vRegD_rule,
  /* 1114 */  vRegD_rule,
  /* 1115 */  vRegF_rule,
  /* 1116 */  vRegD_rule,
  /* 1117 */  vRegF_rule,
  /* 1118 */  0,
  /* 1119 */  iRegIorL2I_rule,
  /* 1120 */  iRegIorL2I_rule,
  /* 1121 */  iRegIorL2I_rule,
  /* 1122 */  iRegIorL2I_rule,
  /* 1123 */  iRegIorL2I_rule,
  /* 1124 */  iRegIorL2I_rule,
  /* 1125 */  iRegL_rule,
  /* 1126 */  iRegL_rule,
  /* 1127 */  iRegL_rule,
  /* 1128 */  iRegL_rule,
  /* 1129 */  iRegL_rule,
  /* 1130 */  iRegL_rule,
  /* 1131 */  iRegIorL2I_rule,
  /* 1132 */  _ConvI2L_iRegIorL2I__rule,
  /* 1133 */  iRegL_rule,
  /* 1134 */  iRegIorL2I_rule,
  /* 1135 */  iRegP_rule,
  /* 1136 */  vRegD_rule,
  /* 1137 */  vRegF_rule,
  /* 1138 */  vRegF_rule,
  /* 1139 */  vRegF_rule,
  /* 1140 */  iRegIorL2I_rule,
  /* 1141 */  iRegL_rule,
  /* 1142 */  vRegD_rule,
  /* 1143 */  vRegD_rule,
  /* 1144 */  iRegIorL2I_rule,
  /* 1145 */  iRegL_rule,
  /* 1146 */  vRegF_rule,
  /* 1147 */  iRegI_rule,
  /* 1148 */  vRegD_rule,
  /* 1149 */  iRegL_rule,
  /* 1150 */  iRegL_R11_rule,
  /* 1151 */  immL_rule,
  /* 1152 */  cmpOp_rule,
  /* 1153 */  cmpOp_rule,
  /* 1154 */  vRegF_rule,
  /* 1155 */  vRegD_rule,
  /* 1156 */  vRegF_rule,
  /* 1157 */  vRegD_rule,
  /* 1158 */  iRegIorL2I_rule,
  /* 1159 */  iRegIorL2I_rule,
  /* 1160 */  0,
  /* 1161 */  iRegI_rule,
  /* 1162 */  0,
  /* 1163 */  iRegI_rule,
  /* 1164 */  0,
  /* 1165 */  cmpOp_rule,
  /* 1166 */  cmpOpU_rule,
  /* 1167 */  cmpOpEqNe_rule,
  /* 1168 */  cmpOpEqNe_rule,
  /* 1169 */  cmpOpEqNe_rule,
  /* 1170 */  cmpOpEqNe_rule,
  /* 1171 */  cmpOpEqNe_rule,
  /* 1172 */  cmpOpUEqNeLtGe_rule,
  /* 1173 */  cmpOpUEqNeLtGe_rule,
  /* 1174 */  cmpOpLtGe_rule,
  /* 1175 */  cmpOpLtGe_rule,
  /* 1176 */  cmpOpEqNe_rule,
  /* 1177 */  cmpOpEqNe_rule,
  /* 1178 */  cmpOpLtGe_rule,
  /* 1179 */  cmpOpLtGe_rule,
  /* 1180 */  cmpOpEqNe_rule,
  /* 1181 */  cmpOpEqNe_rule,
  /* 1182 */  cmpOp_rule,
  /* 1183 */  cmpOpU_rule,
  /* 1184 */  iRegP_rule,
  /* 1185 */  0,
  /* 1186 */  0,
  /* 1187 */  0,
  /* 1188 */  0,
  /* 1189 */  0,
  /* 1190 */  0,
  /* 1191 */  iRegPNoSp_rule,
  /* 1192 */  iRegPNoSp_rule,
  /* 1193 */  0,
  /* 1194 */  0,
  /* 1195 */  0,
  /* 1196 */  0,
  /* 1197 */  iRegP_R4_rule,
  /* 1198 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1199 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1200 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1201 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1202 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /* 1203 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /* 1204 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /* 1205 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /* 1206 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /* 1207 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /* 1208 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1209 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1210 */  _Binary_iRegP_R1_iRegP_R3_rule,
  /* 1211 */  _Binary_iRegP_R1_iRegP_R3_rule,
  /* 1212 */  iRegP_R1_rule,
  /* 1213 */  iRegP_R1_rule,
  /* 1214 */  iRegP_R1_rule,
  /* 1215 */  iRegP_R2_rule,
  /* 1216 */  iRegP_R0_rule,
  /* 1217 */  iRegP_R2_rule,
  /* 1218 */  vmem2_rule,
  /* 1219 */  vmem4_rule,
  /* 1220 */  vmem8_rule,
  /* 1221 */  vmem16_rule,
  /* 1222 */  vmem2_rule,
  /* 1223 */  vmem4_rule,
  /* 1224 */  vmem8_rule,
  /* 1225 */  vmem16_rule,
  /* 1226 */  iRegIorL2I_rule,
  /* 1227 */  iRegIorL2I_rule,
  /* 1228 */  iRegIorL2I_rule,
  /* 1229 */  iRegIorL2I_rule,
  /* 1230 */  iRegL_rule,
  /* 1231 */  iRegIorL2I_rule,
  /* 1232 */  iRegIorL2I_rule,
  /* 1233 */  iRegIorL2I_rule,
  /* 1234 */  iRegIorL2I_rule,
  /* 1235 */  iRegL_rule,
  /* 1236 */  iRegIorL2I_rule,
  /* 1237 */  iRegIorL2I_rule,
  /* 1238 */  iRegIorL2I_rule,
  /* 1239 */  iRegIorL2I_rule,
  /* 1240 */  iRegIorL2I_rule,
  /* 1241 */  iRegIorL2I_rule,
  /* 1242 */  iRegIorL2I_rule,
  /* 1243 */  iRegIorL2I_rule,
  /* 1244 */  iRegIorL2I_rule,
  /* 1245 */  iRegIorL2I_rule,
  /* 1246 */  iRegIorL2I_rule,
  /* 1247 */  iRegIorL2I_rule,
  /* 1248 */  iRegL_rule,
  /* 1249 */  iRegL_rule,
  /* 1250 */  vRegF_rule,
  /* 1251 */  vRegF_rule,
  /* 1252 */  vRegD_rule,
  /* 1253 */  vRegF_rule,
  /* 1254 */  vRegF_rule,
  /* 1255 */  vRegD_rule,
  /* 1256 */  iRegIorL2I_rule,
  /* 1257 */  iRegIorL2I_rule,
  /* 1258 */  iRegIorL2I_rule,
  /* 1259 */  iRegIorL2I_rule,
  /* 1260 */  iRegIorL2I_rule,
  /* 1261 */  iRegIorL2I_rule,
  /* 1262 */  iRegIorL2I_rule,
  /* 1263 */  iRegIorL2I_rule,
  /* 1264 */  iRegIorL2I_rule,
  /* 1265 */  iRegIorL2I_rule,
  /* 1266 */  iRegIorL2I_rule,
  /* 1267 */  iRegIorL2I_rule,
  /* 1268 */  iRegIorL2I_rule,
  /* 1269 */  iRegIorL2I_rule,
  /* 1270 */  iRegIorL2I_rule,
  /* 1271 */  iRegIorL2I_rule,
  /* 1272 */  iRegIorL2I_rule,
  /* 1273 */  iRegIorL2I_rule,
  /* 1274 */  iRegL_rule,
  /* 1275 */  iRegL_rule,
  /* 1276 */  iRegL_rule,
  /* 1277 */  _Binary_vecD_iRegIorL2I_rule,
  /* 1278 */  _Binary_vecX_iRegIorL2I_rule,
  /* 1279 */  _Binary_vecD_iRegIorL2I_rule,
  /* 1280 */  _Binary_vecX_iRegIorL2I_rule,
  /* 1281 */  _Binary_vecD_iRegIorL2I_rule,
  /* 1282 */  _Binary_vecX_iRegIorL2I_rule,
  /* 1283 */  _Binary_vecX_iRegL_rule,
  /* 1284 */  _Binary_vecD_vRegF_rule,
  /* 1285 */  _Binary_vecX_vRegF_rule,
  /* 1286 */  _Binary_vecX_vRegD_rule,
  /* 1287 */  vecD_rule,
  /* 1288 */  vecX_rule,
  /* 1289 */  vecD_rule,
  /* 1290 */  vecX_rule,
  /* 1291 */  vecD_rule,
  /* 1292 */  vecX_rule,
  /* 1293 */  vecX_rule,
  /* 1294 */  vecD_rule,
  /* 1295 */  vecX_rule,
  /* 1296 */  vecX_rule,
  /* 1297 */  _Binary_vecD_vecD_rule,
  /* 1298 */  _Binary_vecX_vecX_rule,
  /* 1299 */  vecX_rule,
  /* 1300 */  vecD_rule,
  /* 1301 */  _ReplicateB_immI_M1__rule,
  /* 1302 */  vecD_rule,
  /* 1303 */  _ReplicateS_immI_M1__rule,
  /* 1304 */  vecD_rule,
  /* 1305 */  _ReplicateI_immI_M1__rule,
  /* 1306 */  vecX_rule,
  /* 1307 */  _ReplicateB_immI_M1__rule,
  /* 1308 */  vecX_rule,
  /* 1309 */  _ReplicateS_immI_M1__rule,
  /* 1310 */  vecX_rule,
  /* 1311 */  _ReplicateI_immI_M1__rule,
  /* 1312 */  vecX_rule,
  /* 1313 */  _ReplicateL_immL_M1__rule,
  /* 1314 */  vecD_rule,
  /* 1315 */  _XorV_vecD__ReplicateB_immI_M1__rule,
  /* 1316 */  vecD_rule,
  /* 1317 */  _XorV__ReplicateB_immI_M1__vecD_rule,
  /* 1318 */  vecD_rule,
  /* 1319 */  _XorV_vecD__ReplicateS_immI_M1__rule,
  /* 1320 */  vecD_rule,
  /* 1321 */  _XorV__ReplicateS_immI_M1__vecD_rule,
  /* 1322 */  vecD_rule,
  /* 1323 */  _XorV_vecD__ReplicateI_immI_M1__rule,
  /* 1324 */  vecD_rule,
  /* 1325 */  _XorV__ReplicateI_immI_M1__vecD_rule,
  /* 1326 */  vecX_rule,
  /* 1327 */  _XorV_vecX__ReplicateB_immI_M1__rule,
  /* 1328 */  vecX_rule,
  /* 1329 */  _XorV__ReplicateB_immI_M1__vecX_rule,
  /* 1330 */  vecX_rule,
  /* 1331 */  _XorV_vecX__ReplicateS_immI_M1__rule,
  /* 1332 */  vecX_rule,
  /* 1333 */  _XorV__ReplicateS_immI_M1__vecX_rule,
  /* 1334 */  vecX_rule,
  /* 1335 */  _XorV_vecX__ReplicateI_immI_M1__rule,
  /* 1336 */  vecX_rule,
  /* 1337 */  _XorV__ReplicateI_immI_M1__vecX_rule,
  /* 1338 */  vecX_rule,
  /* 1339 */  _XorV_vecX__ReplicateL_immL_M1__rule,
  /* 1340 */  vecX_rule,
  /* 1341 */  _XorV__ReplicateL_immL_M1__vecX_rule,
  /* 1342 */  vecD_rule,
  /* 1343 */  vecX_rule,
  /* 1344 */  vecD_rule,
  /* 1345 */  vecX_rule,
  /* 1346 */  vecD_rule,
  /* 1347 */  vecX_rule,
  /* 1348 */  vecD_rule,
  /* 1349 */  vecX_rule,
  /* 1350 */  vecD_rule,
  /* 1351 */  vecX_rule,
  /* 1352 */  vecD_rule,
  /* 1353 */  vecX_rule,
  /* 1354 */  vecX_rule,
  /* 1355 */  vecX_rule,
  /* 1356 */  _Binary_vecD_vecD_rule,
  /* 1357 */  _Binary_vecX_vecX_rule,
  /* 1358 */  vecD_rule,
  /* 1359 */  vecX_rule,
  /* 1360 */  vecD_rule,
  /* 1361 */  vecX_rule,
  /* 1362 */  vecD_rule,
  /* 1363 */  vecX_rule,
  /* 1364 */  vecX_rule,
  /* 1365 */  vecD_rule,
  /* 1366 */  vecX_rule,
  /* 1367 */  vecD_rule,
  /* 1368 */  vecX_rule,
  /* 1369 */  vecX_rule,
  /* 1370 */  vecD_rule,
  /* 1371 */  vecX_rule,
  /* 1372 */  vecD_rule,
  /* 1373 */  vecX_rule,
  /* 1374 */  _SubVF_vecD_vecD_rule,
  /* 1375 */  _SubVF_vecX_vecX_rule,
  /* 1376 */  _SubVD_vecX_vecX_rule,
  /* 1377 */  iRegIorL2I_rule,
  /* 1378 */  iRegIorL2I_rule,
  /* 1379 */  immI_rule,
  /* 1380 */  immI_rule,
  /* 1381 */  iRegIorL2I_rule,
  /* 1382 */  iRegIorL2I_rule,
  /* 1383 */  immI_rule,
  /* 1384 */  immI_rule,
  /* 1385 */  iRegIorL2I_rule,
  /* 1386 */  iRegIorL2I_rule,
  /* 1387 */  immI_rule,
  /* 1388 */  immI_rule,
  /* 1389 */  iRegL_rule,
  /* 1390 */  immI0_rule,
  /* 1391 */  vRegF_rule,
  /* 1392 */  vRegF_rule,
  /* 1393 */  vRegD_rule,
  /* 1394 */  iRegIorL2I_rule,
  /* 1395 */  iRegIorL2I_rule,
  /* 1396 */  iRegIorL2I_rule,
  /* 1397 */  iRegIorL2I_rule,
  /* 1398 */  vRegF_rule,
  /* 1399 */  vRegF_rule,
  /* 1400 */  vRegF_rule,
  /* 1401 */  vRegF_rule,
  /* 1402 */  vRegD_rule,
  /* 1403 */  vRegD_rule,
  /* 1404 */  vecD_rule,
  /* 1405 */  vecX_rule,
  /* 1406 */  vecD_rule,
  /* 1407 */  vecX_rule,
  /* 1408 */  vecD_rule,
  /* 1409 */  vecX_rule,
  /* 1410 */  vecX_rule,
  /* 1411 */  vecD_rule,
  /* 1412 */  vecX_rule,
  /* 1413 */  vecX_rule,
  /* 1414 */  vecD_rule,
  /* 1415 */  vecX_rule,
  /* 1416 */  vecD_rule,
  /* 1417 */  vecX_rule,
  /* 1418 */  vecD_rule,
  /* 1419 */  vecX_rule,
  /* 1420 */  vecX_rule,
  /* 1421 */  vecD_rule,
  /* 1422 */  vecX_rule,
  /* 1423 */  vecX_rule,
  /* 1424 */  vecD_rule,
  /* 1425 */  vecX_rule,
  /* 1426 */  vecD_rule,
  /* 1427 */  vecX_rule,
  /* 1428 */  vecD_rule,
  /* 1429 */  vecX_rule,
  /* 1430 */  vecD_rule,
  /* 1431 */  vecX_rule,
  /* 1432 */  vecX_rule,
  /* 1433 */  vecD_rule,
  /* 1434 */  _MulVS_vecD_vecD_rule,
  /* 1435 */  vecX_rule,
  /* 1436 */  _MulVS_vecX_vecX_rule,
  /* 1437 */  vecD_rule,
  /* 1438 */  _MulVI_vecD_vecD_rule,
  /* 1439 */  vecX_rule,
  /* 1440 */  _MulVI_vecX_vecX_rule,
  /* 1441 */  vecD_rule,
  /* 1442 */  vecX_rule,
  /* 1443 */  vecX_rule,
  /* 1444 */  vecD_rule,
  /* 1445 */  vecX_rule,
  /* 1446 */  vecD_rule,
  /* 1447 */  vecX_rule,
  /* 1448 */  vecD_rule,
  /* 1449 */  vecD_rule,
  /* 1450 */  vecX_rule,
  /* 1451 */  vecX_rule,
  /* 1452 */  vecX_rule,
  /* 1453 */  vecX_rule,
  /* 1454 */  vecX_rule,
  /* 1455 */  vecD_rule,
  /* 1456 */  vecX_rule,
  /* 1457 */  vecX_rule,
  /* 1458 */  vecD_rule,
  /* 1459 */  vecX_rule,
  /* 1460 */  vecD_rule,
  /* 1461 */  vecX_rule,
  /* 1462 */  vecD_rule,
  /* 1463 */  vecX_rule,
  /* 1464 */  vecD_rule,
  /* 1465 */  vecX_rule,
  /* 1466 */  vecD_rule,
  /* 1467 */  vecX_rule,
  /* 1468 */  vecD_rule,
  /* 1469 */  vecX_rule,
  /* 1470 */  vecD_rule,
  /* 1471 */  vecX_rule,
  /* 1472 */  vecD_rule,
  /* 1473 */  vecX_rule,
  /* 1474 */  vecD_rule,
  /* 1475 */  vecX_rule,
  /* 1476 */  vecD_rule,
  /* 1477 */  vecX_rule,
  /* 1478 */  vecD_rule,
  /* 1479 */  vecX_rule,
  /* 1480 */  vecD_rule,
  /* 1481 */  vecX_rule,
  /* 1482 */  vecD_rule,
  /* 1483 */  vecX_rule,
  /* 1484 */  vecD_rule,
  /* 1485 */  vecX_rule,
  /* 1486 */  vecD_rule,
  /* 1487 */  vecX_rule,
  /* 1488 */  vecD_rule,
  /* 1489 */  vecX_rule,
  /* 1490 */  vecD_rule,
  /* 1491 */  vecX_rule,
  /* 1492 */  vecD_rule,
  /* 1493 */  vecX_rule,
  /* 1494 */  vecD_rule,
  /* 1495 */  vecX_rule,
  /* 1496 */  vecD_rule,
  /* 1497 */  vecX_rule,
  /* 1498 */  vecD_rule,
  /* 1499 */  vecX_rule,
  /* 1500 */  vecX_rule,
  /* 1501 */  vecX_rule,
  /* 1502 */  vecX_rule,
  /* 1503 */  vecX_rule,
  /* 1504 */  vecX_rule,
  /* 1505 */  vecX_rule,
  /* 1506 */  vecD_rule,
  /* 1507 */  _RShiftVB_vecD__RShiftCntV_immI__rule,
  /* 1508 */  vecX_rule,
  /* 1509 */  _RShiftVB_vecX__RShiftCntV_immI__rule,
  /* 1510 */  vecD_rule,
  /* 1511 */  _RShiftVS_vecD__RShiftCntV_immI__rule,
  /* 1512 */  vecX_rule,
  /* 1513 */  _RShiftVS_vecX__RShiftCntV_immI__rule,
  /* 1514 */  vecD_rule,
  /* 1515 */  _RShiftVI_vecD__RShiftCntV_immI__rule,
  /* 1516 */  vecX_rule,
  /* 1517 */  _RShiftVI_vecX__RShiftCntV_immI__rule,
  /* 1518 */  vecX_rule,
  /* 1519 */  _RShiftVL_vecX__RShiftCntV_immI__rule,
  /* 1520 */  vecD_rule,
  /* 1521 */  _URShiftVB_vecD__RShiftCntV_immI__rule,
  /* 1522 */  vecX_rule,
  /* 1523 */  _URShiftVB_vecX__RShiftCntV_immI__rule,
  /* 1524 */  vecD_rule,
  /* 1525 */  _URShiftVS_vecD__RShiftCntV_immI__rule,
  /* 1526 */  vecX_rule,
  /* 1527 */  _URShiftVS_vecX__RShiftCntV_immI__rule,
  /* 1528 */  vecD_rule,
  /* 1529 */  _URShiftVI_vecD__RShiftCntV_immI__rule,
  /* 1530 */  vecX_rule,
  /* 1531 */  _URShiftVI_vecX__RShiftCntV_immI__rule,
  /* 1532 */  vecX_rule,
  /* 1533 */  _URShiftVL_vecX__RShiftCntV_immI__rule,
  /* 1534 */  vecD_rule,
  /* 1535 */  vecX_rule,
  /* 1536 */  vecX_rule,
  /* 1537 */  vecD_rule,
  /* 1538 */  vecX_rule,
  /* 1539 */  vecX_rule,
  /* 1540 */  vecX_rule,
  /* 1541 */  vmemA_rule,
  /* 1542 */  vmemA_rule,
  /* 1543 */  vReg_rule,
  /* 1544 */  vReg_rule,
  /* 1545 */  vReg_rule,
  /* 1546 */  vReg_rule,
  /* 1547 */  vReg_rule,
  /* 1548 */  vReg_rule,
  /* 1549 */  vReg_rule,
  /* 1550 */  vReg_rule,
  /* 1551 */  vReg_rule,
  /* 1552 */  vReg_rule,
  /* 1553 */  _ReplicateB_immI_M1__rule,
  /* 1554 */  vReg_rule,
  /* 1555 */  _ReplicateS_immI_M1__rule,
  /* 1556 */  vReg_rule,
  /* 1557 */  _ReplicateI_immI_M1__rule,
  /* 1558 */  vReg_rule,
  /* 1559 */  _ReplicateL_immL_M1__rule,
  /* 1560 */  vReg_rule,
  /* 1561 */  _XorV_vReg__ReplicateB_immI_M1__rule,
  /* 1562 */  vReg_rule,
  /* 1563 */  _XorV__ReplicateB_immI_M1__vReg_rule,
  /* 1564 */  vReg_rule,
  /* 1565 */  _XorV_vReg__ReplicateS_immI_M1__rule,
  /* 1566 */  vReg_rule,
  /* 1567 */  _XorV__ReplicateS_immI_M1__vReg_rule,
  /* 1568 */  vReg_rule,
  /* 1569 */  _XorV_vReg__ReplicateI_immI_M1__rule,
  /* 1570 */  vReg_rule,
  /* 1571 */  _XorV__ReplicateI_immI_M1__vReg_rule,
  /* 1572 */  vReg_rule,
  /* 1573 */  _XorV_vReg__ReplicateL_immL_M1__rule,
  /* 1574 */  vReg_rule,
  /* 1575 */  _XorV__ReplicateL_immL_M1__vReg_rule,
  /* 1576 */  vReg_rule,
  /* 1577 */  vReg_rule,
  /* 1578 */  vReg_rule,
  /* 1579 */  vReg_rule,
  /* 1580 */  vReg_rule,
  /* 1581 */  vReg_rule,
  /* 1582 */  vReg_rule,
  /* 1583 */  vReg_rule,
  /* 1584 */  vReg_rule,
  /* 1585 */  vReg_rule,
  /* 1586 */  _NegVF_vReg__rule,
  /* 1587 */  _NegVF_vReg__rule,
  /* 1588 */  _NegVD_vReg__rule,
  /* 1589 */  _NegVD_vReg__rule,
  /* 1590 */  _NegVF_vReg__rule,
  /* 1591 */  _NegVD_vReg__rule,
  /* 1592 */  vReg_rule,
  /* 1593 */  _MulVB_vReg_vReg_rule,
  /* 1594 */  vReg_rule,
  /* 1595 */  _MulVS_vReg_vReg_rule,
  /* 1596 */  vReg_rule,
  /* 1597 */  _MulVI_vReg_vReg_rule,
  /* 1598 */  vReg_rule,
  /* 1599 */  _MulVL_vReg_vReg_rule,
  /* 1600 */  vReg_rule,
  /* 1601 */  vReg_rule,
  /* 1602 */  vReg_rule,
  /* 1603 */  vReg_rule,
  /* 1604 */  vReg_rule,
  /* 1605 */  vReg_rule,
  /* 1606 */  vReg_rule,
  /* 1607 */  vReg_rule,
  /* 1608 */  vReg_rule,
  /* 1609 */  vReg_rule,
  /* 1610 */  iRegIorL2I_rule,
  /* 1611 */  iRegIorL2I_rule,
  /* 1612 */  iRegIorL2I_rule,
  /* 1613 */  iRegL_rule,
  /* 1614 */  vRegF_rule,
  /* 1615 */  vRegD_rule,
  /* 1616 */  vRegF_rule,
  /* 1617 */  vRegD_rule,
  /* 1618 */  vRegF_rule,
  /* 1619 */  vRegD_rule,
  /* 1620 */  vReg_rule,
  /* 1621 */  iRegIorL2I_rule,
  /* 1622 */  iRegIorL2I_rule,
  /* 1623 */  iRegIorL2I_rule,
  /* 1624 */  iRegL_rule,
  /* 1625 */  immI8_rule,
  /* 1626 */  immI8_shift8_rule,
  /* 1627 */  immI8_shift8_rule,
  /* 1628 */  immL8_shift8_rule,
  /* 1629 */  vRegF_rule,
  /* 1630 */  vRegD_rule,
  /* 1631 */  vReg_rule,
  /* 1632 */  vReg_rule,
  /* 1633 */  vReg_rule,
  /* 1634 */  vReg_rule,
  /* 1635 */  vReg_rule,
  /* 1636 */  vReg_rule,
  /* 1637 */  vReg_rule,
  /* 1638 */  vReg_rule,
  /* 1639 */  vReg_rule,
  /* 1640 */  vReg_rule,
  /* 1641 */  vReg_rule,
  /* 1642 */  vReg_rule,
  /* 1643 */  vReg_rule,
  /* 1644 */  vReg_rule,
  /* 1645 */  vReg_rule,
  /* 1646 */  vReg_rule,
  /* 1647 */  vReg_rule,
  /* 1648 */  vReg_rule,
  /* 1649 */  vReg_rule,
  /* 1650 */  vReg_rule,
  /* 1651 */  vReg_rule,
  /* 1652 */  vReg_rule,
  /* 1653 */  vReg_rule,
  /* 1654 */  vReg_rule,
  /* 1655 */  vReg_rule,
  /* 1656 */  vReg_rule,
  /* 1657 */  vReg_rule,
  /* 1658 */  vReg_rule,
  /* 1659 */  vReg_rule,
  /* 1660 */  vReg_rule,
  /* 1661 */  indirect_rule,
  /* 1662 */  indirect_rule,
  /* 1663 */  indirect_rule,
  /* 1664 */  indirect_rule,
  /* 1665 */  indirect_rule,
  /* 1666 */  indirect_rule,
  /* 1667 */  indirect_rule,
  /* 1668 */  indirect_rule,
  /* 1669 */  indirect_rule,
  /* 1670 */  indirect_rule,
  /* 1671 */  indirect_rule,
  /* 1672 */  indirect_rule,
  /* 1673 */  memory8_rule,
  /* 1674 */  indirect_rule,
  /* 1675 */  indirect_rule,
  /* 1676 */  indirect_rule,
  /* 1677 */  indirect_rule,
  /* 1678 */  indirect_rule,
  /* 1679 */  indirect_rule,
  /* 1680 */  indirect_rule,
  /* 1681 */  indirect_rule,
  /* 1682 */  indirect_rule,
  // last instruction
  0 // no trailing comma
};

const        int   rightOp[] = {
  /*    0 */  0,
  /*    1 */  0,
  /*    2 */  0,
  /*    3 */  0,
  /*    4 */  0,
  /*    5 */  0,
  /*    6 */  0,
  /*    7 */  0,
  /*    8 */  0,
  /*    9 */  0,
  /*   10 */  0,
  /*   11 */  0,
  /*   12 */  0,
  /*   13 */  0,
  /*   14 */  0,
  /*   15 */  0,
  /*   16 */  0,
  /*   17 */  0,
  /*   18 */  0,
  /*   19 */  0,
  /*   20 */  0,
  /*   21 */  0,
  /*   22 */  0,
  /*   23 */  0,
  /*   24 */  0,
  /*   25 */  0,
  /*   26 */  0,
  /*   27 */  0,
  /*   28 */  0,
  /*   29 */  0,
  /*   30 */  0,
  /*   31 */  0,
  /*   32 */  0,
  /*   33 */  0,
  /*   34 */  0,
  /*   35 */  0,
  /*   36 */  0,
  /*   37 */  0,
  /*   38 */  0,
  /*   39 */  0,
  /*   40 */  0,
  /*   41 */  0,
  /*   42 */  0,
  /*   43 */  0,
  /*   44 */  0,
  /*   45 */  0,
  /*   46 */  0,
  /*   47 */  0,
  /*   48 */  0,
  /*   49 */  0,
  /*   50 */  0,
  /*   51 */  0,
  /*   52 */  0,
  /*   53 */  0,
  /*   54 */  0,
  /*   55 */  0,
  /*   56 */  0,
  /*   57 */  0,
  /*   58 */  0,
  /*   59 */  0,
  /*   60 */  0,
  /*   61 */  0,
  /*   62 */  0,
  /*   63 */  0,
  /*   64 */  0,
  /*   65 */  0,
  /*   66 */  0,
  /*   67 */  0,
  /*   68 */  0,
  /*   69 */  0,
  /*   70 */  0,
  /*   71 */  0,
  /*   72 */  0,
  /*   73 */  0,
  /*   74 */  0,
  /*   75 */  0,
  /*   76 */  0,
  /*   77 */  0,
  /*   78 */  0,
  /*   79 */  0,
  /*   80 */  0,
  /*   81 */  0,
  /*   82 */  0,
  /*   83 */  0,
  /*   84 */  0,
  /*   85 */  0,
  /*   86 */  0,
  /*   87 */  0,
  /*   88 */  0,
  /*   89 */  0,
  /*   90 */  0,
  /*   91 */  0,
  /*   92 */  0,
  /*   93 */  0,
  /*   94 */  0,
  /*   95 */  0,
  /*   96 */  0,
  /*   97 */  0,
  /*   98 */  0,
  /*   99 */  0,
  /*  100 */  0,
  /*  101 */  0,
  /*  102 */  0,
  /*  103 */  0,
  /*  104 */  0,
  /*  105 */  0,
  /*  106 */  0,
  /*  107 */  0,
  /*  108 */  0,
  /*  109 */  0,
  /*  110 */  0,
  /*  111 */  0,
  /*  112 */  0,
  /*  113 */  0,
  /*  114 */  0,
  /*  115 */  0,
  /*  116 */  0,
  /*  117 */  0,
  /*  118 */  0,
  /*  119 */  0,
  /*  120 */  0,
  /*  121 */  0,
  /*  122 */  0,
  /*  123 */  0,
  /*  124 */  0,
  /*  125 */  0,
  /*  126 */  0,
  /*  127 */  0,
  /*  128 */  0,
  /*  129 */  0,
  /*  130 */  0,
  /*  131 */  0,
  /*  132 */  0,
  /*  133 */  0,
  /*  134 */  0,
  /*  135 */  0,
  /*  136 */  0,
  /*  137 */  0,
  /*  138 */  0,
  /*  139 */  0,
  /*  140 */  0,
  /*  141 */  0,
  /*  142 */  0,
  /*  143 */  0,
  /*  144 */  0,
  /*  145 */  0,
  /*  146 */  0,
  /*  147 */  0,
  /*  148 */  0,
  /*  149 */  0,
  /*  150 */  _LShiftL__ConvI2L_iRegI__immIScale_rule,
  /*  151 */  _LShiftL_iRegL_immIScale_rule,
  /*  152 */  _ConvI2L_iRegI__rule,
  /*  153 */  iRegL_rule,
  /*  154 */  immIOffset_rule,
  /*  155 */  immIOffset1_rule,
  /*  156 */  immIOffset2_rule,
  /*  157 */  immIOffset4_rule,
  /*  158 */  immIOffset8_rule,
  /*  159 */  immIOffset16_rule,
  /*  160 */  immLoffset_rule,
  /*  161 */  immLoffset1_rule,
  /*  162 */  immLoffset2_rule,
  /*  163 */  immLoffset4_rule,
  /*  164 */  immLoffset8_rule,
  /*  165 */  immLoffset16_rule,
  /*  166 */  0,
  /*  167 */  _LShiftL__ConvI2L_iRegI__immIScale_rule,
  /*  168 */  _LShiftL_iRegL_immIScale_rule,
  /*  169 */  _ConvI2L_iRegI__rule,
  /*  170 */  iRegL_rule,
  /*  171 */  immIOffset_rule,
  /*  172 */  immLoffset_rule,
  /*  173 */  immL_pc_off_rule,
  /*  174 */  0,
  /*  175 */  0,
  /*  176 */  0,
  /*  177 */  0,
  /*  178 */  0,
  /*  179 */  0,
  /*  180 */  0,
  /*  181 */  0,
  /*  182 */  0,
  /*  183 */  0,
  /*  184 */  0,
  /*  185 */  0,
  /*  186 */  0,
  /*  187 */  vmemA_immIOffset4_rule,
  /*  188 */  vmemA_immLOffset4_rule,
  // last operand
  /*  189 */  0,
  /*  190 */  0,
  /*  191 */  0,
  /*  192 */  0,
  /*  193 */  0,
  /*  194 */  0,
  /*  195 */  0,
  /*  196 */  0,
  /*  197 */  0,
  /*  198 */  0,
  /*  199 */  0,
  // last operand class
  /*  200 */  0,
  /*  201 */  immIScale_rule,
  /*  202 */  immIScale_rule,
  /*  203 */  0,
  /*  204 */  0,
  /*  205 */  0,
  /*  206 */  0,
  /*  207 */  0,
  /*  208 */  0,
  /*  209 */  0,
  /*  210 */  0,
  /*  211 */  0,
  /*  212 */  0,
  /*  213 */  0,
  /*  214 */  0,
  /*  215 */  0,
  /*  216 */  0,
  /*  217 */  0,
  /*  218 */  0,
  /*  219 */  iRegP_rule,
  /*  220 */  iRegLNoSp_rule,
  /*  221 */  iRegINoSp_rule,
  /*  222 */  iRegNNoSp_rule,
  /*  223 */  iRegI_rule,
  /*  224 */  iRegL_rule,
  /*  225 */  iRegN_rule,
  /*  226 */  rFlagsReg_rule,
  /*  227 */  iRegIorL2I_rule,
  /*  228 */  rFlagsRegU_rule,
  /*  229 */  iRegIorL2I_rule,
  /*  230 */  immI0_rule,
  /*  231 */  immI0_rule,
  /*  232 */  immL0_rule,
  /*  233 */  iRegL_rule,
  /*  234 */  immP0_rule,
  /*  235 */  iRegP_rule,
  /*  236 */  immN0_rule,
  /*  237 */  iRegN_rule,
  /*  238 */  vRegF_rule,
  /*  239 */  vRegD_rule,
  /*  240 */  0,
  /*  241 */  0,
  /*  242 */  immIScale_rule,
  /*  243 */  iRegIorL2I_rule,
  /*  244 */  iRegIorL2I_rule,
  /*  245 */  iRegL_rule,
  /*  246 */  iRegL_rule,
  /*  247 */  _ConvI2L_iRegIorL2I__rule,
  /*  248 */  _ConvI2L_iRegIorL2I__rule,
  /*  249 */  immI_M1_rule,
  /*  250 */  immL_M1_rule,
  /*  251 */  iRegIorL2I_rule,
  /*  252 */  iRegL_rule,
  /*  253 */  immI_rule,
  /*  254 */  immI_M1_rule,
  /*  255 */  immI_rule,
  /*  256 */  immL_M1_rule,
  /*  257 */  immI_rule,
  /*  258 */  immI_M1_rule,
  /*  259 */  immI_rule,
  /*  260 */  immL_M1_rule,
  /*  261 */  immI_rule,
  /*  262 */  immI_M1_rule,
  /*  263 */  immI_rule,
  /*  264 */  immL_M1_rule,
  /*  265 */  immI_rule,
  /*  266 */  immI_M1_rule,
  /*  267 */  immI_rule,
  /*  268 */  immL_M1_rule,
  /*  269 */  iRegIorL2I_rule,
  /*  270 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  271 */  iRegL_rule,
  /*  272 */  _URShiftL_iRegL_immI_rule,
  /*  273 */  iRegIorL2I_rule,
  /*  274 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  275 */  iRegL_rule,
  /*  276 */  _RShiftL_iRegL_immI_rule,
  /*  277 */  iRegIorL2I_rule,
  /*  278 */  _RotateRight_iRegIorL2I_immI_rule,
  /*  279 */  iRegL_rule,
  /*  280 */  _RotateRight_iRegL_immI_rule,
  /*  281 */  iRegIorL2I_rule,
  /*  282 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  283 */  iRegL_rule,
  /*  284 */  _LShiftL_iRegL_immI_rule,
  /*  285 */  immI_bitmask_rule,
  /*  286 */  immI_bitmask_rule,
  /*  287 */  immL_bitmask_rule,
  /*  288 */  immI_rule,
  /*  289 */  immL_positive_bitmaskI_rule,
  /*  290 */  immI_rule,
  /*  291 */  0,
  /*  292 */  0,
  /*  293 */  immI_bitmask_rule,
  /*  294 */  immI_16_rule,
  /*  295 */  immI_16_rule,
  /*  296 */  immI_24_rule,
  /*  297 */  immI_24_rule,
  /*  298 */  immI_24_rule,
  /*  299 */  immI_48_rule,
  /*  300 */  immI_48_rule,
  /*  301 */  immI_32_rule,
  /*  302 */  immI_32_rule,
  /*  303 */  immI_56_rule,
  /*  304 */  immI_56_rule,
  /*  305 */  immI_56_rule,
  /*  306 */  immI_255_rule,
  /*  307 */  immI_65535_rule,
  /*  308 */  immL_255_rule,
  /*  309 */  immL_65535_rule,
  /*  310 */  immL_4294967295_rule,
  /*  311 */  immIExt_rule,
  /*  312 */  immIExt_rule,
  /*  313 */  immIExt_rule,
  /*  314 */  immIExt_rule,
  /*  315 */  immIExt_rule,
  /*  316 */  immIExt_rule,
  /*  317 */  immIExt_rule,
  /*  318 */  immIExt_rule,
  /*  319 */  immIExt_rule,
  /*  320 */  immIExt_rule,
  /*  321 */  immIExt_rule,
  /*  322 */  0,
  /*  323 */  vRegF_rule,
  /*  324 */  _NegF_vRegF__rule,
  /*  325 */  0,
  /*  326 */  vRegD_rule,
  /*  327 */  _NegD_vRegD__rule,
  /*  328 */  vRegF_rule,
  /*  329 */  vRegD_rule,
  /*  330 */  iRegIorL2I_rule,
  /*  331 */  iRegL_rule,
  /*  332 */  immI0_rule,
  /*  333 */  immL0_rule,
  /*  334 */  immP0_rule,
  /*  335 */  immN0_rule,
  /*  336 */  immP0_rule,
  /*  337 */  immI0_rule,
  /*  338 */  immL0_rule,
  /*  339 */  immL_rule,
  /*  340 */  immL0_rule,
  /*  341 */  immI_rule,
  /*  342 */  immI0_rule,
  /*  343 */  iRegL_rule,
  /*  344 */  iRegIorL2I_rule,
  /*  345 */  iRegP_R0_rule,
  /*  346 */  iRegI_R2_rule,
  /*  347 */  iRegI_R4_rule,
  /*  348 */  iRegI_R4_rule,
  /*  349 */  iRegI_R2_rule,
  /*  350 */  immI_le_4_rule,
  /*  351 */  immI_1_rule,
  /*  352 */  iRegP_R3_rule,
  /*  353 */  iRegI_R3_rule,
  /*  354 */  iRegIorL2I_rule,
  /*  355 */  iRegIorL2I_rule,
  /*  356 */  iRegL_rule,
  /*  357 */  vRegF_rule,
  /*  358 */  vRegF_rule,
  /*  359 */  vRegD_rule,
  /*  360 */  vecD_rule,
  /*  361 */  vecX_rule,
  /*  362 */  0,
  /*  363 */  0,
  /*  364 */  0,
  /*  365 */  0,
  /*  366 */  _ReplicateB_immI_M1__rule,
  /*  367 */  vecD_rule,
  /*  368 */  _ReplicateS_immI_M1__rule,
  /*  369 */  vecD_rule,
  /*  370 */  _ReplicateI_immI_M1__rule,
  /*  371 */  vecD_rule,
  /*  372 */  _ReplicateB_immI_M1__rule,
  /*  373 */  vecX_rule,
  /*  374 */  _ReplicateS_immI_M1__rule,
  /*  375 */  vecX_rule,
  /*  376 */  _ReplicateI_immI_M1__rule,
  /*  377 */  vecX_rule,
  /*  378 */  _ReplicateL_immL_M1__rule,
  /*  379 */  vecX_rule,
  /*  380 */  vecD_rule,
  /*  381 */  vecX_rule,
  /*  382 */  vecX_rule,
  /*  383 */  vecD_rule,
  /*  384 */  vecX_rule,
  /*  385 */  vecD_rule,
  /*  386 */  vecX_rule,
  /*  387 */  0,
  /*  388 */  vecD_rule,
  /*  389 */  _NegVF_vecD__rule,
  /*  390 */  0,
  /*  391 */  vecX_rule,
  /*  392 */  _NegVF_vecX__rule,
  /*  393 */  0,
  /*  394 */  vecX_rule,
  /*  395 */  _NegVD_vecX__rule,
  /*  396 */  0,
  /*  397 */  0,
  /*  398 */  _RShiftCntV_immI__rule,
  /*  399 */  _RShiftCntV_immI__rule,
  /*  400 */  _RShiftCntV_immI__rule,
  /*  401 */  _RShiftCntV_immI__rule,
  /*  402 */  _RShiftCntV_immI__rule,
  /*  403 */  _RShiftCntV_immI__rule,
  /*  404 */  _RShiftCntV_immI__rule,
  /*  405 */  _RShiftCntV_immI__rule,
  /*  406 */  _RShiftCntV_immI__rule,
  /*  407 */  _RShiftCntV_immI__rule,
  /*  408 */  _RShiftCntV_immI__rule,
  /*  409 */  _RShiftCntV_immI__rule,
  /*  410 */  _RShiftCntV_immI__rule,
  /*  411 */  _RShiftCntV_immI__rule,
  /*  412 */  _ReplicateB_immI_M1__rule,
  /*  413 */  vReg_rule,
  /*  414 */  _ReplicateS_immI_M1__rule,
  /*  415 */  vReg_rule,
  /*  416 */  _ReplicateI_immI_M1__rule,
  /*  417 */  vReg_rule,
  /*  418 */  _ReplicateL_immL_M1__rule,
  /*  419 */  vReg_rule,
  /*  420 */  vReg_rule,
  /*  421 */  0,
  /*  422 */  vReg_rule,
  /*  423 */  _NegVF_vReg__rule,
  /*  424 */  0,
  /*  425 */  vReg_rule,
  /*  426 */  _NegVD_vReg__rule,
  /*  427 */  vReg_rule,
  /*  428 */  vReg_rule,
  /*  429 */  vReg_rule,
  /*  430 */  vReg_rule,
  // last internally defined operand
  /*  431 */  0,
  /*  432 */  0,
  /*  433 */  0,
  /*  434 */  0,
  /*  435 */  0,
  /*  436 */  0,
  /*  437 */  0,
  /*  438 */  0,
  /*  439 */  0,
  /*  440 */  0,
  /*  441 */  0,
  /*  442 */  0,
  /*  443 */  0,
  /*  444 */  0,
  /*  445 */  0,
  /*  446 */  0,
  /*  447 */  0,
  /*  448 */  0,
  /*  449 */  0,
  /*  450 */  0,
  /*  451 */  0,
  /*  452 */  0,
  /*  453 */  0,
  /*  454 */  0,
  /*  455 */  0,
  /*  456 */  0,
  /*  457 */  0,
  /*  458 */  0,
  /*  459 */  _Binary_iRegP_iRegP_rule,
  /*  460 */  _Binary_iRegLNoSp_iRegLNoSp_rule,
  /*  461 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  462 */  0,
  /*  463 */  0,
  /*  464 */  0,
  /*  465 */  0,
  /*  466 */  0,
  /*  467 */  0,
  /*  468 */  0,
  /*  469 */  0,
  /*  470 */  0,
  /*  471 */  0,
  /*  472 */  0,
  /*  473 */  0,
  /*  474 */  iRegIorL2I_rule,
  /*  475 */  immIAddSub_rule,
  /*  476 */  iRegL_rule,
  /*  477 */  immLAddSub_rule,
  /*  478 */  iRegIorL2I_rule,
  /*  479 */  immIAddSub_rule,
  /*  480 */  iRegL_rule,
  /*  481 */  immLAddSub_rule,
  /*  482 */  iRegIorL2I_rule,
  /*  483 */  iRegL_rule,
  /*  484 */  iRegIorL2I_rule,
  /*  485 */  iRegL_rule,
  /*  486 */  iRegI_rule,
  /*  487 */  immI0_rule,
  /*  488 */  immIAddSub_rule,
  /*  489 */  immI_rule,
  /*  490 */  iRegI_rule,
  /*  491 */  immI0_rule,
  /*  492 */  immIAddSub_rule,
  /*  493 */  immI_rule,
  /*  494 */  iRegL_rule,
  /*  495 */  immL0_rule,
  /*  496 */  immLAddSub_rule,
  /*  497 */  immL_rule,
  /*  498 */  iRegL_rule,
  /*  499 */  immL0_rule,
  /*  500 */  immLAddSub_rule,
  /*  501 */  immL_rule,
  /*  502 */  iRegP_rule,
  /*  503 */  iRegN_rule,
  /*  504 */  immP0_rule,
  /*  505 */  immN0_rule,
  /*  506 */  vRegF_rule,
  /*  507 */  immF0_rule,
  /*  508 */  vRegD_rule,
  /*  509 */  immD0_rule,
  /*  510 */  immL0_rule,
  /*  511 */  immI0_rule,
  /*  512 */  immL0_rule,
  /*  513 */  immI0_rule,
  /*  514 */  iRegP_rule,
  /*  515 */  iRegP_rule,
  /*  516 */  immP0_rule,
  /*  517 */  0,
  /*  518 */  0,
  /*  519 */  0,
  /*  520 */  0,
  /*  521 */  0,
  /*  522 */  0,
  /*  523 */  0,
  /*  524 */  0,
  /*  525 */  0,
  /*  526 */  0,
  /*  527 */  0,
  /*  528 */  0,
  /*  529 */  0,
  /*  530 */  0,
  /*  531 */  0,
  /*  532 */  0,
  /*  533 */  0,
  /*  534 */  0,
  /*  535 */  0,
  /*  536 */  0,
  /*  537 */  0,
  /*  538 */  0,
  /*  539 */  0,
  /*  540 */  0,
  /*  541 */  0,
  /*  542 */  0,
  /*  543 */  0,
  /*  544 */  0,
  /*  545 */  0,
  /*  546 */  0,
  /*  547 */  0,
  /*  548 */  0,
  /*  549 */  0,
  /*  550 */  0,
  /*  551 */  0,
  /*  552 */  0,
  /*  553 */  0,
  /*  554 */  0,
  /*  555 */  0,
  /*  556 */  0,
  /*  557 */  0,
  /*  558 */  0,
  /*  559 */  0,
  /*  560 */  0,
  /*  561 */  0,
  /*  562 */  0,
  /*  563 */  0,
  /*  564 */  0,
  /*  565 */  0,
  /*  566 */  0,
  /*  567 */  0,
  /*  568 */  0,
  /*  569 */  0,
  /*  570 */  0,
  /*  571 */  0,
  /*  572 */  0,
  /*  573 */  0,
  /*  574 */  0,
  /*  575 */  0,
  /*  576 */  0,
  /*  577 */  0,
  /*  578 */  0,
  /*  579 */  0,
  /*  580 */  0,
  /*  581 */  0,
  /*  582 */  0,
  /*  583 */  0,
  /*  584 */  0,
  /*  585 */  0,
  /*  586 */  0,
  /*  587 */  0,
  /*  588 */  0,
  /*  589 */  0,
  /*  590 */  0,
  /*  591 */  0,
  /*  592 */  0,
  /*  593 */  0,
  /*  594 */  0,
  /*  595 */  0,
  /*  596 */  0,
  /*  597 */  0,
  /*  598 */  0,
  /*  599 */  0,
  /*  600 */  0,
  /*  601 */  0,
  /*  602 */  0,
  /*  603 */  0,
  /*  604 */  0,
  /*  605 */  0,
  /*  606 */  0,
  /*  607 */  0,
  /*  608 */  0,
  /*  609 */  immL_32bits_rule,
  /*  610 */  0,
  /*  611 */  0,
  /*  612 */  0,
  /*  613 */  0,
  /*  614 */  0,
  /*  615 */  0,
  /*  616 */  0,
  /*  617 */  0,
  /*  618 */  immI0_rule,
  /*  619 */  immI0_rule,
  /*  620 */  iRegIorL2I_rule,
  /*  621 */  immI0_rule,
  /*  622 */  iRegIorL2I_rule,
  /*  623 */  immI0_rule,
  /*  624 */  iRegIorL2I_rule,
  /*  625 */  immI0_rule,
  /*  626 */  iRegL_rule,
  /*  627 */  immL0_rule,
  /*  628 */  iRegP_rule,
  /*  629 */  immP0_rule,
  /*  630 */  iRegN_rule,
  /*  631 */  immN0_rule,
  /*  632 */  vRegF_rule,
  /*  633 */  vRegD_rule,
  /*  634 */  iRegN_rule,
  /*  635 */  0,
  /*  636 */  0,
  /*  637 */  0,
  /*  638 */  0,
  /*  639 */  0,
  /*  640 */  0,
  /*  641 */  0,
  /*  642 */  0,
  /*  643 */  0,
  /*  644 */  0,
  /*  645 */  immL_32bits_rule,
  /*  646 */  0,
  /*  647 */  0,
  /*  648 */  0,
  /*  649 */  0,
  /*  650 */  0,
  /*  651 */  iRegIorL2I_rule,
  /*  652 */  iRegIorL2I_rule,
  /*  653 */  iRegIorL2I_rule,
  /*  654 */  iRegL_rule,
  /*  655 */  iRegP_rule,
  /*  656 */  iRegN_rule,
  /*  657 */  vRegF_rule,
  /*  658 */  vRegD_rule,
  /*  659 */  0,
  /*  660 */  0,
  /*  661 */  0,
  /*  662 */  0,
  /*  663 */  0,
  /*  664 */  0,
  /*  665 */  0,
  /*  666 */  0,
  /*  667 */  0,
  /*  668 */  0,
  /*  669 */  0,
  /*  670 */  0,
  /*  671 */  0,
  /*  672 */  0,
  /*  673 */  0,
  /*  674 */  0,
  /*  675 */  0,
  /*  676 */  0,
  /*  677 */  0,
  /*  678 */  0,
  /*  679 */  0,
  /*  680 */  0,
  /*  681 */  0,
  /*  682 */  0,
  /*  683 */  0,
  /*  684 */  0,
  /*  685 */  0,
  /*  686 */  0,
  /*  687 */  0,
  /*  688 */  0,
  /*  689 */  0,
  /*  690 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  691 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  692 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  693 */  _Binary_iRegLNoSp_iRegLNoSp_rule,
  /*  694 */  _Binary_iRegP_iRegP_rule,
  /*  695 */  _Binary_iRegNNoSp_iRegNNoSp_rule,
  /*  696 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  697 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  698 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  699 */  _Binary_iRegLNoSp_iRegLNoSp_rule,
  /*  700 */  _Binary_iRegP_iRegP_rule,
  /*  701 */  _Binary_iRegNNoSp_iRegNNoSp_rule,
  /*  702 */  _Binary_iRegI_iRegI_rule,
  /*  703 */  _Binary_iRegI_iRegI_rule,
  /*  704 */  _Binary_iRegI_iRegI_rule,
  /*  705 */  _Binary_iRegL_iRegL_rule,
  /*  706 */  _Binary_iRegN_iRegN_rule,
  /*  707 */  _Binary_iRegP_iRegP_rule,
  /*  708 */  _Binary_iRegI_iRegI_rule,
  /*  709 */  _Binary_iRegI_iRegI_rule,
  /*  710 */  _Binary_iRegI_iRegI_rule,
  /*  711 */  _Binary_iRegL_iRegL_rule,
  /*  712 */  _Binary_iRegN_iRegN_rule,
  /*  713 */  _Binary_iRegP_iRegP_rule,
  /*  714 */  _Binary_iRegI_iRegI_rule,
  /*  715 */  _Binary_iRegI_iRegI_rule,
  /*  716 */  _Binary_iRegI_iRegI_rule,
  /*  717 */  _Binary_iRegL_iRegL_rule,
  /*  718 */  _Binary_iRegN_iRegN_rule,
  /*  719 */  _Binary_iRegP_iRegP_rule,
  /*  720 */  _Binary_iRegI_iRegI_rule,
  /*  721 */  _Binary_iRegI_iRegI_rule,
  /*  722 */  _Binary_iRegI_iRegI_rule,
  /*  723 */  _Binary_iRegL_iRegL_rule,
  /*  724 */  _Binary_iRegN_iRegN_rule,
  /*  725 */  _Binary_iRegP_iRegP_rule,
  /*  726 */  iRegI_rule,
  /*  727 */  iRegL_rule,
  /*  728 */  iRegN_rule,
  /*  729 */  iRegP_rule,
  /*  730 */  iRegI_rule,
  /*  731 */  iRegL_rule,
  /*  732 */  iRegN_rule,
  /*  733 */  iRegP_rule,
  /*  734 */  iRegL_rule,
  /*  735 */  iRegL_rule,
  /*  736 */  immLAddSub_rule,
  /*  737 */  immLAddSub_rule,
  /*  738 */  iRegIorL2I_rule,
  /*  739 */  iRegIorL2I_rule,
  /*  740 */  immIAddSub_rule,
  /*  741 */  immIAddSub_rule,
  /*  742 */  iRegL_rule,
  /*  743 */  iRegL_rule,
  /*  744 */  immLAddSub_rule,
  /*  745 */  immLAddSub_rule,
  /*  746 */  iRegIorL2I_rule,
  /*  747 */  iRegIorL2I_rule,
  /*  748 */  immIAddSub_rule,
  /*  749 */  immIAddSub_rule,
  /*  750 */  iRegL_rule,
  /*  751 */  immLAddSub_rule,
  /*  752 */  _Binary_iRegIorL2I_iRegIorL2I_rule,
  /*  753 */  _Binary_iRegIorL2I_iRegIorL2I_rule,
  /*  754 */  _Binary_immI0_iRegIorL2I_rule,
  /*  755 */  _Binary_immI0_iRegIorL2I_rule,
  /*  756 */  _Binary_iRegIorL2I_immI0_rule,
  /*  757 */  _Binary_iRegIorL2I_immI0_rule,
  /*  758 */  _Binary_immI_1_immI0_rule,
  /*  759 */  _Binary_immI_1_immI0_rule,
  /*  760 */  _Binary_iRegL_iRegL_rule,
  /*  761 */  _Binary_iRegL_iRegL_rule,
  /*  762 */  _Binary_iRegL_immL0_rule,
  /*  763 */  _Binary_iRegL_immL0_rule,
  /*  764 */  _Binary_immL0_iRegL_rule,
  /*  765 */  _Binary_immL0_iRegL_rule,
  /*  766 */  _Binary_iRegP_iRegP_rule,
  /*  767 */  _Binary_iRegP_iRegP_rule,
  /*  768 */  _Binary_iRegP_immP0_rule,
  /*  769 */  _Binary_iRegP_immP0_rule,
  /*  770 */  _Binary_immP0_iRegP_rule,
  /*  771 */  _Binary_immP0_iRegP_rule,
  /*  772 */  _Binary_iRegN_iRegN_rule,
  /*  773 */  _Binary_iRegN_iRegN_rule,
  /*  774 */  _Binary_iRegN_immN0_rule,
  /*  775 */  _Binary_iRegN_immN0_rule,
  /*  776 */  _Binary_immN0_iRegN_rule,
  /*  777 */  _Binary_immN0_iRegN_rule,
  /*  778 */  _Binary_vRegF_vRegF_rule,
  /*  779 */  _Binary_vRegF_vRegF_rule,
  /*  780 */  _Binary_vRegD_vRegD_rule,
  /*  781 */  _Binary_vRegD_vRegD_rule,
  /*  782 */  iRegIorL2I_rule,
  /*  783 */  immIAddSub_rule,
  /*  784 */  immIAddSub_rule,
  /*  785 */  iRegL_rule,
  /*  786 */  _ConvI2L_iRegIorL2I__rule,
  /*  787 */  _LShiftL_iRegL_immIScale_rule,
  /*  788 */  _LShiftL__ConvI2L_iRegIorL2I__immIScale_rule,
  /*  789 */  immI_rule,
  /*  790 */  immLAddSub_rule,
  /*  791 */  iRegL_rule,
  /*  792 */  immLAddSub_rule,
  /*  793 */  iRegIorL2I_rule,
  /*  794 */  immIAddSub_rule,
  /*  795 */  iRegL_rule,
  /*  796 */  immLAddSub_rule,
  /*  797 */  iRegIorL2I_rule,
  /*  798 */  iRegL_rule,
  /*  799 */  iRegIorL2I_rule,
  /*  800 */  _ConvI2L_iRegIorL2I__rule,
  /*  801 */  _ConvI2L_iRegIorL2I__rule,
  /*  802 */  iRegL_rule,
  /*  803 */  iRegL_rule,
  /*  804 */  _MulI_iRegIorL2I_iRegIorL2I_rule,
  /*  805 */  iRegIorL2I_rule,
  /*  806 */  _MulI_iRegIorL2I_iRegIorL2I_rule,
  /*  807 */  iRegIorL2I_rule,
  /*  808 */  _SubI_immI0_iRegIorL2I_rule,
  /*  809 */  _SubI_immI0_iRegIorL2I_rule,
  /*  810 */  iRegIorL2I_rule,
  /*  811 */  _MulL_iRegL_iRegL_rule,
  /*  812 */  iRegL_rule,
  /*  813 */  _MulL_iRegL_iRegL_rule,
  /*  814 */  iRegL_rule,
  /*  815 */  _SubL_immL0_iRegL_rule,
  /*  816 */  _SubL_immL0_iRegL_rule,
  /*  817 */  iRegL_rule,
  /*  818 */  _MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I__rule,
  /*  819 */  iRegLNoSp_rule,
  /*  820 */  _MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I__rule,
  /*  821 */  iRegLNoSp_rule,
  /*  822 */  _MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I__rule,
  /*  823 */  _MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I__rule,
  /*  824 */  _ConvI2L_iRegIorL2I__rule,
  /*  825 */  _SubL_immL0__ConvI2L_iRegIorL2I__rule,
  /*  826 */  _SubL_immL0__ConvI2L_iRegIorL2I__rule,
  /*  827 */  _ConvI2L_iRegIorL2I__rule,
  /*  828 */  _Binary_iRegIorL2I_iRegIorL2I_rule,
  /*  829 */  iRegIorL2I_rule,
  /*  830 */  iRegL_rule,
  /*  831 */  iRegIorL2I_rule,
  /*  832 */  iRegL_rule,
  /*  833 */  iRegIorL2I_rule,
  /*  834 */  immI_rule,
  /*  835 */  iRegIorL2I_rule,
  /*  836 */  immI_rule,
  /*  837 */  iRegIorL2I_rule,
  /*  838 */  immI_rule,
  /*  839 */  iRegIorL2I_rule,
  /*  840 */  immI_rule,
  /*  841 */  iRegIorL2I_rule,
  /*  842 */  immI_rule,
  /*  843 */  immI_rule,
  /*  844 */  iRegIorL2I_rule,
  /*  845 */  immI_rule,
  /*  846 */  immL_M1_rule,
  /*  847 */  immI_M1_rule,
  /*  848 */  _XorI_iRegIorL2I_immI_M1_rule,
  /*  849 */  iRegIorL2I_rule,
  /*  850 */  _XorL_iRegL_immL_M1_rule,
  /*  851 */  iRegL_rule,
  /*  852 */  _XorI_iRegIorL2I_immI_M1_rule,
  /*  853 */  iRegIorL2I_rule,
  /*  854 */  _XorL_iRegL_immL_M1_rule,
  /*  855 */  iRegL_rule,
  /*  856 */  _XorI_iRegIorL2I_iRegIorL2I_rule,
  /*  857 */  immI_M1_rule,
  /*  858 */  _XorL_iRegL_iRegL_rule,
  /*  859 */  immL_M1_rule,
  /*  860 */  _XorI__URShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  861 */  iRegIorL2I_rule,
  /*  862 */  _XorL__URShiftL_iRegL_immI_immL_M1_rule,
  /*  863 */  iRegL_rule,
  /*  864 */  _XorI__RShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  865 */  iRegIorL2I_rule,
  /*  866 */  _XorL__RShiftL_iRegL_immI_immL_M1_rule,
  /*  867 */  iRegL_rule,
  /*  868 */  _XorI__RotateRight_iRegIorL2I_immI_immI_M1_rule,
  /*  869 */  iRegIorL2I_rule,
  /*  870 */  _XorL__RotateRight_iRegL_immI_immL_M1_rule,
  /*  871 */  iRegL_rule,
  /*  872 */  _XorI__LShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  873 */  iRegIorL2I_rule,
  /*  874 */  _XorL__LShiftL_iRegL_immI_immL_M1_rule,
  /*  875 */  iRegL_rule,
  /*  876 */  _XorI__URShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  877 */  immI_M1_rule,
  /*  878 */  _XorI_iRegIorL2I__URShiftI_iRegIorL2I_immI_rule,
  /*  879 */  immI_M1_rule,
  /*  880 */  _XorL__URShiftL_iRegL_immI_iRegL_rule,
  /*  881 */  immL_M1_rule,
  /*  882 */  _XorL_iRegL__URShiftL_iRegL_immI_rule,
  /*  883 */  immL_M1_rule,
  /*  884 */  _XorI__RShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  885 */  immI_M1_rule,
  /*  886 */  _XorI_iRegIorL2I__RShiftI_iRegIorL2I_immI_rule,
  /*  887 */  immI_M1_rule,
  /*  888 */  _XorL__RShiftL_iRegL_immI_iRegL_rule,
  /*  889 */  immL_M1_rule,
  /*  890 */  _XorL_iRegL__RShiftL_iRegL_immI_rule,
  /*  891 */  immL_M1_rule,
  /*  892 */  _XorI__RotateRight_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  893 */  immI_M1_rule,
  /*  894 */  _XorI_iRegIorL2I__RotateRight_iRegIorL2I_immI_rule,
  /*  895 */  immI_M1_rule,
  /*  896 */  _XorL__RotateRight_iRegL_immI_iRegL_rule,
  /*  897 */  immL_M1_rule,
  /*  898 */  _XorL_iRegL__RotateRight_iRegL_immI_rule,
  /*  899 */  immL_M1_rule,
  /*  900 */  _XorI__LShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  901 */  immI_M1_rule,
  /*  902 */  _XorI_iRegIorL2I__LShiftI_iRegIorL2I_immI_rule,
  /*  903 */  immI_M1_rule,
  /*  904 */  _XorL__LShiftL_iRegL_immI_iRegL_rule,
  /*  905 */  immL_M1_rule,
  /*  906 */  _XorL_iRegL__LShiftL_iRegL_immI_rule,
  /*  907 */  immL_M1_rule,
  /*  908 */  _XorI__URShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  909 */  iRegIorL2I_rule,
  /*  910 */  _XorL__URShiftL_iRegL_immI_immL_M1_rule,
  /*  911 */  iRegL_rule,
  /*  912 */  _XorI__RShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  913 */  iRegIorL2I_rule,
  /*  914 */  _XorL__RShiftL_iRegL_immI_immL_M1_rule,
  /*  915 */  iRegL_rule,
  /*  916 */  _XorI__RotateRight_iRegIorL2I_immI_immI_M1_rule,
  /*  917 */  iRegIorL2I_rule,
  /*  918 */  _XorL__RotateRight_iRegL_immI_immL_M1_rule,
  /*  919 */  iRegL_rule,
  /*  920 */  _XorI__LShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  921 */  iRegIorL2I_rule,
  /*  922 */  _XorL__LShiftL_iRegL_immI_immL_M1_rule,
  /*  923 */  iRegL_rule,
  /*  924 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  925 */  iRegIorL2I_rule,
  /*  926 */  _URShiftL_iRegL_immI_rule,
  /*  927 */  iRegL_rule,
  /*  928 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  929 */  iRegIorL2I_rule,
  /*  930 */  _RShiftL_iRegL_immI_rule,
  /*  931 */  iRegL_rule,
  /*  932 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  933 */  iRegIorL2I_rule,
  /*  934 */  _LShiftL_iRegL_immI_rule,
  /*  935 */  iRegL_rule,
  /*  936 */  _RotateRight_iRegIorL2I_immI_rule,
  /*  937 */  iRegIorL2I_rule,
  /*  938 */  _RotateRight_iRegL_immI_rule,
  /*  939 */  iRegL_rule,
  /*  940 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  941 */  iRegIorL2I_rule,
  /*  942 */  _URShiftL_iRegL_immI_rule,
  /*  943 */  iRegL_rule,
  /*  944 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  945 */  iRegIorL2I_rule,
  /*  946 */  _RShiftL_iRegL_immI_rule,
  /*  947 */  iRegL_rule,
  /*  948 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  949 */  iRegIorL2I_rule,
  /*  950 */  _LShiftL_iRegL_immI_rule,
  /*  951 */  iRegL_rule,
  /*  952 */  _RotateRight_iRegIorL2I_immI_rule,
  /*  953 */  iRegIorL2I_rule,
  /*  954 */  _RotateRight_iRegL_immI_rule,
  /*  955 */  iRegL_rule,
  /*  956 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  957 */  iRegIorL2I_rule,
  /*  958 */  _URShiftL_iRegL_immI_rule,
  /*  959 */  iRegL_rule,
  /*  960 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  961 */  iRegIorL2I_rule,
  /*  962 */  _RShiftL_iRegL_immI_rule,
  /*  963 */  iRegL_rule,
  /*  964 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  965 */  iRegIorL2I_rule,
  /*  966 */  _LShiftL_iRegL_immI_rule,
  /*  967 */  iRegL_rule,
  /*  968 */  _RotateRight_iRegIorL2I_immI_rule,
  /*  969 */  iRegIorL2I_rule,
  /*  970 */  _RotateRight_iRegL_immI_rule,
  /*  971 */  iRegL_rule,
  /*  972 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  973 */  iRegIorL2I_rule,
  /*  974 */  _URShiftL_iRegL_immI_rule,
  /*  975 */  iRegL_rule,
  /*  976 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  977 */  iRegIorL2I_rule,
  /*  978 */  _RShiftL_iRegL_immI_rule,
  /*  979 */  iRegL_rule,
  /*  980 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  981 */  iRegIorL2I_rule,
  /*  982 */  _LShiftL_iRegL_immI_rule,
  /*  983 */  iRegL_rule,
  /*  984 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  985 */  _URShiftL_iRegL_immI_rule,
  /*  986 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  987 */  _RShiftL_iRegL_immI_rule,
  /*  988 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  989 */  _LShiftL_iRegL_immI_rule,
  /*  990 */  immI_rule,
  /*  991 */  immI_rule,
  /*  992 */  immI_rule,
  /*  993 */  immI_rule,
  /*  994 */  immI_bitmask_rule,
  /*  995 */  immL_bitmask_rule,
  /*  996 */  0,
  /*  997 */  immI_rule,
  /*  998 */  immI_rule,
  /*  999 */  0,
  /* 1000 */  0,
  /* 1001 */  immI_rule,
  /* 1002 */  immI_rule,
  /* 1003 */  0,
  /* 1004 */  _URShiftL_iRegL_immI_rule,
  /* 1005 */  _LShiftL_iRegL_immI_rule,
  /* 1006 */  _URShiftI_iRegIorL2I_immI_rule,
  /* 1007 */  _LShiftI_iRegIorL2I_immI_rule,
  /* 1008 */  _URShiftL_iRegL_immI_rule,
  /* 1009 */  _LShiftL_iRegL_immI_rule,
  /* 1010 */  _URShiftI_iRegIorL2I_immI_rule,
  /* 1011 */  _LShiftI_iRegIorL2I_immI_rule,
  /* 1012 */  immI_rule,
  /* 1013 */  immI_rule,
  /* 1014 */  iRegI_rule,
  /* 1015 */  iRegI_rule,
  /* 1016 */  iRegI_rule,
  /* 1017 */  iRegI_rule,
  /* 1018 */  _ConvI2L_iRegIorL2I__rule,
  /* 1019 */  iRegL_rule,
  /* 1020 */  _ConvI2L_iRegIorL2I__rule,
  /* 1021 */  _RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_rule,
  /* 1022 */  iRegIorL2I_rule,
  /* 1023 */  _RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /* 1024 */  iRegIorL2I_rule,
  /* 1025 */  _URShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /* 1026 */  iRegIorL2I_rule,
  /* 1027 */  _RShiftL__LShiftL_iRegL_immI_48_immI_48_rule,
  /* 1028 */  iRegL_rule,
  /* 1029 */  _RShiftL__LShiftL_iRegL_immI_32_immI_32_rule,
  /* 1030 */  iRegL_rule,
  /* 1031 */  _RShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /* 1032 */  iRegL_rule,
  /* 1033 */  _URShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /* 1034 */  iRegL_rule,
  /* 1035 */  _AndI_iRegIorL2I_immI_255_rule,
  /* 1036 */  iRegIorL2I_rule,
  /* 1037 */  _AndI_iRegIorL2I_immI_65535_rule,
  /* 1038 */  iRegIorL2I_rule,
  /* 1039 */  _AndL_iRegL_immL_255_rule,
  /* 1040 */  iRegL_rule,
  /* 1041 */  _AndL_iRegL_immL_65535_rule,
  /* 1042 */  iRegL_rule,
  /* 1043 */  _AndL_iRegL_immL_4294967295_rule,
  /* 1044 */  iRegL_rule,
  /* 1045 */  _AndI_iRegIorL2I_immI_255_rule,
  /* 1046 */  _AndI_iRegIorL2I_immI_65535_rule,
  /* 1047 */  _AndL_iRegL_immL_255_rule,
  /* 1048 */  _AndL_iRegL_immL_65535_rule,
  /* 1049 */  _AndL_iRegL_immL_4294967295_rule,
  /* 1050 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_56_immI_56_immIExt_rule,
  /* 1051 */  iRegL_rule,
  /* 1052 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_48_immI_48_immIExt_rule,
  /* 1053 */  iRegL_rule,
  /* 1054 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_32_immI_32_immIExt_rule,
  /* 1055 */  iRegL_rule,
  /* 1056 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_56_immI_56_immIExt_rule,
  /* 1057 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_48_immI_48_immIExt_rule,
  /* 1058 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_32_immI_32_immIExt_rule,
  /* 1059 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_immIExt_rule,
  /* 1060 */  iRegIorL2I_rule,
  /* 1061 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_immIExt_rule,
  /* 1062 */  iRegIorL2I_rule,
  /* 1063 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_immIExt_rule,
  /* 1064 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_immIExt_rule,
  /* 1065 */  _LShiftL__ConvI2L_iRegIorL2I__immIExt_rule,
  /* 1066 */  iRegL_rule,
  /* 1067 */  _LShiftL__ConvI2L_iRegIorL2I__immIExt_rule,
  /* 1068 */  _LShiftL__AndL_iRegL_immL_255_immIExt_rule,
  /* 1069 */  iRegL_rule,
  /* 1070 */  _LShiftL__AndL_iRegL_immL_65535_immIExt_rule,
  /* 1071 */  iRegL_rule,
  /* 1072 */  _LShiftL__AndL_iRegL_immL_4294967295_immIExt_rule,
  /* 1073 */  iRegL_rule,
  /* 1074 */  _LShiftL__AndL_iRegL_immL_255_immIExt_rule,
  /* 1075 */  _LShiftL__AndL_iRegL_immL_65535_immIExt_rule,
  /* 1076 */  _LShiftL__AndL_iRegL_immL_4294967295_immIExt_rule,
  /* 1077 */  _LShiftI__AndI_iRegIorL2I_immI_255_immIExt_rule,
  /* 1078 */  iRegIorL2I_rule,
  /* 1079 */  _LShiftI__AndI_iRegIorL2I_immI_65535_immIExt_rule,
  /* 1080 */  iRegIorL2I_rule,
  /* 1081 */  _LShiftI__AndI_iRegIorL2I_immI_255_immIExt_rule,
  /* 1082 */  _LShiftI__AndI_iRegIorL2I_immI_65535_immIExt_rule,
  /* 1083 */  vRegF_rule,
  /* 1084 */  vRegD_rule,
  /* 1085 */  vRegF_rule,
  /* 1086 */  vRegD_rule,
  /* 1087 */  vRegF_rule,
  /* 1088 */  vRegD_rule,
  /* 1089 */  _Binary_vRegF_vRegF_rule,
  /* 1090 */  _Binary_vRegD_vRegD_rule,
  /* 1091 */  _Binary__NegF_vRegF__vRegF_rule,
  /* 1092 */  _Binary_vRegF__NegF_vRegF__rule,
  /* 1093 */  _Binary__NegD_vRegD__vRegD_rule,
  /* 1094 */  _Binary_vRegD__NegD_vRegD__rule,
  /* 1095 */  _Binary__NegF_vRegF__vRegF_rule,
  /* 1096 */  _Binary_vRegF__NegF_vRegF__rule,
  /* 1097 */  _Binary__NegD_vRegD__vRegD_rule,
  /* 1098 */  _Binary_vRegD__NegD_vRegD__rule,
  /* 1099 */  _Binary_vRegF_vRegF_rule,
  /* 1100 */  _Binary_vRegD_vRegD_rule,
  /* 1101 */  vRegF_rule,
  /* 1102 */  vRegF_rule,
  /* 1103 */  vRegD_rule,
  /* 1104 */  vRegD_rule,
  /* 1105 */  vRegF_rule,
  /* 1106 */  vRegD_rule,
  /* 1107 */  0,
  /* 1108 */  0,
  /* 1109 */  0,
  /* 1110 */  0,
  /* 1111 */  0,
  /* 1112 */  0,
  /* 1113 */  immI_rule,
  /* 1114 */  _Binary_vRegD_vRegD_rule,
  /* 1115 */  vRegF_rule,
  /* 1116 */  _Binary_vRegD_vRegD_rule,
  /* 1117 */  _Binary_vRegF_vRegF_rule,
  /* 1118 */  0,
  /* 1119 */  iRegIorL2I_rule,
  /* 1120 */  immILog_rule,
  /* 1121 */  iRegIorL2I_rule,
  /* 1122 */  immILog_rule,
  /* 1123 */  iRegIorL2I_rule,
  /* 1124 */  immILog_rule,
  /* 1125 */  iRegL_rule,
  /* 1126 */  immLLog_rule,
  /* 1127 */  iRegL_rule,
  /* 1128 */  immLLog_rule,
  /* 1129 */  iRegL_rule,
  /* 1130 */  immLLog_rule,
  /* 1131 */  0,
  /* 1132 */  immL_32bits_rule,
  /* 1133 */  0,
  /* 1134 */  0,
  /* 1135 */  0,
  /* 1136 */  0,
  /* 1137 */  0,
  /* 1138 */  0,
  /* 1139 */  0,
  /* 1140 */  0,
  /* 1141 */  0,
  /* 1142 */  0,
  /* 1143 */  0,
  /* 1144 */  0,
  /* 1145 */  0,
  /* 1146 */  0,
  /* 1147 */  0,
  /* 1148 */  0,
  /* 1149 */  0,
  /* 1150 */  iRegP_R10_rule,
  /* 1151 */  iRegP_R10_rule,
  /* 1152 */  _OverflowMulI_iRegIorL2I_iRegIorL2I_rule,
  /* 1153 */  _OverflowMulL_iRegL_iRegL_rule,
  /* 1154 */  vRegF_rule,
  /* 1155 */  vRegD_rule,
  /* 1156 */  immF0_rule,
  /* 1157 */  immD0_rule,
  /* 1158 */  iRegIorL2I_rule,
  /* 1159 */  immI0_rule,
  /* 1160 */  0,
  /* 1161 */  iRegI_rule,
  /* 1162 */  0,
  /* 1163 */  iRegI_rule,
  /* 1164 */  0,
  /* 1165 */  rFlagsReg_rule,
  /* 1166 */  rFlagsRegU_rule,
  /* 1167 */  _CmpI_iRegIorL2I_immI0_rule,
  /* 1168 */  _CmpL_iRegL_immL0_rule,
  /* 1169 */  _CmpP_iRegP_immP0_rule,
  /* 1170 */  _CmpN_iRegN_immN0_rule,
  /* 1171 */  _CmpP__DecodeN_iRegN__immP0_rule,
  /* 1172 */  _CmpU_iRegIorL2I_immI0_rule,
  /* 1173 */  _CmpUL_iRegL_immL0_rule,
  /* 1174 */  _CmpL_iRegL_immL0_rule,
  /* 1175 */  _CmpI_iRegIorL2I_immI0_rule,
  /* 1176 */  _CmpL__AndL_iRegL_immL_immL0_rule,
  /* 1177 */  _CmpI__AndI_iRegIorL2I_immI_immI0_rule,
  /* 1178 */  _CmpL_iRegL_immL0_rule,
  /* 1179 */  _CmpI_iRegIorL2I_immI0_rule,
  /* 1180 */  _CmpL__AndL_iRegL_immL_immL0_rule,
  /* 1181 */  _CmpI__AndI_iRegIorL2I_immI_immI0_rule,
  /* 1182 */  rFlagsReg_rule,
  /* 1183 */  rFlagsRegU_rule,
  /* 1184 */  0,
  /* 1185 */  0,
  /* 1186 */  0,
  /* 1187 */  0,
  /* 1188 */  0,
  /* 1189 */  0,
  /* 1190 */  0,
  /* 1191 */  inline_cache_RegP_rule,
  /* 1192 */  iRegP_R0_rule,
  /* 1193 */  0,
  /* 1194 */  0,
  /* 1195 */  0,
  /* 1196 */  0,
  /* 1197 */  iRegP_R0_rule,
  /* 1198 */  _Binary_iRegP_R3_iRegI_R4_rule,
  /* 1199 */  _Binary_iRegP_R3_iRegI_R4_rule,
  /* 1200 */  _Binary_iRegP_R3_iRegI_R4_rule,
  /* 1201 */  _Binary_iRegP_R3_iRegI_R4_rule,
  /* 1202 */  _Binary_iRegP_R3_iRegI_R2_rule,
  /* 1203 */  _Binary_iRegP_R3_iRegI_R2_rule,
  /* 1204 */  _Binary_iRegP_R3_iRegI_R2_rule,
  /* 1205 */  _Binary_iRegP_R3_immI_le_4_rule,
  /* 1206 */  _Binary_iRegP_R3_immI_le_4_rule,
  /* 1207 */  _Binary_iRegP_R3_immI_1_rule,
  /* 1208 */  iRegI_R3_rule,
  /* 1209 */  iRegI_R3_rule,
  /* 1210 */  iRegI_R4_rule,
  /* 1211 */  iRegI_R4_rule,
  /* 1212 */  iRegP_R2_rule,
  /* 1213 */  iRegP_R2_rule,
  /* 1214 */  iRegI_R2_rule,
  /* 1215 */  _Binary_iRegP_R1_iRegI_R3_rule,
  /* 1216 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1217 */  _Binary_iRegP_R1_iRegI_R3_rule,
  /* 1218 */  0,
  /* 1219 */  0,
  /* 1220 */  0,
  /* 1221 */  0,
  /* 1222 */  vecD_rule,
  /* 1223 */  vecD_rule,
  /* 1224 */  vecD_rule,
  /* 1225 */  vecX_rule,
  /* 1226 */  vecD_rule,
  /* 1227 */  vecX_rule,
  /* 1228 */  vecD_rule,
  /* 1229 */  vecX_rule,
  /* 1230 */  vecX_rule,
  /* 1231 */  vecD_rule,
  /* 1232 */  vecX_rule,
  /* 1233 */  vecD_rule,
  /* 1234 */  vecX_rule,
  /* 1235 */  vecX_rule,
  /* 1236 */  vecD_rule,
  /* 1237 */  vecX_rule,
  /* 1238 */  vecD_rule,
  /* 1239 */  vecX_rule,
  /* 1240 */  vecX_rule,
  /* 1241 */  vecD_rule,
  /* 1242 */  vecX_rule,
  /* 1243 */  vecD_rule,
  /* 1244 */  vecX_rule,
  /* 1245 */  vecX_rule,
  /* 1246 */  vecD_rule,
  /* 1247 */  vecD_rule,
  /* 1248 */  vecX_rule,
  /* 1249 */  vecX_rule,
  /* 1250 */  vecD_rule,
  /* 1251 */  vecX_rule,
  /* 1252 */  vecX_rule,
  /* 1253 */  vecD_rule,
  /* 1254 */  vecX_rule,
  /* 1255 */  vecX_rule,
  /* 1256 */  vecD_rule,
  /* 1257 */  vecD_rule,
  /* 1258 */  vecD_rule,
  /* 1259 */  vecX_rule,
  /* 1260 */  vecX_rule,
  /* 1261 */  vecX_rule,
  /* 1262 */  vecD_rule,
  /* 1263 */  vecD_rule,
  /* 1264 */  vecD_rule,
  /* 1265 */  vecX_rule,
  /* 1266 */  vecX_rule,
  /* 1267 */  vecX_rule,
  /* 1268 */  vecD_rule,
  /* 1269 */  vecD_rule,
  /* 1270 */  vecD_rule,
  /* 1271 */  vecX_rule,
  /* 1272 */  vecX_rule,
  /* 1273 */  vecX_rule,
  /* 1274 */  vecX_rule,
  /* 1275 */  vecX_rule,
  /* 1276 */  vecX_rule,
  /* 1277 */  immI_rule,
  /* 1278 */  immI_rule,
  /* 1279 */  immI_rule,
  /* 1280 */  immI_rule,
  /* 1281 */  immI_rule,
  /* 1282 */  immI_rule,
  /* 1283 */  immI_rule,
  /* 1284 */  immI_rule,
  /* 1285 */  immI_rule,
  /* 1286 */  immI_rule,
  /* 1287 */  immI_rule,
  /* 1288 */  immI_rule,
  /* 1289 */  immI_rule,
  /* 1290 */  immI_rule,
  /* 1291 */  immI_rule,
  /* 1292 */  immI_rule,
  /* 1293 */  immI_rule,
  /* 1294 */  immI_rule,
  /* 1295 */  immI_rule,
  /* 1296 */  immI_rule,
  /* 1297 */  immI_rule,
  /* 1298 */  immI_rule,
  /* 1299 */  vecX_rule,
  /* 1300 */  _ReplicateB_immI_M1__rule,
  /* 1301 */  vecD_rule,
  /* 1302 */  _ReplicateS_immI_M1__rule,
  /* 1303 */  vecD_rule,
  /* 1304 */  _ReplicateI_immI_M1__rule,
  /* 1305 */  vecD_rule,
  /* 1306 */  _ReplicateB_immI_M1__rule,
  /* 1307 */  vecX_rule,
  /* 1308 */  _ReplicateS_immI_M1__rule,
  /* 1309 */  vecX_rule,
  /* 1310 */  _ReplicateI_immI_M1__rule,
  /* 1311 */  vecX_rule,
  /* 1312 */  _ReplicateL_immL_M1__rule,
  /* 1313 */  vecX_rule,
  /* 1314 */  _XorV_vecD__ReplicateB_immI_M1__rule,
  /* 1315 */  vecD_rule,
  /* 1316 */  _XorV__ReplicateB_immI_M1__vecD_rule,
  /* 1317 */  vecD_rule,
  /* 1318 */  _XorV_vecD__ReplicateS_immI_M1__rule,
  /* 1319 */  vecD_rule,
  /* 1320 */  _XorV__ReplicateS_immI_M1__vecD_rule,
  /* 1321 */  vecD_rule,
  /* 1322 */  _XorV_vecD__ReplicateI_immI_M1__rule,
  /* 1323 */  vecD_rule,
  /* 1324 */  _XorV__ReplicateI_immI_M1__vecD_rule,
  /* 1325 */  vecD_rule,
  /* 1326 */  _XorV_vecX__ReplicateB_immI_M1__rule,
  /* 1327 */  vecX_rule,
  /* 1328 */  _XorV__ReplicateB_immI_M1__vecX_rule,
  /* 1329 */  vecX_rule,
  /* 1330 */  _XorV_vecX__ReplicateS_immI_M1__rule,
  /* 1331 */  vecX_rule,
  /* 1332 */  _XorV__ReplicateS_immI_M1__vecX_rule,
  /* 1333 */  vecX_rule,
  /* 1334 */  _XorV_vecX__ReplicateI_immI_M1__rule,
  /* 1335 */  vecX_rule,
  /* 1336 */  _XorV__ReplicateI_immI_M1__vecX_rule,
  /* 1337 */  vecX_rule,
  /* 1338 */  _XorV_vecX__ReplicateL_immL_M1__rule,
  /* 1339 */  vecX_rule,
  /* 1340 */  _XorV__ReplicateL_immL_M1__vecX_rule,
  /* 1341 */  vecX_rule,
  /* 1342 */  vecD_rule,
  /* 1343 */  vecX_rule,
  /* 1344 */  vecD_rule,
  /* 1345 */  vecX_rule,
  /* 1346 */  vecD_rule,
  /* 1347 */  vecX_rule,
  /* 1348 */  vecD_rule,
  /* 1349 */  vecX_rule,
  /* 1350 */  vecD_rule,
  /* 1351 */  vecX_rule,
  /* 1352 */  vecD_rule,
  /* 1353 */  vecX_rule,
  /* 1354 */  vecX_rule,
  /* 1355 */  vecX_rule,
  /* 1356 */  vecD_rule,
  /* 1357 */  vecX_rule,
  /* 1358 */  immI_1_rule,
  /* 1359 */  immI_1_rule,
  /* 1360 */  immI_2_rule,
  /* 1361 */  immI_2_rule,
  /* 1362 */  immI_4_rule,
  /* 1363 */  immI_4_rule,
  /* 1364 */  immI_8_rule,
  /* 1365 */  vecD_rule,
  /* 1366 */  vecX_rule,
  /* 1367 */  vecD_rule,
  /* 1368 */  vecX_rule,
  /* 1369 */  vecX_rule,
  /* 1370 */  vecD_rule,
  /* 1371 */  vecX_rule,
  /* 1372 */  vecD_rule,
  /* 1373 */  vecX_rule,
  /* 1374 */  0,
  /* 1375 */  0,
  /* 1376 */  0,
  /* 1377 */  0,
  /* 1378 */  0,
  /* 1379 */  0,
  /* 1380 */  0,
  /* 1381 */  0,
  /* 1382 */  0,
  /* 1383 */  0,
  /* 1384 */  0,
  /* 1385 */  0,
  /* 1386 */  0,
  /* 1387 */  0,
  /* 1388 */  0,
  /* 1389 */  0,
  /* 1390 */  0,
  /* 1391 */  0,
  /* 1392 */  0,
  /* 1393 */  0,
  /* 1394 */  vecD_rule,
  /* 1395 */  vecX_rule,
  /* 1396 */  vecD_rule,
  /* 1397 */  vecX_rule,
  /* 1398 */  vecD_rule,
  /* 1399 */  vecX_rule,
  /* 1400 */  vecD_rule,
  /* 1401 */  vecX_rule,
  /* 1402 */  vecX_rule,
  /* 1403 */  vecX_rule,
  /* 1404 */  vecD_rule,
  /* 1405 */  vecX_rule,
  /* 1406 */  vecD_rule,
  /* 1407 */  vecX_rule,
  /* 1408 */  vecD_rule,
  /* 1409 */  vecX_rule,
  /* 1410 */  vecX_rule,
  /* 1411 */  vecD_rule,
  /* 1412 */  vecX_rule,
  /* 1413 */  vecX_rule,
  /* 1414 */  vecD_rule,
  /* 1415 */  vecX_rule,
  /* 1416 */  vecD_rule,
  /* 1417 */  vecX_rule,
  /* 1418 */  vecD_rule,
  /* 1419 */  vecX_rule,
  /* 1420 */  vecX_rule,
  /* 1421 */  vecD_rule,
  /* 1422 */  vecX_rule,
  /* 1423 */  vecX_rule,
  /* 1424 */  vecD_rule,
  /* 1425 */  vecX_rule,
  /* 1426 */  vecD_rule,
  /* 1427 */  vecX_rule,
  /* 1428 */  vecD_rule,
  /* 1429 */  vecX_rule,
  /* 1430 */  vecD_rule,
  /* 1431 */  vecX_rule,
  /* 1432 */  vecX_rule,
  /* 1433 */  _MulVS_vecD_vecD_rule,
  /* 1434 */  vecD_rule,
  /* 1435 */  _MulVS_vecX_vecX_rule,
  /* 1436 */  vecX_rule,
  /* 1437 */  _MulVI_vecD_vecD_rule,
  /* 1438 */  vecD_rule,
  /* 1439 */  _MulVI_vecX_vecX_rule,
  /* 1440 */  vecX_rule,
  /* 1441 */  _Binary_vecD_vecD_rule,
  /* 1442 */  _Binary_vecX_vecX_rule,
  /* 1443 */  _Binary_vecX_vecX_rule,
  /* 1444 */  _MulVS_vecD_vecD_rule,
  /* 1445 */  _MulVS_vecX_vecX_rule,
  /* 1446 */  _MulVI_vecD_vecD_rule,
  /* 1447 */  _MulVI_vecX_vecX_rule,
  /* 1448 */  _Binary__NegVF_vecD__vecD_rule,
  /* 1449 */  _Binary_vecD__NegVF_vecD__rule,
  /* 1450 */  _Binary__NegVF_vecX__vecX_rule,
  /* 1451 */  _Binary_vecX__NegVF_vecX__rule,
  /* 1452 */  _Binary__NegVD_vecX__vecX_rule,
  /* 1453 */  _Binary_vecX__NegVD_vecX__rule,
  /* 1454 */  vecX_rule,
  /* 1455 */  vecD_rule,
  /* 1456 */  vecX_rule,
  /* 1457 */  vecX_rule,
  /* 1458 */  vecD_rule,
  /* 1459 */  vecX_rule,
  /* 1460 */  vecD_rule,
  /* 1461 */  vecX_rule,
  /* 1462 */  vecD_rule,
  /* 1463 */  vecX_rule,
  /* 1464 */  vecD_rule,
  /* 1465 */  vecX_rule,
  /* 1466 */  vecD_rule,
  /* 1467 */  vecX_rule,
  /* 1468 */  vecD_rule,
  /* 1469 */  vecX_rule,
  /* 1470 */  _LShiftCntV_immI__rule,
  /* 1471 */  _LShiftCntV_immI__rule,
  /* 1472 */  _RShiftCntV_immI__rule,
  /* 1473 */  _RShiftCntV_immI__rule,
  /* 1474 */  _RShiftCntV_immI__rule,
  /* 1475 */  _RShiftCntV_immI__rule,
  /* 1476 */  vecD_rule,
  /* 1477 */  vecX_rule,
  /* 1478 */  vecD_rule,
  /* 1479 */  vecX_rule,
  /* 1480 */  vecD_rule,
  /* 1481 */  vecX_rule,
  /* 1482 */  _LShiftCntV_immI__rule,
  /* 1483 */  _LShiftCntV_immI__rule,
  /* 1484 */  _RShiftCntV_immI__rule,
  /* 1485 */  _RShiftCntV_immI__rule,
  /* 1486 */  _RShiftCntV_immI__rule,
  /* 1487 */  _RShiftCntV_immI__rule,
  /* 1488 */  vecD_rule,
  /* 1489 */  vecX_rule,
  /* 1490 */  vecD_rule,
  /* 1491 */  vecX_rule,
  /* 1492 */  vecD_rule,
  /* 1493 */  vecX_rule,
  /* 1494 */  _LShiftCntV_immI__rule,
  /* 1495 */  _LShiftCntV_immI__rule,
  /* 1496 */  _RShiftCntV_immI__rule,
  /* 1497 */  _RShiftCntV_immI__rule,
  /* 1498 */  _RShiftCntV_immI__rule,
  /* 1499 */  _RShiftCntV_immI__rule,
  /* 1500 */  vecX_rule,
  /* 1501 */  vecX_rule,
  /* 1502 */  vecX_rule,
  /* 1503 */  _LShiftCntV_immI__rule,
  /* 1504 */  _RShiftCntV_immI__rule,
  /* 1505 */  _RShiftCntV_immI__rule,
  /* 1506 */  _RShiftVB_vecD__RShiftCntV_immI__rule,
  /* 1507 */  vecD_rule,
  /* 1508 */  _RShiftVB_vecX__RShiftCntV_immI__rule,
  /* 1509 */  vecX_rule,
  /* 1510 */  _RShiftVS_vecD__RShiftCntV_immI__rule,
  /* 1511 */  vecD_rule,
  /* 1512 */  _RShiftVS_vecX__RShiftCntV_immI__rule,
  /* 1513 */  vecX_rule,
  /* 1514 */  _RShiftVI_vecD__RShiftCntV_immI__rule,
  /* 1515 */  vecD_rule,
  /* 1516 */  _RShiftVI_vecX__RShiftCntV_immI__rule,
  /* 1517 */  vecX_rule,
  /* 1518 */  _RShiftVL_vecX__RShiftCntV_immI__rule,
  /* 1519 */  vecX_rule,
  /* 1520 */  _URShiftVB_vecD__RShiftCntV_immI__rule,
  /* 1521 */  vecD_rule,
  /* 1522 */  _URShiftVB_vecX__RShiftCntV_immI__rule,
  /* 1523 */  vecX_rule,
  /* 1524 */  _URShiftVS_vecD__RShiftCntV_immI__rule,
  /* 1525 */  vecD_rule,
  /* 1526 */  _URShiftVS_vecX__RShiftCntV_immI__rule,
  /* 1527 */  vecX_rule,
  /* 1528 */  _URShiftVI_vecD__RShiftCntV_immI__rule,
  /* 1529 */  vecD_rule,
  /* 1530 */  _URShiftVI_vecX__RShiftCntV_immI__rule,
  /* 1531 */  vecX_rule,
  /* 1532 */  _URShiftVL_vecX__RShiftCntV_immI__rule,
  /* 1533 */  vecX_rule,
  /* 1534 */  vecD_rule,
  /* 1535 */  vecX_rule,
  /* 1536 */  vecX_rule,
  /* 1537 */  vecD_rule,
  /* 1538 */  vecX_rule,
  /* 1539 */  vecX_rule,
  /* 1540 */  immI_rule,
  /* 1541 */  0,
  /* 1542 */  vReg_rule,
  /* 1543 */  vReg_rule,
  /* 1544 */  vReg_rule,
  /* 1545 */  vReg_rule,
  /* 1546 */  vReg_rule,
  /* 1547 */  vReg_rule,
  /* 1548 */  vReg_rule,
  /* 1549 */  vReg_rule,
  /* 1550 */  vReg_rule,
  /* 1551 */  vReg_rule,
  /* 1552 */  _ReplicateB_immI_M1__rule,
  /* 1553 */  vReg_rule,
  /* 1554 */  _ReplicateS_immI_M1__rule,
  /* 1555 */  vReg_rule,
  /* 1556 */  _ReplicateI_immI_M1__rule,
  /* 1557 */  vReg_rule,
  /* 1558 */  _ReplicateL_immL_M1__rule,
  /* 1559 */  vReg_rule,
  /* 1560 */  _XorV_vReg__ReplicateB_immI_M1__rule,
  /* 1561 */  vReg_rule,
  /* 1562 */  _XorV__ReplicateB_immI_M1__vReg_rule,
  /* 1563 */  vReg_rule,
  /* 1564 */  _XorV_vReg__ReplicateS_immI_M1__rule,
  /* 1565 */  vReg_rule,
  /* 1566 */  _XorV__ReplicateS_immI_M1__vReg_rule,
  /* 1567 */  vReg_rule,
  /* 1568 */  _XorV_vReg__ReplicateI_immI_M1__rule,
  /* 1569 */  vReg_rule,
  /* 1570 */  _XorV__ReplicateI_immI_M1__vReg_rule,
  /* 1571 */  vReg_rule,
  /* 1572 */  _XorV_vReg__ReplicateL_immL_M1__rule,
  /* 1573 */  vReg_rule,
  /* 1574 */  _XorV__ReplicateL_immL_M1__vReg_rule,
  /* 1575 */  vReg_rule,
  /* 1576 */  vReg_rule,
  /* 1577 */  vReg_rule,
  /* 1578 */  vReg_rule,
  /* 1579 */  vReg_rule,
  /* 1580 */  _Binary_vReg_vReg_rule,
  /* 1581 */  _Binary_vReg_vReg_rule,
  /* 1582 */  _Binary__NegVF_vReg__vReg_rule,
  /* 1583 */  _Binary_vReg__NegVF_vReg__rule,
  /* 1584 */  _Binary__NegVD_vReg__vReg_rule,
  /* 1585 */  _Binary_vReg__NegVD_vReg__rule,
  /* 1586 */  _Binary__NegVF_vReg__vReg_rule,
  /* 1587 */  _Binary_vReg__NegVF_vReg__rule,
  /* 1588 */  _Binary__NegVD_vReg__vReg_rule,
  /* 1589 */  _Binary_vReg__NegVD_vReg__rule,
  /* 1590 */  _Binary_vReg_vReg_rule,
  /* 1591 */  _Binary_vReg_vReg_rule,
  /* 1592 */  _MulVB_vReg_vReg_rule,
  /* 1593 */  vReg_rule,
  /* 1594 */  _MulVS_vReg_vReg_rule,
  /* 1595 */  vReg_rule,
  /* 1596 */  _MulVI_vReg_vReg_rule,
  /* 1597 */  vReg_rule,
  /* 1598 */  _MulVL_vReg_vReg_rule,
  /* 1599 */  vReg_rule,
  /* 1600 */  _MulVB_vReg_vReg_rule,
  /* 1601 */  _MulVS_vReg_vReg_rule,
  /* 1602 */  _MulVI_vReg_vReg_rule,
  /* 1603 */  _MulVL_vReg_vReg_rule,
  /* 1604 */  vReg_rule,
  /* 1605 */  vReg_rule,
  /* 1606 */  vReg_rule,
  /* 1607 */  vReg_rule,
  /* 1608 */  vReg_rule,
  /* 1609 */  vReg_rule,
  /* 1610 */  vReg_rule,
  /* 1611 */  vReg_rule,
  /* 1612 */  vReg_rule,
  /* 1613 */  vReg_rule,
  /* 1614 */  vReg_rule,
  /* 1615 */  vReg_rule,
  /* 1616 */  vReg_rule,
  /* 1617 */  vReg_rule,
  /* 1618 */  vReg_rule,
  /* 1619 */  vReg_rule,
  /* 1620 */  immI_rule,
  /* 1621 */  0,
  /* 1622 */  0,
  /* 1623 */  0,
  /* 1624 */  0,
  /* 1625 */  0,
  /* 1626 */  0,
  /* 1627 */  0,
  /* 1628 */  0,
  /* 1629 */  0,
  /* 1630 */  0,
  /* 1631 */  vReg_rule,
  /* 1632 */  vReg_rule,
  /* 1633 */  vReg_rule,
  /* 1634 */  vReg_rule,
  /* 1635 */  vReg_rule,
  /* 1636 */  vReg_rule,
  /* 1637 */  vReg_rule,
  /* 1638 */  vReg_rule,
  /* 1639 */  vReg_rule,
  /* 1640 */  vReg_rule,
  /* 1641 */  vReg_rule,
  /* 1642 */  vReg_rule,
  /* 1643 */  _RShiftCntV_immI__rule,
  /* 1644 */  _RShiftCntV_immI__rule,
  /* 1645 */  _RShiftCntV_immI__rule,
  /* 1646 */  _RShiftCntV_immI__rule,
  /* 1647 */  _RShiftCntV_immI__rule,
  /* 1648 */  _RShiftCntV_immI__rule,
  /* 1649 */  _RShiftCntV_immI__rule,
  /* 1650 */  _RShiftCntV_immI__rule,
  /* 1651 */  _LShiftCntV_immI__rule,
  /* 1652 */  _LShiftCntV_immI__rule,
  /* 1653 */  _LShiftCntV_immI__rule,
  /* 1654 */  _LShiftCntV_immI__rule,
  /* 1655 */  vReg_rule,
  /* 1656 */  vReg_rule,
  /* 1657 */  vReg_rule,
  /* 1658 */  vReg_rule,
  /* 1659 */  vReg_rule,
  /* 1660 */  vReg_rule,
  /* 1661 */  _Binary_iRegP_iRegP_rule,
  /* 1662 */  _Binary_iRegN_iRegN_rule,
  /* 1663 */  _Binary_iRegP_iRegP_rule,
  /* 1664 */  _Binary_iRegN_iRegN_rule,
  /* 1665 */  _Binary_iRegN_iRegN_rule,
  /* 1666 */  _Binary_iRegP_iRegP_rule,
  /* 1667 */  _Binary_iRegN_iRegN_rule,
  /* 1668 */  _Binary_iRegP_iRegP_rule,
  /* 1669 */  _Binary_iRegN_iRegN_rule,
  /* 1670 */  _Binary_iRegP_iRegP_rule,
  /* 1671 */  _Binary_iRegN_iRegN_rule,
  /* 1672 */  _Binary_iRegP_iRegP_rule,
  /* 1673 */  0,
  /* 1674 */  0,
  /* 1675 */  _Binary_iRegP_iRegP_rule,
  /* 1676 */  _Binary_iRegP_iRegP_rule,
  /* 1677 */  _Binary_iRegP_iRegP_rule,
  /* 1678 */  _Binary_iRegP_iRegP_rule,
  /* 1679 */  _Binary_iRegP_iRegP_rule,
  /* 1680 */  _Binary_iRegP_iRegP_rule,
  /* 1681 */  iRegP_rule,
  /* 1682 */  iRegP_rule,
  // last instruction
  0 // no trailing comma
};

const char        *ruleName[] = {
  /*    0 */  "UNIVERSE",
  /*    1 */  "LABEL",
  /*    2 */  "SREGI",
  /*    3 */  "SREGP",
  /*    4 */  "SREGF",
  /*    5 */  "SREGD",
  /*    6 */  "SREGL",
  /*    7 */  "METHOD",
  /*    8 */  "IMMI",
  /*    9 */  "IMMI0",
  /*   10 */  "IMMI_1",
  /*   11 */  "IMMI_M1",
  /*   12 */  "IMMIEXT",
  /*   13 */  "IMMI_LE_4",
  /*   14 */  "IMMI_31",
  /*   15 */  "IMMI_2",
  /*   16 */  "IMMI_4",
  /*   17 */  "IMMI_8",
  /*   18 */  "IMMI_16",
  /*   19 */  "IMMI_24",
  /*   20 */  "IMMI_32",
  /*   21 */  "IMMI_48",
  /*   22 */  "IMMI_56",
  /*   23 */  "IMMI_63",
  /*   24 */  "IMMI_64",
  /*   25 */  "IMMI_255",
  /*   26 */  "IMMI_65535",
  /*   27 */  "IMML_255",
  /*   28 */  "IMML_65535",
  /*   29 */  "IMML_4294967295",
  /*   30 */  "IMML_BITMASK",
  /*   31 */  "IMMI_BITMASK",
  /*   32 */  "IMML_POSITIVE_BITMASKI",
  /*   33 */  "IMMISCALE",
  /*   34 */  "IMMI26",
  /*   35 */  "IMMI19",
  /*   36 */  "IMMIU12",
  /*   37 */  "IMMLU12",
  /*   38 */  "IMMIOFFSET",
  /*   39 */  "IMMIOFFSET1",
  /*   40 */  "IMMIOFFSET2",
  /*   41 */  "IMMIOFFSET4",
  /*   42 */  "IMMIOFFSET8",
  /*   43 */  "IMMIOFFSET16",
  /*   44 */  "IMMLOFFSET",
  /*   45 */  "IMMLOFFSET1",
  /*   46 */  "IMMLOFFSET2",
  /*   47 */  "IMMLOFFSET4",
  /*   48 */  "IMMLOFFSET8",
  /*   49 */  "IMMLOFFSET16",
  /*   50 */  "IMMI8",
  /*   51 */  "IMMI8_SHIFT8",
  /*   52 */  "IMML8_SHIFT8",
  /*   53 */  "IMMIADDSUB",
  /*   54 */  "IMMILOG",
  /*   55 */  "IMML",
  /*   56 */  "IMML0",
  /*   57 */  "IMML_1",
  /*   58 */  "IMML_M1",
  /*   59 */  "IMML_PC_OFF",
  /*   60 */  "IMMLADDSUB",
  /*   61 */  "IMMLLOG",
  /*   62 */  "IMML_32BITS",
  /*   63 */  "IMMP",
  /*   64 */  "IMMP0",
  /*   65 */  "IMMP_1",
  /*   66 */  "IMMBYTEMAPBASE",
  /*   67 */  "IMMP_M1",
  /*   68 */  "IMMP_M2",
  /*   69 */  "IMMD",
  /*   70 */  "IMMD0",
  /*   71 */  "IMMDPACKED",
  /*   72 */  "IMMF",
  /*   73 */  "IMMF0",
  /*   74 */  "IMMFPACKED",
  /*   75 */  "IMMN",
  /*   76 */  "IMMN0",
  /*   77 */  "IMMNKLASS",
  /*   78 */  "IREGI",
  /*   79 */  "IREGINOSP",
  /*   80 */  "IREGL",
  /*   81 */  "IREGLNOSP",
  /*   82 */  "IREGP",
  /*   83 */  "IREGPNOSP",
  /*   84 */  "IREGP_R0",
  /*   85 */  "IREGP_R1",
  /*   86 */  "IREGP_R2",
  /*   87 */  "IREGP_R3",
  /*   88 */  "IREGP_R4",
  /*   89 */  "IREGP_R5",
  /*   90 */  "IREGP_R10",
  /*   91 */  "IREGL_R0",
  /*   92 */  "IREGL_R2",
  /*   93 */  "IREGL_R3",
  /*   94 */  "IREGL_R11",
  /*   95 */  "IREGP_FP",
  /*   96 */  "IREGI_R0",
  /*   97 */  "IREGI_R2",
  /*   98 */  "IREGI_R3",
  /*   99 */  "IREGI_R4",
  /*  100 */  "IREGN",
  /*  101 */  "IREGN_R0",
  /*  102 */  "IREGN_R2",
  /*  103 */  "IREGN_R3",
  /*  104 */  "IREGNNOSP",
  /*  105 */  "IREGIHEAPBASE",
  /*  106 */  "VREGF",
  /*  107 */  "VREGD",
  /*  108 */  "VREG",
  /*  109 */  "VECD",
  /*  110 */  "VECX",
  /*  111 */  "VREGD_V0",
  /*  112 */  "VREGD_V1",
  /*  113 */  "VREGD_V2",
  /*  114 */  "VREGD_V3",
  /*  115 */  "VREGD_V4",
  /*  116 */  "VREGD_V5",
  /*  117 */  "VREGD_V6",
  /*  118 */  "VREGD_V7",
  /*  119 */  "VREGD_V8",
  /*  120 */  "VREGD_V9",
  /*  121 */  "VREGD_V10",
  /*  122 */  "VREGD_V11",
  /*  123 */  "VREGD_V12",
  /*  124 */  "VREGD_V13",
  /*  125 */  "VREGD_V14",
  /*  126 */  "VREGD_V15",
  /*  127 */  "VREGD_V16",
  /*  128 */  "VREGD_V17",
  /*  129 */  "VREGD_V18",
  /*  130 */  "VREGD_V19",
  /*  131 */  "VREGD_V20",
  /*  132 */  "VREGD_V21",
  /*  133 */  "VREGD_V22",
  /*  134 */  "VREGD_V23",
  /*  135 */  "VREGD_V24",
  /*  136 */  "VREGD_V25",
  /*  137 */  "VREGD_V26",
  /*  138 */  "VREGD_V27",
  /*  139 */  "VREGD_V28",
  /*  140 */  "VREGD_V29",
  /*  141 */  "VREGD_V30",
  /*  142 */  "VREGD_V31",
  /*  143 */  "PREGGOV",
  /*  144 */  "RFLAGSREG",
  /*  145 */  "RFLAGSREGU",
  /*  146 */  "INLINE_CACHE_REGP",
  /*  147 */  "THREAD_REGP",
  /*  148 */  "LR_REGP",
  /*  149 */  "INDIRECT",
  /*  150 */  "INDINDEXSCALEDI2L",
  /*  151 */  "INDINDEXSCALED",
  /*  152 */  "INDINDEXI2L",
  /*  153 */  "INDINDEX",
  /*  154 */  "INDOFFI",
  /*  155 */  "INDOFFI1",
  /*  156 */  "INDOFFI2",
  /*  157 */  "INDOFFI4",
  /*  158 */  "INDOFFI8",
  /*  159 */  "INDOFFI16",
  /*  160 */  "INDOFFL",
  /*  161 */  "INDOFFL1",
  /*  162 */  "INDOFFL2",
  /*  163 */  "INDOFFL4",
  /*  164 */  "INDOFFL8",
  /*  165 */  "INDOFFL16",
  /*  166 */  "INDIRECTN",
  /*  167 */  "INDINDEXSCALEDI2LN",
  /*  168 */  "INDINDEXSCALEDN",
  /*  169 */  "INDINDEXI2LN",
  /*  170 */  "INDINDEXN",
  /*  171 */  "INDOFFIN",
  /*  172 */  "INDOFFLN",
  /*  173 */  "THREAD_ANCHOR_PC",
  /*  174 */  "STACKSLOTP",
  /*  175 */  "STACKSLOTI",
  /*  176 */  "STACKSLOTF",
  /*  177 */  "STACKSLOTD",
  /*  178 */  "STACKSLOTL",
  /*  179 */  "CMPOP",
  /*  180 */  "CMPOPU",
  /*  181 */  "CMPOPEQNE",
  /*  182 */  "CMPOPLTGE",
  /*  183 */  "CMPOPUEQNELTGE",
  /*  184 */  "IREGL2I",
  /*  185 */  "VMEMA_IMMIOFFSET4",
  /*  186 */  "VMEMA_IMMLOFFSET4",
  /*  187 */  "VMEMA_INDOFFI4",
  /*  188 */  "VMEMA_INDOFFL4",
  // last operand
  /*  189 */  "VMEM2",
  /*  190 */  "VMEM4",
  /*  191 */  "VMEM8",
  /*  192 */  "VMEM16",
  /*  193 */  "MEMORY1",
  /*  194 */  "MEMORY2",
  /*  195 */  "MEMORY4",
  /*  196 */  "MEMORY8",
  /*  197 */  "MEMORY",
  /*  198 */  "IREGIORL2I",
  /*  199 */  "VMEMA",
  // last operand class
  /*  200 */  "_ConvI2L_iRegI_",
  /*  201 */  "_LShiftL__ConvI2L_iRegI__immIScale",
  /*  202 */  "_LShiftL_iRegL_immIScale",
  /*  203 */  "_DecodeN_iRegN_",
  /*  204 */  "_LoadB_memory1_",
  /*  205 */  "_LoadUB_memory1_",
  /*  206 */  "_LoadS_memory2_",
  /*  207 */  "_LoadUS_memory2_",
  /*  208 */  "_LoadI_memory4_",
  /*  209 */  "_ConvI2L__LoadI_memory4__",
  /*  210 */  "_LoadB_indirect_",
  /*  211 */  "_LoadUB_indirect_",
  /*  212 */  "_LoadUS_indirect_",
  /*  213 */  "_LoadS_indirect_",
  /*  214 */  "_LoadI_indirect_",
  /*  215 */  "_ConvI2L__LoadI_indirect__",
  /*  216 */  "_LoadL_memory8_",
  /*  217 */  "_CastP2X_iRegP_",
  /*  218 */  "_CastP2X__DecodeN_iRegN__",
  /*  219 */  "_Binary_iRegP_iRegP",
  /*  220 */  "_Binary_iRegLNoSp_iRegLNoSp",
  /*  221 */  "_Binary_iRegINoSp_iRegINoSp",
  /*  222 */  "_Binary_iRegNNoSp_iRegNNoSp",
  /*  223 */  "_Binary_iRegI_iRegI",
  /*  224 */  "_Binary_iRegL_iRegL",
  /*  225 */  "_Binary_iRegN_iRegN",
  /*  226 */  "_Binary_cmpOp_rFlagsReg",
  /*  227 */  "_Binary_iRegIorL2I_iRegIorL2I",
  /*  228 */  "_Binary_cmpOpU_rFlagsRegU",
  /*  229 */  "_Binary_immI0_iRegIorL2I",
  /*  230 */  "_Binary_iRegIorL2I_immI0",
  /*  231 */  "_Binary_immI_1_immI0",
  /*  232 */  "_Binary_iRegL_immL0",
  /*  233 */  "_Binary_immL0_iRegL",
  /*  234 */  "_Binary_iRegP_immP0",
  /*  235 */  "_Binary_immP0_iRegP",
  /*  236 */  "_Binary_iRegN_immN0",
  /*  237 */  "_Binary_immN0_iRegN",
  /*  238 */  "_Binary_vRegF_vRegF",
  /*  239 */  "_Binary_vRegD_vRegD",
  /*  240 */  "_ConvL2I_iRegL_",
  /*  241 */  "_ConvI2L_iRegIorL2I_",
  /*  242 */  "_LShiftL__ConvI2L_iRegIorL2I__immIScale",
  /*  243 */  "_MulI_iRegIorL2I_iRegIorL2I",
  /*  244 */  "_SubI_immI0_iRegIorL2I",
  /*  245 */  "_MulL_iRegL_iRegL",
  /*  246 */  "_SubL_immL0_iRegL",
  /*  247 */  "_MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I_",
  /*  248 */  "_SubL_immL0__ConvI2L_iRegIorL2I_",
  /*  249 */  "_XorI_iRegIorL2I_immI_M1",
  /*  250 */  "_XorL_iRegL_immL_M1",
  /*  251 */  "_XorI_iRegIorL2I_iRegIorL2I",
  /*  252 */  "_XorL_iRegL_iRegL",
  /*  253 */  "_URShiftI_iRegIorL2I_immI",
  /*  254 */  "_XorI__URShiftI_iRegIorL2I_immI_immI_M1",
  /*  255 */  "_URShiftL_iRegL_immI",
  /*  256 */  "_XorL__URShiftL_iRegL_immI_immL_M1",
  /*  257 */  "_RShiftI_iRegIorL2I_immI",
  /*  258 */  "_XorI__RShiftI_iRegIorL2I_immI_immI_M1",
  /*  259 */  "_RShiftL_iRegL_immI",
  /*  260 */  "_XorL__RShiftL_iRegL_immI_immL_M1",
  /*  261 */  "_RotateRight_iRegIorL2I_immI",
  /*  262 */  "_XorI__RotateRight_iRegIorL2I_immI_immI_M1",
  /*  263 */  "_RotateRight_iRegL_immI",
  /*  264 */  "_XorL__RotateRight_iRegL_immI_immL_M1",
  /*  265 */  "_LShiftI_iRegIorL2I_immI",
  /*  266 */  "_XorI__LShiftI_iRegIorL2I_immI_immI_M1",
  /*  267 */  "_LShiftL_iRegL_immI",
  /*  268 */  "_XorL__LShiftL_iRegL_immI_immL_M1",
  /*  269 */  "_XorI__URShiftI_iRegIorL2I_immI_iRegIorL2I",
  /*  270 */  "_XorI_iRegIorL2I__URShiftI_iRegIorL2I_immI",
  /*  271 */  "_XorL__URShiftL_iRegL_immI_iRegL",
  /*  272 */  "_XorL_iRegL__URShiftL_iRegL_immI",
  /*  273 */  "_XorI__RShiftI_iRegIorL2I_immI_iRegIorL2I",
  /*  274 */  "_XorI_iRegIorL2I__RShiftI_iRegIorL2I_immI",
  /*  275 */  "_XorL__RShiftL_iRegL_immI_iRegL",
  /*  276 */  "_XorL_iRegL__RShiftL_iRegL_immI",
  /*  277 */  "_XorI__RotateRight_iRegIorL2I_immI_iRegIorL2I",
  /*  278 */  "_XorI_iRegIorL2I__RotateRight_iRegIorL2I_immI",
  /*  279 */  "_XorL__RotateRight_iRegL_immI_iRegL",
  /*  280 */  "_XorL_iRegL__RotateRight_iRegL_immI",
  /*  281 */  "_XorI__LShiftI_iRegIorL2I_immI_iRegIorL2I",
  /*  282 */  "_XorI_iRegIorL2I__LShiftI_iRegIorL2I_immI",
  /*  283 */  "_XorL__LShiftL_iRegL_immI_iRegL",
  /*  284 */  "_XorL_iRegL__LShiftL_iRegL_immI",
  /*  285 */  "_AndI__URShiftI_iRegIorL2I_immI_immI_bitmask",
  /*  286 */  "_AndI_iRegIorL2I_immI_bitmask",
  /*  287 */  "_AndL_iRegL_immL_bitmask",
  /*  288 */  "_LShiftI__AndI_iRegIorL2I_immI_bitmask_immI",
  /*  289 */  "_AndL_iRegL_immL_positive_bitmaskI",
  /*  290 */  "_LShiftL__AndL_iRegL_immL_positive_bitmaskI_immI",
  /*  291 */  "_ConvI2L__AndI_iRegIorL2I_immI_bitmask_",
  /*  292 */  "_ConvL2I__AndL_iRegL_immL_positive_bitmaskI_",
  /*  293 */  "_AndI_iRegI_immI_bitmask",
  /*  294 */  "_LShiftI_iRegIorL2I_immI_16",
  /*  295 */  "_RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16",
  /*  296 */  "_LShiftI_iRegIorL2I_immI_24",
  /*  297 */  "_RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24",
  /*  298 */  "_URShiftI__LShiftI_iRegIorL2I_immI_24_immI_24",
  /*  299 */  "_LShiftL_iRegL_immI_48",
  /*  300 */  "_RShiftL__LShiftL_iRegL_immI_48_immI_48",
  /*  301 */  "_LShiftL_iRegL_immI_32",
  /*  302 */  "_RShiftL__LShiftL_iRegL_immI_32_immI_32",
  /*  303 */  "_LShiftL_iRegL_immI_56",
  /*  304 */  "_RShiftL__LShiftL_iRegL_immI_56_immI_56",
  /*  305 */  "_URShiftL__LShiftL_iRegL_immI_56_immI_56",
  /*  306 */  "_AndI_iRegIorL2I_immI_255",
  /*  307 */  "_AndI_iRegIorL2I_immI_65535",
  /*  308 */  "_AndL_iRegL_immL_255",
  /*  309 */  "_AndL_iRegL_immL_65535",
  /*  310 */  "_AndL_iRegL_immL_4294967295",
  /*  311 */  "_LShiftL__RShiftL__LShiftL_iRegL_immI_56_immI_56_immIExt",
  /*  312 */  "_LShiftL__RShiftL__LShiftL_iRegL_immI_48_immI_48_immIExt",
  /*  313 */  "_LShiftL__RShiftL__LShiftL_iRegL_immI_32_immI_32_immIExt",
  /*  314 */  "_LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_immIExt",
  /*  315 */  "_LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_immIExt",
  /*  316 */  "_LShiftL__ConvI2L_iRegIorL2I__immIExt",
  /*  317 */  "_LShiftL__AndL_iRegL_immL_255_immIExt",
  /*  318 */  "_LShiftL__AndL_iRegL_immL_65535_immIExt",
  /*  319 */  "_LShiftL__AndL_iRegL_immL_4294967295_immIExt",
  /*  320 */  "_LShiftI__AndI_iRegIorL2I_immI_255_immIExt",
  /*  321 */  "_LShiftI__AndI_iRegIorL2I_immI_65535_immIExt",
  /*  322 */  "_NegF_vRegF_",
  /*  323 */  "_Binary__NegF_vRegF__vRegF",
  /*  324 */  "_Binary_vRegF__NegF_vRegF_",
  /*  325 */  "_NegD_vRegD_",
  /*  326 */  "_Binary__NegD_vRegD__vRegD",
  /*  327 */  "_Binary_vRegD__NegD_vRegD_",
  /*  328 */  "_SubF_vRegF_vRegF",
  /*  329 */  "_SubD_vRegD_vRegD",
  /*  330 */  "_OverflowMulI_iRegIorL2I_iRegIorL2I",
  /*  331 */  "_OverflowMulL_iRegL_iRegL",
  /*  332 */  "_CmpI_iRegIorL2I_immI0",
  /*  333 */  "_CmpL_iRegL_immL0",
  /*  334 */  "_CmpP_iRegP_immP0",
  /*  335 */  "_CmpN_iRegN_immN0",
  /*  336 */  "_CmpP__DecodeN_iRegN__immP0",
  /*  337 */  "_CmpU_iRegIorL2I_immI0",
  /*  338 */  "_CmpUL_iRegL_immL0",
  /*  339 */  "_AndL_iRegL_immL",
  /*  340 */  "_CmpL__AndL_iRegL_immL_immL0",
  /*  341 */  "_AndI_iRegIorL2I_immI",
  /*  342 */  "_CmpI__AndI_iRegIorL2I_immI_immI0",
  /*  343 */  "_AndL_iRegL_iRegL",
  /*  344 */  "_AndI_iRegIorL2I_iRegIorL2I",
  /*  345 */  "_PartialSubtypeCheck_iRegP_R4_iRegP_R0",
  /*  346 */  "_Binary_iRegP_R1_iRegI_R2",
  /*  347 */  "_Binary_iRegP_R3_iRegI_R4",
  /*  348 */  "_Binary_iRegP_R1_iRegI_R4",
  /*  349 */  "_Binary_iRegP_R3_iRegI_R2",
  /*  350 */  "_Binary_iRegP_R3_immI_le_4",
  /*  351 */  "_Binary_iRegP_R3_immI_1",
  /*  352 */  "_Binary_iRegP_R1_iRegP_R3",
  /*  353 */  "_Binary_iRegP_R1_iRegI_R3",
  /*  354 */  "_Binary_vecD_iRegIorL2I",
  /*  355 */  "_Binary_vecX_iRegIorL2I",
  /*  356 */  "_Binary_vecX_iRegL",
  /*  357 */  "_Binary_vecD_vRegF",
  /*  358 */  "_Binary_vecX_vRegF",
  /*  359 */  "_Binary_vecX_vRegD",
  /*  360 */  "_Binary_vecD_vecD",
  /*  361 */  "_Binary_vecX_vecX",
  /*  362 */  "_ReplicateB_immI_M1_",
  /*  363 */  "_ReplicateS_immI_M1_",
  /*  364 */  "_ReplicateI_immI_M1_",
  /*  365 */  "_ReplicateL_immL_M1_",
  /*  366 */  "_XorV_vecD__ReplicateB_immI_M1_",
  /*  367 */  "_XorV__ReplicateB_immI_M1__vecD",
  /*  368 */  "_XorV_vecD__ReplicateS_immI_M1_",
  /*  369 */  "_XorV__ReplicateS_immI_M1__vecD",
  /*  370 */  "_XorV_vecD__ReplicateI_immI_M1_",
  /*  371 */  "_XorV__ReplicateI_immI_M1__vecD",
  /*  372 */  "_XorV_vecX__ReplicateB_immI_M1_",
  /*  373 */  "_XorV__ReplicateB_immI_M1__vecX",
  /*  374 */  "_XorV_vecX__ReplicateS_immI_M1_",
  /*  375 */  "_XorV__ReplicateS_immI_M1__vecX",
  /*  376 */  "_XorV_vecX__ReplicateI_immI_M1_",
  /*  377 */  "_XorV__ReplicateI_immI_M1__vecX",
  /*  378 */  "_XorV_vecX__ReplicateL_immL_M1_",
  /*  379 */  "_XorV__ReplicateL_immL_M1__vecX",
  /*  380 */  "_SubVF_vecD_vecD",
  /*  381 */  "_SubVF_vecX_vecX",
  /*  382 */  "_SubVD_vecX_vecX",
  /*  383 */  "_MulVS_vecD_vecD",
  /*  384 */  "_MulVS_vecX_vecX",
  /*  385 */  "_MulVI_vecD_vecD",
  /*  386 */  "_MulVI_vecX_vecX",
  /*  387 */  "_NegVF_vecD_",
  /*  388 */  "_Binary__NegVF_vecD__vecD",
  /*  389 */  "_Binary_vecD__NegVF_vecD_",
  /*  390 */  "_NegVF_vecX_",
  /*  391 */  "_Binary__NegVF_vecX__vecX",
  /*  392 */  "_Binary_vecX__NegVF_vecX_",
  /*  393 */  "_NegVD_vecX_",
  /*  394 */  "_Binary__NegVD_vecX__vecX",
  /*  395 */  "_Binary_vecX__NegVD_vecX_",
  /*  396 */  "_LShiftCntV_immI_",
  /*  397 */  "_RShiftCntV_immI_",
  /*  398 */  "_RShiftVB_vecD__RShiftCntV_immI_",
  /*  399 */  "_RShiftVB_vecX__RShiftCntV_immI_",
  /*  400 */  "_RShiftVS_vecD__RShiftCntV_immI_",
  /*  401 */  "_RShiftVS_vecX__RShiftCntV_immI_",
  /*  402 */  "_RShiftVI_vecD__RShiftCntV_immI_",
  /*  403 */  "_RShiftVI_vecX__RShiftCntV_immI_",
  /*  404 */  "_RShiftVL_vecX__RShiftCntV_immI_",
  /*  405 */  "_URShiftVB_vecD__RShiftCntV_immI_",
  /*  406 */  "_URShiftVB_vecX__RShiftCntV_immI_",
  /*  407 */  "_URShiftVS_vecD__RShiftCntV_immI_",
  /*  408 */  "_URShiftVS_vecX__RShiftCntV_immI_",
  /*  409 */  "_URShiftVI_vecD__RShiftCntV_immI_",
  /*  410 */  "_URShiftVI_vecX__RShiftCntV_immI_",
  /*  411 */  "_URShiftVL_vecX__RShiftCntV_immI_",
  /*  412 */  "_XorV_vReg__ReplicateB_immI_M1_",
  /*  413 */  "_XorV__ReplicateB_immI_M1__vReg",
  /*  414 */  "_XorV_vReg__ReplicateS_immI_M1_",
  /*  415 */  "_XorV__ReplicateS_immI_M1__vReg",
  /*  416 */  "_XorV_vReg__ReplicateI_immI_M1_",
  /*  417 */  "_XorV__ReplicateI_immI_M1__vReg",
  /*  418 */  "_XorV_vReg__ReplicateL_immL_M1_",
  /*  419 */  "_XorV__ReplicateL_immL_M1__vReg",
  /*  420 */  "_Binary_vReg_vReg",
  /*  421 */  "_NegVF_vReg_",
  /*  422 */  "_Binary__NegVF_vReg__vReg",
  /*  423 */  "_Binary_vReg__NegVF_vReg_",
  /*  424 */  "_NegVD_vReg_",
  /*  425 */  "_Binary__NegVD_vReg__vReg",
  /*  426 */  "_Binary_vReg__NegVD_vReg_",
  /*  427 */  "_MulVB_vReg_vReg",
  /*  428 */  "_MulVS_vReg_vReg",
  /*  429 */  "_MulVI_vReg_vReg",
  /*  430 */  "_MulVL_vReg_vReg",
  // last internally defined operand
  /*  431 */  "loadConI",
  /*  432 */  "loadConL",
  /*  433 */  "loadConP",
  /*  434 */  "loadConP0",
  /*  435 */  "loadConP1",
  /*  436 */  "loadByteMapBase",
  /*  437 */  "loadConN",
  /*  438 */  "loadConN0",
  /*  439 */  "loadConNKlass",
  /*  440 */  "loadConF_packed",
  /*  441 */  "loadConF",
  /*  442 */  "loadConD_packed",
  /*  443 */  "loadConD",
  /*  444 */  "countLeadingZerosI",
  /*  445 */  "countLeadingZerosL",
  /*  446 */  "countTrailingZerosI",
  /*  447 */  "countTrailingZerosL",
  /*  448 */  "castX2P",
  /*  449 */  "castP2X",
  /*  450 */  "checkCastPP",
  /*  451 */  "castPP",
  /*  452 */  "castII",
  /*  453 */  "castLL",
  /*  454 */  "castFF",
  /*  455 */  "castDD",
  /*  456 */  "castVVD",
  /*  457 */  "castVVX",
  /*  458 */  "castVV",
  /*  459 */  "storePConditional",
  /*  460 */  "storeLConditional",
  /*  461 */  "storeIConditional",
  /*  462 */  "negF_reg_reg",
  /*  463 */  "negD_reg_reg",
  /*  464 */  "absF_reg",
  /*  465 */  "absD_reg",
  /*  466 */  "MoveF2I_stack_reg",
  /*  467 */  "MoveI2F_stack_reg",
  /*  468 */  "MoveD2L_stack_reg",
  /*  469 */  "MoveL2D_stack_reg",
  /*  470 */  "MoveF2I_reg_reg",
  /*  471 */  "MoveI2F_reg_reg",
  /*  472 */  "MoveD2L_reg_reg",
  /*  473 */  "MoveL2D_reg_reg",
  /*  474 */  "overflowAddI_reg_reg",
  /*  475 */  "overflowAddI_reg_imm",
  /*  476 */  "overflowAddL_reg_reg",
  /*  477 */  "overflowAddL_reg_imm",
  /*  478 */  "overflowSubI_reg_reg",
  /*  479 */  "overflowSubI_reg_imm",
  /*  480 */  "overflowSubL_reg_reg",
  /*  481 */  "overflowSubL_reg_imm",
  /*  482 */  "overflowNegI_reg",
  /*  483 */  "overflowNegL_reg",
  /*  484 */  "overflowMulI_reg",
  /*  485 */  "overflowMulL_reg",
  /*  486 */  "compI_reg_reg",
  /*  487 */  "compI_reg_immI0",
  /*  488 */  "compI_reg_immIAddSub",
  /*  489 */  "compI_reg_immI",
  /*  490 */  "compU_reg_reg",
  /*  491 */  "compU_reg_immI0",
  /*  492 */  "compU_reg_immIAddSub",
  /*  493 */  "compU_reg_immI",
  /*  494 */  "compL_reg_reg",
  /*  495 */  "compL_reg_immL0",
  /*  496 */  "compL_reg_immLAddSub",
  /*  497 */  "compL_reg_immL",
  /*  498 */  "compUL_reg_reg",
  /*  499 */  "compUL_reg_immL0",
  /*  500 */  "compUL_reg_immLAddSub",
  /*  501 */  "compUL_reg_immL",
  /*  502 */  "compP_reg_reg",
  /*  503 */  "compN_reg_reg",
  /*  504 */  "testP_reg",
  /*  505 */  "testN_reg",
  /*  506 */  "compF_reg_reg",
  /*  507 */  "compF_reg_zero",
  /*  508 */  "compD_reg_reg",
  /*  509 */  "compD_reg_zero",
  /*  510 */  "cmpL_and",
  /*  511 */  "cmpI_and",
  /*  512 */  "cmpL_and_reg",
  /*  513 */  "cmpI_and_reg",
  /*  514 */  "cmpFastLock",
  /*  515 */  "cmpFastUnlock",
  /*  516 */  "partialSubtypeCheckVsZero",
  /*  517 */  "tlsLoadP",
  /*  518 */  "reinterpretD",
  /*  519 */  "reinterpretX",
  /*  520 */  "reinterpretD2X",
  /*  521 */  "reinterpretX2D",
  /*  522 */  "vcvt4Bto4S",
  /*  523 */  "vcvt8Bto8S",
  /*  524 */  "vcvt4Sto4B",
  /*  525 */  "vcvt8Sto8B",
  /*  526 */  "vcvt4Sto4I",
  /*  527 */  "vcvt4Ito4S",
  /*  528 */  "vcvt2Ito2L",
  /*  529 */  "vcvt2Lto2I",
  /*  530 */  "vcvt4Bto4I",
  /*  531 */  "vcvt4Ito4B",
  /*  532 */  "vcvt4Bto4F",
  /*  533 */  "vcvt4Sto4F",
  /*  534 */  "vcvt2Ito2D",
  /*  535 */  "vcvt2Ito2F",
  /*  536 */  "vcvt4Ito4F",
  /*  537 */  "vcvt2Lto2D",
  /*  538 */  "vcvt2Fto2D",
  /*  539 */  "vcvt2Dto2F",
  /*  540 */  "vcvt2Lto2F",
  /*  541 */  "loadmask8B",
  /*  542 */  "loadmask16B",
  /*  543 */  "loadmask4S",
  /*  544 */  "loadmask8S",
  /*  545 */  "loadmask2I",
  /*  546 */  "loadmask4I",
  /*  547 */  "loadmask2L",
  /*  548 */  "vmaskcastD",
  /*  549 */  "vmaskcastX",
  /*  550 */  "loadcon8B",
  /*  551 */  "loadcon16B",
  /*  552 */  "loadshuffle8B",
  /*  553 */  "loadshuffle16B",
  /*  554 */  "loadshuffle4S",
  /*  555 */  "loadshuffle8S",
  /*  556 */  "loadshuffle4I",
  /*  557 */  "vabs8B",
  /*  558 */  "vabs16B",
  /*  559 */  "vabs4S",
  /*  560 */  "vabs8S",
  /*  561 */  "vabs2I",
  /*  562 */  "vabs4I",
  /*  563 */  "vabs2L",
  /*  564 */  "vabs2F",
  /*  565 */  "vabs4F",
  /*  566 */  "vabs2D",
  /*  567 */  "vsqrt2F",
  /*  568 */  "vsqrt4F",
  /*  569 */  "vsqrt2D",
  /*  570 */  "vneg2F",
  /*  571 */  "vneg4F",
  /*  572 */  "vneg2D",
  /*  573 */  "vshiftcnt8B",
  /*  574 */  "vshiftcnt8B_0",
  /*  575 */  "vshiftcnt16B",
  /*  576 */  "vshiftcnt16B_0",
  /*  577 */  "vpopcount4I",
  /*  578 */  "vpopcount2I",
  /*  579 */  "vabsB",
  /*  580 */  "vabsS",
  /*  581 */  "vabsI",
  /*  582 */  "vabsL",
  /*  583 */  "vabsF",
  /*  584 */  "vabsD",
  /*  585 */  "vnegF",
  /*  586 */  "vnegD",
  /*  587 */  "vpopcountI",
  /*  588 */  "vshiftcntB",
  /*  589 */  "vshiftcntB_0",
  /*  590 */  "vshiftcntS",
  /*  591 */  "vshiftcntS_0",
  /*  592 */  "vshiftcntI",
  /*  593 */  "vshiftcntI_0",
  /*  594 */  "vshiftcntL",
  /*  595 */  "vshiftcntL_0",
  /*  596 */  "vsqrtF",
  /*  597 */  "vsqrtD",
  /*  598 */  "vmaskcast",
  /*  599 */  "loadB",
  /*  600 */  "loadB2L",
  /*  601 */  "loadUB",
  /*  602 */  "loadUB2L",
  /*  603 */  "loadS",
  /*  604 */  "loadS2L",
  /*  605 */  "loadUS",
  /*  606 */  "loadUS2L",
  /*  607 */  "loadI",
  /*  608 */  "loadI2L",
  /*  609 */  "loadUI2L",
  /*  610 */  "loadL",
  /*  611 */  "loadRange",
  /*  612 */  "loadP",
  /*  613 */  "loadN",
  /*  614 */  "loadKlass",
  /*  615 */  "loadNKlass",
  /*  616 */  "loadF",
  /*  617 */  "loadD",
  /*  618 */  "storeimmCM0",
  /*  619 */  "storeimmCM0_ordered",
  /*  620 */  "storeB",
  /*  621 */  "storeimmB0",
  /*  622 */  "storeC",
  /*  623 */  "storeimmC0",
  /*  624 */  "storeI",
  /*  625 */  "storeimmI0",
  /*  626 */  "storeL",
  /*  627 */  "storeimmL0",
  /*  628 */  "storeP",
  /*  629 */  "storeimmP0",
  /*  630 */  "storeN",
  /*  631 */  "storeImmN0",
  /*  632 */  "storeF",
  /*  633 */  "storeD",
  /*  634 */  "storeNKlass",
  /*  635 */  "prefetchalloc",
  /*  636 */  "loadB_volatile",
  /*  637 */  "loadB2L_volatile",
  /*  638 */  "loadUB_volatile",
  /*  639 */  "loadUB2L_volatile",
  /*  640 */  "loadS_volatile",
  /*  641 */  "loadUS_volatile",
  /*  642 */  "loadUS2L_volatile",
  /*  643 */  "loadS2L_volatile",
  /*  644 */  "loadI_volatile",
  /*  645 */  "loadUI2L_volatile",
  /*  646 */  "loadL_volatile",
  /*  647 */  "loadP_volatile",
  /*  648 */  "loadN_volatile",
  /*  649 */  "loadF_volatile",
  /*  650 */  "loadD_volatile",
  /*  651 */  "storeB_volatile",
  /*  652 */  "storeC_volatile",
  /*  653 */  "storeI_volatile",
  /*  654 */  "storeL_volatile",
  /*  655 */  "storeP_volatile",
  /*  656 */  "storeN_volatile",
  /*  657 */  "storeF_volatile",
  /*  658 */  "storeD_volatile",
  /*  659 */  "cacheWB",
  /*  660 */  "cacheWBPreSync",
  /*  661 */  "cacheWBPostSync",
  /*  662 */  "bytes_reverse_int",
  /*  663 */  "bytes_reverse_long",
  /*  664 */  "bytes_reverse_unsigned_short",
  /*  665 */  "bytes_reverse_short",
  /*  666 */  "popCountI",
  /*  667 */  "popCountI_mem",
  /*  668 */  "popCountL",
  /*  669 */  "popCountL_mem",
  /*  670 */  "load_fence",
  /*  671 */  "unnecessary_membar_acquire",
  /*  672 */  "membar_acquire",
  /*  673 */  "membar_acquire_lock",
  /*  674 */  "store_fence",
  /*  675 */  "unnecessary_membar_release",
  /*  676 */  "membar_release",
  /*  677 */  "membar_storestore",
  /*  678 */  "membar_release_lock",
  /*  679 */  "unnecessary_membar_volatile",
  /*  680 */  "membar_volatile",
  /*  681 */  "convP2I",
  /*  682 */  "convN2I",
  /*  683 */  "encodeHeapOop",
  /*  684 */  "encodeHeapOop_not_null",
  /*  685 */  "decodeHeapOop",
  /*  686 */  "decodeHeapOop_not_null",
  /*  687 */  "encodeKlass_not_null",
  /*  688 */  "decodeKlass_not_null",
  /*  689 */  "loadPLocked",
  /*  690 */  "compareAndSwapB",
  /*  691 */  "compareAndSwapS",
  /*  692 */  "compareAndSwapI",
  /*  693 */  "compareAndSwapL",
  /*  694 */  "compareAndSwapP",
  /*  695 */  "compareAndSwapN",
  /*  696 */  "compareAndSwapBAcq",
  /*  697 */  "compareAndSwapSAcq",
  /*  698 */  "compareAndSwapIAcq",
  /*  699 */  "compareAndSwapLAcq",
  /*  700 */  "compareAndSwapPAcq",
  /*  701 */  "compareAndSwapNAcq",
  /*  702 */  "compareAndExchangeB",
  /*  703 */  "compareAndExchangeS",
  /*  704 */  "compareAndExchangeI",
  /*  705 */  "compareAndExchangeL",
  /*  706 */  "compareAndExchangeN",
  /*  707 */  "compareAndExchangeP",
  /*  708 */  "compareAndExchangeBAcq",
  /*  709 */  "compareAndExchangeSAcq",
  /*  710 */  "compareAndExchangeIAcq",
  /*  711 */  "compareAndExchangeLAcq",
  /*  712 */  "compareAndExchangeNAcq",
  /*  713 */  "compareAndExchangePAcq",
  /*  714 */  "weakCompareAndSwapB",
  /*  715 */  "weakCompareAndSwapS",
  /*  716 */  "weakCompareAndSwapI",
  /*  717 */  "weakCompareAndSwapL",
  /*  718 */  "weakCompareAndSwapN",
  /*  719 */  "weakCompareAndSwapP",
  /*  720 */  "weakCompareAndSwapBAcq",
  /*  721 */  "weakCompareAndSwapSAcq",
  /*  722 */  "weakCompareAndSwapIAcq",
  /*  723 */  "weakCompareAndSwapLAcq",
  /*  724 */  "weakCompareAndSwapNAcq",
  /*  725 */  "weakCompareAndSwapPAcq",
  /*  726 */  "get_and_setI",
  /*  727 */  "get_and_setL",
  /*  728 */  "get_and_setN",
  /*  729 */  "get_and_setP",
  /*  730 */  "get_and_setIAcq",
  /*  731 */  "get_and_setLAcq",
  /*  732 */  "get_and_setNAcq",
  /*  733 */  "get_and_setPAcq",
  /*  734 */  "get_and_addL",
  /*  735 */  "get_and_addL_no_res",
  /*  736 */  "get_and_addLi",
  /*  737 */  "get_and_addLi_no_res",
  /*  738 */  "get_and_addI",
  /*  739 */  "get_and_addI_no_res",
  /*  740 */  "get_and_addIi",
  /*  741 */  "get_and_addIi_no_res",
  /*  742 */  "get_and_addLAcq",
  /*  743 */  "get_and_addL_no_resAcq",
  /*  744 */  "get_and_addLiAcq",
  /*  745 */  "get_and_addLi_no_resAcq",
  /*  746 */  "get_and_addIAcq",
  /*  747 */  "get_and_addI_no_resAcq",
  /*  748 */  "get_and_addIiAcq",
  /*  749 */  "get_and_addIi_no_resAcq",
  /*  750 */  "cmpL3_reg_reg",
  /*  751 */  "cmpL3_reg_imm",
  /*  752 */  "cmovI_reg_reg",
  /*  753 */  "cmovUI_reg_reg",
  /*  754 */  "cmovI_zero_reg",
  /*  755 */  "cmovUI_zero_reg",
  /*  756 */  "cmovI_reg_zero",
  /*  757 */  "cmovUI_reg_zero",
  /*  758 */  "cmovI_reg_zero_one",
  /*  759 */  "cmovUI_reg_zero_one",
  /*  760 */  "cmovL_reg_reg",
  /*  761 */  "cmovUL_reg_reg",
  /*  762 */  "cmovL_reg_zero",
  /*  763 */  "cmovUL_reg_zero",
  /*  764 */  "cmovL_zero_reg",
  /*  765 */  "cmovUL_zero_reg",
  /*  766 */  "cmovP_reg_reg",
  /*  767 */  "cmovUP_reg_reg",
  /*  768 */  "cmovP_reg_zero",
  /*  769 */  "cmovUP_reg_zero",
  /*  770 */  "cmovP_zero_reg",
  /*  771 */  "cmovUP_zero_reg",
  /*  772 */  "cmovN_reg_reg",
  /*  773 */  "cmovUN_reg_reg",
  /*  774 */  "cmovN_reg_zero",
  /*  775 */  "cmovUN_reg_zero",
  /*  776 */  "cmovN_zero_reg",
  /*  777 */  "cmovUN_zero_reg",
  /*  778 */  "cmovF_reg",
  /*  779 */  "cmovUF_reg",
  /*  780 */  "cmovD_reg",
  /*  781 */  "cmovUD_reg",
  /*  782 */  "addI_reg_reg",
  /*  783 */  "addI_reg_imm",
  /*  784 */  "addI_reg_imm_i2l",
  /*  785 */  "addP_reg_reg",
  /*  786 */  "addP_reg_reg_ext",
  /*  787 */  "addP_reg_reg_lsl",
  /*  788 */  "addP_reg_reg_ext_shift",
  /*  789 */  "lshift_ext",
  /*  790 */  "addP_reg_imm",
  /*  791 */  "addL_reg_reg",
  /*  792 */  "addL_reg_imm",
  /*  793 */  "subI_reg_reg",
  /*  794 */  "subI_reg_imm",
  /*  795 */  "subL_reg_reg",
  /*  796 */  "subL_reg_imm",
  /*  797 */  "negI_reg",
  /*  798 */  "negL_reg",
  /*  799 */  "mulI",
  /*  800 */  "smulI",
  /*  801 */  "smulI_0",
  /*  802 */  "mulL",
  /*  803 */  "mulHiL_rReg",
  /*  804 */  "maddI",
  /*  805 */  "maddI_0",
  /*  806 */  "msubI",
  /*  807 */  "mnegI",
  /*  808 */  "mnegI_0",
  /*  809 */  "mnegI_1",
  /*  810 */  "mnegI_2",
  /*  811 */  "maddL",
  /*  812 */  "maddL_0",
  /*  813 */  "msubL",
  /*  814 */  "mnegL",
  /*  815 */  "mnegL_0",
  /*  816 */  "mnegL_1",
  /*  817 */  "mnegL_2",
  /*  818 */  "smaddL",
  /*  819 */  "smaddL_1",
  /*  820 */  "smaddL_0",
  /*  821 */  "smaddL_2",
  /*  822 */  "smsubL",
  /*  823 */  "smsubL_0",
  /*  824 */  "smnegL",
  /*  825 */  "smnegL_0",
  /*  826 */  "smnegL_1",
  /*  827 */  "smnegL_2",
  /*  828 */  "muladdS2I",
  /*  829 */  "divI",
  /*  830 */  "divL",
  /*  831 */  "modI",
  /*  832 */  "modL",
  /*  833 */  "lShiftI_reg_reg",
  /*  834 */  "lShiftI_reg_imm",
  /*  835 */  "urShiftI_reg_reg",
  /*  836 */  "urShiftI_reg_imm",
  /*  837 */  "rShiftI_reg_reg",
  /*  838 */  "rShiftI_reg_imm",
  /*  839 */  "lShiftL_reg_reg",
  /*  840 */  "lShiftL_reg_imm",
  /*  841 */  "urShiftL_reg_reg",
  /*  842 */  "urShiftL_reg_imm",
  /*  843 */  "urShiftP_reg_imm",
  /*  844 */  "rShiftL_reg_reg",
  /*  845 */  "rShiftL_reg_imm",
  /*  846 */  "regL_not_reg",
  /*  847 */  "regI_not_reg",
  /*  848 */  "AndI_reg_not_reg",
  /*  849 */  "AndI_reg_not_reg_0",
  /*  850 */  "AndL_reg_not_reg",
  /*  851 */  "AndL_reg_not_reg_0",
  /*  852 */  "OrI_reg_not_reg",
  /*  853 */  "OrI_reg_not_reg_0",
  /*  854 */  "OrL_reg_not_reg",
  /*  855 */  "OrL_reg_not_reg_0",
  /*  856 */  "XorI_reg_not_reg",
  /*  857 */  "XorI_reg_not_reg_0",
  /*  858 */  "XorL_reg_not_reg",
  /*  859 */  "XorL_reg_not_reg_0",
  /*  860 */  "AndI_reg_URShift_not_reg",
  /*  861 */  "AndI_reg_URShift_not_reg_0",
  /*  862 */  "AndL_reg_URShift_not_reg",
  /*  863 */  "AndL_reg_URShift_not_reg_0",
  /*  864 */  "AndI_reg_RShift_not_reg",
  /*  865 */  "AndI_reg_RShift_not_reg_0",
  /*  866 */  "AndL_reg_RShift_not_reg",
  /*  867 */  "AndL_reg_RShift_not_reg_0",
  /*  868 */  "AndI_reg_RotateRight_not_reg",
  /*  869 */  "AndI_reg_RotateRight_not_reg_0",
  /*  870 */  "AndL_reg_RotateRight_not_reg",
  /*  871 */  "AndL_reg_RotateRight_not_reg_0",
  /*  872 */  "AndI_reg_LShift_not_reg",
  /*  873 */  "AndI_reg_LShift_not_reg_0",
  /*  874 */  "AndL_reg_LShift_not_reg",
  /*  875 */  "AndL_reg_LShift_not_reg_0",
  /*  876 */  "XorI_reg_URShift_not_reg",
  /*  877 */  "XorI_reg_URShift_not_reg_1",
  /*  878 */  "XorI_reg_URShift_not_reg_0",
  /*  879 */  "XorI_reg_URShift_not_reg_2",
  /*  880 */  "XorL_reg_URShift_not_reg",
  /*  881 */  "XorL_reg_URShift_not_reg_1",
  /*  882 */  "XorL_reg_URShift_not_reg_0",
  /*  883 */  "XorL_reg_URShift_not_reg_2",
  /*  884 */  "XorI_reg_RShift_not_reg",
  /*  885 */  "XorI_reg_RShift_not_reg_1",
  /*  886 */  "XorI_reg_RShift_not_reg_0",
  /*  887 */  "XorI_reg_RShift_not_reg_2",
  /*  888 */  "XorL_reg_RShift_not_reg",
  /*  889 */  "XorL_reg_RShift_not_reg_1",
  /*  890 */  "XorL_reg_RShift_not_reg_0",
  /*  891 */  "XorL_reg_RShift_not_reg_2",
  /*  892 */  "XorI_reg_RotateRight_not_reg",
  /*  893 */  "XorI_reg_RotateRight_not_reg_1",
  /*  894 */  "XorI_reg_RotateRight_not_reg_0",
  /*  895 */  "XorI_reg_RotateRight_not_reg_2",
  /*  896 */  "XorL_reg_RotateRight_not_reg",
  /*  897 */  "XorL_reg_RotateRight_not_reg_1",
  /*  898 */  "XorL_reg_RotateRight_not_reg_0",
  /*  899 */  "XorL_reg_RotateRight_not_reg_2",
  /*  900 */  "XorI_reg_LShift_not_reg",
  /*  901 */  "XorI_reg_LShift_not_reg_1",
  /*  902 */  "XorI_reg_LShift_not_reg_0",
  /*  903 */  "XorI_reg_LShift_not_reg_2",
  /*  904 */  "XorL_reg_LShift_not_reg",
  /*  905 */  "XorL_reg_LShift_not_reg_1",
  /*  906 */  "XorL_reg_LShift_not_reg_0",
  /*  907 */  "XorL_reg_LShift_not_reg_2",
  /*  908 */  "OrI_reg_URShift_not_reg",
  /*  909 */  "OrI_reg_URShift_not_reg_0",
  /*  910 */  "OrL_reg_URShift_not_reg",
  /*  911 */  "OrL_reg_URShift_not_reg_0",
  /*  912 */  "OrI_reg_RShift_not_reg",
  /*  913 */  "OrI_reg_RShift_not_reg_0",
  /*  914 */  "OrL_reg_RShift_not_reg",
  /*  915 */  "OrL_reg_RShift_not_reg_0",
  /*  916 */  "OrI_reg_RotateRight_not_reg",
  /*  917 */  "OrI_reg_RotateRight_not_reg_0",
  /*  918 */  "OrL_reg_RotateRight_not_reg",
  /*  919 */  "OrL_reg_RotateRight_not_reg_0",
  /*  920 */  "OrI_reg_LShift_not_reg",
  /*  921 */  "OrI_reg_LShift_not_reg_0",
  /*  922 */  "OrL_reg_LShift_not_reg",
  /*  923 */  "OrL_reg_LShift_not_reg_0",
  /*  924 */  "AndI_reg_URShift_reg",
  /*  925 */  "AndI_reg_URShift_reg_0",
  /*  926 */  "AndL_reg_URShift_reg",
  /*  927 */  "AndL_reg_URShift_reg_0",
  /*  928 */  "AndI_reg_RShift_reg",
  /*  929 */  "AndI_reg_RShift_reg_0",
  /*  930 */  "AndL_reg_RShift_reg",
  /*  931 */  "AndL_reg_RShift_reg_0",
  /*  932 */  "AndI_reg_LShift_reg",
  /*  933 */  "AndI_reg_LShift_reg_0",
  /*  934 */  "AndL_reg_LShift_reg",
  /*  935 */  "AndL_reg_LShift_reg_0",
  /*  936 */  "AndI_reg_RotateRight_reg",
  /*  937 */  "AndI_reg_RotateRight_reg_0",
  /*  938 */  "AndL_reg_RotateRight_reg",
  /*  939 */  "AndL_reg_RotateRight_reg_0",
  /*  940 */  "XorI_reg_URShift_reg",
  /*  941 */  "XorI_reg_URShift_reg_0",
  /*  942 */  "XorL_reg_URShift_reg",
  /*  943 */  "XorL_reg_URShift_reg_0",
  /*  944 */  "XorI_reg_RShift_reg",
  /*  945 */  "XorI_reg_RShift_reg_0",
  /*  946 */  "XorL_reg_RShift_reg",
  /*  947 */  "XorL_reg_RShift_reg_0",
  /*  948 */  "XorI_reg_LShift_reg",
  /*  949 */  "XorI_reg_LShift_reg_0",
  /*  950 */  "XorL_reg_LShift_reg",
  /*  951 */  "XorL_reg_LShift_reg_0",
  /*  952 */  "XorI_reg_RotateRight_reg",
  /*  953 */  "XorI_reg_RotateRight_reg_0",
  /*  954 */  "XorL_reg_RotateRight_reg",
  /*  955 */  "XorL_reg_RotateRight_reg_0",
  /*  956 */  "OrI_reg_URShift_reg",
  /*  957 */  "OrI_reg_URShift_reg_0",
  /*  958 */  "OrL_reg_URShift_reg",
  /*  959 */  "OrL_reg_URShift_reg_0",
  /*  960 */  "OrI_reg_RShift_reg",
  /*  961 */  "OrI_reg_RShift_reg_0",
  /*  962 */  "OrL_reg_RShift_reg",
  /*  963 */  "OrL_reg_RShift_reg_0",
  /*  964 */  "OrI_reg_LShift_reg",
  /*  965 */  "OrI_reg_LShift_reg_0",
  /*  966 */  "OrL_reg_LShift_reg",
  /*  967 */  "OrL_reg_LShift_reg_0",
  /*  968 */  "OrI_reg_RotateRight_reg",
  /*  969 */  "OrI_reg_RotateRight_reg_0",
  /*  970 */  "OrL_reg_RotateRight_reg",
  /*  971 */  "OrL_reg_RotateRight_reg_0",
  /*  972 */  "AddI_reg_URShift_reg",
  /*  973 */  "AddI_reg_URShift_reg_0",
  /*  974 */  "AddL_reg_URShift_reg",
  /*  975 */  "AddL_reg_URShift_reg_0",
  /*  976 */  "AddI_reg_RShift_reg",
  /*  977 */  "AddI_reg_RShift_reg_0",
  /*  978 */  "AddL_reg_RShift_reg",
  /*  979 */  "AddL_reg_RShift_reg_0",
  /*  980 */  "AddI_reg_LShift_reg",
  /*  981 */  "AddI_reg_LShift_reg_0",
  /*  982 */  "AddL_reg_LShift_reg",
  /*  983 */  "AddL_reg_LShift_reg_0",
  /*  984 */  "SubI_reg_URShift_reg",
  /*  985 */  "SubL_reg_URShift_reg",
  /*  986 */  "SubI_reg_RShift_reg",
  /*  987 */  "SubL_reg_RShift_reg",
  /*  988 */  "SubI_reg_LShift_reg",
  /*  989 */  "SubL_reg_LShift_reg",
  /*  990 */  "sbfmL",
  /*  991 */  "sbfmwI",
  /*  992 */  "ubfmL",
  /*  993 */  "ubfmwI",
  /*  994 */  "ubfxwI",
  /*  995 */  "ubfxL",
  /*  996 */  "ubfxIConvI2L",
  /*  997 */  "ubfizwI",
  /*  998 */  "ubfizL",
  /*  999 */  "ubfizwIConvI2L",
  /* 1000 */  "ubfizLConvL2I",
  /* 1001 */  "ubfizIConvI2L",
  /* 1002 */  "ubfizLConvL2Ix",
  /* 1003 */  "ubfizIConvI2LAndI",
  /* 1004 */  "extrOrL",
  /* 1005 */  "extrOrL_0",
  /* 1006 */  "extrOrI",
  /* 1007 */  "extrOrI_0",
  /* 1008 */  "extrAddL",
  /* 1009 */  "extrAddL_0",
  /* 1010 */  "extrAddI",
  /* 1011 */  "extrAddI_0",
  /* 1012 */  "rorI_imm",
  /* 1013 */  "rorL_imm",
  /* 1014 */  "rorI_reg",
  /* 1015 */  "rorL_reg",
  /* 1016 */  "rolI_reg",
  /* 1017 */  "rolL_reg",
  /* 1018 */  "AddExtI",
  /* 1019 */  "AddExtI_0",
  /* 1020 */  "SubExtI",
  /* 1021 */  "AddExtI_sxth",
  /* 1022 */  "AddExtI_sxth_0",
  /* 1023 */  "AddExtI_sxtb",
  /* 1024 */  "AddExtI_sxtb_0",
  /* 1025 */  "AddExtI_uxtb",
  /* 1026 */  "AddExtI_uxtb_0",
  /* 1027 */  "AddExtL_sxth",
  /* 1028 */  "AddExtL_sxth_0",
  /* 1029 */  "AddExtL_sxtw",
  /* 1030 */  "AddExtL_sxtw_0",
  /* 1031 */  "AddExtL_sxtb",
  /* 1032 */  "AddExtL_sxtb_0",
  /* 1033 */  "AddExtL_uxtb",
  /* 1034 */  "AddExtL_uxtb_0",
  /* 1035 */  "AddExtI_uxtb_and",
  /* 1036 */  "AddExtI_uxtb_and_0",
  /* 1037 */  "AddExtI_uxth_and",
  /* 1038 */  "AddExtI_uxth_and_0",
  /* 1039 */  "AddExtL_uxtb_and",
  /* 1040 */  "AddExtL_uxtb_and_0",
  /* 1041 */  "AddExtL_uxth_and",
  /* 1042 */  "AddExtL_uxth_and_0",
  /* 1043 */  "AddExtL_uxtw_and",
  /* 1044 */  "AddExtL_uxtw_and_0",
  /* 1045 */  "SubExtI_uxtb_and",
  /* 1046 */  "SubExtI_uxth_and",
  /* 1047 */  "SubExtL_uxtb_and",
  /* 1048 */  "SubExtL_uxth_and",
  /* 1049 */  "SubExtL_uxtw_and",
  /* 1050 */  "AddExtL_sxtb_shift",
  /* 1051 */  "AddExtL_sxtb_shift_0",
  /* 1052 */  "AddExtL_sxth_shift",
  /* 1053 */  "AddExtL_sxth_shift_0",
  /* 1054 */  "AddExtL_sxtw_shift",
  /* 1055 */  "AddExtL_sxtw_shift_0",
  /* 1056 */  "SubExtL_sxtb_shift",
  /* 1057 */  "SubExtL_sxth_shift",
  /* 1058 */  "SubExtL_sxtw_shift",
  /* 1059 */  "AddExtI_sxtb_shift",
  /* 1060 */  "AddExtI_sxtb_shift_0",
  /* 1061 */  "AddExtI_sxth_shift",
  /* 1062 */  "AddExtI_sxth_shift_0",
  /* 1063 */  "SubExtI_sxtb_shift",
  /* 1064 */  "SubExtI_sxth_shift",
  /* 1065 */  "AddExtI_shift",
  /* 1066 */  "AddExtI_shift_0",
  /* 1067 */  "SubExtI_shift",
  /* 1068 */  "AddExtL_uxtb_and_shift",
  /* 1069 */  "AddExtL_uxtb_and_shift_0",
  /* 1070 */  "AddExtL_uxth_and_shift",
  /* 1071 */  "AddExtL_uxth_and_shift_0",
  /* 1072 */  "AddExtL_uxtw_and_shift",
  /* 1073 */  "AddExtL_uxtw_and_shift_0",
  /* 1074 */  "SubExtL_uxtb_and_shift",
  /* 1075 */  "SubExtL_uxth_and_shift",
  /* 1076 */  "SubExtL_uxtw_and_shift",
  /* 1077 */  "AddExtI_uxtb_and_shift",
  /* 1078 */  "AddExtI_uxtb_and_shift_0",
  /* 1079 */  "AddExtI_uxth_and_shift",
  /* 1080 */  "AddExtI_uxth_and_shift_0",
  /* 1081 */  "SubExtI_uxtb_and_shift",
  /* 1082 */  "SubExtI_uxth_and_shift",
  /* 1083 */  "addF_reg_reg",
  /* 1084 */  "addD_reg_reg",
  /* 1085 */  "subF_reg_reg",
  /* 1086 */  "subD_reg_reg",
  /* 1087 */  "mulF_reg_reg",
  /* 1088 */  "mulD_reg_reg",
  /* 1089 */  "maddF_reg_reg",
  /* 1090 */  "maddD_reg_reg",
  /* 1091 */  "msubF_reg_reg",
  /* 1092 */  "msubF_reg_reg_0",
  /* 1093 */  "msubD_reg_reg",
  /* 1094 */  "msubD_reg_reg_0",
  /* 1095 */  "mnaddF_reg_reg",
  /* 1096 */  "mnaddF_reg_reg_0",
  /* 1097 */  "mnaddD_reg_reg",
  /* 1098 */  "mnaddD_reg_reg_0",
  /* 1099 */  "mnsubF_reg_reg",
  /* 1100 */  "mnsubD_reg_reg",
  /* 1101 */  "maxF_reg_reg",
  /* 1102 */  "minF_reg_reg",
  /* 1103 */  "maxD_reg_reg",
  /* 1104 */  "minD_reg_reg",
  /* 1105 */  "divF_reg_reg",
  /* 1106 */  "divD_reg_reg",
  /* 1107 */  "absI_reg",
  /* 1108 */  "absL_reg",
  /* 1109 */  "absdF_reg",
  /* 1110 */  "absdD_reg",
  /* 1111 */  "sqrtD_reg",
  /* 1112 */  "sqrtF_reg",
  /* 1113 */  "roundD_reg",
  /* 1114 */  "copySignD_reg",
  /* 1115 */  "copySignF_reg",
  /* 1116 */  "signumD_reg",
  /* 1117 */  "signumF_reg",
  /* 1118 */  "onspinwait",
  /* 1119 */  "andI_reg_reg",
  /* 1120 */  "andI_reg_imm",
  /* 1121 */  "orI_reg_reg",
  /* 1122 */  "orI_reg_imm",
  /* 1123 */  "xorI_reg_reg",
  /* 1124 */  "xorI_reg_imm",
  /* 1125 */  "andL_reg_reg",
  /* 1126 */  "andL_reg_imm",
  /* 1127 */  "orL_reg_reg",
  /* 1128 */  "orL_reg_imm",
  /* 1129 */  "xorL_reg_reg",
  /* 1130 */  "xorL_reg_imm",
  /* 1131 */  "convI2L_reg_reg",
  /* 1132 */  "convUI2L_reg_reg",
  /* 1133 */  "convL2I_reg",
  /* 1134 */  "convI2B",
  /* 1135 */  "convP2B",
  /* 1136 */  "convD2F_reg",
  /* 1137 */  "convF2D_reg",
  /* 1138 */  "convF2I_reg_reg",
  /* 1139 */  "convF2L_reg_reg",
  /* 1140 */  "convI2F_reg_reg",
  /* 1141 */  "convL2F_reg_reg",
  /* 1142 */  "convD2I_reg_reg",
  /* 1143 */  "convD2L_reg_reg",
  /* 1144 */  "convI2D_reg_reg",
  /* 1145 */  "convL2D_reg_reg",
  /* 1146 */  "MoveF2I_reg_stack",
  /* 1147 */  "MoveI2F_reg_stack",
  /* 1148 */  "MoveD2L_reg_stack",
  /* 1149 */  "MoveL2D_reg_stack",
  /* 1150 */  "clearArray_reg_reg",
  /* 1151 */  "clearArray_imm_reg",
  /* 1152 */  "overflowMulI_reg_branch",
  /* 1153 */  "overflowMulL_reg_branch",
  /* 1154 */  "compF3_reg_reg",
  /* 1155 */  "compD3_reg_reg",
  /* 1156 */  "compF3_reg_immF0",
  /* 1157 */  "compD3_reg_immD0",
  /* 1158 */  "cmpLTMask_reg_reg",
  /* 1159 */  "cmpLTMask_reg_zero",
  /* 1160 */  "cmovI_reg_reg_lt",
  /* 1161 */  "minI_rReg",
  /* 1162 */  "cmovI_reg_reg_gt",
  /* 1163 */  "maxI_rReg",
  /* 1164 */  "branch",
  /* 1165 */  "branchCon",
  /* 1166 */  "branchConU",
  /* 1167 */  "cmpI_imm0_branch",
  /* 1168 */  "cmpL_imm0_branch",
  /* 1169 */  "cmpP_imm0_branch",
  /* 1170 */  "cmpN_imm0_branch",
  /* 1171 */  "cmpP_narrowOop_imm0_branch",
  /* 1172 */  "cmpUI_imm0_branch",
  /* 1173 */  "cmpUL_imm0_branch",
  /* 1174 */  "cmpL_branch_sign",
  /* 1175 */  "cmpI_branch_sign",
  /* 1176 */  "cmpL_branch_bit",
  /* 1177 */  "cmpI_branch_bit",
  /* 1178 */  "far_cmpL_branch_sign",
  /* 1179 */  "far_cmpI_branch_sign",
  /* 1180 */  "far_cmpL_branch_bit",
  /* 1181 */  "far_cmpI_branch_bit",
  /* 1182 */  "branchLoopEnd",
  /* 1183 */  "branchLoopEndU",
  /* 1184 */  "safePoint",
  /* 1185 */  "CallStaticJavaDirect",
  /* 1186 */  "CallDynamicJavaDirect",
  /* 1187 */  "CallRuntimeDirect",
  /* 1188 */  "CallLeafDirect",
  /* 1189 */  "CallLeafNoFPDirect",
  /* 1190 */  "CallNativeDirect",
  /* 1191 */  "TailCalljmpInd",
  /* 1192 */  "TailjmpInd",
  /* 1193 */  "CreateException",
  /* 1194 */  "RethrowException",
  /* 1195 */  "Ret",
  /* 1196 */  "ShouldNotReachHere",
  /* 1197 */  "partialSubtypeCheck",
  /* 1198 */  "string_compareU",
  /* 1199 */  "string_compareL",
  /* 1200 */  "string_compareUL",
  /* 1201 */  "string_compareLU",
  /* 1202 */  "string_indexofUU",
  /* 1203 */  "string_indexofLL",
  /* 1204 */  "string_indexofUL",
  /* 1205 */  "string_indexof_conUU",
  /* 1206 */  "string_indexof_conLL",
  /* 1207 */  "string_indexof_conUL",
  /* 1208 */  "string_indexof_char",
  /* 1209 */  "stringL_indexof_char",
  /* 1210 */  "string_equalsL",
  /* 1211 */  "string_equalsU",
  /* 1212 */  "array_equalsB",
  /* 1213 */  "array_equalsC",
  /* 1214 */  "has_negatives",
  /* 1215 */  "string_compress",
  /* 1216 */  "string_inflate",
  /* 1217 */  "encode_iso_array",
  /* 1218 */  "loadV2",
  /* 1219 */  "loadV4",
  /* 1220 */  "loadV8",
  /* 1221 */  "loadV16",
  /* 1222 */  "storeV2",
  /* 1223 */  "storeV4",
  /* 1224 */  "storeV8",
  /* 1225 */  "storeV16",
  /* 1226 */  "reduce_add8B",
  /* 1227 */  "reduce_add16B",
  /* 1228 */  "reduce_add4S",
  /* 1229 */  "reduce_add8S",
  /* 1230 */  "reduce_add2L",
  /* 1231 */  "reduce_mul8B",
  /* 1232 */  "reduce_mul16B",
  /* 1233 */  "reduce_mul4S",
  /* 1234 */  "reduce_mul8S",
  /* 1235 */  "reduce_mul2L",
  /* 1236 */  "reduce_max8B",
  /* 1237 */  "reduce_max16B",
  /* 1238 */  "reduce_max4S",
  /* 1239 */  "reduce_max8S",
  /* 1240 */  "reduce_max4I",
  /* 1241 */  "reduce_min8B",
  /* 1242 */  "reduce_min16B",
  /* 1243 */  "reduce_min4S",
  /* 1244 */  "reduce_min8S",
  /* 1245 */  "reduce_min4I",
  /* 1246 */  "reduce_max2I",
  /* 1247 */  "reduce_min2I",
  /* 1248 */  "reduce_max2L",
  /* 1249 */  "reduce_min2L",
  /* 1250 */  "reduce_max2F",
  /* 1251 */  "reduce_max4F",
  /* 1252 */  "reduce_max2D",
  /* 1253 */  "reduce_min2F",
  /* 1254 */  "reduce_min4F",
  /* 1255 */  "reduce_min2D",
  /* 1256 */  "reduce_and8B",
  /* 1257 */  "reduce_orr8B",
  /* 1258 */  "reduce_eor8B",
  /* 1259 */  "reduce_and16B",
  /* 1260 */  "reduce_orr16B",
  /* 1261 */  "reduce_eor16B",
  /* 1262 */  "reduce_and4S",
  /* 1263 */  "reduce_orr4S",
  /* 1264 */  "reduce_eor4S",
  /* 1265 */  "reduce_and8S",
  /* 1266 */  "reduce_orr8S",
  /* 1267 */  "reduce_eor8S",
  /* 1268 */  "reduce_and2I",
  /* 1269 */  "reduce_orr2I",
  /* 1270 */  "reduce_eor2I",
  /* 1271 */  "reduce_and4I",
  /* 1272 */  "reduce_orr4I",
  /* 1273 */  "reduce_eor4I",
  /* 1274 */  "reduce_and2L",
  /* 1275 */  "reduce_orr2L",
  /* 1276 */  "reduce_eor2L",
  /* 1277 */  "insert8B",
  /* 1278 */  "insert16B",
  /* 1279 */  "insert4S",
  /* 1280 */  "insert8S",
  /* 1281 */  "insert2I",
  /* 1282 */  "insert4I",
  /* 1283 */  "insert2L",
  /* 1284 */  "insert2F",
  /* 1285 */  "insert4F",
  /* 1286 */  "insert2D",
  /* 1287 */  "extract8B",
  /* 1288 */  "extract16B",
  /* 1289 */  "extract4S",
  /* 1290 */  "extract8S",
  /* 1291 */  "extract2I",
  /* 1292 */  "extract4I",
  /* 1293 */  "extract2L",
  /* 1294 */  "extract2F",
  /* 1295 */  "extract4F",
  /* 1296 */  "extract2D",
  /* 1297 */  "vcmpD",
  /* 1298 */  "vcmpX",
  /* 1299 */  "vmul2L",
  /* 1300 */  "vnot2I",
  /* 1301 */  "vnot2I_0",
  /* 1302 */  "vnot2I_1",
  /* 1303 */  "vnot2I_2",
  /* 1304 */  "vnot2I_3",
  /* 1305 */  "vnot2I_4",
  /* 1306 */  "vnot4I",
  /* 1307 */  "vnot4I_0",
  /* 1308 */  "vnot4I_1",
  /* 1309 */  "vnot4I_2",
  /* 1310 */  "vnot4I_3",
  /* 1311 */  "vnot4I_4",
  /* 1312 */  "vnot2L",
  /* 1313 */  "vnot2L_0",
  /* 1314 */  "vand_not2I",
  /* 1315 */  "vand_not2I_1",
  /* 1316 */  "vand_not2I_0",
  /* 1317 */  "vand_not2I_2",
  /* 1318 */  "vand_not2I_3",
  /* 1319 */  "vand_not2I_5",
  /* 1320 */  "vand_not2I_4",
  /* 1321 */  "vand_not2I_6",
  /* 1322 */  "vand_not2I_7",
  /* 1323 */  "vand_not2I_9",
  /* 1324 */  "vand_not2I_8",
  /* 1325 */  "vand_not2I_10",
  /* 1326 */  "vand_not4I",
  /* 1327 */  "vand_not4I_1",
  /* 1328 */  "vand_not4I_0",
  /* 1329 */  "vand_not4I_2",
  /* 1330 */  "vand_not4I_3",
  /* 1331 */  "vand_not4I_5",
  /* 1332 */  "vand_not4I_4",
  /* 1333 */  "vand_not4I_6",
  /* 1334 */  "vand_not4I_7",
  /* 1335 */  "vand_not4I_9",
  /* 1336 */  "vand_not4I_8",
  /* 1337 */  "vand_not4I_10",
  /* 1338 */  "vand_not2L",
  /* 1339 */  "vand_not2L_1",
  /* 1340 */  "vand_not2L_0",
  /* 1341 */  "vand_not2L_2",
  /* 1342 */  "vmax8B",
  /* 1343 */  "vmax16B",
  /* 1344 */  "vmax4S",
  /* 1345 */  "vmax8S",
  /* 1346 */  "vmax2I",
  /* 1347 */  "vmax4I",
  /* 1348 */  "vmin8B",
  /* 1349 */  "vmin16B",
  /* 1350 */  "vmin4S",
  /* 1351 */  "vmin8S",
  /* 1352 */  "vmin2I",
  /* 1353 */  "vmin4I",
  /* 1354 */  "vmax2L",
  /* 1355 */  "vmin2L",
  /* 1356 */  "vbsl8B",
  /* 1357 */  "vbsl16B",
  /* 1358 */  "storemask8B",
  /* 1359 */  "storemask16B",
  /* 1360 */  "storemask4S",
  /* 1361 */  "storemask8S",
  /* 1362 */  "storemask2I",
  /* 1363 */  "storemask4I",
  /* 1364 */  "storemask2L",
  /* 1365 */  "rearrange8B",
  /* 1366 */  "rearrange16B",
  /* 1367 */  "rearrange4S",
  /* 1368 */  "rearrange8S",
  /* 1369 */  "rearrange4I",
  /* 1370 */  "anytrue_in_mask8B",
  /* 1371 */  "anytrue_in_mask16B",
  /* 1372 */  "alltrue_in_mask8B",
  /* 1373 */  "alltrue_in_mask16B",
  /* 1374 */  "vabd2F",
  /* 1375 */  "vabd4F",
  /* 1376 */  "vabd2D",
  /* 1377 */  "replicate8B",
  /* 1378 */  "replicate16B",
  /* 1379 */  "replicate8B_imm",
  /* 1380 */  "replicate16B_imm",
  /* 1381 */  "replicate4S",
  /* 1382 */  "replicate8S",
  /* 1383 */  "replicate4S_imm",
  /* 1384 */  "replicate8S_imm",
  /* 1385 */  "replicate2I",
  /* 1386 */  "replicate4I",
  /* 1387 */  "replicate2I_imm",
  /* 1388 */  "replicate4I_imm",
  /* 1389 */  "replicate2L",
  /* 1390 */  "replicate2L_zero",
  /* 1391 */  "replicate2F",
  /* 1392 */  "replicate4F",
  /* 1393 */  "replicate2D",
  /* 1394 */  "reduce_add2I",
  /* 1395 */  "reduce_add4I",
  /* 1396 */  "reduce_mul2I",
  /* 1397 */  "reduce_mul4I",
  /* 1398 */  "reduce_add2F",
  /* 1399 */  "reduce_add4F",
  /* 1400 */  "reduce_mul2F",
  /* 1401 */  "reduce_mul4F",
  /* 1402 */  "reduce_add2D",
  /* 1403 */  "reduce_mul2D",
  /* 1404 */  "vadd8B",
  /* 1405 */  "vadd16B",
  /* 1406 */  "vadd4S",
  /* 1407 */  "vadd8S",
  /* 1408 */  "vadd2I",
  /* 1409 */  "vadd4I",
  /* 1410 */  "vadd2L",
  /* 1411 */  "vadd2F",
  /* 1412 */  "vadd4F",
  /* 1413 */  "vadd2D",
  /* 1414 */  "vsub8B",
  /* 1415 */  "vsub16B",
  /* 1416 */  "vsub4S",
  /* 1417 */  "vsub8S",
  /* 1418 */  "vsub2I",
  /* 1419 */  "vsub4I",
  /* 1420 */  "vsub2L",
  /* 1421 */  "vsub2F",
  /* 1422 */  "vsub4F",
  /* 1423 */  "vsub2D",
  /* 1424 */  "vmul8B",
  /* 1425 */  "vmul16B",
  /* 1426 */  "vmul4S",
  /* 1427 */  "vmul8S",
  /* 1428 */  "vmul2I",
  /* 1429 */  "vmul4I",
  /* 1430 */  "vmul2F",
  /* 1431 */  "vmul4F",
  /* 1432 */  "vmul2D",
  /* 1433 */  "vmla4S",
  /* 1434 */  "vmla4S_0",
  /* 1435 */  "vmla8S",
  /* 1436 */  "vmla8S_0",
  /* 1437 */  "vmla2I",
  /* 1438 */  "vmla2I_0",
  /* 1439 */  "vmla4I",
  /* 1440 */  "vmla4I_0",
  /* 1441 */  "vmla2F",
  /* 1442 */  "vmla4F",
  /* 1443 */  "vmla2D",
  /* 1444 */  "vmls4S",
  /* 1445 */  "vmls8S",
  /* 1446 */  "vmls2I",
  /* 1447 */  "vmls4I",
  /* 1448 */  "vmls2F",
  /* 1449 */  "vmls2F_0",
  /* 1450 */  "vmls4F",
  /* 1451 */  "vmls4F_0",
  /* 1452 */  "vmls2D",
  /* 1453 */  "vmls2D_0",
  /* 1454 */  "vmuladdS2I",
  /* 1455 */  "vdiv2F",
  /* 1456 */  "vdiv4F",
  /* 1457 */  "vdiv2D",
  /* 1458 */  "vand8B",
  /* 1459 */  "vand16B",
  /* 1460 */  "vor8B",
  /* 1461 */  "vor16B",
  /* 1462 */  "vxor8B",
  /* 1463 */  "vxor16B",
  /* 1464 */  "vsll8B",
  /* 1465 */  "vsll16B",
  /* 1466 */  "vsra8B",
  /* 1467 */  "vsra16B",
  /* 1468 */  "vsrl8B",
  /* 1469 */  "vsrl16B",
  /* 1470 */  "vsll8B_imm",
  /* 1471 */  "vsll16B_imm",
  /* 1472 */  "vsra8B_imm",
  /* 1473 */  "vsra16B_imm",
  /* 1474 */  "vsrl8B_imm",
  /* 1475 */  "vsrl16B_imm",
  /* 1476 */  "vsll4S",
  /* 1477 */  "vsll8S",
  /* 1478 */  "vsra4S",
  /* 1479 */  "vsra8S",
  /* 1480 */  "vsrl4S",
  /* 1481 */  "vsrl8S",
  /* 1482 */  "vsll4S_imm",
  /* 1483 */  "vsll8S_imm",
  /* 1484 */  "vsra4S_imm",
  /* 1485 */  "vsra8S_imm",
  /* 1486 */  "vsrl4S_imm",
  /* 1487 */  "vsrl8S_imm",
  /* 1488 */  "vsll2I",
  /* 1489 */  "vsll4I",
  /* 1490 */  "vsra2I",
  /* 1491 */  "vsra4I",
  /* 1492 */  "vsrl2I",
  /* 1493 */  "vsrl4I",
  /* 1494 */  "vsll2I_imm",
  /* 1495 */  "vsll4I_imm",
  /* 1496 */  "vsra2I_imm",
  /* 1497 */  "vsra4I_imm",
  /* 1498 */  "vsrl2I_imm",
  /* 1499 */  "vsrl4I_imm",
  /* 1500 */  "vsll2L",
  /* 1501 */  "vsra2L",
  /* 1502 */  "vsrl2L",
  /* 1503 */  "vsll2L_imm",
  /* 1504 */  "vsra2L_imm",
  /* 1505 */  "vsrl2L_imm",
  /* 1506 */  "vsraa8B_imm",
  /* 1507 */  "vsraa8B_imm_0",
  /* 1508 */  "vsraa16B_imm",
  /* 1509 */  "vsraa16B_imm_0",
  /* 1510 */  "vsraa4S_imm",
  /* 1511 */  "vsraa4S_imm_0",
  /* 1512 */  "vsraa8S_imm",
  /* 1513 */  "vsraa8S_imm_0",
  /* 1514 */  "vsraa2I_imm",
  /* 1515 */  "vsraa2I_imm_0",
  /* 1516 */  "vsraa4I_imm",
  /* 1517 */  "vsraa4I_imm_0",
  /* 1518 */  "vsraa2L_imm",
  /* 1519 */  "vsraa2L_imm_0",
  /* 1520 */  "vsrla8B_imm",
  /* 1521 */  "vsrla8B_imm_0",
  /* 1522 */  "vsrla16B_imm",
  /* 1523 */  "vsrla16B_imm_0",
  /* 1524 */  "vsrla4S_imm",
  /* 1525 */  "vsrla4S_imm_0",
  /* 1526 */  "vsrla8S_imm",
  /* 1527 */  "vsrla8S_imm_0",
  /* 1528 */  "vsrla2I_imm",
  /* 1529 */  "vsrla2I_imm_0",
  /* 1530 */  "vsrla4I_imm",
  /* 1531 */  "vsrla4I_imm_0",
  /* 1532 */  "vsrla2L_imm",
  /* 1533 */  "vsrla2L_imm_0",
  /* 1534 */  "vmax2F",
  /* 1535 */  "vmax4F",
  /* 1536 */  "vmax2D",
  /* 1537 */  "vmin2F",
  /* 1538 */  "vmin4F",
  /* 1539 */  "vmin2D",
  /* 1540 */  "vround2D_reg",
  /* 1541 */  "loadV",
  /* 1542 */  "storeV",
  /* 1543 */  "vaddB",
  /* 1544 */  "vaddS",
  /* 1545 */  "vaddI",
  /* 1546 */  "vaddL",
  /* 1547 */  "vaddF",
  /* 1548 */  "vaddD",
  /* 1549 */  "vand",
  /* 1550 */  "vor",
  /* 1551 */  "vxor",
  /* 1552 */  "vnotI",
  /* 1553 */  "vnotI_0",
  /* 1554 */  "vnotI_1",
  /* 1555 */  "vnotI_2",
  /* 1556 */  "vnotI_3",
  /* 1557 */  "vnotI_4",
  /* 1558 */  "vnotL",
  /* 1559 */  "vnotL_0",
  /* 1560 */  "vand_notI",
  /* 1561 */  "vand_notI_1",
  /* 1562 */  "vand_notI_0",
  /* 1563 */  "vand_notI_2",
  /* 1564 */  "vand_notI_3",
  /* 1565 */  "vand_notI_5",
  /* 1566 */  "vand_notI_4",
  /* 1567 */  "vand_notI_6",
  /* 1568 */  "vand_notI_7",
  /* 1569 */  "vand_notI_9",
  /* 1570 */  "vand_notI_8",
  /* 1571 */  "vand_notI_10",
  /* 1572 */  "vand_notL",
  /* 1573 */  "vand_notL_1",
  /* 1574 */  "vand_notL_0",
  /* 1575 */  "vand_notL_2",
  /* 1576 */  "vdivF",
  /* 1577 */  "vdivD",
  /* 1578 */  "vmin",
  /* 1579 */  "vmax",
  /* 1580 */  "vfmlaF",
  /* 1581 */  "vfmlaD",
  /* 1582 */  "vfmlsF",
  /* 1583 */  "vfmlsF_0",
  /* 1584 */  "vfmlsD",
  /* 1585 */  "vfmlsD_0",
  /* 1586 */  "vfnmlaF",
  /* 1587 */  "vfnmlaF_0",
  /* 1588 */  "vfnmlaD",
  /* 1589 */  "vfnmlaD_0",
  /* 1590 */  "vfnmlsF",
  /* 1591 */  "vfnmlsD",
  /* 1592 */  "vmlaB",
  /* 1593 */  "vmlaB_0",
  /* 1594 */  "vmlaS",
  /* 1595 */  "vmlaS_0",
  /* 1596 */  "vmlaI",
  /* 1597 */  "vmlaI_0",
  /* 1598 */  "vmlaL",
  /* 1599 */  "vmlaL_0",
  /* 1600 */  "vmlsB",
  /* 1601 */  "vmlsS",
  /* 1602 */  "vmlsI",
  /* 1603 */  "vmlsL",
  /* 1604 */  "vmulB",
  /* 1605 */  "vmulS",
  /* 1606 */  "vmulI",
  /* 1607 */  "vmulL",
  /* 1608 */  "vmulF",
  /* 1609 */  "vmulD",
  /* 1610 */  "reduce_addB",
  /* 1611 */  "reduce_addS",
  /* 1612 */  "reduce_addI",
  /* 1613 */  "reduce_addL",
  /* 1614 */  "reduce_addF",
  /* 1615 */  "reduce_addD",
  /* 1616 */  "reduce_maxF",
  /* 1617 */  "reduce_maxD",
  /* 1618 */  "reduce_minF",
  /* 1619 */  "reduce_minD",
  /* 1620 */  "vroundD",
  /* 1621 */  "replicateB",
  /* 1622 */  "replicateS",
  /* 1623 */  "replicateI",
  /* 1624 */  "replicateL",
  /* 1625 */  "replicateB_imm8",
  /* 1626 */  "replicateS_imm8",
  /* 1627 */  "replicateI_imm8",
  /* 1628 */  "replicateL_imm8",
  /* 1629 */  "replicateF",
  /* 1630 */  "replicateD",
  /* 1631 */  "vasrB",
  /* 1632 */  "vasrS",
  /* 1633 */  "vasrI",
  /* 1634 */  "vasrL",
  /* 1635 */  "vlslB",
  /* 1636 */  "vlslS",
  /* 1637 */  "vlslI",
  /* 1638 */  "vlslL",
  /* 1639 */  "vlsrB",
  /* 1640 */  "vlsrS",
  /* 1641 */  "vlsrI",
  /* 1642 */  "vlsrL",
  /* 1643 */  "vasrB_imm",
  /* 1644 */  "vasrS_imm",
  /* 1645 */  "vasrI_imm",
  /* 1646 */  "vasrL_imm",
  /* 1647 */  "vlsrB_imm",
  /* 1648 */  "vlsrS_imm",
  /* 1649 */  "vlsrI_imm",
  /* 1650 */  "vlsrL_imm",
  /* 1651 */  "vlslB_imm",
  /* 1652 */  "vlslS_imm",
  /* 1653 */  "vlslI_imm",
  /* 1654 */  "vlslL_imm",
  /* 1655 */  "vsubB",
  /* 1656 */  "vsubS",
  /* 1657 */  "vsubI",
  /* 1658 */  "vsubL",
  /* 1659 */  "vsubF",
  /* 1660 */  "vsubD",
  /* 1661 */  "compareAndSwapP_shenandoah",
  /* 1662 */  "compareAndSwapN_shenandoah",
  /* 1663 */  "compareAndSwapPAcq_shenandoah",
  /* 1664 */  "compareAndSwapNAcq_shenandoah",
  /* 1665 */  "compareAndExchangeN_shenandoah",
  /* 1666 */  "compareAndExchangeP_shenandoah",
  /* 1667 */  "compareAndExchangeNAcq_shenandoah",
  /* 1668 */  "compareAndExchangePAcq_shenandoah",
  /* 1669 */  "weakCompareAndSwapN_shenandoah",
  /* 1670 */  "weakCompareAndSwapP_shenandoah",
  /* 1671 */  "weakCompareAndSwapNAcq_shenandoah",
  /* 1672 */  "weakCompareAndSwapPAcq_shenandoah",
  /* 1673 */  "zLoadP",
  /* 1674 */  "zLoadPVolatile",
  /* 1675 */  "zCompareAndSwapP",
  /* 1676 */  "zCompareAndSwapP_0",
  /* 1677 */  "zCompareAndSwapPAcq",
  /* 1678 */  "zCompareAndSwapPAcq_0",
  /* 1679 */  "zCompareAndExchangeP",
  /* 1680 */  "zCompareAndExchangePAcq",
  /* 1681 */  "zGetAndSetP",
  /* 1682 */  "zGetAndSetPAcq",
  // last instruction
  "invalid rule name" // no trailing comma
};

const        bool  swallowed[] = {
  /*    0 */  false,
  /*    1 */  false,
  /*    2 */  false,
  /*    3 */  false,
  /*    4 */  false,
  /*    5 */  false,
  /*    6 */  false,
  /*    7 */  false,
  /*    8 */  true,
  /*    9 */  true,
  /*   10 */  true,
  /*   11 */  true,
  /*   12 */  true,
  /*   13 */  true,
  /*   14 */  true,
  /*   15 */  true,
  /*   16 */  true,
  /*   17 */  true,
  /*   18 */  true,
  /*   19 */  true,
  /*   20 */  true,
  /*   21 */  true,
  /*   22 */  true,
  /*   23 */  true,
  /*   24 */  true,
  /*   25 */  true,
  /*   26 */  true,
  /*   27 */  true,
  /*   28 */  true,
  /*   29 */  true,
  /*   30 */  true,
  /*   31 */  true,
  /*   32 */  true,
  /*   33 */  true,
  /*   34 */  true,
  /*   35 */  true,
  /*   36 */  true,
  /*   37 */  true,
  /*   38 */  true,
  /*   39 */  true,
  /*   40 */  true,
  /*   41 */  true,
  /*   42 */  true,
  /*   43 */  true,
  /*   44 */  true,
  /*   45 */  true,
  /*   46 */  true,
  /*   47 */  true,
  /*   48 */  true,
  /*   49 */  true,
  /*   50 */  true,
  /*   51 */  true,
  /*   52 */  true,
  /*   53 */  true,
  /*   54 */  true,
  /*   55 */  true,
  /*   56 */  true,
  /*   57 */  true,
  /*   58 */  true,
  /*   59 */  true,
  /*   60 */  true,
  /*   61 */  true,
  /*   62 */  true,
  /*   63 */  true,
  /*   64 */  true,
  /*   65 */  true,
  /*   66 */  true,
  /*   67 */  true,
  /*   68 */  true,
  /*   69 */  true,
  /*   70 */  true,
  /*   71 */  true,
  /*   72 */  true,
  /*   73 */  true,
  /*   74 */  true,
  /*   75 */  true,
  /*   76 */  true,
  /*   77 */  true,
  /*   78 */  false,
  /*   79 */  false,
  /*   80 */  false,
  /*   81 */  false,
  /*   82 */  false,
  /*   83 */  false,
  /*   84 */  false,
  /*   85 */  false,
  /*   86 */  false,
  /*   87 */  false,
  /*   88 */  false,
  /*   89 */  false,
  /*   90 */  false,
  /*   91 */  false,
  /*   92 */  false,
  /*   93 */  false,
  /*   94 */  false,
  /*   95 */  false,
  /*   96 */  false,
  /*   97 */  false,
  /*   98 */  false,
  /*   99 */  false,
  /*  100 */  false,
  /*  101 */  false,
  /*  102 */  false,
  /*  103 */  false,
  /*  104 */  false,
  /*  105 */  false,
  /*  106 */  false,
  /*  107 */  false,
  /*  108 */  false,
  /*  109 */  false,
  /*  110 */  false,
  /*  111 */  false,
  /*  112 */  false,
  /*  113 */  false,
  /*  114 */  false,
  /*  115 */  false,
  /*  116 */  false,
  /*  117 */  false,
  /*  118 */  false,
  /*  119 */  false,
  /*  120 */  false,
  /*  121 */  false,
  /*  122 */  false,
  /*  123 */  false,
  /*  124 */  false,
  /*  125 */  false,
  /*  126 */  false,
  /*  127 */  false,
  /*  128 */  false,
  /*  129 */  false,
  /*  130 */  false,
  /*  131 */  false,
  /*  132 */  false,
  /*  133 */  false,
  /*  134 */  false,
  /*  135 */  false,
  /*  136 */  false,
  /*  137 */  false,
  /*  138 */  false,
  /*  139 */  false,
  /*  140 */  false,
  /*  141 */  false,
  /*  142 */  false,
  /*  143 */  false,
  /*  144 */  false,
  /*  145 */  false,
  /*  146 */  false,
  /*  147 */  false,
  /*  148 */  false,
  /*  149 */  false,
  /*  150 */  false,
  /*  151 */  false,
  /*  152 */  false,
  /*  153 */  false,
  /*  154 */  false,
  /*  155 */  false,
  /*  156 */  false,
  /*  157 */  false,
  /*  158 */  false,
  /*  159 */  false,
  /*  160 */  false,
  /*  161 */  false,
  /*  162 */  false,
  /*  163 */  false,
  /*  164 */  false,
  /*  165 */  false,
  /*  166 */  false,
  /*  167 */  false,
  /*  168 */  false,
  /*  169 */  false,
  /*  170 */  false,
  /*  171 */  false,
  /*  172 */  false,
  /*  173 */  false,
  /*  174 */  false,
  /*  175 */  false,
  /*  176 */  false,
  /*  177 */  false,
  /*  178 */  false,
  /*  179 */  true,
  /*  180 */  true,
  /*  181 */  true,
  /*  182 */  true,
  /*  183 */  true,
  /*  184 */  false,
  /*  185 */  true,
  /*  186 */  true,
  /*  187 */  false,
  /*  188 */  false,
  // last operand
  /*  189 */  false,
  /*  190 */  false,
  /*  191 */  false,
  /*  192 */  false,
  /*  193 */  false,
  /*  194 */  false,
  /*  195 */  false,
  /*  196 */  false,
  /*  197 */  false,
  /*  198 */  false,
  /*  199 */  false,
  // last operand class
  /*  200 */  false,
  /*  201 */  false,
  /*  202 */  false,
  /*  203 */  false,
  /*  204 */  false,
  /*  205 */  false,
  /*  206 */  false,
  /*  207 */  false,
  /*  208 */  false,
  /*  209 */  false,
  /*  210 */  false,
  /*  211 */  false,
  /*  212 */  false,
  /*  213 */  false,
  /*  214 */  false,
  /*  215 */  false,
  /*  216 */  false,
  /*  217 */  false,
  /*  218 */  false,
  /*  219 */  false,
  /*  220 */  false,
  /*  221 */  false,
  /*  222 */  false,
  /*  223 */  false,
  /*  224 */  false,
  /*  225 */  false,
  /*  226 */  false,
  /*  227 */  false,
  /*  228 */  false,
  /*  229 */  false,
  /*  230 */  false,
  /*  231 */  false,
  /*  232 */  false,
  /*  233 */  false,
  /*  234 */  false,
  /*  235 */  false,
  /*  236 */  false,
  /*  237 */  false,
  /*  238 */  false,
  /*  239 */  false,
  /*  240 */  false,
  /*  241 */  false,
  /*  242 */  false,
  /*  243 */  false,
  /*  244 */  false,
  /*  245 */  false,
  /*  246 */  false,
  /*  247 */  false,
  /*  248 */  false,
  /*  249 */  false,
  /*  250 */  false,
  /*  251 */  false,
  /*  252 */  false,
  /*  253 */  false,
  /*  254 */  false,
  /*  255 */  false,
  /*  256 */  false,
  /*  257 */  false,
  /*  258 */  false,
  /*  259 */  false,
  /*  260 */  false,
  /*  261 */  false,
  /*  262 */  false,
  /*  263 */  false,
  /*  264 */  false,
  /*  265 */  false,
  /*  266 */  false,
  /*  267 */  false,
  /*  268 */  false,
  /*  269 */  false,
  /*  270 */  false,
  /*  271 */  false,
  /*  272 */  false,
  /*  273 */  false,
  /*  274 */  false,
  /*  275 */  false,
  /*  276 */  false,
  /*  277 */  false,
  /*  278 */  false,
  /*  279 */  false,
  /*  280 */  false,
  /*  281 */  false,
  /*  282 */  false,
  /*  283 */  false,
  /*  284 */  false,
  /*  285 */  false,
  /*  286 */  false,
  /*  287 */  false,
  /*  288 */  false,
  /*  289 */  false,
  /*  290 */  false,
  /*  291 */  false,
  /*  292 */  false,
  /*  293 */  false,
  /*  294 */  false,
  /*  295 */  false,
  /*  296 */  false,
  /*  297 */  false,
  /*  298 */  false,
  /*  299 */  false,
  /*  300 */  false,
  /*  301 */  false,
  /*  302 */  false,
  /*  303 */  false,
  /*  304 */  false,
  /*  305 */  false,
  /*  306 */  false,
  /*  307 */  false,
  /*  308 */  false,
  /*  309 */  false,
  /*  310 */  false,
  /*  311 */  false,
  /*  312 */  false,
  /*  313 */  false,
  /*  314 */  false,
  /*  315 */  false,
  /*  316 */  false,
  /*  317 */  false,
  /*  318 */  false,
  /*  319 */  false,
  /*  320 */  false,
  /*  321 */  false,
  /*  322 */  false,
  /*  323 */  false,
  /*  324 */  false,
  /*  325 */  false,
  /*  326 */  false,
  /*  327 */  false,
  /*  328 */  false,
  /*  329 */  false,
  /*  330 */  false,
  /*  331 */  false,
  /*  332 */  false,
  /*  333 */  false,
  /*  334 */  false,
  /*  335 */  false,
  /*  336 */  false,
  /*  337 */  false,
  /*  338 */  false,
  /*  339 */  false,
  /*  340 */  false,
  /*  341 */  false,
  /*  342 */  false,
  /*  343 */  false,
  /*  344 */  false,
  /*  345 */  false,
  /*  346 */  false,
  /*  347 */  false,
  /*  348 */  false,
  /*  349 */  false,
  /*  350 */  false,
  /*  351 */  false,
  /*  352 */  false,
  /*  353 */  false,
  /*  354 */  false,
  /*  355 */  false,
  /*  356 */  false,
  /*  357 */  false,
  /*  358 */  false,
  /*  359 */  false,
  /*  360 */  false,
  /*  361 */  false,
  /*  362 */  false,
  /*  363 */  false,
  /*  364 */  false,
  /*  365 */  false,
  /*  366 */  false,
  /*  367 */  false,
  /*  368 */  false,
  /*  369 */  false,
  /*  370 */  false,
  /*  371 */  false,
  /*  372 */  false,
  /*  373 */  false,
  /*  374 */  false,
  /*  375 */  false,
  /*  376 */  false,
  /*  377 */  false,
  /*  378 */  false,
  /*  379 */  false,
  /*  380 */  false,
  /*  381 */  false,
  /*  382 */  false,
  /*  383 */  false,
  /*  384 */  false,
  /*  385 */  false,
  /*  386 */  false,
  /*  387 */  false,
  /*  388 */  false,
  /*  389 */  false,
  /*  390 */  false,
  /*  391 */  false,
  /*  392 */  false,
  /*  393 */  false,
  /*  394 */  false,
  /*  395 */  false,
  /*  396 */  false,
  /*  397 */  false,
  /*  398 */  false,
  /*  399 */  false,
  /*  400 */  false,
  /*  401 */  false,
  /*  402 */  false,
  /*  403 */  false,
  /*  404 */  false,
  /*  405 */  false,
  /*  406 */  false,
  /*  407 */  false,
  /*  408 */  false,
  /*  409 */  false,
  /*  410 */  false,
  /*  411 */  false,
  /*  412 */  false,
  /*  413 */  false,
  /*  414 */  false,
  /*  415 */  false,
  /*  416 */  false,
  /*  417 */  false,
  /*  418 */  false,
  /*  419 */  false,
  /*  420 */  false,
  /*  421 */  false,
  /*  422 */  false,
  /*  423 */  false,
  /*  424 */  false,
  /*  425 */  false,
  /*  426 */  false,
  /*  427 */  false,
  /*  428 */  false,
  /*  429 */  false,
  /*  430 */  false,
  // last internally defined operand
  /*  431 */  false,
  /*  432 */  false,
  /*  433 */  false,
  /*  434 */  false,
  /*  435 */  false,
  /*  436 */  false,
  /*  437 */  false,
  /*  438 */  false,
  /*  439 */  false,
  /*  440 */  false,
  /*  441 */  false,
  /*  442 */  false,
  /*  443 */  false,
  /*  444 */  false,
  /*  445 */  false,
  /*  446 */  false,
  /*  447 */  false,
  /*  448 */  false,
  /*  449 */  false,
  /*  450 */  false,
  /*  451 */  false,
  /*  452 */  false,
  /*  453 */  false,
  /*  454 */  false,
  /*  455 */  false,
  /*  456 */  false,
  /*  457 */  false,
  /*  458 */  false,
  /*  459 */  false,
  /*  460 */  false,
  /*  461 */  false,
  /*  462 */  false,
  /*  463 */  false,
  /*  464 */  false,
  /*  465 */  false,
  /*  466 */  false,
  /*  467 */  false,
  /*  468 */  false,
  /*  469 */  false,
  /*  470 */  false,
  /*  471 */  false,
  /*  472 */  false,
  /*  473 */  false,
  /*  474 */  false,
  /*  475 */  false,
  /*  476 */  false,
  /*  477 */  false,
  /*  478 */  false,
  /*  479 */  false,
  /*  480 */  false,
  /*  481 */  false,
  /*  482 */  false,
  /*  483 */  false,
  /*  484 */  false,
  /*  485 */  false,
  /*  486 */  false,
  /*  487 */  false,
  /*  488 */  false,
  /*  489 */  false,
  /*  490 */  false,
  /*  491 */  false,
  /*  492 */  false,
  /*  493 */  false,
  /*  494 */  false,
  /*  495 */  false,
  /*  496 */  false,
  /*  497 */  false,
  /*  498 */  false,
  /*  499 */  false,
  /*  500 */  false,
  /*  501 */  false,
  /*  502 */  false,
  /*  503 */  false,
  /*  504 */  false,
  /*  505 */  false,
  /*  506 */  false,
  /*  507 */  false,
  /*  508 */  false,
  /*  509 */  false,
  /*  510 */  false,
  /*  511 */  false,
  /*  512 */  false,
  /*  513 */  false,
  /*  514 */  false,
  /*  515 */  false,
  /*  516 */  false,
  /*  517 */  false,
  /*  518 */  false,
  /*  519 */  false,
  /*  520 */  false,
  /*  521 */  false,
  /*  522 */  false,
  /*  523 */  false,
  /*  524 */  false,
  /*  525 */  false,
  /*  526 */  false,
  /*  527 */  false,
  /*  528 */  false,
  /*  529 */  false,
  /*  530 */  false,
  /*  531 */  false,
  /*  532 */  false,
  /*  533 */  false,
  /*  534 */  false,
  /*  535 */  false,
  /*  536 */  false,
  /*  537 */  false,
  /*  538 */  false,
  /*  539 */  false,
  /*  540 */  false,
  /*  541 */  false,
  /*  542 */  false,
  /*  543 */  false,
  /*  544 */  false,
  /*  545 */  false,
  /*  546 */  false,
  /*  547 */  false,
  /*  548 */  false,
  /*  549 */  false,
  /*  550 */  false,
  /*  551 */  false,
  /*  552 */  false,
  /*  553 */  false,
  /*  554 */  false,
  /*  555 */  false,
  /*  556 */  false,
  /*  557 */  false,
  /*  558 */  false,
  /*  559 */  false,
  /*  560 */  false,
  /*  561 */  false,
  /*  562 */  false,
  /*  563 */  false,
  /*  564 */  false,
  /*  565 */  false,
  /*  566 */  false,
  /*  567 */  false,
  /*  568 */  false,
  /*  569 */  false,
  /*  570 */  false,
  /*  571 */  false,
  /*  572 */  false,
  /*  573 */  false,
  /*  574 */  false,
  /*  575 */  false,
  /*  576 */  false,
  /*  577 */  false,
  /*  578 */  false,
  /*  579 */  false,
  /*  580 */  false,
  /*  581 */  false,
  /*  582 */  false,
  /*  583 */  false,
  /*  584 */  false,
  /*  585 */  false,
  /*  586 */  false,
  /*  587 */  false,
  /*  588 */  false,
  /*  589 */  false,
  /*  590 */  false,
  /*  591 */  false,
  /*  592 */  false,
  /*  593 */  false,
  /*  594 */  false,
  /*  595 */  false,
  /*  596 */  false,
  /*  597 */  false,
  /*  598 */  false,
  /*  599 */  false,
  /*  600 */  false,
  /*  601 */  false,
  /*  602 */  false,
  /*  603 */  false,
  /*  604 */  false,
  /*  605 */  false,
  /*  606 */  false,
  /*  607 */  false,
  /*  608 */  false,
  /*  609 */  false,
  /*  610 */  false,
  /*  611 */  false,
  /*  612 */  false,
  /*  613 */  false,
  /*  614 */  false,
  /*  615 */  false,
  /*  616 */  false,
  /*  617 */  false,
  /*  618 */  false,
  /*  619 */  false,
  /*  620 */  false,
  /*  621 */  false,
  /*  622 */  false,
  /*  623 */  false,
  /*  624 */  false,
  /*  625 */  false,
  /*  626 */  false,
  /*  627 */  false,
  /*  628 */  false,
  /*  629 */  false,
  /*  630 */  false,
  /*  631 */  false,
  /*  632 */  false,
  /*  633 */  false,
  /*  634 */  false,
  /*  635 */  false,
  /*  636 */  false,
  /*  637 */  false,
  /*  638 */  false,
  /*  639 */  false,
  /*  640 */  false,
  /*  641 */  false,
  /*  642 */  false,
  /*  643 */  false,
  /*  644 */  false,
  /*  645 */  false,
  /*  646 */  false,
  /*  647 */  false,
  /*  648 */  false,
  /*  649 */  false,
  /*  650 */  false,
  /*  651 */  false,
  /*  652 */  false,
  /*  653 */  false,
  /*  654 */  false,
  /*  655 */  false,
  /*  656 */  false,
  /*  657 */  false,
  /*  658 */  false,
  /*  659 */  false,
  /*  660 */  false,
  /*  661 */  false,
  /*  662 */  false,
  /*  663 */  false,
  /*  664 */  false,
  /*  665 */  false,
  /*  666 */  false,
  /*  667 */  false,
  /*  668 */  false,
  /*  669 */  false,
  /*  670 */  false,
  /*  671 */  false,
  /*  672 */  false,
  /*  673 */  false,
  /*  674 */  false,
  /*  675 */  false,
  /*  676 */  false,
  /*  677 */  false,
  /*  678 */  false,
  /*  679 */  false,
  /*  680 */  false,
  /*  681 */  false,
  /*  682 */  false,
  /*  683 */  false,
  /*  684 */  false,
  /*  685 */  false,
  /*  686 */  false,
  /*  687 */  false,
  /*  688 */  false,
  /*  689 */  false,
  /*  690 */  false,
  /*  691 */  false,
  /*  692 */  false,
  /*  693 */  false,
  /*  694 */  false,
  /*  695 */  false,
  /*  696 */  false,
  /*  697 */  false,
  /*  698 */  false,
  /*  699 */  false,
  /*  700 */  false,
  /*  701 */  false,
  /*  702 */  false,
  /*  703 */  false,
  /*  704 */  false,
  /*  705 */  false,
  /*  706 */  false,
  /*  707 */  false,
  /*  708 */  false,
  /*  709 */  false,
  /*  710 */  false,
  /*  711 */  false,
  /*  712 */  false,
  /*  713 */  false,
  /*  714 */  false,
  /*  715 */  false,
  /*  716 */  false,
  /*  717 */  false,
  /*  718 */  false,
  /*  719 */  false,
  /*  720 */  false,
  /*  721 */  false,
  /*  722 */  false,
  /*  723 */  false,
  /*  724 */  false,
  /*  725 */  false,
  /*  726 */  false,
  /*  727 */  false,
  /*  728 */  false,
  /*  729 */  false,
  /*  730 */  false,
  /*  731 */  false,
  /*  732 */  false,
  /*  733 */  false,
  /*  734 */  false,
  /*  735 */  false,
  /*  736 */  false,
  /*  737 */  false,
  /*  738 */  false,
  /*  739 */  false,
  /*  740 */  false,
  /*  741 */  false,
  /*  742 */  false,
  /*  743 */  false,
  /*  744 */  false,
  /*  745 */  false,
  /*  746 */  false,
  /*  747 */  false,
  /*  748 */  false,
  /*  749 */  false,
  /*  750 */  false,
  /*  751 */  false,
  /*  752 */  false,
  /*  753 */  false,
  /*  754 */  false,
  /*  755 */  false,
  /*  756 */  false,
  /*  757 */  false,
  /*  758 */  false,
  /*  759 */  false,
  /*  760 */  false,
  /*  761 */  false,
  /*  762 */  false,
  /*  763 */  false,
  /*  764 */  false,
  /*  765 */  false,
  /*  766 */  false,
  /*  767 */  false,
  /*  768 */  false,
  /*  769 */  false,
  /*  770 */  false,
  /*  771 */  false,
  /*  772 */  false,
  /*  773 */  false,
  /*  774 */  false,
  /*  775 */  false,
  /*  776 */  false,
  /*  777 */  false,
  /*  778 */  false,
  /*  779 */  false,
  /*  780 */  false,
  /*  781 */  false,
  /*  782 */  false,
  /*  783 */  false,
  /*  784 */  false,
  /*  785 */  false,
  /*  786 */  false,
  /*  787 */  false,
  /*  788 */  false,
  /*  789 */  false,
  /*  790 */  false,
  /*  791 */  false,
  /*  792 */  false,
  /*  793 */  false,
  /*  794 */  false,
  /*  795 */  false,
  /*  796 */  false,
  /*  797 */  false,
  /*  798 */  false,
  /*  799 */  false,
  /*  800 */  false,
  /*  801 */  false,
  /*  802 */  false,
  /*  803 */  false,
  /*  804 */  false,
  /*  805 */  false,
  /*  806 */  false,
  /*  807 */  false,
  /*  808 */  false,
  /*  809 */  false,
  /*  810 */  false,
  /*  811 */  false,
  /*  812 */  false,
  /*  813 */  false,
  /*  814 */  false,
  /*  815 */  false,
  /*  816 */  false,
  /*  817 */  false,
  /*  818 */  false,
  /*  819 */  false,
  /*  820 */  false,
  /*  821 */  false,
  /*  822 */  false,
  /*  823 */  false,
  /*  824 */  false,
  /*  825 */  false,
  /*  826 */  false,
  /*  827 */  false,
  /*  828 */  false,
  /*  829 */  false,
  /*  830 */  false,
  /*  831 */  false,
  /*  832 */  false,
  /*  833 */  false,
  /*  834 */  false,
  /*  835 */  false,
  /*  836 */  false,
  /*  837 */  false,
  /*  838 */  false,
  /*  839 */  false,
  /*  840 */  false,
  /*  841 */  false,
  /*  842 */  false,
  /*  843 */  false,
  /*  844 */  false,
  /*  845 */  false,
  /*  846 */  false,
  /*  847 */  false,
  /*  848 */  false,
  /*  849 */  false,
  /*  850 */  false,
  /*  851 */  false,
  /*  852 */  false,
  /*  853 */  false,
  /*  854 */  false,
  /*  855 */  false,
  /*  856 */  false,
  /*  857 */  false,
  /*  858 */  false,
  /*  859 */  false,
  /*  860 */  false,
  /*  861 */  false,
  /*  862 */  false,
  /*  863 */  false,
  /*  864 */  false,
  /*  865 */  false,
  /*  866 */  false,
  /*  867 */  false,
  /*  868 */  false,
  /*  869 */  false,
  /*  870 */  false,
  /*  871 */  false,
  /*  872 */  false,
  /*  873 */  false,
  /*  874 */  false,
  /*  875 */  false,
  /*  876 */  false,
  /*  877 */  false,
  /*  878 */  false,
  /*  879 */  false,
  /*  880 */  false,
  /*  881 */  false,
  /*  882 */  false,
  /*  883 */  false,
  /*  884 */  false,
  /*  885 */  false,
  /*  886 */  false,
  /*  887 */  false,
  /*  888 */  false,
  /*  889 */  false,
  /*  890 */  false,
  /*  891 */  false,
  /*  892 */  false,
  /*  893 */  false,
  /*  894 */  false,
  /*  895 */  false,
  /*  896 */  false,
  /*  897 */  false,
  /*  898 */  false,
  /*  899 */  false,
  /*  900 */  false,
  /*  901 */  false,
  /*  902 */  false,
  /*  903 */  false,
  /*  904 */  false,
  /*  905 */  false,
  /*  906 */  false,
  /*  907 */  false,
  /*  908 */  false,
  /*  909 */  false,
  /*  910 */  false,
  /*  911 */  false,
  /*  912 */  false,
  /*  913 */  false,
  /*  914 */  false,
  /*  915 */  false,
  /*  916 */  false,
  /*  917 */  false,
  /*  918 */  false,
  /*  919 */  false,
  /*  920 */  false,
  /*  921 */  false,
  /*  922 */  false,
  /*  923 */  false,
  /*  924 */  false,
  /*  925 */  false,
  /*  926 */  false,
  /*  927 */  false,
  /*  928 */  false,
  /*  929 */  false,
  /*  930 */  false,
  /*  931 */  false,
  /*  932 */  false,
  /*  933 */  false,
  /*  934 */  false,
  /*  935 */  false,
  /*  936 */  false,
  /*  937 */  false,
  /*  938 */  false,
  /*  939 */  false,
  /*  940 */  false,
  /*  941 */  false,
  /*  942 */  false,
  /*  943 */  false,
  /*  944 */  false,
  /*  945 */  false,
  /*  946 */  false,
  /*  947 */  false,
  /*  948 */  false,
  /*  949 */  false,
  /*  950 */  false,
  /*  951 */  false,
  /*  952 */  false,
  /*  953 */  false,
  /*  954 */  false,
  /*  955 */  false,
  /*  956 */  false,
  /*  957 */  false,
  /*  958 */  false,
  /*  959 */  false,
  /*  960 */  false,
  /*  961 */  false,
  /*  962 */  false,
  /*  963 */  false,
  /*  964 */  false,
  /*  965 */  false,
  /*  966 */  false,
  /*  967 */  false,
  /*  968 */  false,
  /*  969 */  false,
  /*  970 */  false,
  /*  971 */  false,
  /*  972 */  false,
  /*  973 */  false,
  /*  974 */  false,
  /*  975 */  false,
  /*  976 */  false,
  /*  977 */  false,
  /*  978 */  false,
  /*  979 */  false,
  /*  980 */  false,
  /*  981 */  false,
  /*  982 */  false,
  /*  983 */  false,
  /*  984 */  false,
  /*  985 */  false,
  /*  986 */  false,
  /*  987 */  false,
  /*  988 */  false,
  /*  989 */  false,
  /*  990 */  false,
  /*  991 */  false,
  /*  992 */  false,
  /*  993 */  false,
  /*  994 */  false,
  /*  995 */  false,
  /*  996 */  false,
  /*  997 */  false,
  /*  998 */  false,
  /*  999 */  false,
  /* 1000 */  false,
  /* 1001 */  false,
  /* 1002 */  false,
  /* 1003 */  false,
  /* 1004 */  false,
  /* 1005 */  false,
  /* 1006 */  false,
  /* 1007 */  false,
  /* 1008 */  false,
  /* 1009 */  false,
  /* 1010 */  false,
  /* 1011 */  false,
  /* 1012 */  false,
  /* 1013 */  false,
  /* 1014 */  false,
  /* 1015 */  false,
  /* 1016 */  false,
  /* 1017 */  false,
  /* 1018 */  false,
  /* 1019 */  false,
  /* 1020 */  false,
  /* 1021 */  false,
  /* 1022 */  false,
  /* 1023 */  false,
  /* 1024 */  false,
  /* 1025 */  false,
  /* 1026 */  false,
  /* 1027 */  false,
  /* 1028 */  false,
  /* 1029 */  false,
  /* 1030 */  false,
  /* 1031 */  false,
  /* 1032 */  false,
  /* 1033 */  false,
  /* 1034 */  false,
  /* 1035 */  false,
  /* 1036 */  false,
  /* 1037 */  false,
  /* 1038 */  false,
  /* 1039 */  false,
  /* 1040 */  false,
  /* 1041 */  false,
  /* 1042 */  false,
  /* 1043 */  false,
  /* 1044 */  false,
  /* 1045 */  false,
  /* 1046 */  false,
  /* 1047 */  false,
  /* 1048 */  false,
  /* 1049 */  false,
  /* 1050 */  false,
  /* 1051 */  false,
  /* 1052 */  false,
  /* 1053 */  false,
  /* 1054 */  false,
  /* 1055 */  false,
  /* 1056 */  false,
  /* 1057 */  false,
  /* 1058 */  false,
  /* 1059 */  false,
  /* 1060 */  false,
  /* 1061 */  false,
  /* 1062 */  false,
  /* 1063 */  false,
  /* 1064 */  false,
  /* 1065 */  false,
  /* 1066 */  false,
  /* 1067 */  false,
  /* 1068 */  false,
  /* 1069 */  false,
  /* 1070 */  false,
  /* 1071 */  false,
  /* 1072 */  false,
  /* 1073 */  false,
  /* 1074 */  false,
  /* 1075 */  false,
  /* 1076 */  false,
  /* 1077 */  false,
  /* 1078 */  false,
  /* 1079 */  false,
  /* 1080 */  false,
  /* 1081 */  false,
  /* 1082 */  false,
  /* 1083 */  false,
  /* 1084 */  false,
  /* 1085 */  false,
  /* 1086 */  false,
  /* 1087 */  false,
  /* 1088 */  false,
  /* 1089 */  false,
  /* 1090 */  false,
  /* 1091 */  false,
  /* 1092 */  false,
  /* 1093 */  false,
  /* 1094 */  false,
  /* 1095 */  false,
  /* 1096 */  false,
  /* 1097 */  false,
  /* 1098 */  false,
  /* 1099 */  false,
  /* 1100 */  false,
  /* 1101 */  false,
  /* 1102 */  false,
  /* 1103 */  false,
  /* 1104 */  false,
  /* 1105 */  false,
  /* 1106 */  false,
  /* 1107 */  false,
  /* 1108 */  false,
  /* 1109 */  false,
  /* 1110 */  false,
  /* 1111 */  false,
  /* 1112 */  false,
  /* 1113 */  false,
  /* 1114 */  false,
  /* 1115 */  false,
  /* 1116 */  false,
  /* 1117 */  false,
  /* 1118 */  false,
  /* 1119 */  false,
  /* 1120 */  false,
  /* 1121 */  false,
  /* 1122 */  false,
  /* 1123 */  false,
  /* 1124 */  false,
  /* 1125 */  false,
  /* 1126 */  false,
  /* 1127 */  false,
  /* 1128 */  false,
  /* 1129 */  false,
  /* 1130 */  false,
  /* 1131 */  false,
  /* 1132 */  false,
  /* 1133 */  false,
  /* 1134 */  false,
  /* 1135 */  false,
  /* 1136 */  false,
  /* 1137 */  false,
  /* 1138 */  false,
  /* 1139 */  false,
  /* 1140 */  false,
  /* 1141 */  false,
  /* 1142 */  false,
  /* 1143 */  false,
  /* 1144 */  false,
  /* 1145 */  false,
  /* 1146 */  false,
  /* 1147 */  false,
  /* 1148 */  false,
  /* 1149 */  false,
  /* 1150 */  false,
  /* 1151 */  false,
  /* 1152 */  false,
  /* 1153 */  false,
  /* 1154 */  false,
  /* 1155 */  false,
  /* 1156 */  false,
  /* 1157 */  false,
  /* 1158 */  false,
  /* 1159 */  false,
  /* 1160 */  false,
  /* 1161 */  false,
  /* 1162 */  false,
  /* 1163 */  false,
  /* 1164 */  false,
  /* 1165 */  false,
  /* 1166 */  false,
  /* 1167 */  false,
  /* 1168 */  false,
  /* 1169 */  false,
  /* 1170 */  false,
  /* 1171 */  false,
  /* 1172 */  false,
  /* 1173 */  false,
  /* 1174 */  false,
  /* 1175 */  false,
  /* 1176 */  false,
  /* 1177 */  false,
  /* 1178 */  false,
  /* 1179 */  false,
  /* 1180 */  false,
  /* 1181 */  false,
  /* 1182 */  false,
  /* 1183 */  false,
  /* 1184 */  false,
  /* 1185 */  false,
  /* 1186 */  false,
  /* 1187 */  false,
  /* 1188 */  false,
  /* 1189 */  false,
  /* 1190 */  false,
  /* 1191 */  false,
  /* 1192 */  false,
  /* 1193 */  false,
  /* 1194 */  false,
  /* 1195 */  false,
  /* 1196 */  false,
  /* 1197 */  false,
  /* 1198 */  false,
  /* 1199 */  false,
  /* 1200 */  false,
  /* 1201 */  false,
  /* 1202 */  false,
  /* 1203 */  false,
  /* 1204 */  false,
  /* 1205 */  false,
  /* 1206 */  false,
  /* 1207 */  false,
  /* 1208 */  false,
  /* 1209 */  false,
  /* 1210 */  false,
  /* 1211 */  false,
  /* 1212 */  false,
  /* 1213 */  false,
  /* 1214 */  false,
  /* 1215 */  false,
  /* 1216 */  false,
  /* 1217 */  false,
  /* 1218 */  false,
  /* 1219 */  false,
  /* 1220 */  false,
  /* 1221 */  false,
  /* 1222 */  false,
  /* 1223 */  false,
  /* 1224 */  false,
  /* 1225 */  false,
  /* 1226 */  false,
  /* 1227 */  false,
  /* 1228 */  false,
  /* 1229 */  false,
  /* 1230 */  false,
  /* 1231 */  false,
  /* 1232 */  false,
  /* 1233 */  false,
  /* 1234 */  false,
  /* 1235 */  false,
  /* 1236 */  false,
  /* 1237 */  false,
  /* 1238 */  false,
  /* 1239 */  false,
  /* 1240 */  false,
  /* 1241 */  false,
  /* 1242 */  false,
  /* 1243 */  false,
  /* 1244 */  false,
  /* 1245 */  false,
  /* 1246 */  false,
  /* 1247 */  false,
  /* 1248 */  false,
  /* 1249 */  false,
  /* 1250 */  false,
  /* 1251 */  false,
  /* 1252 */  false,
  /* 1253 */  false,
  /* 1254 */  false,
  /* 1255 */  false,
  /* 1256 */  false,
  /* 1257 */  false,
  /* 1258 */  false,
  /* 1259 */  false,
  /* 1260 */  false,
  /* 1261 */  false,
  /* 1262 */  false,
  /* 1263 */  false,
  /* 1264 */  false,
  /* 1265 */  false,
  /* 1266 */  false,
  /* 1267 */  false,
  /* 1268 */  false,
  /* 1269 */  false,
  /* 1270 */  false,
  /* 1271 */  false,
  /* 1272 */  false,
  /* 1273 */  false,
  /* 1274 */  false,
  /* 1275 */  false,
  /* 1276 */  false,
  /* 1277 */  false,
  /* 1278 */  false,
  /* 1279 */  false,
  /* 1280 */  false,
  /* 1281 */  false,
  /* 1282 */  false,
  /* 1283 */  false,
  /* 1284 */  false,
  /* 1285 */  false,
  /* 1286 */  false,
  /* 1287 */  false,
  /* 1288 */  false,
  /* 1289 */  false,
  /* 1290 */  false,
  /* 1291 */  false,
  /* 1292 */  false,
  /* 1293 */  false,
  /* 1294 */  false,
  /* 1295 */  false,
  /* 1296 */  false,
  /* 1297 */  false,
  /* 1298 */  false,
  /* 1299 */  false,
  /* 1300 */  false,
  /* 1301 */  false,
  /* 1302 */  false,
  /* 1303 */  false,
  /* 1304 */  false,
  /* 1305 */  false,
  /* 1306 */  false,
  /* 1307 */  false,
  /* 1308 */  false,
  /* 1309 */  false,
  /* 1310 */  false,
  /* 1311 */  false,
  /* 1312 */  false,
  /* 1313 */  false,
  /* 1314 */  false,
  /* 1315 */  false,
  /* 1316 */  false,
  /* 1317 */  false,
  /* 1318 */  false,
  /* 1319 */  false,
  /* 1320 */  false,
  /* 1321 */  false,
  /* 1322 */  false,
  /* 1323 */  false,
  /* 1324 */  false,
  /* 1325 */  false,
  /* 1326 */  false,
  /* 1327 */  false,
  /* 1328 */  false,
  /* 1329 */  false,
  /* 1330 */  false,
  /* 1331 */  false,
  /* 1332 */  false,
  /* 1333 */  false,
  /* 1334 */  false,
  /* 1335 */  false,
  /* 1336 */  false,
  /* 1337 */  false,
  /* 1338 */  false,
  /* 1339 */  false,
  /* 1340 */  false,
  /* 1341 */  false,
  /* 1342 */  false,
  /* 1343 */  false,
  /* 1344 */  false,
  /* 1345 */  false,
  /* 1346 */  false,
  /* 1347 */  false,
  /* 1348 */  false,
  /* 1349 */  false,
  /* 1350 */  false,
  /* 1351 */  false,
  /* 1352 */  false,
  /* 1353 */  false,
  /* 1354 */  false,
  /* 1355 */  false,
  /* 1356 */  false,
  /* 1357 */  false,
  /* 1358 */  false,
  /* 1359 */  false,
  /* 1360 */  false,
  /* 1361 */  false,
  /* 1362 */  false,
  /* 1363 */  false,
  /* 1364 */  false,
  /* 1365 */  false,
  /* 1366 */  false,
  /* 1367 */  false,
  /* 1368 */  false,
  /* 1369 */  false,
  /* 1370 */  false,
  /* 1371 */  false,
  /* 1372 */  false,
  /* 1373 */  false,
  /* 1374 */  false,
  /* 1375 */  false,
  /* 1376 */  false,
  /* 1377 */  false,
  /* 1378 */  false,
  /* 1379 */  false,
  /* 1380 */  false,
  /* 1381 */  false,
  /* 1382 */  false,
  /* 1383 */  false,
  /* 1384 */  false,
  /* 1385 */  false,
  /* 1386 */  false,
  /* 1387 */  false,
  /* 1388 */  false,
  /* 1389 */  false,
  /* 1390 */  false,
  /* 1391 */  false,
  /* 1392 */  false,
  /* 1393 */  false,
  /* 1394 */  false,
  /* 1395 */  false,
  /* 1396 */  false,
  /* 1397 */  false,
  /* 1398 */  false,
  /* 1399 */  false,
  /* 1400 */  false,
  /* 1401 */  false,
  /* 1402 */  false,
  /* 1403 */  false,
  /* 1404 */  false,
  /* 1405 */  false,
  /* 1406 */  false,
  /* 1407 */  false,
  /* 1408 */  false,
  /* 1409 */  false,
  /* 1410 */  false,
  /* 1411 */  false,
  /* 1412 */  false,
  /* 1413 */  false,
  /* 1414 */  false,
  /* 1415 */  false,
  /* 1416 */  false,
  /* 1417 */  false,
  /* 1418 */  false,
  /* 1419 */  false,
  /* 1420 */  false,
  /* 1421 */  false,
  /* 1422 */  false,
  /* 1423 */  false,
  /* 1424 */  false,
  /* 1425 */  false,
  /* 1426 */  false,
  /* 1427 */  false,
  /* 1428 */  false,
  /* 1429 */  false,
  /* 1430 */  false,
  /* 1431 */  false,
  /* 1432 */  false,
  /* 1433 */  false,
  /* 1434 */  false,
  /* 1435 */  false,
  /* 1436 */  false,
  /* 1437 */  false,
  /* 1438 */  false,
  /* 1439 */  false,
  /* 1440 */  false,
  /* 1441 */  false,
  /* 1442 */  false,
  /* 1443 */  false,
  /* 1444 */  false,
  /* 1445 */  false,
  /* 1446 */  false,
  /* 1447 */  false,
  /* 1448 */  false,
  /* 1449 */  false,
  /* 1450 */  false,
  /* 1451 */  false,
  /* 1452 */  false,
  /* 1453 */  false,
  /* 1454 */  false,
  /* 1455 */  false,
  /* 1456 */  false,
  /* 1457 */  false,
  /* 1458 */  false,
  /* 1459 */  false,
  /* 1460 */  false,
  /* 1461 */  false,
  /* 1462 */  false,
  /* 1463 */  false,
  /* 1464 */  false,
  /* 1465 */  false,
  /* 1466 */  false,
  /* 1467 */  false,
  /* 1468 */  false,
  /* 1469 */  false,
  /* 1470 */  false,
  /* 1471 */  false,
  /* 1472 */  false,
  /* 1473 */  false,
  /* 1474 */  false,
  /* 1475 */  false,
  /* 1476 */  false,
  /* 1477 */  false,
  /* 1478 */  false,
  /* 1479 */  false,
  /* 1480 */  false,
  /* 1481 */  false,
  /* 1482 */  false,
  /* 1483 */  false,
  /* 1484 */  false,
  /* 1485 */  false,
  /* 1486 */  false,
  /* 1487 */  false,
  /* 1488 */  false,
  /* 1489 */  false,
  /* 1490 */  false,
  /* 1491 */  false,
  /* 1492 */  false,
  /* 1493 */  false,
  /* 1494 */  false,
  /* 1495 */  false,
  /* 1496 */  false,
  /* 1497 */  false,
  /* 1498 */  false,
  /* 1499 */  false,
  /* 1500 */  false,
  /* 1501 */  false,
  /* 1502 */  false,
  /* 1503 */  false,
  /* 1504 */  false,
  /* 1505 */  false,
  /* 1506 */  false,
  /* 1507 */  false,
  /* 1508 */  false,
  /* 1509 */  false,
  /* 1510 */  false,
  /* 1511 */  false,
  /* 1512 */  false,
  /* 1513 */  false,
  /* 1514 */  false,
  /* 1515 */  false,
  /* 1516 */  false,
  /* 1517 */  false,
  /* 1518 */  false,
  /* 1519 */  false,
  /* 1520 */  false,
  /* 1521 */  false,
  /* 1522 */  false,
  /* 1523 */  false,
  /* 1524 */  false,
  /* 1525 */  false,
  /* 1526 */  false,
  /* 1527 */  false,
  /* 1528 */  false,
  /* 1529 */  false,
  /* 1530 */  false,
  /* 1531 */  false,
  /* 1532 */  false,
  /* 1533 */  false,
  /* 1534 */  false,
  /* 1535 */  false,
  /* 1536 */  false,
  /* 1537 */  false,
  /* 1538 */  false,
  /* 1539 */  false,
  /* 1540 */  false,
  /* 1541 */  false,
  /* 1542 */  false,
  /* 1543 */  false,
  /* 1544 */  false,
  /* 1545 */  false,
  /* 1546 */  false,
  /* 1547 */  false,
  /* 1548 */  false,
  /* 1549 */  false,
  /* 1550 */  false,
  /* 1551 */  false,
  /* 1552 */  false,
  /* 1553 */  false,
  /* 1554 */  false,
  /* 1555 */  false,
  /* 1556 */  false,
  /* 1557 */  false,
  /* 1558 */  false,
  /* 1559 */  false,
  /* 1560 */  false,
  /* 1561 */  false,
  /* 1562 */  false,
  /* 1563 */  false,
  /* 1564 */  false,
  /* 1565 */  false,
  /* 1566 */  false,
  /* 1567 */  false,
  /* 1568 */  false,
  /* 1569 */  false,
  /* 1570 */  false,
  /* 1571 */  false,
  /* 1572 */  false,
  /* 1573 */  false,
  /* 1574 */  false,
  /* 1575 */  false,
  /* 1576 */  false,
  /* 1577 */  false,
  /* 1578 */  false,
  /* 1579 */  false,
  /* 1580 */  false,
  /* 1581 */  false,
  /* 1582 */  false,
  /* 1583 */  false,
  /* 1584 */  false,
  /* 1585 */  false,
  /* 1586 */  false,
  /* 1587 */  false,
  /* 1588 */  false,
  /* 1589 */  false,
  /* 1590 */  false,
  /* 1591 */  false,
  /* 1592 */  false,
  /* 1593 */  false,
  /* 1594 */  false,
  /* 1595 */  false,
  /* 1596 */  false,
  /* 1597 */  false,
  /* 1598 */  false,
  /* 1599 */  false,
  /* 1600 */  false,
  /* 1601 */  false,
  /* 1602 */  false,
  /* 1603 */  false,
  /* 1604 */  false,
  /* 1605 */  false,
  /* 1606 */  false,
  /* 1607 */  false,
  /* 1608 */  false,
  /* 1609 */  false,
  /* 1610 */  false,
  /* 1611 */  false,
  /* 1612 */  false,
  /* 1613 */  false,
  /* 1614 */  false,
  /* 1615 */  false,
  /* 1616 */  false,
  /* 1617 */  false,
  /* 1618 */  false,
  /* 1619 */  false,
  /* 1620 */  false,
  /* 1621 */  false,
  /* 1622 */  false,
  /* 1623 */  false,
  /* 1624 */  false,
  /* 1625 */  false,
  /* 1626 */  false,
  /* 1627 */  false,
  /* 1628 */  false,
  /* 1629 */  false,
  /* 1630 */  false,
  /* 1631 */  false,
  /* 1632 */  false,
  /* 1633 */  false,
  /* 1634 */  false,
  /* 1635 */  false,
  /* 1636 */  false,
  /* 1637 */  false,
  /* 1638 */  false,
  /* 1639 */  false,
  /* 1640 */  false,
  /* 1641 */  false,
  /* 1642 */  false,
  /* 1643 */  false,
  /* 1644 */  false,
  /* 1645 */  false,
  /* 1646 */  false,
  /* 1647 */  false,
  /* 1648 */  false,
  /* 1649 */  false,
  /* 1650 */  false,
  /* 1651 */  false,
  /* 1652 */  false,
  /* 1653 */  false,
  /* 1654 */  false,
  /* 1655 */  false,
  /* 1656 */  false,
  /* 1657 */  false,
  /* 1658 */  false,
  /* 1659 */  false,
  /* 1660 */  false,
  /* 1661 */  false,
  /* 1662 */  false,
  /* 1663 */  false,
  /* 1664 */  false,
  /* 1665 */  false,
  /* 1666 */  false,
  /* 1667 */  false,
  /* 1668 */  false,
  /* 1669 */  false,
  /* 1670 */  false,
  /* 1671 */  false,
  /* 1672 */  false,
  /* 1673 */  false,
  /* 1674 */  false,
  /* 1675 */  false,
  /* 1676 */  false,
  /* 1677 */  false,
  /* 1678 */  false,
  /* 1679 */  false,
  /* 1680 */  false,
  /* 1681 */  false,
  /* 1682 */  false,
  // last instruction
  false // no trailing comma
};

// Mapping from machine-independent opcode to boolean
const        char must_clone[] = {
  0, // Node: 0
  0, // Set: 1
  0, // RegN: 2
  0, // RegI: 3
  0, // RegP: 4
  0, // RegF: 5
  0, // RegD: 6
  0, // RegL: 7
  0, // VecA: 8
  0, // VecS: 9
  0, // VecD: 10
  0, // VecX: 11
  0, // VecY: 12
  0, // VecZ: 13
  0, // RegVectMask: 14
  0, // RegFlags: 15
  0, // _last_machine_leaf: 16
  0, // AbsD: 17
  0, // AbsF: 18
  0, // AbsI: 19
  0, // AbsL: 20
  0, // AddD: 21
  0, // AddF: 22
  0, // AddI: 23
  0, // AddL: 24
  0, // AddP: 25
  0, // Allocate: 26
  0, // AllocateArray: 27
  0, // AndI: 28
  0, // AndL: 29
  0, // ArrayCopy: 30
  0, // AryEq: 31
  0, // AtanD: 32
  1, // Binary: 33
  0, // Blackhole: 34
  1, // Bool: 35
  0, // BoxLock: 36
  0, // ReverseBytesI: 37
  0, // ReverseBytesL: 38
  0, // ReverseBytesUS: 39
  0, // ReverseBytesS: 40
  0, // CProj: 41
  0, // CacheWB: 42
  0, // CacheWBPreSync: 43
  0, // CacheWBPostSync: 44
  0, // CallDynamicJava: 45
  0, // CallJava: 46
  0, // CallLeaf: 47
  0, // CallLeafNoFP: 48
  0, // CallLeafVector: 49
  0, // CallRuntime: 50
  0, // CallNative: 51
  0, // CallStaticJava: 52
  0, // CastDD: 53
  0, // CastFF: 54
  0, // CastII: 55
  0, // CastLL: 56
  0, // CastVV: 57
  0, // CastX2P: 58
  0, // CastP2X: 59
  0, // CastPP: 60
  0, // Catch: 61
  0, // CatchProj: 62
  0, // CheckCastPP: 63
  0, // ClearArray: 64
  0, // ConstraintCast: 65
  0, // CMoveD: 66
  0, // CMoveVD: 67
  0, // CMoveF: 68
  0, // CMoveVF: 69
  0, // CMoveI: 70
  0, // CMoveL: 71
  0, // CMoveP: 72
  0, // CMoveN: 73
  1, // CmpN: 74
  1, // CmpD: 75
  0, // CmpD3: 76
  1, // CmpF: 77
  0, // CmpF3: 78
  1, // CmpI: 79
  1, // CmpL: 80
  0, // CmpL3: 81
  0, // CmpLTMask: 82
  1, // CmpP: 83
  1, // CmpU: 84
  1, // CmpUL: 85
  0, // CompareAndSwapB: 86
  0, // CompareAndSwapS: 87
  0, // CompareAndSwapI: 88
  0, // CompareAndSwapL: 89
  0, // CompareAndSwapP: 90
  0, // CompareAndSwapN: 91
  0, // WeakCompareAndSwapB: 92
  0, // WeakCompareAndSwapS: 93
  0, // WeakCompareAndSwapI: 94
  0, // WeakCompareAndSwapL: 95
  0, // WeakCompareAndSwapP: 96
  0, // WeakCompareAndSwapN: 97
  0, // CompareAndExchangeB: 98
  0, // CompareAndExchangeS: 99
  0, // CompareAndExchangeI: 100
  0, // CompareAndExchangeL: 101
  0, // CompareAndExchangeP: 102
  0, // CompareAndExchangeN: 103
  0, // GetAndAddB: 104
  0, // GetAndAddS: 105
  0, // GetAndAddI: 106
  0, // GetAndAddL: 107
  0, // GetAndSetB: 108
  0, // GetAndSetS: 109
  0, // GetAndSetI: 110
  0, // GetAndSetL: 111
  0, // GetAndSetP: 112
  0, // GetAndSetN: 113
  0, // Con: 114
  0, // ConN: 115
  0, // ConNKlass: 116
  0, // ConD: 117
  0, // ConF: 118
  0, // ConI: 119
  0, // ConL: 120
  0, // ConP: 121
  0, // Conv2B: 122
  0, // ConvD2F: 123
  0, // ConvD2I: 124
  0, // ConvD2L: 125
  0, // ConvF2D: 126
  0, // ConvF2I: 127
  0, // ConvF2L: 128
  0, // ConvI2D: 129
  0, // ConvI2F: 130
  0, // ConvI2L: 131
  0, // ConvL2D: 132
  0, // ConvL2F: 133
  0, // ConvL2I: 134
  0, // CountedLoop: 135
  0, // CountedLoopEnd: 136
  0, // OuterStripMinedLoop: 137
  0, // OuterStripMinedLoopEnd: 138
  0, // LongCountedLoop: 139
  0, // LongCountedLoopEnd: 140
  0, // CountLeadingZerosI: 141
  0, // CountLeadingZerosL: 142
  0, // CountTrailingZerosI: 143
  0, // CountTrailingZerosL: 144
  0, // CreateEx: 145
  0, // DecodeN: 146
  0, // DecodeNKlass: 147
  0, // DivD: 148
  0, // DivF: 149
  0, // DivI: 150
  0, // DivL: 151
  0, // DivMod: 152
  0, // DivModI: 153
  0, // DivModL: 154
  0, // EncodeISOArray: 155
  0, // EncodeP: 156
  0, // EncodePKlass: 157
  1, // FastLock: 158
  1, // FastUnlock: 159
  0, // FmaD: 160
  0, // FmaF: 161
  0, // Goto: 162
  0, // Halt: 163
  0, // HasNegatives: 164
  0, // If: 165
  0, // RangeCheck: 166
  0, // IfFalse: 167
  0, // IfTrue: 168
  0, // Initialize: 169
  0, // JProj: 170
  0, // Jump: 171
  0, // JumpProj: 172
  0, // LShiftI: 173
  0, // LShiftL: 174
  0, // LoadB: 175
  0, // LoadUB: 176
  0, // LoadUS: 177
  0, // LoadD: 178
  0, // LoadD_unaligned: 179
  0, // LoadF: 180
  0, // LoadI: 181
  0, // LoadKlass: 182
  0, // LoadNKlass: 183
  0, // LoadL: 184
  0, // LoadL_unaligned: 185
  0, // LoadPLocked: 186
  0, // LoadP: 187
  0, // LoadN: 188
  0, // LoadRange: 189
  0, // LoadS: 190
  0, // Lock: 191
  0, // Loop: 192
  0, // LoopLimit: 193
  0, // Mach: 194
  0, // MachNullCheck: 195
  0, // MachProj: 196
  0, // MulAddS2I: 197
  0, // MaxI: 198
  0, // MaxL: 199
  0, // MaxD: 200
  0, // MaxF: 201
  0, // MemBarAcquire: 202
  0, // LoadFence: 203
  0, // SetVectMaskI: 204
  0, // MemBarAcquireLock: 205
  0, // MemBarCPUOrder: 206
  0, // MemBarRelease: 207
  0, // StoreFence: 208
  0, // MemBarReleaseLock: 209
  0, // MemBarVolatile: 210
  0, // MemBarStoreStore: 211
  0, // MergeMem: 212
  0, // MinI: 213
  0, // MinL: 214
  0, // MinF: 215
  0, // MinD: 216
  0, // ModD: 217
  0, // ModF: 218
  0, // ModI: 219
  0, // ModL: 220
  0, // MoveI2F: 221
  0, // MoveF2I: 222
  0, // MoveL2D: 223
  0, // MoveD2L: 224
  0, // MulD: 225
  0, // MulF: 226
  0, // MulHiL: 227
  0, // MulI: 228
  0, // MulL: 229
  0, // Multi: 230
  0, // NegI: 231
  0, // NegL: 232
  0, // NegD: 233
  0, // NegF: 234
  0, // NeverBranch: 235
  0, // OnSpinWait: 236
  0, // Opaque1: 237
  0, // OpaqueLoopInit: 238
  0, // OpaqueLoopStride: 239
  0, // Opaque2: 240
  0, // Opaque3: 241
  0, // Opaque4: 242
  0, // ProfileBoolean: 243
  0, // OrI: 244
  0, // OrL: 245
  1, // OverflowAddI: 246
  1, // OverflowSubI: 247
  1, // OverflowMulI: 248
  1, // OverflowAddL: 249
  1, // OverflowSubL: 250
  1, // OverflowMulL: 251
  0, // PCTable: 252
  0, // Parm: 253
  0, // PartialSubtypeCheck: 254
  0, // SubTypeCheck: 255
  0, // Phi: 256
  0, // PopCountI: 257
  0, // PopCountL: 258
  0, // PopCountVI: 259
  0, // PrefetchAllocation: 260
  0, // Proj: 261
  0, // RShiftI: 262
  0, // RShiftL: 263
  0, // Region: 264
  0, // Rethrow: 265
  0, // Return: 266
  0, // Root: 267
  0, // RoundDouble: 268
  0, // RoundDoubleMode: 269
  0, // RoundDoubleModeV: 270
  0, // RoundFloat: 271
  0, // RotateLeft: 272
  0, // RotateLeftV: 273
  0, // RotateRight: 274
  0, // RotateRightV: 275
  0, // SafePoint: 276
  0, // SafePointScalarObject: 277
  0, // ShenandoahCompareAndExchangeP: 278
  0, // ShenandoahCompareAndExchangeN: 279
  0, // ShenandoahCompareAndSwapN: 280
  0, // ShenandoahCompareAndSwapP: 281
  0, // ShenandoahWeakCompareAndSwapN: 282
  0, // ShenandoahWeakCompareAndSwapP: 283
  0, // ShenandoahIUBarrier: 284
  0, // ShenandoahLoadReferenceBarrier: 285
  0, // SCMemProj: 286
  0, // CopySignD: 287
  0, // CopySignF: 288
  0, // SignumD: 289
  0, // SignumF: 290
  0, // SqrtD: 291
  0, // SqrtF: 292
  0, // Start: 293
  0, // StartOSR: 294
  0, // StoreB: 295
  0, // StoreC: 296
  0, // StoreCM: 297
  0, // StorePConditional: 298
  0, // StoreIConditional: 299
  0, // StoreLConditional: 300
  0, // StoreD: 301
  0, // StoreF: 302
  0, // StoreI: 303
  0, // StoreL: 304
  0, // StoreP: 305
  0, // StoreN: 306
  0, // StoreNKlass: 307
  0, // StrComp: 308
  0, // StrCompressedCopy: 309
  0, // StrEquals: 310
  0, // StrIndexOf: 311
  0, // StrIndexOfChar: 312
  0, // StrInflatedCopy: 313
  0, // SubD: 314
  0, // SubF: 315
  0, // SubI: 316
  0, // SubL: 317
  0, // TailCall: 318
  0, // TailJump: 319
  0, // MacroLogicV: 320
  0, // ThreadLocal: 321
  0, // Unlock: 322
  0, // URShiftB: 323
  0, // URShiftS: 324
  0, // URShiftI: 325
  0, // URShiftL: 326
  0, // XorI: 327
  0, // XorL: 328
  0, // Vector: 329
  0, // AddVB: 330
  0, // AddVS: 331
  0, // AddVI: 332
  0, // AddReductionVI: 333
  0, // AddVL: 334
  0, // AddReductionVL: 335
  0, // AddVF: 336
  0, // AddReductionVF: 337
  0, // AddVD: 338
  0, // AddReductionVD: 339
  0, // SubVB: 340
  0, // SubVS: 341
  0, // SubVI: 342
  0, // SubVL: 343
  0, // SubVF: 344
  0, // SubVD: 345
  0, // MulVB: 346
  0, // MulVS: 347
  0, // MulVI: 348
  0, // MulReductionVI: 349
  0, // MulVL: 350
  0, // MulReductionVL: 351
  0, // MulVF: 352
  0, // MulReductionVF: 353
  0, // MulVD: 354
  0, // MulReductionVD: 355
  0, // MulAddVS2VI: 356
  0, // FmaVD: 357
  0, // FmaVF: 358
  0, // DivVF: 359
  0, // DivVD: 360
  0, // AbsVB: 361
  0, // AbsVS: 362
  0, // AbsVI: 363
  0, // AbsVL: 364
  0, // AbsVF: 365
  0, // AbsVD: 366
  0, // NegVI: 367
  0, // NegVF: 368
  0, // NegVD: 369
  0, // SqrtVD: 370
  0, // SqrtVF: 371
  0, // LShiftCntV: 372
  0, // RShiftCntV: 373
  0, // LShiftVB: 374
  0, // LShiftVS: 375
  0, // LShiftVI: 376
  0, // LShiftVL: 377
  0, // RShiftVB: 378
  0, // RShiftVS: 379
  0, // RShiftVI: 380
  0, // RShiftVL: 381
  0, // URShiftVB: 382
  0, // URShiftVS: 383
  0, // URShiftVI: 384
  0, // URShiftVL: 385
  0, // AndV: 386
  0, // AndReductionV: 387
  0, // OrV: 388
  0, // OrReductionV: 389
  0, // XorV: 390
  0, // XorReductionV: 391
  0, // MinV: 392
  0, // MaxV: 393
  0, // MinReductionV: 394
  0, // MaxReductionV: 395
  0, // LoadVector: 396
  0, // LoadVectorGather: 397
  0, // StoreVector: 398
  0, // StoreVectorScatter: 399
  0, // LoadVectorMasked: 400
  0, // StoreVectorMasked: 401
  0, // VectorCmpMasked: 402
  0, // VectorMaskGen: 403
  0, // VectorMaskOp: 404
  0, // VectorMaskTrueCount: 405
  0, // VectorMaskFirstTrue: 406
  0, // VectorMaskLastTrue: 407
  0, // Pack: 408
  0, // PackB: 409
  0, // PackS: 410
  0, // PackI: 411
  0, // PackL: 412
  0, // PackF: 413
  0, // PackD: 414
  0, // Pack2L: 415
  0, // Pack2D: 416
  0, // ReplicateB: 417
  0, // ReplicateS: 418
  0, // ReplicateI: 419
  0, // ReplicateL: 420
  0, // ReplicateF: 421
  0, // ReplicateD: 422
  0, // Extract: 423
  0, // ExtractB: 424
  0, // ExtractUB: 425
  0, // ExtractC: 426
  0, // ExtractS: 427
  0, // ExtractI: 428
  0, // ExtractL: 429
  0, // ExtractF: 430
  0, // ExtractD: 431
  0, // Digit: 432
  0, // LowerCase: 433
  0, // UpperCase: 434
  0, // Whitespace: 435
  0, // VectorBox: 436
  0, // VectorBoxAllocate: 437
  0, // VectorUnbox: 438
  0, // VectorMaskWrapper: 439
  0, // VectorMaskCmp: 440
  0, // VectorMaskCast: 441
  0, // VectorTest: 442
  0, // VectorBlend: 443
  0, // VectorRearrange: 444
  0, // VectorLoadMask: 445
  0, // VectorLoadShuffle: 446
  0, // VectorLoadConst: 447
  0, // VectorStoreMask: 448
  0, // VectorReinterpret: 449
  0, // VectorCast: 450
  0, // VectorCastB2X: 451
  0, // VectorCastS2X: 452
  0, // VectorCastI2X: 453
  0, // VectorCastL2X: 454
  0, // VectorCastF2X: 455
  0, // VectorCastD2X: 456
  0 // no trailing comma // VectorInsert: 457
};
//  The following instructions can cisc-spill



// An array of character pointers to machine register names.
const char *Matcher::regName[REG_COUNT] = {
  "R10",
  "R10_H",
  "R11",
  "R11_H",
  "R12",
  "R12_H",
  "R13",
  "R13_H",
  "R14",
  "R14_H",
  "R15",
  "R15_H",
  "R16",
  "R16_H",
  "R17",
  "R17_H",
  "R18",
  "R18_H",
  "R0",
  "R0_H",
  "R1",
  "R1_H",
  "R2",
  "R2_H",
  "R3",
  "R3_H",
  "R4",
  "R4_H",
  "R5",
  "R5_H",
  "R6",
  "R6_H",
  "R7",
  "R7_H",
  "R19",
  "R19_H",
  "R20",
  "R20_H",
  "R21",
  "R21_H",
  "R22",
  "R22_H",
  "R23",
  "R23_H",
  "R24",
  "R24_H",
  "R25",
  "R25_H",
  "R26",
  "R26_H",
  "R27",
  "R27_H",
  "R28",
  "R28_H",
  "R29",
  "R29_H",
  "R30",
  "R30_H",
  "R31",
  "R31_H",
  "R8",
  "R8_H",
  "R9",
  "R9_H",
  "V16",
  "V16_H",
  "V16_J",
  "V16_K",
  "V16_L",
  "V16_M",
  "V16_N",
  "V16_O",
  "V17",
  "V17_H",
  "V17_J",
  "V17_K",
  "V17_L",
  "V17_M",
  "V17_N",
  "V17_O",
  "V18",
  "V18_H",
  "V18_J",
  "V18_K",
  "V18_L",
  "V18_M",
  "V18_N",
  "V18_O",
  "V19",
  "V19_H",
  "V19_J",
  "V19_K",
  "V19_L",
  "V19_M",
  "V19_N",
  "V19_O",
  "V20",
  "V20_H",
  "V20_J",
  "V20_K",
  "V20_L",
  "V20_M",
  "V20_N",
  "V20_O",
  "V21",
  "V21_H",
  "V21_J",
  "V21_K",
  "V21_L",
  "V21_M",
  "V21_N",
  "V21_O",
  "V22",
  "V22_H",
  "V22_J",
  "V22_K",
  "V22_L",
  "V22_M",
  "V22_N",
  "V22_O",
  "V23",
  "V23_H",
  "V23_J",
  "V23_K",
  "V23_L",
  "V23_M",
  "V23_N",
  "V23_O",
  "V24",
  "V24_H",
  "V24_J",
  "V24_K",
  "V24_L",
  "V24_M",
  "V24_N",
  "V24_O",
  "V25",
  "V25_H",
  "V25_J",
  "V25_K",
  "V25_L",
  "V25_M",
  "V25_N",
  "V25_O",
  "V26",
  "V26_H",
  "V26_J",
  "V26_K",
  "V26_L",
  "V26_M",
  "V26_N",
  "V26_O",
  "V27",
  "V27_H",
  "V27_J",
  "V27_K",
  "V27_L",
  "V27_M",
  "V27_N",
  "V27_O",
  "V28",
  "V28_H",
  "V28_J",
  "V28_K",
  "V28_L",
  "V28_M",
  "V28_N",
  "V28_O",
  "V29",
  "V29_H",
  "V29_J",
  "V29_K",
  "V29_L",
  "V29_M",
  "V29_N",
  "V29_O",
  "V30",
  "V30_H",
  "V30_J",
  "V30_K",
  "V30_L",
  "V30_M",
  "V30_N",
  "V30_O",
  "V31",
  "V31_H",
  "V31_J",
  "V31_K",
  "V31_L",
  "V31_M",
  "V31_N",
  "V31_O",
  "V0",
  "V0_H",
  "V0_J",
  "V0_K",
  "V0_L",
  "V0_M",
  "V0_N",
  "V0_O",
  "V1",
  "V1_H",
  "V1_J",
  "V1_K",
  "V1_L",
  "V1_M",
  "V1_N",
  "V1_O",
  "V2",
  "V2_H",
  "V2_J",
  "V2_K",
  "V2_L",
  "V2_M",
  "V2_N",
  "V2_O",
  "V3",
  "V3_H",
  "V3_J",
  "V3_K",
  "V3_L",
  "V3_M",
  "V3_N",
  "V3_O",
  "V4",
  "V4_H",
  "V4_J",
  "V4_K",
  "V4_L",
  "V4_M",
  "V4_N",
  "V4_O",
  "V5",
  "V5_H",
  "V5_J",
  "V5_K",
  "V5_L",
  "V5_M",
  "V5_N",
  "V5_O",
  "V6",
  "V6_H",
  "V6_J",
  "V6_K",
  "V6_L",
  "V6_M",
  "V6_N",
  "V6_O",
  "V7",
  "V7_H",
  "V7_J",
  "V7_K",
  "V7_L",
  "V7_M",
  "V7_N",
  "V7_O",
  "V8",
  "V8_H",
  "V8_J",
  "V8_K",
  "V8_L",
  "V8_M",
  "V8_N",
  "V8_O",
  "V9",
  "V9_H",
  "V9_J",
  "V9_K",
  "V9_L",
  "V9_M",
  "V9_N",
  "V9_O",
  "V10",
  "V10_H",
  "V10_J",
  "V10_K",
  "V10_L",
  "V10_M",
  "V10_N",
  "V10_O",
  "V11",
  "V11_H",
  "V11_J",
  "V11_K",
  "V11_L",
  "V11_M",
  "V11_N",
  "V11_O",
  "V12",
  "V12_H",
  "V12_J",
  "V12_K",
  "V12_L",
  "V12_M",
  "V12_N",
  "V12_O",
  "V13",
  "V13_H",
  "V13_J",
  "V13_K",
  "V13_L",
  "V13_M",
  "V13_N",
  "V13_O",
  "V14",
  "V14_H",
  "V14_J",
  "V14_K",
  "V14_L",
  "V14_M",
  "V14_N",
  "V14_O",
  "V15",
  "V15_H",
  "V15_J",
  "V15_K",
  "V15_L",
  "V15_M",
  "V15_N",
  "V15_O",
  "P0",
  "P1",
  "P2",
  "P3",
  "P4",
  "P5",
  "P6",
  "P7",
  "P8",
  "P9",
  "P10",
  "P11",
  "P12",
  "P13",
  "P14",
  "P15",
  "RFLAGS" // no trailing comma
};

// An array of character pointers to machine register names.
const VMReg OptoReg::opto2vm[REG_COUNT] = {
	r10->as_VMReg()        ,
	r10->as_VMReg()->next(),
	r11->as_VMReg()        ,
	r11->as_VMReg()->next(),
	r12->as_VMReg()        ,
	r12->as_VMReg()->next(),
	r13->as_VMReg()        ,
	r13->as_VMReg()->next(),
	r14->as_VMReg()        ,
	r14->as_VMReg()->next(),
	r15->as_VMReg()        ,
	r15->as_VMReg()->next(),
	r16->as_VMReg()        ,
	r16->as_VMReg()->next(),
	r17->as_VMReg()        ,
	r17->as_VMReg()->next(),
	r18_tls->as_VMReg()        ,
	r18_tls->as_VMReg()->next(),
	r0->as_VMReg()         ,
	r0->as_VMReg()->next() ,
	r1->as_VMReg()         ,
	r1->as_VMReg()->next() ,
	r2->as_VMReg()         ,
	r2->as_VMReg()->next() ,
	r3->as_VMReg()         ,
	r3->as_VMReg()->next() ,
	r4->as_VMReg()         ,
	r4->as_VMReg()->next() ,
	r5->as_VMReg()         ,
	r5->as_VMReg()->next() ,
	r6->as_VMReg()         ,
	r6->as_VMReg()->next() ,
	r7->as_VMReg()         ,
	r7->as_VMReg()->next() ,
	r19->as_VMReg()        ,
	r19->as_VMReg()->next(),
	r20->as_VMReg()        ,
	r20->as_VMReg()->next(),
	r21->as_VMReg()        ,
	r21->as_VMReg()->next(),
	r22->as_VMReg()        ,
	r22->as_VMReg()->next(),
	r23->as_VMReg()        ,
	r23->as_VMReg()->next(),
	r24->as_VMReg()        ,
	r24->as_VMReg()->next(),
	r25->as_VMReg()        ,
	r25->as_VMReg()->next(),
	r26->as_VMReg()        ,
	r26->as_VMReg()->next(),
	r27->as_VMReg()        ,
	r27->as_VMReg()->next(),
	r28->as_VMReg()        ,
	r28->as_VMReg()->next(),
	r29->as_VMReg()        ,
	r29->as_VMReg()->next(),
	r30->as_VMReg()        ,
	r30->as_VMReg()->next(),
	r31_sp->as_VMReg()     ,
	r31_sp->as_VMReg()->next(),
	r8->as_VMReg()         ,
	r8->as_VMReg()->next() ,
	r9->as_VMReg()         ,
	r9->as_VMReg()->next() ,
	v16->as_VMReg()          ,
	v16->as_VMReg()->next()  ,
	v16->as_VMReg()->next(2) ,
	v16->as_VMReg()->next(3) ,
	v16->as_VMReg()->next(4) ,
	v16->as_VMReg()->next(5) ,
	v16->as_VMReg()->next(6) ,
	v16->as_VMReg()->next(7) ,
	v17->as_VMReg()          ,
	v17->as_VMReg()->next()  ,
	v17->as_VMReg()->next(2) ,
	v17->as_VMReg()->next(3) ,
	v17->as_VMReg()->next(4) ,
	v17->as_VMReg()->next(5) ,
	v17->as_VMReg()->next(6) ,
	v17->as_VMReg()->next(7) ,
	v18->as_VMReg()          ,
	v18->as_VMReg()->next()  ,
	v18->as_VMReg()->next(2) ,
	v18->as_VMReg()->next(3) ,
	v18->as_VMReg()->next(4) ,
	v18->as_VMReg()->next(5) ,
	v18->as_VMReg()->next(6) ,
	v18->as_VMReg()->next(7) ,
	v19->as_VMReg()          ,
	v19->as_VMReg()->next()  ,
	v19->as_VMReg()->next(2) ,
	v19->as_VMReg()->next(3) ,
	v19->as_VMReg()->next(4) ,
	v19->as_VMReg()->next(5) ,
	v19->as_VMReg()->next(6) ,
	v19->as_VMReg()->next(7) ,
	v20->as_VMReg()          ,
	v20->as_VMReg()->next()  ,
	v20->as_VMReg()->next(2) ,
	v20->as_VMReg()->next(3) ,
	v20->as_VMReg()->next(4) ,
	v20->as_VMReg()->next(5) ,
	v20->as_VMReg()->next(6) ,
	v20->as_VMReg()->next(7) ,
	v21->as_VMReg()          ,
	v21->as_VMReg()->next()  ,
	v21->as_VMReg()->next(2) ,
	v21->as_VMReg()->next(3) ,
	v21->as_VMReg()->next(4) ,
	v21->as_VMReg()->next(5) ,
	v21->as_VMReg()->next(6) ,
	v21->as_VMReg()->next(7) ,
	v22->as_VMReg()          ,
	v22->as_VMReg()->next()  ,
	v22->as_VMReg()->next(2) ,
	v22->as_VMReg()->next(3) ,
	v22->as_VMReg()->next(4) ,
	v22->as_VMReg()->next(5) ,
	v22->as_VMReg()->next(6) ,
	v22->as_VMReg()->next(7) ,
	v23->as_VMReg()          ,
	v23->as_VMReg()->next()  ,
	v23->as_VMReg()->next(2) ,
	v23->as_VMReg()->next(3) ,
	v23->as_VMReg()->next(4) ,
	v23->as_VMReg()->next(5) ,
	v23->as_VMReg()->next(6) ,
	v23->as_VMReg()->next(7) ,
	v24->as_VMReg()          ,
	v24->as_VMReg()->next()  ,
	v24->as_VMReg()->next(2) ,
	v24->as_VMReg()->next(3) ,
	v24->as_VMReg()->next(4) ,
	v24->as_VMReg()->next(5) ,
	v24->as_VMReg()->next(6) ,
	v24->as_VMReg()->next(7) ,
	v25->as_VMReg()          ,
	v25->as_VMReg()->next()  ,
	v25->as_VMReg()->next(2) ,
	v25->as_VMReg()->next(3) ,
	v25->as_VMReg()->next(4) ,
	v25->as_VMReg()->next(5) ,
	v25->as_VMReg()->next(6) ,
	v25->as_VMReg()->next(7) ,
	v26->as_VMReg()          ,
	v26->as_VMReg()->next()  ,
	v26->as_VMReg()->next(2) ,
	v26->as_VMReg()->next(3) ,
	v26->as_VMReg()->next(4) ,
	v26->as_VMReg()->next(5) ,
	v26->as_VMReg()->next(6) ,
	v26->as_VMReg()->next(7) ,
	v27->as_VMReg()          ,
	v27->as_VMReg()->next()  ,
	v27->as_VMReg()->next(2) ,
	v27->as_VMReg()->next(3) ,
	v27->as_VMReg()->next(4) ,
	v27->as_VMReg()->next(5) ,
	v27->as_VMReg()->next(6) ,
	v27->as_VMReg()->next(7) ,
	v28->as_VMReg()          ,
	v28->as_VMReg()->next()  ,
	v28->as_VMReg()->next(2) ,
	v28->as_VMReg()->next(3) ,
	v28->as_VMReg()->next(4) ,
	v28->as_VMReg()->next(5) ,
	v28->as_VMReg()->next(6) ,
	v28->as_VMReg()->next(7) ,
	v29->as_VMReg()          ,
	v29->as_VMReg()->next()  ,
	v29->as_VMReg()->next(2) ,
	v29->as_VMReg()->next(3) ,
	v29->as_VMReg()->next(4) ,
	v29->as_VMReg()->next(5) ,
	v29->as_VMReg()->next(6) ,
	v29->as_VMReg()->next(7) ,
	v30->as_VMReg()          ,
	v30->as_VMReg()->next()  ,
	v30->as_VMReg()->next(2) ,
	v30->as_VMReg()->next(3) ,
	v30->as_VMReg()->next(4) ,
	v30->as_VMReg()->next(5) ,
	v30->as_VMReg()->next(6) ,
	v30->as_VMReg()->next(7) ,
	v31->as_VMReg()          ,
	v31->as_VMReg()->next()  ,
	v31->as_VMReg()->next(2) ,
	v31->as_VMReg()->next(3) ,
	v31->as_VMReg()->next(4) ,
	v31->as_VMReg()->next(5) ,
	v31->as_VMReg()->next(6) ,
	v31->as_VMReg()->next(7) ,
	v0->as_VMReg()          ,
	v0->as_VMReg()->next()  ,
	v0->as_VMReg()->next(2) ,
	v0->as_VMReg()->next(3) ,
	v0->as_VMReg()->next(4) ,
	v0->as_VMReg()->next(5) ,
	v0->as_VMReg()->next(6) ,
	v0->as_VMReg()->next(7) ,
	v1->as_VMReg()          ,
	v1->as_VMReg()->next()  ,
	v1->as_VMReg()->next(2) ,
	v1->as_VMReg()->next(3) ,
	v1->as_VMReg()->next(4) ,
	v1->as_VMReg()->next(5) ,
	v1->as_VMReg()->next(6) ,
	v1->as_VMReg()->next(7) ,
	v2->as_VMReg()          ,
	v2->as_VMReg()->next()  ,
	v2->as_VMReg()->next(2) ,
	v2->as_VMReg()->next(3) ,
	v2->as_VMReg()->next(4) ,
	v2->as_VMReg()->next(5) ,
	v2->as_VMReg()->next(6) ,
	v2->as_VMReg()->next(7) ,
	v3->as_VMReg()          ,
	v3->as_VMReg()->next()  ,
	v3->as_VMReg()->next(2) ,
	v3->as_VMReg()->next(3) ,
	v3->as_VMReg()->next(4) ,
	v3->as_VMReg()->next(5) ,
	v3->as_VMReg()->next(6) ,
	v3->as_VMReg()->next(7) ,
	v4->as_VMReg()          ,
	v4->as_VMReg()->next()  ,
	v4->as_VMReg()->next(2) ,
	v4->as_VMReg()->next(3) ,
	v4->as_VMReg()->next(4) ,
	v4->as_VMReg()->next(5) ,
	v4->as_VMReg()->next(6) ,
	v4->as_VMReg()->next(7) ,
	v5->as_VMReg()          ,
	v5->as_VMReg()->next()  ,
	v5->as_VMReg()->next(2) ,
	v5->as_VMReg()->next(3) ,
	v5->as_VMReg()->next(4) ,
	v5->as_VMReg()->next(5) ,
	v5->as_VMReg()->next(6) ,
	v5->as_VMReg()->next(7) ,
	v6->as_VMReg()          ,
	v6->as_VMReg()->next()  ,
	v6->as_VMReg()->next(2) ,
	v6->as_VMReg()->next(3) ,
	v6->as_VMReg()->next(4) ,
	v6->as_VMReg()->next(5) ,
	v6->as_VMReg()->next(6) ,
	v6->as_VMReg()->next(7) ,
	v7->as_VMReg()          ,
	v7->as_VMReg()->next()  ,
	v7->as_VMReg()->next(2) ,
	v7->as_VMReg()->next(3) ,
	v7->as_VMReg()->next(4) ,
	v7->as_VMReg()->next(5) ,
	v7->as_VMReg()->next(6) ,
	v7->as_VMReg()->next(7) ,
	v8->as_VMReg()          ,
	v8->as_VMReg()->next()  ,
	v8->as_VMReg()->next(2) ,
	v8->as_VMReg()->next(3) ,
	v8->as_VMReg()->next(4) ,
	v8->as_VMReg()->next(5) ,
	v8->as_VMReg()->next(6) ,
	v8->as_VMReg()->next(7) ,
	v9->as_VMReg()          ,
	v9->as_VMReg()->next()  ,
	v9->as_VMReg()->next(2) ,
	v9->as_VMReg()->next(3) ,
	v9->as_VMReg()->next(4) ,
	v9->as_VMReg()->next(5) ,
	v9->as_VMReg()->next(6) ,
	v9->as_VMReg()->next(7) ,
	v10->as_VMReg()          ,
	v10->as_VMReg()->next()  ,
	v10->as_VMReg()->next(2) ,
	v10->as_VMReg()->next(3) ,
	v10->as_VMReg()->next(4) ,
	v10->as_VMReg()->next(5) ,
	v10->as_VMReg()->next(6) ,
	v10->as_VMReg()->next(7) ,
	v11->as_VMReg()          ,
	v11->as_VMReg()->next()  ,
	v11->as_VMReg()->next(2) ,
	v11->as_VMReg()->next(3) ,
	v11->as_VMReg()->next(4) ,
	v11->as_VMReg()->next(5) ,
	v11->as_VMReg()->next(6) ,
	v11->as_VMReg()->next(7) ,
	v12->as_VMReg()          ,
	v12->as_VMReg()->next()  ,
	v12->as_VMReg()->next(2) ,
	v12->as_VMReg()->next(3) ,
	v12->as_VMReg()->next(4) ,
	v12->as_VMReg()->next(5) ,
	v12->as_VMReg()->next(6) ,
	v12->as_VMReg()->next(7) ,
	v13->as_VMReg()          ,
	v13->as_VMReg()->next()  ,
	v13->as_VMReg()->next(2) ,
	v13->as_VMReg()->next(3) ,
	v13->as_VMReg()->next(4) ,
	v13->as_VMReg()->next(5) ,
	v13->as_VMReg()->next(6) ,
	v13->as_VMReg()->next(7) ,
	v14->as_VMReg()          ,
	v14->as_VMReg()->next()  ,
	v14->as_VMReg()->next(2) ,
	v14->as_VMReg()->next(3) ,
	v14->as_VMReg()->next(4) ,
	v14->as_VMReg()->next(5) ,
	v14->as_VMReg()->next(6) ,
	v14->as_VMReg()->next(7) ,
	v15->as_VMReg()          ,
	v15->as_VMReg()->next()  ,
	v15->as_VMReg()->next(2) ,
	v15->as_VMReg()->next(3) ,
	v15->as_VMReg()->next(4) ,
	v15->as_VMReg()->next(5) ,
	v15->as_VMReg()->next(6) ,
	v15->as_VMReg()->next(7) ,
	p0->as_VMReg(),
	p1->as_VMReg(),
	p2->as_VMReg(),
	p3->as_VMReg(),
	p4->as_VMReg(),
	p5->as_VMReg(),
	p6->as_VMReg(),
	p7->as_VMReg(),
	p8->as_VMReg(),
	p9->as_VMReg(),
	p10->as_VMReg(),
	p11->as_VMReg(),
	p12->as_VMReg(),
	p13->as_VMReg(),
	p14->as_VMReg(),
	p15->as_VMReg(),
	VMRegImpl::Bad() // no trailing comma
	};

 OptoReg::Name OptoReg::vm2opto[ConcreteRegisterImpl::number_of_registers];

// An array of the machine register encode values
const unsigned char Matcher::_regEncode[REG_COUNT] = {
  (unsigned char)'\xA',  // R10
  (unsigned char)'\xA',  // R10_H
  (unsigned char)'\xB',  // R11
  (unsigned char)'\xB',  // R11_H
  (unsigned char)'\xC',  // R12
  (unsigned char)'\xC',  // R12_H
  (unsigned char)'\xD',  // R13
  (unsigned char)'\xD',  // R13_H
  (unsigned char)'\xE',  // R14
  (unsigned char)'\xE',  // R14_H
  (unsigned char)'\xF',  // R15
  (unsigned char)'\xF',  // R15_H
  (unsigned char)'\x10',  // R16
  (unsigned char)'\x10',  // R16_H
  (unsigned char)'\x11',  // R17
  (unsigned char)'\x11',  // R17_H
  (unsigned char)'\x12',  // R18
  (unsigned char)'\x12',  // R18_H
  (unsigned char)'\x0',  // R0
  (unsigned char)'\x0',  // R0_H
  (unsigned char)'\x1',  // R1
  (unsigned char)'\x1',  // R1_H
  (unsigned char)'\x2',  // R2
  (unsigned char)'\x2',  // R2_H
  (unsigned char)'\x3',  // R3
  (unsigned char)'\x3',  // R3_H
  (unsigned char)'\x4',  // R4
  (unsigned char)'\x4',  // R4_H
  (unsigned char)'\x5',  // R5
  (unsigned char)'\x5',  // R5_H
  (unsigned char)'\x6',  // R6
  (unsigned char)'\x6',  // R6_H
  (unsigned char)'\x7',  // R7
  (unsigned char)'\x7',  // R7_H
  (unsigned char)'\x13',  // R19
  (unsigned char)'\x13',  // R19_H
  (unsigned char)'\x14',  // R20
  (unsigned char)'\x14',  // R20_H
  (unsigned char)'\x15',  // R21
  (unsigned char)'\x15',  // R21_H
  (unsigned char)'\x16',  // R22
  (unsigned char)'\x16',  // R22_H
  (unsigned char)'\x17',  // R23
  (unsigned char)'\x17',  // R23_H
  (unsigned char)'\x18',  // R24
  (unsigned char)'\x18',  // R24_H
  (unsigned char)'\x19',  // R25
  (unsigned char)'\x19',  // R25_H
  (unsigned char)'\x1A',  // R26
  (unsigned char)'\x1A',  // R26_H
  (unsigned char)'\x1B',  // R27
  (unsigned char)'\x1B',  // R27_H
  (unsigned char)'\x1C',  // R28
  (unsigned char)'\x1C',  // R28_H
  (unsigned char)'\x1D',  // R29
  (unsigned char)'\x1D',  // R29_H
  (unsigned char)'\x1E',  // R30
  (unsigned char)'\x1E',  // R30_H
  (unsigned char)'\x1F',  // R31
  (unsigned char)'\x1F',  // R31_H
  (unsigned char)'\x8',  // R8
  (unsigned char)'\x8',  // R8_H
  (unsigned char)'\x9',  // R9
  (unsigned char)'\x9',  // R9_H
  (unsigned char)'\x10',  // V16
  (unsigned char)'\x10',  // V16_H
  (unsigned char)'\x10',  // V16_J
  (unsigned char)'\x10',  // V16_K
  (unsigned char)'\x10',  // V16_L
  (unsigned char)'\x10',  // V16_M
  (unsigned char)'\x10',  // V16_N
  (unsigned char)'\x10',  // V16_O
  (unsigned char)'\x11',  // V17
  (unsigned char)'\x11',  // V17_H
  (unsigned char)'\x11',  // V17_J
  (unsigned char)'\x11',  // V17_K
  (unsigned char)'\x11',  // V17_L
  (unsigned char)'\x11',  // V17_M
  (unsigned char)'\x11',  // V17_N
  (unsigned char)'\x11',  // V17_O
  (unsigned char)'\x12',  // V18
  (unsigned char)'\x12',  // V18_H
  (unsigned char)'\x12',  // V18_J
  (unsigned char)'\x12',  // V18_K
  (unsigned char)'\x12',  // V18_L
  (unsigned char)'\x12',  // V18_M
  (unsigned char)'\x12',  // V18_N
  (unsigned char)'\x12',  // V18_O
  (unsigned char)'\x13',  // V19
  (unsigned char)'\x13',  // V19_H
  (unsigned char)'\x13',  // V19_J
  (unsigned char)'\x13',  // V19_K
  (unsigned char)'\x13',  // V19_L
  (unsigned char)'\x13',  // V19_M
  (unsigned char)'\x13',  // V19_N
  (unsigned char)'\x13',  // V19_O
  (unsigned char)'\x14',  // V20
  (unsigned char)'\x14',  // V20_H
  (unsigned char)'\x14',  // V20_J
  (unsigned char)'\x14',  // V20_K
  (unsigned char)'\x14',  // V20_L
  (unsigned char)'\x14',  // V20_M
  (unsigned char)'\x14',  // V20_N
  (unsigned char)'\x14',  // V20_O
  (unsigned char)'\x15',  // V21
  (unsigned char)'\x15',  // V21_H
  (unsigned char)'\x15',  // V21_J
  (unsigned char)'\x15',  // V21_K
  (unsigned char)'\x15',  // V21_L
  (unsigned char)'\x15',  // V21_M
  (unsigned char)'\x15',  // V21_N
  (unsigned char)'\x15',  // V21_O
  (unsigned char)'\x16',  // V22
  (unsigned char)'\x16',  // V22_H
  (unsigned char)'\x16',  // V22_J
  (unsigned char)'\x16',  // V22_K
  (unsigned char)'\x16',  // V22_L
  (unsigned char)'\x16',  // V22_M
  (unsigned char)'\x16',  // V22_N
  (unsigned char)'\x16',  // V22_O
  (unsigned char)'\x17',  // V23
  (unsigned char)'\x17',  // V23_H
  (unsigned char)'\x17',  // V23_J
  (unsigned char)'\x17',  // V23_K
  (unsigned char)'\x17',  // V23_L
  (unsigned char)'\x17',  // V23_M
  (unsigned char)'\x17',  // V23_N
  (unsigned char)'\x17',  // V23_O
  (unsigned char)'\x18',  // V24
  (unsigned char)'\x18',  // V24_H
  (unsigned char)'\x18',  // V24_J
  (unsigned char)'\x18',  // V24_K
  (unsigned char)'\x18',  // V24_L
  (unsigned char)'\x18',  // V24_M
  (unsigned char)'\x18',  // V24_N
  (unsigned char)'\x18',  // V24_O
  (unsigned char)'\x19',  // V25
  (unsigned char)'\x19',  // V25_H
  (unsigned char)'\x19',  // V25_J
  (unsigned char)'\x19',  // V25_K
  (unsigned char)'\x19',  // V25_L
  (unsigned char)'\x19',  // V25_M
  (unsigned char)'\x19',  // V25_N
  (unsigned char)'\x19',  // V25_O
  (unsigned char)'\x1A',  // V26
  (unsigned char)'\x1A',  // V26_H
  (unsigned char)'\x1A',  // V26_J
  (unsigned char)'\x1A',  // V26_K
  (unsigned char)'\x1A',  // V26_L
  (unsigned char)'\x1A',  // V26_M
  (unsigned char)'\x1A',  // V26_N
  (unsigned char)'\x1A',  // V26_O
  (unsigned char)'\x1B',  // V27
  (unsigned char)'\x1B',  // V27_H
  (unsigned char)'\x1B',  // V27_J
  (unsigned char)'\x1B',  // V27_K
  (unsigned char)'\x1B',  // V27_L
  (unsigned char)'\x1B',  // V27_M
  (unsigned char)'\x1B',  // V27_N
  (unsigned char)'\x1B',  // V27_O
  (unsigned char)'\x1C',  // V28
  (unsigned char)'\x1C',  // V28_H
  (unsigned char)'\x1C',  // V28_J
  (unsigned char)'\x1C',  // V28_K
  (unsigned char)'\x1C',  // V28_L
  (unsigned char)'\x1C',  // V28_M
  (unsigned char)'\x1C',  // V28_N
  (unsigned char)'\x1C',  // V28_O
  (unsigned char)'\x1D',  // V29
  (unsigned char)'\x1D',  // V29_H
  (unsigned char)'\x1D',  // V29_J
  (unsigned char)'\x1D',  // V29_K
  (unsigned char)'\x1D',  // V29_L
  (unsigned char)'\x1D',  // V29_M
  (unsigned char)'\x1D',  // V29_N
  (unsigned char)'\x1D',  // V29_O
  (unsigned char)'\x1E',  // V30
  (unsigned char)'\x1E',  // V30_H
  (unsigned char)'\x1E',  // V30_J
  (unsigned char)'\x1E',  // V30_K
  (unsigned char)'\x1E',  // V30_L
  (unsigned char)'\x1E',  // V30_M
  (unsigned char)'\x1E',  // V30_N
  (unsigned char)'\x1E',  // V30_O
  (unsigned char)'\x1F',  // V31
  (unsigned char)'\x1F',  // V31_H
  (unsigned char)'\x1F',  // V31_J
  (unsigned char)'\x1F',  // V31_K
  (unsigned char)'\x1F',  // V31_L
  (unsigned char)'\x1F',  // V31_M
  (unsigned char)'\x1F',  // V31_N
  (unsigned char)'\x1F',  // V31_O
  (unsigned char)'\x0',  // V0
  (unsigned char)'\x0',  // V0_H
  (unsigned char)'\x0',  // V0_J
  (unsigned char)'\x0',  // V0_K
  (unsigned char)'\x0',  // V0_L
  (unsigned char)'\x0',  // V0_M
  (unsigned char)'\x0',  // V0_N
  (unsigned char)'\x0',  // V0_O
  (unsigned char)'\x1',  // V1
  (unsigned char)'\x1',  // V1_H
  (unsigned char)'\x1',  // V1_J
  (unsigned char)'\x1',  // V1_K
  (unsigned char)'\x1',  // V1_L
  (unsigned char)'\x1',  // V1_M
  (unsigned char)'\x1',  // V1_N
  (unsigned char)'\x1',  // V1_O
  (unsigned char)'\x2',  // V2
  (unsigned char)'\x2',  // V2_H
  (unsigned char)'\x2',  // V2_J
  (unsigned char)'\x2',  // V2_K
  (unsigned char)'\x2',  // V2_L
  (unsigned char)'\x2',  // V2_M
  (unsigned char)'\x2',  // V2_N
  (unsigned char)'\x2',  // V2_O
  (unsigned char)'\x3',  // V3
  (unsigned char)'\x3',  // V3_H
  (unsigned char)'\x3',  // V3_J
  (unsigned char)'\x3',  // V3_K
  (unsigned char)'\x3',  // V3_L
  (unsigned char)'\x3',  // V3_M
  (unsigned char)'\x3',  // V3_N
  (unsigned char)'\x3',  // V3_O
  (unsigned char)'\x4',  // V4
  (unsigned char)'\x4',  // V4_H
  (unsigned char)'\x4',  // V4_J
  (unsigned char)'\x4',  // V4_K
  (unsigned char)'\x4',  // V4_L
  (unsigned char)'\x4',  // V4_M
  (unsigned char)'\x4',  // V4_N
  (unsigned char)'\x4',  // V4_O
  (unsigned char)'\x5',  // V5
  (unsigned char)'\x5',  // V5_H
  (unsigned char)'\x5',  // V5_J
  (unsigned char)'\x5',  // V5_K
  (unsigned char)'\x5',  // V5_L
  (unsigned char)'\x5',  // V5_M
  (unsigned char)'\x5',  // V5_N
  (unsigned char)'\x5',  // V5_O
  (unsigned char)'\x6',  // V6
  (unsigned char)'\x6',  // V6_H
  (unsigned char)'\x6',  // V6_J
  (unsigned char)'\x6',  // V6_K
  (unsigned char)'\x6',  // V6_L
  (unsigned char)'\x6',  // V6_M
  (unsigned char)'\x6',  // V6_N
  (unsigned char)'\x6',  // V6_O
  (unsigned char)'\x7',  // V7
  (unsigned char)'\x7',  // V7_H
  (unsigned char)'\x7',  // V7_J
  (unsigned char)'\x7',  // V7_K
  (unsigned char)'\x7',  // V7_L
  (unsigned char)'\x7',  // V7_M
  (unsigned char)'\x7',  // V7_N
  (unsigned char)'\x7',  // V7_O
  (unsigned char)'\x8',  // V8
  (unsigned char)'\x8',  // V8_H
  (unsigned char)'\x8',  // V8_J
  (unsigned char)'\x8',  // V8_K
  (unsigned char)'\x8',  // V8_L
  (unsigned char)'\x8',  // V8_M
  (unsigned char)'\x8',  // V8_N
  (unsigned char)'\x8',  // V8_O
  (unsigned char)'\x9',  // V9
  (unsigned char)'\x9',  // V9_H
  (unsigned char)'\x9',  // V9_J
  (unsigned char)'\x9',  // V9_K
  (unsigned char)'\x9',  // V9_L
  (unsigned char)'\x9',  // V9_M
  (unsigned char)'\x9',  // V9_N
  (unsigned char)'\x9',  // V9_O
  (unsigned char)'\xA',  // V10
  (unsigned char)'\xA',  // V10_H
  (unsigned char)'\xA',  // V10_J
  (unsigned char)'\xA',  // V10_K
  (unsigned char)'\xA',  // V10_L
  (unsigned char)'\xA',  // V10_M
  (unsigned char)'\xA',  // V10_N
  (unsigned char)'\xA',  // V10_O
  (unsigned char)'\xB',  // V11
  (unsigned char)'\xB',  // V11_H
  (unsigned char)'\xB',  // V11_J
  (unsigned char)'\xB',  // V11_K
  (unsigned char)'\xB',  // V11_L
  (unsigned char)'\xB',  // V11_M
  (unsigned char)'\xB',  // V11_N
  (unsigned char)'\xB',  // V11_O
  (unsigned char)'\xC',  // V12
  (unsigned char)'\xC',  // V12_H
  (unsigned char)'\xC',  // V12_J
  (unsigned char)'\xC',  // V12_K
  (unsigned char)'\xC',  // V12_L
  (unsigned char)'\xC',  // V12_M
  (unsigned char)'\xC',  // V12_N
  (unsigned char)'\xC',  // V12_O
  (unsigned char)'\xD',  // V13
  (unsigned char)'\xD',  // V13_H
  (unsigned char)'\xD',  // V13_J
  (unsigned char)'\xD',  // V13_K
  (unsigned char)'\xD',  // V13_L
  (unsigned char)'\xD',  // V13_M
  (unsigned char)'\xD',  // V13_N
  (unsigned char)'\xD',  // V13_O
  (unsigned char)'\xE',  // V14
  (unsigned char)'\xE',  // V14_H
  (unsigned char)'\xE',  // V14_J
  (unsigned char)'\xE',  // V14_K
  (unsigned char)'\xE',  // V14_L
  (unsigned char)'\xE',  // V14_M
  (unsigned char)'\xE',  // V14_N
  (unsigned char)'\xE',  // V14_O
  (unsigned char)'\xF',  // V15
  (unsigned char)'\xF',  // V15_H
  (unsigned char)'\xF',  // V15_J
  (unsigned char)'\xF',  // V15_K
  (unsigned char)'\xF',  // V15_L
  (unsigned char)'\xF',  // V15_M
  (unsigned char)'\xF',  // V15_N
  (unsigned char)'\xF',  // V15_O
  (unsigned char)'\x0',  // P0
  (unsigned char)'\x1',  // P1
  (unsigned char)'\x2',  // P2
  (unsigned char)'\x3',  // P3
  (unsigned char)'\x4',  // P4
  (unsigned char)'\x5',  // P5
  (unsigned char)'\x6',  // P6
  (unsigned char)'\x7',  // P7
  (unsigned char)'\x8',  // P8
  (unsigned char)'\x9',  // P9
  (unsigned char)'\xA',  // P10
  (unsigned char)'\xB',  // P11
  (unsigned char)'\xC',  // P12
  (unsigned char)'\xD',  // P13
  (unsigned char)'\xE',  // P14
  (unsigned char)'\xF',  // P15
  (unsigned char)'\x20' // no trailing comma  // RFLAGS
};


//------------------Define classes derived from MachOper---------------------
MachOper  *labelOper::clone() const {
  return  new labelOper(_label, _block_num);
}
uint labelOper::opcode() const { return LABEL; }

const RegMask *sRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegFOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

MachOper  *methodOper::clone() const {
  return  new methodOper(_method);
}
uint methodOper::opcode() const { return METHOD; }

const RegMask *iRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *iRegINoSpOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &NO_SPECIAL_REG32_mask();
}

const RegMask *iRegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG_mask();
}

const RegMask *iRegLNoSpOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &NO_SPECIAL_REG_mask();
}

const RegMask *iRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *iRegPNoSpOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &NO_SPECIAL_PTR_REG_mask();
}

const RegMask *iRegP_R0Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R0_REG_mask();
}

const RegMask *iRegP_R1Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R1_REG_mask();
}

const RegMask *iRegP_R2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R2_REG_mask();
}

const RegMask *iRegP_R3Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R3_REG_mask();
}

const RegMask *iRegP_R4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R4_REG_mask();
}

const RegMask *iRegP_R5Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R5_REG_mask();
}

const RegMask *iRegP_R10Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R10_REG_mask();
}

const RegMask *iRegL_R0Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R0_REG_mask();
}

const RegMask *iRegL_R2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R2_REG_mask();
}

const RegMask *iRegL_R3Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R3_REG_mask();
}

const RegMask *iRegL_R11Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R11_REG_mask();
}

const RegMask *iRegP_FPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &FP_REG_mask();
}

const RegMask *iRegI_R0Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_R0_REG_mask();
}

const RegMask *iRegI_R2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_R2_REG_mask();
}

const RegMask *iRegI_R3Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_R3_REG_mask();
}

const RegMask *iRegI_R4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_R4_REG_mask();
}

const RegMask *iRegNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *iRegN_R0Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R0_REG_mask();
}

const RegMask *iRegN_R2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R2_REG_mask();
}

const RegMask *iRegN_R3Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R3_REG_mask();
}

const RegMask *iRegNNoSpOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &NO_SPECIAL_REG32_mask();
}

const RegMask *iRegIHeapbaseOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &HEAPBASE_REG_mask();
}

const RegMask *vRegFOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &FLOAT_REG_mask();
}

const RegMask *vRegDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &DOUBLE_REG_mask();
}

const RegMask *vRegOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &VECTORA_REG_mask();
}

const RegMask *vecDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &VECTORD_REG_mask();
}

const RegMask *vecXOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &VECTORX_REG_mask();
}

const RegMask *vRegD_V0Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V0_REG_mask();
}

const RegMask *vRegD_V1Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V1_REG_mask();
}

const RegMask *vRegD_V2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V2_REG_mask();
}

const RegMask *vRegD_V3Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V3_REG_mask();
}

const RegMask *vRegD_V4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V4_REG_mask();
}

const RegMask *vRegD_V5Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V5_REG_mask();
}

const RegMask *vRegD_V6Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V6_REG_mask();
}

const RegMask *vRegD_V7Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V7_REG_mask();
}

const RegMask *vRegD_V8Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V8_REG_mask();
}

const RegMask *vRegD_V9Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V9_REG_mask();
}

const RegMask *vRegD_V10Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V10_REG_mask();
}

const RegMask *vRegD_V11Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V11_REG_mask();
}

const RegMask *vRegD_V12Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V12_REG_mask();
}

const RegMask *vRegD_V13Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V13_REG_mask();
}

const RegMask *vRegD_V14Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V14_REG_mask();
}

const RegMask *vRegD_V15Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V15_REG_mask();
}

const RegMask *vRegD_V16Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V16_REG_mask();
}

const RegMask *vRegD_V17Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V17_REG_mask();
}

const RegMask *vRegD_V18Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V18_REG_mask();
}

const RegMask *vRegD_V19Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V19_REG_mask();
}

const RegMask *vRegD_V20Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V20_REG_mask();
}

const RegMask *vRegD_V21Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V21_REG_mask();
}

const RegMask *vRegD_V22Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V22_REG_mask();
}

const RegMask *vRegD_V23Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V23_REG_mask();
}

const RegMask *vRegD_V24Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V24_REG_mask();
}

const RegMask *vRegD_V25Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V25_REG_mask();
}

const RegMask *vRegD_V26Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V26_REG_mask();
}

const RegMask *vRegD_V27Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V27_REG_mask();
}

const RegMask *vRegD_V28Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V28_REG_mask();
}

const RegMask *vRegD_V29Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V29_REG_mask();
}

const RegMask *vRegD_V30Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V30_REG_mask();
}

const RegMask *vRegD_V31Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V31_REG_mask();
}

const RegMask *pRegGovOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &GOV_PR_mask();
}

const RegMask *rFlagsRegOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *rFlagsRegUOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *inline_cache_RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &METHOD_REG_mask();
}

const RegMask *thread_RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &THREAD_REG_mask();
}

const RegMask *lr_RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &LR_REG_mask();
}

const RegMask *indirectOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indIndexScaledI2LOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &PTR_REG_mask();
  case 1: return &ANY_REG32_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexScaledOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &PTR_REG_mask();
  case 1: return &ANY_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexI2LOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &PTR_REG_mask();
  case 1: return &ANY_REG32_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &PTR_REG_mask();
  case 1: return &ANY_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indOffIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffI1Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffI2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffI4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffI8Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffI16Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffL1Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffL2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffL4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffL8Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffL16Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indirectNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *indIndexScaledI2LNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *indIndexScaledNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &ANY_REG32_mask();
  case 1: return &ANY_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexI2LNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *indIndexNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &ANY_REG32_mask();
  case 1: return &ANY_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indOffINOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *indOffLNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *thread_anchor_pcOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *stackSlotPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotFOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *iRegL2IOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG_mask();
}

const RegMask *vmemA_indOffI4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *vmemA_indOffL4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

//------------------Define members for classes derived from MachNode----------
// Build short branch version of this instruction
MachNode *far_cmpL_branch_signNode::short_branch_version() {
  cmpL_branch_signNode *node = new cmpL_branch_signNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node);
  return node;
}

// Build short branch version of this instruction
MachNode *far_cmpI_branch_signNode::short_branch_version() {
  cmpI_branch_signNode *node = new cmpI_branch_signNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node);
  return node;
}

// Build short branch version of this instruction
MachNode *far_cmpL_branch_bitNode::short_branch_version() {
  cmpL_branch_bitNode *node = new cmpL_branch_bitNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node);
  return node;
}

// Build short branch version of this instruction
MachNode *far_cmpI_branch_bitNode::short_branch_version() {
  cmpI_branch_bitNode *node = new cmpI_branch_bitNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node);
  return node;
}


// Copy _idx, inputs and operands to new node
void MachNode::fill_new_machnode(MachNode* node) const {
  // New node must use same node index
  node->set_idx( _idx );
  // Copy machine-independent inputs
  for( uint j = 0; j < req(); j++ ) {
    node->add_req(in(j));
  }
  // Copy my operands, except for cisc position
  int nopnds = num_opnds();
  assert( node->num_opnds() == (uint)nopnds, "Must have same number of operands");
  MachOper **to = node->_opnds;
  for( int i = 0; i < nopnds; i++ ) {
    if( i != cisc_operand() ) 
      to[i] = _opnds[i]->clone();
  }
}

void overflowMulI_reg_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void overflowMulI_reg_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void overflowMulL_reg_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void overflowMulL_reg_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(1));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(1));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchConNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchConNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchConUNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchConUNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpI_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpI_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpL_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpL_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpP_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpP_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpN_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpN_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpP_narrowOop_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpP_narrowOop_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpUI_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpUI_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpUL_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpUL_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpL_branch_signNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpL_branch_signNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpI_branch_signNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpI_branch_signNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpL_branch_bitNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpL_branch_bitNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpI_branch_bitNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpI_branch_bitNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void far_cmpL_branch_signNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void far_cmpL_branch_signNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void far_cmpI_branch_signNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void far_cmpI_branch_signNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void far_cmpL_branch_bitNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void far_cmpL_branch_bitNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void far_cmpI_branch_bitNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void far_cmpI_branch_bitNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchLoopEndNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchLoopEndNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchLoopEndUNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchLoopEndUNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void CallStaticJavaDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallDynamicJavaDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallRuntimeDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallLeafDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallLeafNoFPDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallNativeDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

int loadBNode::reloc() const {
  return 1;
}

int loadB2LNode::reloc() const {
  return 1;
}

int loadUBNode::reloc() const {
  return 1;
}

int loadUB2LNode::reloc() const {
  return 1;
}

int loadSNode::reloc() const {
  return 1;
}

int loadS2LNode::reloc() const {
  return 1;
}

int loadUSNode::reloc() const {
  return 1;
}

int loadUS2LNode::reloc() const {
  return 1;
}

int loadINode::reloc() const {
  return 1;
}

int loadI2LNode::reloc() const {
  return 1;
}

int loadUI2LNode::reloc() const {
  return 1;
}

int loadLNode::reloc() const {
  return 1;
}

int loadRangeNode::reloc() const {
  return 1;
}

int loadPNode::reloc() const {
  return 1;
}

int loadNNode::reloc() const {
  return 1;
}

int loadKlassNode::reloc() const {
  return 1;
}

int loadNKlassNode::reloc() const {
  return 1;
}

int loadFNode::reloc() const {
  return 1;
}

int loadDNode::reloc() const {
  return 1;
}

int loadConPNode::reloc() const {
  return 1;
}

int loadConP0Node::reloc() const {
  return 1;
}

int loadConP1Node::reloc() const {
  return 1;
}

int loadByteMapBaseNode::reloc() const {
  return 1;
}

int loadConF_packedNode::reloc() const {
  return 2;
}

int loadConFNode::reloc() const {
  return 2;
}

int loadConD_packedNode::reloc() const {
  return 2;
}

int loadConDNode::reloc() const {
  return 2;
}

int storeimmCM0Node::reloc() const {
  return 2;
}

int storeimmCM0_orderedNode::reloc() const {
  return 2;
}

int storeBNode::reloc() const {
  return 3;
}

int storeimmB0Node::reloc() const {
  return 2;
}

int storeCNode::reloc() const {
  return 3;
}

int storeimmC0Node::reloc() const {
  return 2;
}

int storeINode::reloc() const {
  return 3;
}

int storeimmI0Node::reloc() const {
  return 2;
}

int storeLNode::reloc() const {
  return 2;
}

int storeimmL0Node::reloc() const {
  return 2;
}

int storePNode::reloc() const {
  return 2;
}

int storeimmP0Node::reloc() const {
  return 3;
}

int storeNNode::reloc() const {
  return 2;
}

int storeImmN0Node::reloc() const {
  return 2;
}

int storeFNode::reloc() const {
  return 2;
}

int storeDNode::reloc() const {
  return 2;
}

int storeNKlassNode::reloc() const {
  return 2;
}

int prefetchallocNode::reloc() const {
  return 1;
}

int storeB_volatileNode::reloc() const {
  return 1;
}

int storeC_volatileNode::reloc() const {
  return 1;
}

int storeI_volatileNode::reloc() const {
  return 1;
}

int bytes_reverse_intNode::reloc() const {
  return 1;
}

int bytes_reverse_unsigned_shortNode::reloc() const {
  return 1;
}

int bytes_reverse_shortNode::reloc() const {
  return 1;
}

int countLeadingZerosINode::reloc() const {
  return 1;
}

int countTrailingZerosINode::reloc() const {
  return 1;
}

int popCountINode::reloc() const {
  return 1;
}

int popCountI_memNode::reloc() const {
  return 1;
}

int popCountL_memNode::reloc() const {
  return 1;
}

int storePConditionalNode::reloc() const {
  return 1;
}

int get_and_addINode::reloc() const {
  return 1;
}

int get_and_addI_no_resNode::reloc() const {
  return 1;
}

int get_and_addIAcqNode::reloc() const {
  return 1;
}

int get_and_addI_no_resAcqNode::reloc() const {
  return 1;
}

int cmovI_reg_regNode::reloc() const {
  return 2;
}

int cmovUI_reg_regNode::reloc() const {
  return 2;
}

int cmovI_zero_regNode::reloc() const {
  return 1;
}

int cmovUI_zero_regNode::reloc() const {
  return 1;
}

int cmovI_reg_zeroNode::reloc() const {
  return 1;
}

int cmovUI_reg_zeroNode::reloc() const {
  return 1;
}

int cmovP_reg_zeroNode::reloc() const {
  return 1;
}

int cmovUP_reg_zeroNode::reloc() const {
  return 1;
}

int cmovP_zero_regNode::reloc() const {
  return 1;
}

int cmovUP_zero_regNode::reloc() const {
  return 1;
}

int addI_reg_regNode::reloc() const {
  return 2;
}

int addI_reg_immNode::reloc() const {
  return 1;
}

int addP_reg_reg_extNode::reloc() const {
  return 1;
}

int addP_reg_reg_ext_shiftNode::reloc() const {
  return 1;
}

int lshift_extNode::reloc() const {
  return 1;
}

int subI_reg_regNode::reloc() const {
  return 2;
}

int subI_reg_immNode::reloc() const {
  return 1;
}

int negI_regNode::reloc() const {
  return 1;
}

int mulINode::reloc() const {
  return 2;
}

int smulINode::reloc() const {
  return 2;
}

int smulI_0Node::reloc() const {
  return 2;
}

int maddINode::reloc() const {
  return 3;
}

int maddI_0Node::reloc() const {
  return 3;
}

int msubINode::reloc() const {
  return 3;
}

int mnegINode::reloc() const {
  return 2;
}

int mnegI_0Node::reloc() const {
  return 2;
}

int mnegI_1Node::reloc() const {
  return 2;
}

int mnegI_2Node::reloc() const {
  return 2;
}

int smaddLNode::reloc() const {
  return 2;
}

int smaddL_1Node::reloc() const {
  return 2;
}

int smaddL_0Node::reloc() const {
  return 2;
}

int smaddL_2Node::reloc() const {
  return 2;
}

int smsubLNode::reloc() const {
  return 2;
}

int smsubL_0Node::reloc() const {
  return 2;
}

int smnegLNode::reloc() const {
  return 2;
}

int smnegL_0Node::reloc() const {
  return 2;
}

int smnegL_1Node::reloc() const {
  return 2;
}

int smnegL_2Node::reloc() const {
  return 2;
}

int muladdS2INode::reloc() const {
  return 4;
}

int divINode::reloc() const {
  return 2;
}

int modINode::reloc() const {
  return 2;
}

int lShiftI_reg_regNode::reloc() const {
  return 2;
}

int lShiftI_reg_immNode::reloc() const {
  return 1;
}

int urShiftI_reg_regNode::reloc() const {
  return 2;
}

int urShiftI_reg_immNode::reloc() const {
  return 1;
}

int rShiftI_reg_regNode::reloc() const {
  return 2;
}

int rShiftI_reg_immNode::reloc() const {
  return 1;
}

int lShiftL_reg_regNode::reloc() const {
  return 1;
}

int urShiftL_reg_regNode::reloc() const {
  return 1;
}

int rShiftL_reg_regNode::reloc() const {
  return 1;
}

int regI_not_regNode::reloc() const {
  return 1;
}

int AndI_reg_not_regNode::reloc() const {
  return 2;
}

int AndI_reg_not_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_not_regNode::reloc() const {
  return 2;
}

int OrI_reg_not_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_not_regNode::reloc() const {
  return 2;
}

int XorI_reg_not_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_URShift_not_regNode::reloc() const {
  return 2;
}

int AndI_reg_URShift_not_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_RShift_not_regNode::reloc() const {
  return 2;
}

int AndI_reg_RShift_not_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_RotateRight_not_regNode::reloc() const {
  return 2;
}

int AndI_reg_RotateRight_not_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_LShift_not_regNode::reloc() const {
  return 2;
}

int AndI_reg_LShift_not_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_URShift_not_regNode::reloc() const {
  return 2;
}

int XorI_reg_URShift_not_reg_1Node::reloc() const {
  return 2;
}

int XorI_reg_URShift_not_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_URShift_not_reg_2Node::reloc() const {
  return 2;
}

int XorI_reg_RShift_not_regNode::reloc() const {
  return 2;
}

int XorI_reg_RShift_not_reg_1Node::reloc() const {
  return 2;
}

int XorI_reg_RShift_not_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_RShift_not_reg_2Node::reloc() const {
  return 2;
}

int XorI_reg_RotateRight_not_regNode::reloc() const {
  return 2;
}

int XorI_reg_RotateRight_not_reg_1Node::reloc() const {
  return 2;
}

int XorI_reg_RotateRight_not_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_RotateRight_not_reg_2Node::reloc() const {
  return 2;
}

int XorI_reg_LShift_not_regNode::reloc() const {
  return 2;
}

int XorI_reg_LShift_not_reg_1Node::reloc() const {
  return 2;
}

int XorI_reg_LShift_not_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_LShift_not_reg_2Node::reloc() const {
  return 2;
}

int OrI_reg_URShift_not_regNode::reloc() const {
  return 2;
}

int OrI_reg_URShift_not_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_RShift_not_regNode::reloc() const {
  return 2;
}

int OrI_reg_RShift_not_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_RotateRight_not_regNode::reloc() const {
  return 2;
}

int OrI_reg_RotateRight_not_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_LShift_not_regNode::reloc() const {
  return 2;
}

int OrI_reg_LShift_not_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_URShift_regNode::reloc() const {
  return 2;
}

int AndI_reg_URShift_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_RShift_regNode::reloc() const {
  return 2;
}

int AndI_reg_RShift_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_LShift_regNode::reloc() const {
  return 2;
}

int AndI_reg_LShift_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_RotateRight_regNode::reloc() const {
  return 2;
}

int AndI_reg_RotateRight_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_URShift_regNode::reloc() const {
  return 2;
}

int XorI_reg_URShift_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_RShift_regNode::reloc() const {
  return 2;
}

int XorI_reg_RShift_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_LShift_regNode::reloc() const {
  return 2;
}

int XorI_reg_LShift_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_RotateRight_regNode::reloc() const {
  return 2;
}

int XorI_reg_RotateRight_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_URShift_regNode::reloc() const {
  return 2;
}

int OrI_reg_URShift_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_RShift_regNode::reloc() const {
  return 2;
}

int OrI_reg_RShift_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_LShift_regNode::reloc() const {
  return 2;
}

int OrI_reg_LShift_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_RotateRight_regNode::reloc() const {
  return 2;
}

int OrI_reg_RotateRight_reg_0Node::reloc() const {
  return 2;
}

int AddI_reg_URShift_regNode::reloc() const {
  return 2;
}

int AddI_reg_URShift_reg_0Node::reloc() const {
  return 2;
}

int AddI_reg_RShift_regNode::reloc() const {
  return 2;
}

int AddI_reg_RShift_reg_0Node::reloc() const {
  return 2;
}

int AddI_reg_LShift_regNode::reloc() const {
  return 2;
}

int AddI_reg_LShift_reg_0Node::reloc() const {
  return 2;
}

int SubI_reg_URShift_regNode::reloc() const {
  return 2;
}

int SubI_reg_RShift_regNode::reloc() const {
  return 2;
}

int SubI_reg_LShift_regNode::reloc() const {
  return 2;
}

int sbfmwINode::reloc() const {
  return 1;
}

int ubfmwINode::reloc() const {
  return 1;
}

int ubfxwINode::reloc() const {
  return 1;
}

int ubfxIConvI2LNode::reloc() const {
  return 1;
}

int ubfizwINode::reloc() const {
  return 1;
}

int ubfizwIConvI2LNode::reloc() const {
  return 1;
}

int ubfizIConvI2LNode::reloc() const {
  return 1;
}

int extrOrINode::reloc() const {
  return 2;
}

int extrOrI_0Node::reloc() const {
  return 2;
}

int extrAddINode::reloc() const {
  return 2;
}

int extrAddI_0Node::reloc() const {
  return 2;
}

int AddExtINode::reloc() const {
  return 1;
}

int AddExtI_0Node::reloc() const {
  return 1;
}

int SubExtINode::reloc() const {
  return 1;
}

int AddExtI_sxthNode::reloc() const {
  return 2;
}

int AddExtI_sxth_0Node::reloc() const {
  return 2;
}

int AddExtI_sxtbNode::reloc() const {
  return 2;
}

int AddExtI_sxtb_0Node::reloc() const {
  return 2;
}

int AddExtI_uxtbNode::reloc() const {
  return 2;
}

int AddExtI_uxtb_0Node::reloc() const {
  return 2;
}

int AddExtI_uxtb_andNode::reloc() const {
  return 2;
}

int AddExtI_uxtb_and_0Node::reloc() const {
  return 2;
}

int AddExtI_uxth_andNode::reloc() const {
  return 2;
}

int AddExtI_uxth_and_0Node::reloc() const {
  return 2;
}

int SubExtI_uxtb_andNode::reloc() const {
  return 2;
}

int SubExtI_uxth_andNode::reloc() const {
  return 2;
}

int AddExtI_sxtb_shiftNode::reloc() const {
  return 2;
}

int AddExtI_sxtb_shift_0Node::reloc() const {
  return 2;
}

int AddExtI_sxth_shiftNode::reloc() const {
  return 2;
}

int AddExtI_sxth_shift_0Node::reloc() const {
  return 2;
}

int SubExtI_sxtb_shiftNode::reloc() const {
  return 2;
}

int SubExtI_sxth_shiftNode::reloc() const {
  return 2;
}

int AddExtI_shiftNode::reloc() const {
  return 1;
}

int AddExtI_shift_0Node::reloc() const {
  return 1;
}

int SubExtI_shiftNode::reloc() const {
  return 1;
}

int AddExtI_uxtb_and_shiftNode::reloc() const {
  return 2;
}

int AddExtI_uxtb_and_shift_0Node::reloc() const {
  return 2;
}

int AddExtI_uxth_and_shiftNode::reloc() const {
  return 2;
}

int AddExtI_uxth_and_shift_0Node::reloc() const {
  return 2;
}

int SubExtI_uxtb_and_shiftNode::reloc() const {
  return 2;
}

int SubExtI_uxth_and_shiftNode::reloc() const {
  return 2;
}

int mnsubF_reg_regNode::reloc() const {
  return 1;
}

int mnsubD_reg_regNode::reloc() const {
  return 1;
}

int absI_regNode::reloc() const {
  return 1;
}

int andI_reg_regNode::reloc() const {
  return 2;
}

int andI_reg_immNode::reloc() const {
  return 1;
}

int orI_reg_regNode::reloc() const {
  return 2;
}

int orI_reg_immNode::reloc() const {
  return 1;
}

int xorI_reg_regNode::reloc() const {
  return 2;
}

int xorI_reg_immNode::reloc() const {
  return 1;
}

int convI2L_reg_regNode::reloc() const {
  return 1;
}

int convUI2L_reg_regNode::reloc() const {
  return 1;
}

int convI2BNode::reloc() const {
  return 1;
}

int convI2F_reg_regNode::reloc() const {
  return 1;
}

int convI2D_reg_regNode::reloc() const {
  return 1;
}

int overflowAddI_reg_regNode::reloc() const {
  return 2;
}

int overflowAddI_reg_immNode::reloc() const {
  return 1;
}

int overflowSubI_reg_regNode::reloc() const {
  return 2;
}

int overflowSubI_reg_immNode::reloc() const {
  return 1;
}

int overflowNegI_regNode::reloc() const {
  return 1;
}

int overflowMulI_regNode::reloc() const {
  return 2;
}

int overflowMulI_reg_branchNode::reloc() const {
  return 2;
}

int testP_regNode::reloc() const {
  return 1;
}

int compF_reg_zeroNode::reloc() const {
  return 1;
}

int compD_reg_zeroNode::reloc() const {
  return 1;
}

int compF3_reg_immF0Node::reloc() const {
  return 1;
}

int compD3_reg_immD0Node::reloc() const {
  return 1;
}

int cmpLTMask_reg_regNode::reloc() const {
  return 2;
}

int cmpLTMask_reg_zeroNode::reloc() const {
  return 1;
}

int cmpI_imm0_branchNode::reloc() const {
  return 1;
}

int cmpP_imm0_branchNode::reloc() const {
  return 1;
}

int cmpP_narrowOop_imm0_branchNode::reloc() const {
  return 1;
}

int cmpUI_imm0_branchNode::reloc() const {
  return 1;
}

int cmpI_branch_signNode::reloc() const {
  return 1;
}

int cmpI_branch_bitNode::reloc() const {
  return 1;
}

int far_cmpI_branch_signNode::reloc() const {
  return 1;
}

int far_cmpI_branch_bitNode::reloc() const {
  return 1;
}

int cmpI_andNode::reloc() const {
  return 1;
}

int cmpI_and_regNode::reloc() const {
  return 2;
}

int safePointNode::reloc() const {
  return 1;
}

int CallStaticJavaDirectNode::reloc() const {
  return 1;
}

int CallDynamicJavaDirectNode::reloc() const {
  return 1;
}

int CallRuntimeDirectNode::reloc() const {
  return 1;
}

int CallLeafDirectNode::reloc() const {
  return 1;
}

int CallLeafNoFPDirectNode::reloc() const {
  return 1;
}

int CallNativeDirectNode::reloc() const {
  return 1;
}

int TailCalljmpIndNode::reloc() const {
  return 1;
}

int TailjmpIndNode::reloc() const {
  return 1;
}

int RethrowExceptionNode::reloc() const {
  return 1;
}

int RetNode::reloc() const {
  return 1;
}

int partialSubtypeCheckVsZeroNode::reloc() const {
  return 1;
}

int loadV2Node::reloc() const {
  return 1;
}

int loadV4Node::reloc() const {
  return 1;
}

int loadV8Node::reloc() const {
  return 1;
}

int loadV16Node::reloc() const {
  return 1;
}

int storeV2Node::reloc() const {
  return 2;
}

int storeV4Node::reloc() const {
  return 2;
}

int storeV8Node::reloc() const {
  return 2;
}

int storeV16Node::reloc() const {
  return 2;
}

int reduce_add8BNode::reloc() const {
  return 1;
}

int reduce_add16BNode::reloc() const {
  return 1;
}

int reduce_add4SNode::reloc() const {
  return 1;
}

int reduce_add8SNode::reloc() const {
  return 1;
}

int reduce_mul8BNode::reloc() const {
  return 1;
}

int reduce_mul16BNode::reloc() const {
  return 1;
}

int reduce_mul4SNode::reloc() const {
  return 1;
}

int reduce_mul8SNode::reloc() const {
  return 1;
}

int reduce_max8BNode::reloc() const {
  return 1;
}

int reduce_max16BNode::reloc() const {
  return 1;
}

int reduce_max4SNode::reloc() const {
  return 1;
}

int reduce_max8SNode::reloc() const {
  return 1;
}

int reduce_max4INode::reloc() const {
  return 1;
}

int reduce_min8BNode::reloc() const {
  return 1;
}

int reduce_min16BNode::reloc() const {
  return 1;
}

int reduce_min4SNode::reloc() const {
  return 1;
}

int reduce_min8SNode::reloc() const {
  return 1;
}

int reduce_min4INode::reloc() const {
  return 1;
}

int reduce_max2INode::reloc() const {
  return 1;
}

int reduce_min2INode::reloc() const {
  return 1;
}

int reduce_and8BNode::reloc() const {
  return 1;
}

int reduce_orr8BNode::reloc() const {
  return 1;
}

int reduce_eor8BNode::reloc() const {
  return 1;
}

int reduce_and16BNode::reloc() const {
  return 1;
}

int reduce_orr16BNode::reloc() const {
  return 1;
}

int reduce_eor16BNode::reloc() const {
  return 1;
}

int reduce_and4SNode::reloc() const {
  return 1;
}

int reduce_orr4SNode::reloc() const {
  return 1;
}

int reduce_eor4SNode::reloc() const {
  return 1;
}

int reduce_and8SNode::reloc() const {
  return 1;
}

int reduce_orr8SNode::reloc() const {
  return 1;
}

int reduce_eor8SNode::reloc() const {
  return 1;
}

int reduce_and2INode::reloc() const {
  return 1;
}

int reduce_orr2INode::reloc() const {
  return 1;
}

int reduce_eor2INode::reloc() const {
  return 1;
}

int reduce_and4INode::reloc() const {
  return 1;
}

int reduce_orr4INode::reloc() const {
  return 1;
}

int reduce_eor4INode::reloc() const {
  return 1;
}

int insert8BNode::reloc() const {
  return 1;
}

int insert16BNode::reloc() const {
  return 1;
}

int insert4SNode::reloc() const {
  return 1;
}

int insert8SNode::reloc() const {
  return 1;
}

int insert2INode::reloc() const {
  return 1;
}

int insert4INode::reloc() const {
  return 1;
}

int replicate8BNode::reloc() const {
  return 1;
}

int replicate16BNode::reloc() const {
  return 1;
}

int replicate4SNode::reloc() const {
  return 1;
}

int replicate8SNode::reloc() const {
  return 1;
}

int replicate2INode::reloc() const {
  return 1;
}

int replicate4INode::reloc() const {
  return 1;
}

int reduce_add2INode::reloc() const {
  return 1;
}

int reduce_add4INode::reloc() const {
  return 1;
}

int reduce_mul2INode::reloc() const {
  return 1;
}

int reduce_mul4INode::reloc() const {
  return 1;
}

int vshiftcnt8BNode::reloc() const {
  return 1;
}

int vshiftcnt8B_0Node::reloc() const {
  return 1;
}

int vshiftcnt16BNode::reloc() const {
  return 1;
}

int vshiftcnt16B_0Node::reloc() const {
  return 1;
}

int loadVNode::reloc() const {
  return 1;
}

int storeVNode::reloc() const {
  return 2;
}

int reduce_addBNode::reloc() const {
  return 1;
}

int reduce_addSNode::reloc() const {
  return 1;
}

int reduce_addINode::reloc() const {
  return 1;
}

int replicateBNode::reloc() const {
  return 1;
}

int replicateSNode::reloc() const {
  return 1;
}

int replicateINode::reloc() const {
  return 1;
}

int vshiftcntBNode::reloc() const {
  return 1;
}

int vshiftcntB_0Node::reloc() const {
  return 1;
}

int vshiftcntSNode::reloc() const {
  return 1;
}

int vshiftcntS_0Node::reloc() const {
  return 1;
}

int vshiftcntINode::reloc() const {
  return 1;
}

int vshiftcntI_0Node::reloc() const {
  return 1;
}

int vshiftcntLNode::reloc() const {
  return 1;
}

int vshiftcntL_0Node::reloc() const {
  return 1;
}

int zLoadPNode::reloc() const {
  return 1;
}


void loadBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2843 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrsbw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 1);
  
#line 15014 "ad_aarch64.cpp"
  }
}

void loadB2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2851 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrsb, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 1);
  
#line 15031 "ad_aarch64.cpp"
  }
}

void loadUBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2867 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrb, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 1);
  
#line 15048 "ad_aarch64.cpp"
  }
}

void loadUB2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2867 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrb, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 1);
  
#line 15065 "ad_aarch64.cpp"
  }
}

void loadSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2875 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrshw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 2);
  
#line 15082 "ad_aarch64.cpp"
  }
}

void loadS2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2883 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrsh, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 2);
  
#line 15099 "ad_aarch64.cpp"
  }
}

void loadUSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2899 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrh, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 2);
  
#line 15116 "ad_aarch64.cpp"
  }
}

void loadUS2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2899 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrh, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 2);
  
#line 15133 "ad_aarch64.cpp"
  }
}

void loadINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2915 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 15150 "ad_aarch64.cpp"
  }
}

void loadI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2923 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrsw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 15167 "ad_aarch64.cpp"
  }
}

void loadUI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {

#line 2915 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 15185 "ad_aarch64.cpp"
  }
}

void loadLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2931 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 15202 "ad_aarch64.cpp"
  }
}

void loadRangeNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2915 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 15219 "ad_aarch64.cpp"
  }
}

void loadPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2931 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 15236 "ad_aarch64.cpp"
  }
}

void loadNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2915 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 15253 "ad_aarch64.cpp"
  }
}

void loadKlassNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2931 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 15270 "ad_aarch64.cpp"
  }
}

void loadNKlassNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2915 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 15287 "ad_aarch64.cpp"
  }
}

void loadFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2939 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrs, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 15304 "ad_aarch64.cpp"
  }
}

void loadDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2947 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrd, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 15321 "ad_aarch64.cpp"
  }
}

void loadConINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 3388 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    uint32_t con = (uint32_t)opnd_array(1)->constant();
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    if (con == 0) {
      __ movw(dst_reg, zr);
    } else {
      __ movw(dst_reg, con);
    }
  
#line 15343 "ad_aarch64.cpp"
  }
}

void loadConLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 3399 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    uint64_t con = (uint64_t)opnd_array(1)->constantL();
    if (con == 0) {
      __ mov(dst_reg, zr);
    } else {
      __ mov(dst_reg, con);
    }
  
#line 15365 "ad_aarch64.cpp"
  }
}

void loadConPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 3410 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    address con = (address)opnd_array(1)->constant();
    if (con == NULL || con == (address)1) {
      ShouldNotReachHere();
    } else {
      relocInfo::relocType rtype = opnd_array(1)->constant_reloc();
      if (rtype == relocInfo::oop_type) {
        __ movoop(dst_reg, (jobject)con, /*immediate*/true);
      } else if (rtype == relocInfo::metadata_type) {
        __ mov_metadata(dst_reg, (Metadata*)con);
      } else {
        assert(rtype == relocInfo::none, "unexpected reloc type");
        if (con < (address)(uintptr_t)os::vm_page_size()) {
          __ mov(dst_reg, con);
        } else {
          uint64_t offset;
          __ adrp(dst_reg, con, offset);
          __ add(dst_reg, dst_reg, offset);
        }
      }
    }
  
#line 15401 "ad_aarch64.cpp"
  }
}

void loadConP0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 3435 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ mov(dst_reg, zr);
  
#line 15418 "ad_aarch64.cpp"
  }
}

void loadConP1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 3441 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ mov(dst_reg, (uint64_t)1);
  
#line 15435 "ad_aarch64.cpp"
  }
}

void loadByteMapBaseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 3447 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    __ load_byte_map_base(opnd_array(0)->as_Register(ra_,this)/* dst */);
  
#line 15451 "ad_aarch64.cpp"
  }
}

void loadConNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 3452 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    address con = (address)opnd_array(1)->constant();
    if (con == NULL) {
      ShouldNotReachHere();
    } else {
      relocInfo::relocType rtype = opnd_array(1)->constant_reloc();
      assert(rtype == relocInfo::oop_type, "unexpected reloc type");
      __ set_narrow_oop(dst_reg, (jobject)con);
    }
  
#line 15475 "ad_aarch64.cpp"
  }
}

void loadConN0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 3465 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ mov(dst_reg, zr);
  
#line 15492 "ad_aarch64.cpp"
  }
}

void loadConNKlassNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 3471 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    address con = (address)opnd_array(1)->constant();
    if (con == NULL) {
      ShouldNotReachHere();
    } else {
      relocInfo::relocType rtype = opnd_array(1)->constant_reloc();
      assert(rtype == relocInfo::metadata_type, "unexpected reloc type");
      __ set_narrow_klass(dst_reg, (Klass *)con);
    }
  
#line 15516 "ad_aarch64.cpp"
  }
}

void loadConF_packedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7587 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmovs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), (double)opnd_array(1)->constantF());
  
#line 15532 "ad_aarch64.cpp"
  }
}

void loadConFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7605 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ldrs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 15548 "ad_aarch64.cpp"
  }
}

void loadConFNode::eval_constant(Compile* C) {
  {

#line 7606 "src/hotspot/cpu/aarch64/aarch64.ad"
    _constant = C->output()->constant_table().add(this, opnd_array(1));
#line 15557 "ad_aarch64.cpp"
  }
}
void loadConD_packedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7618 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmovd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->constantD());
  
#line 15572 "ad_aarch64.cpp"
  }
}

void loadConDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7635 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ldrd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 15588 "ad_aarch64.cpp"
  }
}

void loadConDNode::eval_constant(Compile* C) {
  {

#line 7636 "src/hotspot/cpu/aarch64/aarch64.ad"
    _constant = C->output()->constant_table().add(this, opnd_array(1));
#line 15597 "ad_aarch64.cpp"
  }
}
void storeimmCM0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 2963 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::strb, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 1);
  
#line 15614 "ad_aarch64.cpp"
  }
}

void storeimmCM0_orderedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3043 "src/hotspot/cpu/aarch64/aarch64.ad"

      C2_MacroAssembler _masm(&cbuf);
      __ membar(Assembler::StoreStore);
      loadStore(_masm, &MacroAssembler::strb, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 1);
  
#line 15633 "ad_aarch64.cpp"
  }
}

void storeBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2955 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::strb, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 1);
  
#line 15651 "ad_aarch64.cpp"
  }
}

void storeimmB0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 2963 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::strb, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 1);
  
#line 15669 "ad_aarch64.cpp"
  }
}

void storeCNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2971 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::strh, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 2);
  
#line 15687 "ad_aarch64.cpp"
  }
}

void storeimmC0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 2979 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::strh, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 2);
  
#line 15705 "ad_aarch64.cpp"
  }
}

void storeINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2987 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::strw, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 15723 "ad_aarch64.cpp"
  }
}

void storeimmI0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 2995 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::strw, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 15741 "ad_aarch64.cpp"
  }
}

void storeLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3003 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    // we sometimes get asked to store the stack pointer into the
    // current thread -- we cannot do that directly on AArch64
    if (src_reg == r31_sp) {
      C2_MacroAssembler _masm(&cbuf);
      assert(as_Register(opnd_array(1)->base(ra_,this,idx1)) == rthread, "unexpected store for sp");
      __ mov(rscratch2, sp);
      src_reg = rscratch2;
    }
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 15767 "ad_aarch64.cpp"
  }
}

void storeimmL0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3019 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::str, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 15785 "ad_aarch64.cpp"
  }
}

void storePNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3003 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    // we sometimes get asked to store the stack pointer into the
    // current thread -- we cannot do that directly on AArch64
    if (src_reg == r31_sp) {
      C2_MacroAssembler _masm(&cbuf);
      assert(as_Register(opnd_array(1)->base(ra_,this,idx1)) == rthread, "unexpected store for sp");
      __ mov(rscratch2, sp);
      src_reg = rscratch2;
    }
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 15811 "ad_aarch64.cpp"
  }
}

void storeimmP0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3019 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::str, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 15829 "ad_aarch64.cpp"
  }
}

void storeNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2987 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::strw, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 15847 "ad_aarch64.cpp"
  }
}

void storeImmN0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 2995 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::strw, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 15865 "ad_aarch64.cpp"
  }
}

void storeFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3027 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::strs, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 15883 "ad_aarch64.cpp"
  }
}

void storeDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3035 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::strd, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 15901 "ad_aarch64.cpp"
  }
}

void storeNKlassNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2987 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::strw, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 15919 "ad_aarch64.cpp"
  }
}

void prefetchallocNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {

#line 3367 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register base = as_Register(opnd_array(1)->base(ra_,this,idx1));
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    if (index == -1) {
      __ prfm(Address(base, disp), PSTL1KEEP);
    } else {
      Register index_reg = as_Register(index);
      if (disp == 0) {
        __ prfm(Address(base, index_reg, Address::lsl(scale)), PSTL1KEEP);
      } else {
        __ lea(rscratch1, Address(base, disp));
	__ prfm(Address(rscratch1, index_reg, Address::lsl(scale)), PSTL1KEEP);
      }
    }
  
#line 15949 "ad_aarch64.cpp"
  }
}

void loadB_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3126 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    MOV_VOLATILE(dst_reg, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarb);
    __ sxtb(dst_reg, dst_reg);
  
#line 15967 "ad_aarch64.cpp"
  }
}

void loadB2L_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3126 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    MOV_VOLATILE(dst_reg, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarb);
    __ sxtb(dst_reg, dst_reg);
  
#line 15985 "ad_aarch64.cpp"
  }
}

void loadUB_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3138 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarb);
  
#line 16001 "ad_aarch64.cpp"
  }
}

void loadUB2L_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3138 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarb);
  
#line 16017 "ad_aarch64.cpp"
  }
}

void loadS_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3143 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    MOV_VOLATILE(dst_reg, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarh);
    __ sxthw(dst_reg, dst_reg);
  
#line 16035 "ad_aarch64.cpp"
  }
}

void loadUS_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3157 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarh);
  
#line 16051 "ad_aarch64.cpp"
  }
}

void loadUS2L_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3162 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarh);
  
#line 16067 "ad_aarch64.cpp"
  }
}

void loadS2L_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3150 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    MOV_VOLATILE(dst_reg, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarh);
    __ sxth(dst_reg, dst_reg);
  
#line 16085 "ad_aarch64.cpp"
  }
}

void loadI_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3172 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarw);
  
#line 16101 "ad_aarch64.cpp"
  }
}

void loadUI2L_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {

#line 3172 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarw);
  
#line 16118 "ad_aarch64.cpp"
  }
}

void loadL_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3177 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldar);
  
#line 16134 "ad_aarch64.cpp"
  }
}

void loadP_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3177 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldar);
  
#line 16150 "ad_aarch64.cpp"
  }
}

void loadN_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3172 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarw);
  
#line 16166 "ad_aarch64.cpp"
  }
}

void loadF_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3182 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(rscratch1, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarw);
    __ fmovs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), rscratch1);
  
#line 16183 "ad_aarch64.cpp"
  }
}

void loadD_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3188 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(rscratch1, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldar);
    __ fmovd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), rscratch1);
  
#line 16200 "ad_aarch64.cpp"
  }
}

void storeB_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3103 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlrb);
  
#line 16217 "ad_aarch64.cpp"
  }
}

void storeC_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3108 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlrh);
  
#line 16234 "ad_aarch64.cpp"
  }
}

void storeI_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3113 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlrw);
  
#line 16251 "ad_aarch64.cpp"
  }
}

void storeL_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3194 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    // we sometimes get asked to store the stack pointer into the
    // current thread -- we cannot do that directly on AArch64
    if (src_reg == r31_sp) {
      C2_MacroAssembler _masm(&cbuf);
      assert(as_Register(opnd_array(1)->base(ra_,this,idx1)) == rthread, "unexpected store for sp");
      __ mov(rscratch2, sp);
      src_reg = rscratch2;
    }
    MOV_VOLATILE(src_reg, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlr);
  
#line 16277 "ad_aarch64.cpp"
  }
}

void storeP_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3194 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    // we sometimes get asked to store the stack pointer into the
    // current thread -- we cannot do that directly on AArch64
    if (src_reg == r31_sp) {
      C2_MacroAssembler _masm(&cbuf);
      assert(as_Register(opnd_array(1)->base(ra_,this,idx1)) == rthread, "unexpected store for sp");
      __ mov(rscratch2, sp);
      src_reg = rscratch2;
    }
    MOV_VOLATILE(src_reg, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlr);
  
#line 16303 "ad_aarch64.cpp"
  }
}

void storeN_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3113 "src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlrw);
  
#line 16320 "ad_aarch64.cpp"
  }
}

void storeF_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3208 "src/hotspot/cpu/aarch64/aarch64.ad"

    {
      C2_MacroAssembler _masm(&cbuf);
      FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
      __ fmovs(rscratch2, src_reg);
    }
    MOV_VOLATILE(rscratch2, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlrw);
  
#line 16342 "ad_aarch64.cpp"
  }
}

void storeD_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3218 "src/hotspot/cpu/aarch64/aarch64.ad"

    {
      C2_MacroAssembler _masm(&cbuf);
      FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
      __ fmovd(rscratch2, src_reg);
    }
    MOV_VOLATILE(rscratch2, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlr);
  
#line 16364 "ad_aarch64.cpp"
  }
}

void cacheWBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8216 "src/hotspot/cpu/aarch64/aarch64.ad"

    assert(opnd_array(1)->index_position() < 0, "should be");
    assert(opnd_array(1)->disp(ra_,this,idx1)== 0, "should be");
    __ cache_wb(Address(as_Register(opnd_array(1)->base(ra_,this,idx1)), 0));
  
#line 16382 "ad_aarch64.cpp"
  }
}

void cacheWBPreSyncNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8231 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cache_wbsync(true);
  
#line 16398 "ad_aarch64.cpp"
  }
}

void cacheWBPostSyncNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8244 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cache_wbsync(false);
  
#line 16414 "ad_aarch64.cpp"
  }
}

void bytes_reverse_intNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8259 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ revw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 16430 "ad_aarch64.cpp"
  }
}

void bytes_reverse_longNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8272 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ rev(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 16446 "ad_aarch64.cpp"
  }
}

void bytes_reverse_unsigned_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8285 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ rev16w(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 16462 "ad_aarch64.cpp"
  }
}

void bytes_reverse_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8299 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ rev16w(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ sbfmw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(0)->reg(ra_,this)/* dst */), 0U, 15U);
  
#line 16479 "ad_aarch64.cpp"
  }
}

void countLeadingZerosINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8315 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ clzw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 16495 "ad_aarch64.cpp"
  }
}

void countLeadingZerosLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8327 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ clz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 16511 "ad_aarch64.cpp"
  }
}

void countTrailingZerosINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8340 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ rbitw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ clzw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 16528 "ad_aarch64.cpp"
  }
}

void countTrailingZerosLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8354 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ rbit(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ clz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 16545 "ad_aarch64.cpp"
  }
}

void popCountINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8376 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ movw(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */); // ensure top 32 bits 0
    __ mov(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T1D, 0, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ cnt(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ addv(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T1D, 0);
  
#line 16566 "ad_aarch64.cpp"
  }
}

void popCountI_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8397 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister tmp_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrs, tmp_reg, opnd_array(1)->opcode(),
              as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
    __ cnt(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ addv(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T1D, 0);
  
#line 16588 "ad_aarch64.cpp"
  }
}

void popCountLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8420 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mov(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T1D, 0, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ cnt(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ addv(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T1D, 0);
  
#line 16608 "ad_aarch64.cpp"
  }
}

void popCountL_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8440 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister tmp_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrd, tmp_reg, opnd_array(1)->opcode(),
              as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
    __ cnt(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ addv(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T1D, 0);
  
#line 16630 "ad_aarch64.cpp"
  }
}

void load_fenceNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8461 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ membar(Assembler::LoadLoad|Assembler::LoadStore);
  
#line 16646 "ad_aarch64.cpp"
  }
}

void unnecessary_membar_acquireNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8474 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_acquire (elided)");
  
#line 16662 "ad_aarch64.cpp"
  }
}

void membar_acquireNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8488 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_acquire");
    __ membar(Assembler::LoadLoad|Assembler::LoadStore);
  
#line 16679 "ad_aarch64.cpp"
  }
}

void membar_acquire_lockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8503 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_acquire_lock (elided)");
  
#line 16695 "ad_aarch64.cpp"
  }
}

void store_fenceNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8516 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ membar(Assembler::LoadStore|Assembler::StoreStore);
  
#line 16711 "ad_aarch64.cpp"
  }
}

void unnecessary_membar_releaseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8529 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_release (elided)");
  
#line 16727 "ad_aarch64.cpp"
  }
}

void membar_releaseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8542 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_release");
    __ membar(Assembler::LoadStore|Assembler::StoreStore);
  
#line 16744 "ad_aarch64.cpp"
  }
}

void membar_storestoreNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8555 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ membar(Assembler::StoreStore);
  
#line 16760 "ad_aarch64.cpp"
  }
}

void membar_release_lockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8567 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_release_lock (elided)");
  
#line 16776 "ad_aarch64.cpp"
  }
}

void unnecessary_membar_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8581 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_volatile (elided)");
  
#line 16792 "ad_aarch64.cpp"
  }
}

void membar_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8595 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_volatile");
    __ membar(Assembler::StoreLoad);
  
#line 16809 "ad_aarch64.cpp"
  }
}

void castX2PNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8612 "src/hotspot/cpu/aarch64/aarch64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */!= opnd_array(1)->reg(ra_,this,idx1)/* src */) {
      __ mov(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    }
  
#line 16827 "ad_aarch64.cpp"
  }
}

void castP2XNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8627 "src/hotspot/cpu/aarch64/aarch64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */!= opnd_array(1)->reg(ra_,this,idx1)/* src */) {
      __ mov(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    }
  
#line 16845 "ad_aarch64.cpp"
  }
}

void convP2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8642 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ movw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 16861 "ad_aarch64.cpp"
  }
}

void convN2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8658 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ movw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 16877 "ad_aarch64.cpp"
  }
}

void encodeHeapOopNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8673 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register s = opnd_array(1)->as_Register(ra_,this,idx1)/* src */;
    Register d = opnd_array(0)->as_Register(ra_,this)/* dst */;
    __ encode_heap_oop(d, s);
  
#line 16895 "ad_aarch64.cpp"
  }
}

void encodeHeapOop_not_nullNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8686 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ encode_heap_oop_not_null(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 16911 "ad_aarch64.cpp"
  }
}

void decodeHeapOopNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8698 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register s = opnd_array(1)->as_Register(ra_,this,idx1)/* src */;
    Register d = opnd_array(0)->as_Register(ra_,this)/* dst */;
    __ decode_heap_oop(d, s);
  
#line 16929 "ad_aarch64.cpp"
  }
}

void decodeHeapOop_not_nullNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8712 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register s = opnd_array(1)->as_Register(ra_,this,idx1)/* src */;
    Register d = opnd_array(0)->as_Register(ra_,this)/* dst */;
    __ decode_heap_oop_not_null(d, s);
  
#line 16947 "ad_aarch64.cpp"
  }
}

void encodeKlass_not_nullNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8730 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ encode_klass_not_null(dst_reg, src_reg);
  
#line 16965 "ad_aarch64.cpp"
  }
}

void decodeKlass_not_nullNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8745 "src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    if (dst_reg != src_reg) {
      __ decode_klass_not_null(dst_reg, src_reg);
    } else {
      __ decode_klass_not_null(dst_reg);
    }
  
#line 16987 "ad_aarch64.cpp"
  }
}

void checkCastPPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint checkCastPPNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castPPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castPPNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castIINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castIINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castLLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castLLNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castFFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castFFNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castDDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castDDNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castVVDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castVVDNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castVVXNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castVVXNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castVVNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castVVNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void loadPLockedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3230 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register base = as_Register(opnd_array(1)->base(ra_,this,idx1));
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    if (index == -1) {
       if (disp != 0) {
        __ lea(rscratch1, Address(base, disp));
        __ ldaxr(dst_reg, rscratch1);
      } else {
        // TODO
        // should we ever get anything other than this case?
        __ ldaxr(dst_reg, base);
      }
    } else {
      Register index_reg = as_Register(index);
      if (disp == 0) {
        __ lea(rscratch1, Address(base, index_reg, Address::lsl(scale)));
        __ ldaxr(dst_reg, rscratch1);
      } else {
        __ lea(rscratch1, Address(base, disp));
        __ lea(rscratch1, Address(rscratch1, index_reg, Address::lsl(scale)));
        __ ldaxr(dst_reg, rscratch1);
      }
    }
  
#line 17144 "ad_aarch64.cpp"
  }
}

void storePConditionalNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// heap_top_ptr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3259 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register src_reg = as_Register(opnd_array(3)->reg(ra_,this,idx3)/* newval */);
    Register base = as_Register(opnd_array(1)->base(ra_,this,idx1));
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    if (index == -1) {
       if (disp != 0) {
        __ lea(rscratch2, Address(base, disp));
        __ stlxr(rscratch1, src_reg, rscratch2);
      } else {
        // TODO
        // should we ever get anything other than this case?
        __ stlxr(rscratch1, src_reg, base);
      }
    } else {
      Register index_reg = as_Register(index);
      if (disp == 0) {
        __ lea(rscratch2, Address(base, index_reg, Address::lsl(scale)));
        __ stlxr(rscratch1, src_reg, rscratch2);
      } else {
        __ lea(rscratch2, Address(base, disp));
        __ lea(rscratch2, Address(rscratch2, index_reg, Address::lsl(scale)));
        __ stlxr(rscratch1, src_reg, rscratch2);
      }
    }
    __ cmpw(rscratch1, zr);
  
#line 17187 "ad_aarch64.cpp"
  }
}

void storeLConditionalNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3326 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 17208 "ad_aarch64.cpp"
  }
}

void storeIConditionalNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3334 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 17229 "ad_aarch64.cpp"
  }
}

void compareAndSwapBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3313 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::byte, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 17250 "ad_aarch64.cpp"
  }
  {

#line 3359 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 17260 "ad_aarch64.cpp"
  }
}

void compareAndSwapSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3305 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::halfword, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 17281 "ad_aarch64.cpp"
  }
  {

#line 3359 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 17291 "ad_aarch64.cpp"
  }
}

void compareAndSwapINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3297 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 17312 "ad_aarch64.cpp"
  }
  {

#line 3359 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 17322 "ad_aarch64.cpp"
  }
}

void compareAndSwapLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3289 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 17343 "ad_aarch64.cpp"
  }
  {

#line 3359 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 17353 "ad_aarch64.cpp"
  }
}

void compareAndSwapPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3289 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 17374 "ad_aarch64.cpp"
  }
  {

#line 3359 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 17384 "ad_aarch64.cpp"
  }
}

void compareAndSwapNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3297 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 17405 "ad_aarch64.cpp"
  }
  {

#line 3359 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 17415 "ad_aarch64.cpp"
  }
}

void compareAndSwapBAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3350 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::byte, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 17436 "ad_aarch64.cpp"
  }
  {

#line 3359 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 17446 "ad_aarch64.cpp"
  }
}

void compareAndSwapSAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3342 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::halfword, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 17467 "ad_aarch64.cpp"
  }
  {

#line 3359 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 17477 "ad_aarch64.cpp"
  }
}

void compareAndSwapIAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3334 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 17498 "ad_aarch64.cpp"
  }
  {

#line 3359 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 17508 "ad_aarch64.cpp"
  }
}

void compareAndSwapLAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3326 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 17529 "ad_aarch64.cpp"
  }
  {

#line 3359 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 17539 "ad_aarch64.cpp"
  }
}

void compareAndSwapPAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3326 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 17560 "ad_aarch64.cpp"
  }
  {

#line 3359 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 17570 "ad_aarch64.cpp"
  }
}

void compareAndSwapNAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3334 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 17591 "ad_aarch64.cpp"
  }
  {

#line 3359 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 17601 "ad_aarch64.cpp"
  }
}

void compareAndExchangeBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9218 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::byte, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
    __ sxtbw(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 17623 "ad_aarch64.cpp"
  }
}

void compareAndExchangeSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9237 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::halfword, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
    __ sxthw(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 17645 "ad_aarch64.cpp"
  }
}

void compareAndExchangeINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9256 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 17666 "ad_aarch64.cpp"
  }
}

void compareAndExchangeLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9274 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 17687 "ad_aarch64.cpp"
  }
}

void compareAndExchangeNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9292 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 17708 "ad_aarch64.cpp"
  }
}

void compareAndExchangePNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9310 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 17729 "ad_aarch64.cpp"
  }
}

void compareAndExchangeBAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9328 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::byte, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
    __ sxtbw(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 17751 "ad_aarch64.cpp"
  }
}

void compareAndExchangeSAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9347 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::halfword, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
    __ sxthw(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 17773 "ad_aarch64.cpp"
  }
}

void compareAndExchangeIAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9366 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 17794 "ad_aarch64.cpp"
  }
}

void compareAndExchangeLAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9384 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 17815 "ad_aarch64.cpp"
  }
}

void compareAndExchangeNAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9402 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 17836 "ad_aarch64.cpp"
  }
}

void compareAndExchangePAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9420 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 17857 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9439 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::byte, /*acquire*/ false, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 17878 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9459 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::halfword, /*acquire*/ false, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 17899 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9479 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ false, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 17920 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9499 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ false, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 17941 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9519 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ false, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 17962 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9539 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ false, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 17983 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapBAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9559 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::byte, /*acquire*/ true, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 18004 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapSAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9579 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::halfword, /*acquire*/ true, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 18025 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapIAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9599 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ true, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 18046 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapLAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9619 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ true, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 18067 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapNAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9639 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ true, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 18088 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapPAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9659 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ true, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 18109 "ad_aarch64.cpp"
  }
}

void get_and_setINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9675 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchgw(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 18126 "ad_aarch64.cpp"
  }
}

void get_and_setLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9685 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchg(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 18143 "ad_aarch64.cpp"
  }
}

void get_and_setNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9695 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchgw(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 18160 "ad_aarch64.cpp"
  }
}

void get_and_setPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9706 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchg(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 18177 "ad_aarch64.cpp"
  }
}

void get_and_setIAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9717 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchgalw(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 18194 "ad_aarch64.cpp"
  }
}

void get_and_setLAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9728 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchgal(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 18211 "ad_aarch64.cpp"
  }
}

void get_and_setNAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9739 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchgalw(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 18228 "ad_aarch64.cpp"
  }
}

void get_and_setPAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9750 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchgal(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 18245 "ad_aarch64.cpp"
  }
}

void get_and_addLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9761 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_add(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 18262 "ad_aarch64.cpp"
  }
}

void get_and_addL_no_resNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9772 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_add(noreg, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 18279 "ad_aarch64.cpp"
  }
}

void get_and_addLiNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9782 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_add(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->constantL(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 18296 "ad_aarch64.cpp"
  }
}

void get_and_addLi_no_resNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9793 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_add(noreg, opnd_array(2)->constantL(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 18313 "ad_aarch64.cpp"
  }
}

void get_and_addINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9803 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addw(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 18330 "ad_aarch64.cpp"
  }
}

void get_and_addI_no_resNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9814 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addw(noreg, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 18347 "ad_aarch64.cpp"
  }
}

void get_and_addIiNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9824 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addw(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->constant(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 18364 "ad_aarch64.cpp"
  }
}

void get_and_addIi_no_resNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9835 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addw(noreg, opnd_array(2)->constant(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 18381 "ad_aarch64.cpp"
  }
}

void get_and_addLAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9846 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addal(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 18398 "ad_aarch64.cpp"
  }
}

void get_and_addL_no_resAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9857 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addal(noreg, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 18415 "ad_aarch64.cpp"
  }
}

void get_and_addLiAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9868 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addal(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->constantL(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 18432 "ad_aarch64.cpp"
  }
}

void get_and_addLi_no_resAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9879 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addal(noreg, opnd_array(2)->constantL(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 18449 "ad_aarch64.cpp"
  }
}

void get_and_addIAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9890 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addalw(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 18466 "ad_aarch64.cpp"
  }
}

void get_and_addI_no_resAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9901 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addalw(noreg, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 18483 "ad_aarch64.cpp"
  }
}

void get_and_addIiAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9912 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addalw(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->constant(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 18500 "ad_aarch64.cpp"
  }
}

void get_and_addIi_no_resAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9923 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addalw(noreg, opnd_array(2)->constant(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 18517 "ad_aarch64.cpp"
  }
}

void cmpL3_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9943 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmp(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::NE);
    __ cnegw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::LT);
  
#line 18536 "ad_aarch64.cpp"
  }
}

void cmpL3_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9963 "src/hotspot/cpu/aarch64/aarch64.ad"

    int32_t con = (int32_t)opnd_array(2)->constantL();
     if (con < 0) {
      __ adds(zr, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, -con);
    } else {
      __ subs(zr, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, con);
    }
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::NE);
    __ cnegw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::LT);
  
#line 18560 "ad_aarch64.cpp"
  }
}

void cmovI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9996 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18582 "ad_aarch64.cpp"
  }
}

void cmovUI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10012 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18604 "ad_aarch64.cpp"
  }
}

void cmovI_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10037 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
             zr,
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18626 "ad_aarch64.cpp"
  }
}

void cmovUI_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10053 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
             zr,
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18648 "ad_aarch64.cpp"
  }
}

void cmovI_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10069 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             zr,
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18670 "ad_aarch64.cpp"
  }
}

void cmovUI_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10085 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             zr,
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18692 "ad_aarch64.cpp"
  }
}

void cmovI_reg_zero_oneNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// one
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10106 "src/hotspot/cpu/aarch64/aarch64.ad"

    // equivalently
    // cset(as_Register($dst$$reg),
    //      negate_condition((Assembler::Condition)$cmp$$cmpcode));
    __ csincw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             zr,
             zr,
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18717 "ad_aarch64.cpp"
  }
}

void cmovUI_reg_zero_oneNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// one
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10125 "src/hotspot/cpu/aarch64/aarch64.ad"

    // equivalently
    // cset(as_Register($dst$$reg),
    //      negate_condition((Assembler::Condition)$cmp$$cmpcode));
    __ csincw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             zr,
             zr,
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18742 "ad_aarch64.cpp"
  }
}

void cmovL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10144 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18764 "ad_aarch64.cpp"
  }
}

void cmovUL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10160 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18786 "ad_aarch64.cpp"
  }
}

void cmovL_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10178 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            zr,
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18808 "ad_aarch64.cpp"
  }
}

void cmovUL_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10194 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            zr,
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18830 "ad_aarch64.cpp"
  }
}

void cmovL_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10210 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
            zr,
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18852 "ad_aarch64.cpp"
  }
}

void cmovUL_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10226 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
            zr,
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18874 "ad_aarch64.cpp"
  }
}

void cmovP_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10242 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18896 "ad_aarch64.cpp"
  }
}

void cmovUP_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10258 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18918 "ad_aarch64.cpp"
  }
}

void cmovP_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10276 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            zr,
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18940 "ad_aarch64.cpp"
  }
}

void cmovUP_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10292 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            zr,
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18962 "ad_aarch64.cpp"
  }
}

void cmovP_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10308 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
            zr,
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 18984 "ad_aarch64.cpp"
  }
}

void cmovUP_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10324 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
            zr,
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 19006 "ad_aarch64.cpp"
  }
}

void cmovN_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10340 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 19028 "ad_aarch64.cpp"
  }
}

void cmovUN_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10356 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 19050 "ad_aarch64.cpp"
  }
}

void cmovN_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10374 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             zr,
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 19072 "ad_aarch64.cpp"
  }
}

void cmovUN_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10390 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             zr,
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 19094 "ad_aarch64.cpp"
  }
}

void cmovN_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10406 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
             zr,
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 19116 "ad_aarch64.cpp"
  }
}

void cmovUN_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10422 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
             zr,
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 19138 "ad_aarch64.cpp"
  }
}

void cmovF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10439 "src/hotspot/cpu/aarch64/aarch64.ad"

    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    __ fcsels(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              cond);
  
#line 19161 "ad_aarch64.cpp"
  }
}

void cmovUF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10457 "src/hotspot/cpu/aarch64/aarch64.ad"

    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    __ fcsels(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              cond);
  
#line 19184 "ad_aarch64.cpp"
  }
}

void cmovD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10475 "src/hotspot/cpu/aarch64/aarch64.ad"

    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    __ fcseld(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              cond);
  
#line 19207 "ad_aarch64.cpp"
  }
}

void cmovUD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10493 "src/hotspot/cpu/aarch64/aarch64.ad"

    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    __ fcseld(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              cond);
  
#line 19230 "ad_aarch64.cpp"
  }
}

void addI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10522 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 19249 "ad_aarch64.cpp"
  }
}

void addI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3486 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    int32_t con = (int32_t)opnd_array(2)->constant();
    // add has primary == 0, subtract has primary == 1
    if ((0x0 /*primary()*/)) { con = -con; }
    if (con < 0) {
      __ subw(dst_reg, src_reg, -con);
    } else {
      __ addw(dst_reg, src_reg, con);
    }
  
#line 19275 "ad_aarch64.cpp"
  }
}

void addI_reg_imm_i2lNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3486 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    int32_t con = (int32_t)opnd_array(2)->constant();
    // add has primary == 0, subtract has primary == 1
    if ((0x0 /*primary()*/)) { con = -con; }
    if (con < 0) {
      __ subw(dst_reg, src_reg, -con);
    } else {
      __ addw(dst_reg, src_reg, con);
    }
  
#line 19301 "ad_aarch64.cpp"
  }
}

void addP_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10566 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 19320 "ad_aarch64.cpp"
  }
}

void addP_reg_reg_extNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10581 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw);
  
#line 19339 "ad_aarch64.cpp"
  }
}

void addP_reg_reg_lslNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// scale
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10596 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lea(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           Address(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                   Address::lsl(opnd_array(3)->constant())));
  
#line 19359 "ad_aarch64.cpp"
  }
}

void addP_reg_reg_ext_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// scale
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10611 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lea(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           Address(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                   Address::sxtw(opnd_array(3)->constant())));
  
#line 19379 "ad_aarch64.cpp"
  }
}

void lshift_extNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// scale
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10626 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ sbfiz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
          as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
          opnd_array(2)->constant()& 63, MIN2(32, (int)((-opnd_array(2)->constant()) & 63)));
  
#line 19398 "ad_aarch64.cpp"
  }
}

void addP_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3500 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    int32_t con = (int32_t)opnd_array(2)->constantL();
    // add has primary == 0, subtract has primary == 1
    if ((0x0 /*primary()*/)) { con = -con; }
    if (con < 0) {
      __ sub(dst_reg, src_reg, -con);
    } else {
      __ add(dst_reg, src_reg, con);
    }
  
#line 19424 "ad_aarch64.cpp"
  }
}

void addL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10660 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 19443 "ad_aarch64.cpp"
  }
}

void addL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3500 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    int32_t con = (int32_t)opnd_array(2)->constantL();
    // add has primary == 0, subtract has primary == 1
    if ((0x0 /*primary()*/)) { con = -con; }
    if (con < 0) {
      __ sub(dst_reg, src_reg, -con);
    } else {
      __ add(dst_reg, src_reg, con);
    }
  
#line 19469 "ad_aarch64.cpp"
  }
}

void subI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10691 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 19488 "ad_aarch64.cpp"
  }
}

void subI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3486 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    int32_t con = (int32_t)opnd_array(2)->constant();
    // add has primary == 0, subtract has primary == 1
    if ((0x1 /*primary()*/)) { con = -con; }
    if (con < 0) {
      __ subw(dst_reg, src_reg, -con);
    } else {
      __ addw(dst_reg, src_reg, con);
    }
  
#line 19514 "ad_aarch64.cpp"
  }
}

void subL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10723 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 19533 "ad_aarch64.cpp"
  }
}

void subL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3500 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    int32_t con = (int32_t)opnd_array(2)->constantL();
    // add has primary == 0, subtract has primary == 1
    if ((0x1 /*primary()*/)) { con = -con; }
    if (con < 0) {
      __ sub(dst_reg, src_reg, -con);
    } else {
      __ add(dst_reg, src_reg, con);
    }
  
#line 19559 "ad_aarch64.cpp"
  }
}

void negI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10755 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ negw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 19577 "ad_aarch64.cpp"
  }
}

void negL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10771 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ neg(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 19595 "ad_aarch64.cpp"
  }
}

void mulINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10787 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mulw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 19614 "ad_aarch64.cpp"
  }
}

void smulINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10802 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smull(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 19633 "ad_aarch64.cpp"
  }
}

void smulI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10802 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smull(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 19652 "ad_aarch64.cpp"
  }
}

void mulLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10819 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mul(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 19671 "ad_aarch64.cpp"
  }
}

void mulHiL_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10835 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smulh(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 19690 "ad_aarch64.cpp"
  }
}

void maddINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10852 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ maddw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 19711 "ad_aarch64.cpp"
  }
}

void maddI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10852 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ maddw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 19732 "ad_aarch64.cpp"
  }
}

void msubINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10868 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ msubw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 19753 "ad_aarch64.cpp"
  }
}

void mnegINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10887 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mnegw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 19773 "ad_aarch64.cpp"
  }
}

void mnegI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10887 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mnegw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 19793 "ad_aarch64.cpp"
  }
}

void mnegI_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10887 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mnegw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 19813 "ad_aarch64.cpp"
  }
}

void mnegI_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10887 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mnegw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 19833 "ad_aarch64.cpp"
  }
}

void maddLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10904 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ madd(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 19854 "ad_aarch64.cpp"
  }
}

void maddL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10904 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ madd(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 19875 "ad_aarch64.cpp"
  }
}

void msubLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10920 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ msub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 19896 "ad_aarch64.cpp"
  }
}

void mnegLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10939 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mneg(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 19916 "ad_aarch64.cpp"
  }
}

void mnegL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10939 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mneg(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 19936 "ad_aarch64.cpp"
  }
}

void mnegL_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10939 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mneg(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 19956 "ad_aarch64.cpp"
  }
}

void mnegL_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10939 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mneg(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 19976 "ad_aarch64.cpp"
  }
}

void smaddLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10956 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smaddl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 19997 "ad_aarch64.cpp"
  }
}

void smaddL_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10956 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smaddl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 20018 "ad_aarch64.cpp"
  }
}

void smaddL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10956 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smaddl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 20039 "ad_aarch64.cpp"
  }
}

void smaddL_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10956 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smaddl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 20060 "ad_aarch64.cpp"
  }
}

void smsubLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10972 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smsubl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 20081 "ad_aarch64.cpp"
  }
}

void smsubL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10972 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smsubl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 20102 "ad_aarch64.cpp"
  }
}

void smnegLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10989 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smnegl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 20122 "ad_aarch64.cpp"
  }
}

void smnegL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10989 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smnegl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 20142 "ad_aarch64.cpp"
  }
}

void smnegL_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10989 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smnegl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 20162 "ad_aarch64.cpp"
  }
}

void smnegL_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10989 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smnegl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 20182 "ad_aarch64.cpp"
  }
}

void muladdS2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11007 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mulw(rscratch1, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ maddw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src3 */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src4 */), rscratch1); 
#line 20201 "ad_aarch64.cpp"
  }
}

void divINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3514 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
   Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
   Register src1_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
   Register src2_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    __ corrected_idivl(dst_reg, src1_reg, src2_reg, false, rscratch1);
  
#line 20221 "ad_aarch64.cpp"
  }
}

void divLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3522 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
   Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
   Register src1_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
   Register src2_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    __ corrected_idivq(dst_reg, src1_reg, src2_reg, false, rscratch1);
  
#line 20241 "ad_aarch64.cpp"
  }
}

void modINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3530 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
   Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
   Register src1_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
   Register src2_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    __ corrected_idivl(dst_reg, src1_reg, src2_reg, true, rscratch1);
  
#line 20261 "ad_aarch64.cpp"
  }
}

void modLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3538 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
   Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
   Register src1_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
   Register src2_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    __ corrected_idivq(dst_reg, src1_reg, src2_reg, true, rscratch1);
  
#line 20281 "ad_aarch64.cpp"
  }
}

void lShiftI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11073 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lslvw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 20300 "ad_aarch64.cpp"
  }
}

void lShiftI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11089 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lslw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            opnd_array(2)->constant()& 0x1f);
  
#line 20319 "ad_aarch64.cpp"
  }
}

void urShiftI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11105 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lsrvw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 20338 "ad_aarch64.cpp"
  }
}

void urShiftI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11121 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lsrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            opnd_array(2)->constant()& 0x1f);
  
#line 20357 "ad_aarch64.cpp"
  }
}

void rShiftI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11137 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ asrvw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 20376 "ad_aarch64.cpp"
  }
}

void rShiftI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11153 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ asrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            opnd_array(2)->constant()& 0x1f);
  
#line 20395 "ad_aarch64.cpp"
  }
}

void lShiftL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11174 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lslv(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 20414 "ad_aarch64.cpp"
  }
}

void lShiftL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11190 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lsl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            opnd_array(2)->constant()& 0x3f);
  
#line 20433 "ad_aarch64.cpp"
  }
}

void urShiftL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11206 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lsrv(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 20452 "ad_aarch64.cpp"
  }
}

void urShiftL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11222 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lsr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           opnd_array(2)->constant()& 0x3f);
  
#line 20471 "ad_aarch64.cpp"
  }
}

void urShiftP_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11238 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ lsr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           opnd_array(2)->constant()& 0x3f);
  
#line 20490 "ad_aarch64.cpp"
  }
}

void rShiftL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11254 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ asrv(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 20509 "ad_aarch64.cpp"
  }
}

void rShiftL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11270 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ asr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           opnd_array(2)->constant()& 0x3f);
  
#line 20528 "ad_aarch64.cpp"
  }
}

void regL_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11292 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              zr,
              Assembler::LSL, 0);
  
#line 20548 "ad_aarch64.cpp"
  }
}

void regI_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11311 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              zr,
              Assembler::LSL, 0);
  
#line 20568 "ad_aarch64.cpp"
  }
}

void AndI_reg_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11329 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL, 0);
  
#line 20589 "ad_aarch64.cpp"
  }
}

void AndI_reg_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11329 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL, 0);
  
#line 20610 "ad_aarch64.cpp"
  }
}

void AndL_reg_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11347 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL, 0);
  
#line 20631 "ad_aarch64.cpp"
  }
}

void AndL_reg_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11347 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL, 0);
  
#line 20652 "ad_aarch64.cpp"
  }
}

void OrI_reg_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11365 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL, 0);
  
#line 20673 "ad_aarch64.cpp"
  }
}

void OrI_reg_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11365 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL, 0);
  
#line 20694 "ad_aarch64.cpp"
  }
}

void OrL_reg_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11383 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL, 0);
  
#line 20715 "ad_aarch64.cpp"
  }
}

void OrL_reg_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11383 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL, 0);
  
#line 20736 "ad_aarch64.cpp"
  }
}

void XorI_reg_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11401 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL, 0);
  
#line 20757 "ad_aarch64.cpp"
  }
}

void XorI_reg_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11401 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL, 0);
  
#line 20778 "ad_aarch64.cpp"
  }
}

void XorL_reg_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11419 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL, 0);
  
#line 20799 "ad_aarch64.cpp"
  }
}

void XorL_reg_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11419 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL, 0);
  
#line 20820 "ad_aarch64.cpp"
  }
}

void AndI_reg_URShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11439 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 20843 "ad_aarch64.cpp"
  }
}

void AndI_reg_URShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11439 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 20866 "ad_aarch64.cpp"
  }
}

void AndL_reg_URShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11460 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 20889 "ad_aarch64.cpp"
  }
}

void AndL_reg_URShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11460 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 20912 "ad_aarch64.cpp"
  }
}

void AndI_reg_RShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11481 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 20935 "ad_aarch64.cpp"
  }
}

void AndI_reg_RShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11481 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 20958 "ad_aarch64.cpp"
  }
}

void AndL_reg_RShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11502 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 20981 "ad_aarch64.cpp"
  }
}

void AndL_reg_RShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11502 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 21004 "ad_aarch64.cpp"
  }
}

void AndI_reg_RotateRight_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11523 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x1f);
  
#line 21027 "ad_aarch64.cpp"
  }
}

void AndI_reg_RotateRight_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11523 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x1f);
  
#line 21050 "ad_aarch64.cpp"
  }
}

void AndL_reg_RotateRight_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11544 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x3f);
  
#line 21073 "ad_aarch64.cpp"
  }
}

void AndL_reg_RotateRight_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11544 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x3f);
  
#line 21096 "ad_aarch64.cpp"
  }
}

void AndI_reg_LShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11565 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 21119 "ad_aarch64.cpp"
  }
}

void AndI_reg_LShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11565 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 21142 "ad_aarch64.cpp"
  }
}

void AndL_reg_LShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11586 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 21165 "ad_aarch64.cpp"
  }
}

void AndL_reg_LShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11586 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 21188 "ad_aarch64.cpp"
  }
}

void XorI_reg_URShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11607 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 21211 "ad_aarch64.cpp"
  }
}

void XorI_reg_URShift_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11607 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 21234 "ad_aarch64.cpp"
  }
}

void XorI_reg_URShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11607 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::LSR,
              opnd_array(4)->constant()& 0x1f);
  
#line 21257 "ad_aarch64.cpp"
  }
}

void XorI_reg_URShift_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11607 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 21280 "ad_aarch64.cpp"
  }
}

void XorL_reg_URShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11628 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 21303 "ad_aarch64.cpp"
  }
}

void XorL_reg_URShift_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11628 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 21326 "ad_aarch64.cpp"
  }
}

void XorL_reg_URShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11628 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::LSR,
              opnd_array(4)->constant()& 0x3f);
  
#line 21349 "ad_aarch64.cpp"
  }
}

void XorL_reg_URShift_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11628 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 21372 "ad_aarch64.cpp"
  }
}

void XorI_reg_RShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11649 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 21395 "ad_aarch64.cpp"
  }
}

void XorI_reg_RShift_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11649 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 21418 "ad_aarch64.cpp"
  }
}

void XorI_reg_RShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11649 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::ASR,
              opnd_array(4)->constant()& 0x1f);
  
#line 21441 "ad_aarch64.cpp"
  }
}

void XorI_reg_RShift_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11649 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 21464 "ad_aarch64.cpp"
  }
}

void XorL_reg_RShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11670 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 21487 "ad_aarch64.cpp"
  }
}

void XorL_reg_RShift_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11670 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 21510 "ad_aarch64.cpp"
  }
}

void XorL_reg_RShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11670 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::ASR,
              opnd_array(4)->constant()& 0x3f);
  
#line 21533 "ad_aarch64.cpp"
  }
}

void XorL_reg_RShift_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11670 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 21556 "ad_aarch64.cpp"
  }
}

void XorI_reg_RotateRight_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11691 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x1f);
  
#line 21579 "ad_aarch64.cpp"
  }
}

void XorI_reg_RotateRight_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11691 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x1f);
  
#line 21602 "ad_aarch64.cpp"
  }
}

void XorI_reg_RotateRight_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11691 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::ROR,
              opnd_array(4)->constant()& 0x1f);
  
#line 21625 "ad_aarch64.cpp"
  }
}

void XorI_reg_RotateRight_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11691 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x1f);
  
#line 21648 "ad_aarch64.cpp"
  }
}

void XorL_reg_RotateRight_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11712 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x3f);
  
#line 21671 "ad_aarch64.cpp"
  }
}

void XorL_reg_RotateRight_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11712 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x3f);
  
#line 21694 "ad_aarch64.cpp"
  }
}

void XorL_reg_RotateRight_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11712 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::ROR,
              opnd_array(4)->constant()& 0x3f);
  
#line 21717 "ad_aarch64.cpp"
  }
}

void XorL_reg_RotateRight_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11712 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x3f);
  
#line 21740 "ad_aarch64.cpp"
  }
}

void XorI_reg_LShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11733 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 21763 "ad_aarch64.cpp"
  }
}

void XorI_reg_LShift_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11733 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 21786 "ad_aarch64.cpp"
  }
}

void XorI_reg_LShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11733 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::LSL,
              opnd_array(4)->constant()& 0x1f);
  
#line 21809 "ad_aarch64.cpp"
  }
}

void XorI_reg_LShift_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11733 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 21832 "ad_aarch64.cpp"
  }
}

void XorL_reg_LShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11754 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 21855 "ad_aarch64.cpp"
  }
}

void XorL_reg_LShift_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11754 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 21878 "ad_aarch64.cpp"
  }
}

void XorL_reg_LShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11754 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::LSL,
              opnd_array(4)->constant()& 0x3f);
  
#line 21901 "ad_aarch64.cpp"
  }
}

void XorL_reg_LShift_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11754 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 21924 "ad_aarch64.cpp"
  }
}

void OrI_reg_URShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11775 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 21947 "ad_aarch64.cpp"
  }
}

void OrI_reg_URShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11775 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 21970 "ad_aarch64.cpp"
  }
}

void OrL_reg_URShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11796 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 21993 "ad_aarch64.cpp"
  }
}

void OrL_reg_URShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11796 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 22016 "ad_aarch64.cpp"
  }
}

void OrI_reg_RShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11817 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 22039 "ad_aarch64.cpp"
  }
}

void OrI_reg_RShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11817 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 22062 "ad_aarch64.cpp"
  }
}

void OrL_reg_RShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11838 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 22085 "ad_aarch64.cpp"
  }
}

void OrL_reg_RShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11838 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 22108 "ad_aarch64.cpp"
  }
}

void OrI_reg_RotateRight_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11859 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x1f);
  
#line 22131 "ad_aarch64.cpp"
  }
}

void OrI_reg_RotateRight_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11859 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x1f);
  
#line 22154 "ad_aarch64.cpp"
  }
}

void OrL_reg_RotateRight_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11880 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x3f);
  
#line 22177 "ad_aarch64.cpp"
  }
}

void OrL_reg_RotateRight_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11880 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x3f);
  
#line 22200 "ad_aarch64.cpp"
  }
}

void OrI_reg_LShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11901 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 22223 "ad_aarch64.cpp"
  }
}

void OrI_reg_LShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11901 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 22246 "ad_aarch64.cpp"
  }
}

void OrL_reg_LShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11922 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 22269 "ad_aarch64.cpp"
  }
}

void OrL_reg_LShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11922 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 22292 "ad_aarch64.cpp"
  }
}

void AndI_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11943 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 22314 "ad_aarch64.cpp"
  }
}

void AndI_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11943 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 22336 "ad_aarch64.cpp"
  }
}

void AndL_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11964 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 22358 "ad_aarch64.cpp"
  }
}

void AndL_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11964 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 22380 "ad_aarch64.cpp"
  }
}

void AndI_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11985 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 22402 "ad_aarch64.cpp"
  }
}

void AndI_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11985 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 22424 "ad_aarch64.cpp"
  }
}

void AndL_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12006 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 22446 "ad_aarch64.cpp"
  }
}

void AndL_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12006 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 22468 "ad_aarch64.cpp"
  }
}

void AndI_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12027 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 22490 "ad_aarch64.cpp"
  }
}

void AndI_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12027 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 22512 "ad_aarch64.cpp"
  }
}

void AndL_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12048 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 22534 "ad_aarch64.cpp"
  }
}

void AndL_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12048 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 22556 "ad_aarch64.cpp"
  }
}

void AndI_reg_RotateRight_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12069 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x1f);
  
#line 22578 "ad_aarch64.cpp"
  }
}

void AndI_reg_RotateRight_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12069 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x1f);
  
#line 22600 "ad_aarch64.cpp"
  }
}

void AndL_reg_RotateRight_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12090 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x3f);
  
#line 22622 "ad_aarch64.cpp"
  }
}

void AndL_reg_RotateRight_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12090 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x3f);
  
#line 22644 "ad_aarch64.cpp"
  }
}

void XorI_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12111 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 22666 "ad_aarch64.cpp"
  }
}

void XorI_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12111 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 22688 "ad_aarch64.cpp"
  }
}

void XorL_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12132 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 22710 "ad_aarch64.cpp"
  }
}

void XorL_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12132 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 22732 "ad_aarch64.cpp"
  }
}

void XorI_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12153 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 22754 "ad_aarch64.cpp"
  }
}

void XorI_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12153 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 22776 "ad_aarch64.cpp"
  }
}

void XorL_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12174 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 22798 "ad_aarch64.cpp"
  }
}

void XorL_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12174 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 22820 "ad_aarch64.cpp"
  }
}

void XorI_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12195 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 22842 "ad_aarch64.cpp"
  }
}

void XorI_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12195 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 22864 "ad_aarch64.cpp"
  }
}

void XorL_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12216 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 22886 "ad_aarch64.cpp"
  }
}

void XorL_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12216 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 22908 "ad_aarch64.cpp"
  }
}

void XorI_reg_RotateRight_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12237 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x1f);
  
#line 22930 "ad_aarch64.cpp"
  }
}

void XorI_reg_RotateRight_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12237 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x1f);
  
#line 22952 "ad_aarch64.cpp"
  }
}

void XorL_reg_RotateRight_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12258 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x3f);
  
#line 22974 "ad_aarch64.cpp"
  }
}

void XorL_reg_RotateRight_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12258 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x3f);
  
#line 22996 "ad_aarch64.cpp"
  }
}

void OrI_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12279 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 23018 "ad_aarch64.cpp"
  }
}

void OrI_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12279 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 23040 "ad_aarch64.cpp"
  }
}

void OrL_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12300 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 23062 "ad_aarch64.cpp"
  }
}

void OrL_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12300 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 23084 "ad_aarch64.cpp"
  }
}

void OrI_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12321 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 23106 "ad_aarch64.cpp"
  }
}

void OrI_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12321 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 23128 "ad_aarch64.cpp"
  }
}

void OrL_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12342 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 23150 "ad_aarch64.cpp"
  }
}

void OrL_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12342 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 23172 "ad_aarch64.cpp"
  }
}

void OrI_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12363 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 23194 "ad_aarch64.cpp"
  }
}

void OrI_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12363 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 23216 "ad_aarch64.cpp"
  }
}

void OrL_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12384 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 23238 "ad_aarch64.cpp"
  }
}

void OrL_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12384 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 23260 "ad_aarch64.cpp"
  }
}

void OrI_reg_RotateRight_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12405 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x1f);
  
#line 23282 "ad_aarch64.cpp"
  }
}

void OrI_reg_RotateRight_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12405 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x1f);
  
#line 23304 "ad_aarch64.cpp"
  }
}

void OrL_reg_RotateRight_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12426 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x3f);
  
#line 23326 "ad_aarch64.cpp"
  }
}

void OrL_reg_RotateRight_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12426 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x3f);
  
#line 23348 "ad_aarch64.cpp"
  }
}

void AddI_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12447 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 23370 "ad_aarch64.cpp"
  }
}

void AddI_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12447 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 23392 "ad_aarch64.cpp"
  }
}

void AddL_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12468 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 23414 "ad_aarch64.cpp"
  }
}

void AddL_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12468 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 23436 "ad_aarch64.cpp"
  }
}

void AddI_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12489 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 23458 "ad_aarch64.cpp"
  }
}

void AddI_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12489 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 23480 "ad_aarch64.cpp"
  }
}

void AddL_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12510 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 23502 "ad_aarch64.cpp"
  }
}

void AddL_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12510 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 23524 "ad_aarch64.cpp"
  }
}

void AddI_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12531 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 23546 "ad_aarch64.cpp"
  }
}

void AddI_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12531 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 23568 "ad_aarch64.cpp"
  }
}

void AddL_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12552 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 23590 "ad_aarch64.cpp"
  }
}

void AddL_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12552 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 23612 "ad_aarch64.cpp"
  }
}

void SubI_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12573 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 23634 "ad_aarch64.cpp"
  }
}

void SubL_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12594 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 23656 "ad_aarch64.cpp"
  }
}

void SubI_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12615 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 23678 "ad_aarch64.cpp"
  }
}

void SubL_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12636 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 23700 "ad_aarch64.cpp"
  }
}

void SubI_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12657 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 23722 "ad_aarch64.cpp"
  }
}

void SubL_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12678 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 23744 "ad_aarch64.cpp"
  }
}

void sbfmLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift_count
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift_count
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12699 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(2)->constant()& 63;
    int rshift = opnd_array(3)->constant()& 63;
    int s = 63 - lshift;
    int r = (rshift - lshift) & 63;
    __ sbfm(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            r, s);
  
#line 23768 "ad_aarch64.cpp"
  }
}

void sbfmwINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift_count
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift_count
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12722 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(2)->constant()& 31;
    int rshift = opnd_array(3)->constant()& 31;
    int s = 31 - lshift;
    int r = (rshift - lshift) & 31;
    __ sbfmw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            r, s);
  
#line 23792 "ad_aarch64.cpp"
  }
}

void ubfmLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift_count
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift_count
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12745 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(2)->constant()& 63;
    int rshift = opnd_array(3)->constant()& 63;
    int s = 63 - lshift;
    int r = (rshift - lshift) & 63;
    __ ubfm(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            r, s);
  
#line 23816 "ad_aarch64.cpp"
  }
}

void ubfmwINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift_count
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift_count
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12768 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(2)->constant()& 31;
    int rshift = opnd_array(3)->constant()& 31;
    int s = 31 - lshift;
    int r = (rshift - lshift) & 31;
    __ ubfmw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            r, s);
  
#line 23840 "ad_aarch64.cpp"
  }
}

void ubfxwINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12793 "src/hotspot/cpu/aarch64/aarch64.ad"

    int rshift = opnd_array(2)->constant()& 31;
    intptr_t mask = opnd_array(3)->constant();
    int width = exact_log2(mask+1);
    __ ubfxw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), rshift, width);
  
#line 23862 "ad_aarch64.cpp"
  }
}

void ubfxLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12813 "src/hotspot/cpu/aarch64/aarch64.ad"

    int rshift = opnd_array(2)->constant()& 63;
    intptr_t mask = opnd_array(3)->constantL();
    int width = exact_log2_long(mask+1);
    __ ubfx(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), rshift, width);
  
#line 23884 "ad_aarch64.cpp"
  }
}

void ubfxIConvI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12837 "src/hotspot/cpu/aarch64/aarch64.ad"

    int rshift = opnd_array(2)->constant()& 31;
    intptr_t mask = opnd_array(3)->constant();
    int width = exact_log2(mask+1);
    __ ubfx(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), rshift, width);
  
#line 23906 "ad_aarch64.cpp"
  }
}

void ubfizwINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12860 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(3)->constant()& 31;
    intptr_t mask = opnd_array(2)->constant();
    int width = exact_log2(mask+1);
    __ ubfizw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
          as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), lshift, width);
  
#line 23928 "ad_aarch64.cpp"
  }
}

void ubfizLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12882 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(3)->constant()& 63;
    intptr_t mask = opnd_array(2)->constantL();
    int width = exact_log2_long(mask+1);
    __ ubfiz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
          as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), lshift, width);
  
#line 23950 "ad_aarch64.cpp"
  }
}

void ubfizwIConvI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12904 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(3)->constant()& 31;
    intptr_t mask = opnd_array(2)->constant();
    int width = exact_log2(mask+1);
    __ ubfizw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
          as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), lshift, width);
  
#line 23972 "ad_aarch64.cpp"
  }
}

void ubfizLConvL2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12926 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(3)->constant()& 63;
    intptr_t mask = opnd_array(2)->constantL();
    int width = exact_log2_long(mask+1);
    __ ubfiz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
          as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), lshift, width);
  
#line 23994 "ad_aarch64.cpp"
  }
}

void ubfizIConvI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12948 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(3)->constant()& 63;
    intptr_t mask = opnd_array(2)->constant();
    int width = exact_log2(mask+1);
    __ ubfiz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), lshift, width);
  
#line 24016 "ad_aarch64.cpp"
  }
}

void ubfizLConvL2IxNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12969 "src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(3)->constant()& 31;
    intptr_t mask = opnd_array(2)->constantL();
    int width = exact_log2(mask+1);
    __ ubfiz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), lshift, width);
  
#line 24038 "ad_aarch64.cpp"
  }
}

void ubfizIConvI2LAndINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// msk
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12988 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ubfiz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), 0, exact_log2(opnd_array(2)->constant()+ 1));
  
#line 24055 "ad_aarch64.cpp"
  }
}

void extrOrLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13006 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ extr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
            opnd_array(4)->constant()& 63);
  
#line 24075 "ad_aarch64.cpp"
  }
}

void extrOrL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13006 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ extr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
            opnd_array(2)->constant()& 63);
  
#line 24095 "ad_aarch64.cpp"
  }
}

void extrOrINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13024 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ extrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
            opnd_array(4)->constant()& 31);
  
#line 24115 "ad_aarch64.cpp"
  }
}

void extrOrI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13024 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ extrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
            opnd_array(2)->constant()& 31);
  
#line 24135 "ad_aarch64.cpp"
  }
}

void extrAddLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13042 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ extr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
            opnd_array(4)->constant()& 63);
  
#line 24155 "ad_aarch64.cpp"
  }
}

void extrAddL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13042 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ extr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
            opnd_array(2)->constant()& 63);
  
#line 24175 "ad_aarch64.cpp"
  }
}

void extrAddINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13060 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ extrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
            opnd_array(4)->constant()& 31);
  
#line 24195 "ad_aarch64.cpp"
  }
}

void extrAddI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13060 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ extrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
            opnd_array(2)->constant()& 31);
  
#line 24215 "ad_aarch64.cpp"
  }
}

void rorI_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13077 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ extrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
               opnd_array(2)->constant()& 0x1f);
  
#line 24233 "ad_aarch64.cpp"
  }
}

void rorL_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13093 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ extr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
               opnd_array(2)->constant()& 0x3f);
  
#line 24251 "ad_aarch64.cpp"
  }
}

void rorI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13109 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ rorvw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 24268 "ad_aarch64.cpp"
  }
}

void rorL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13124 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ rorv(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 24285 "ad_aarch64.cpp"
  }
}

void rolI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13139 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(rscratch1, zr, as_Register(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
     __ rorvw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), rscratch1);
  
#line 24303 "ad_aarch64.cpp"
  }
}

void rolL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13155 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(rscratch1, zr, as_Register(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
     __ rorv(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), rscratch1);
  
#line 24321 "ad_aarch64.cpp"
  }
}

void AddExtINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13173 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw);
   
#line 24339 "ad_aarch64.cpp"
  }
}

void AddExtI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13173 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtw);
   
#line 24357 "ad_aarch64.cpp"
  }
}

void SubExtINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13188 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw);
   
#line 24375 "ad_aarch64.cpp"
  }
}

void AddExtI_sxthNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13203 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxth);
   
#line 24395 "ad_aarch64.cpp"
  }
}

void AddExtI_sxth_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13203 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxth);
   
#line 24415 "ad_aarch64.cpp"
  }
}

void AddExtI_sxtbNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13218 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtb);
   
#line 24435 "ad_aarch64.cpp"
  }
}

void AddExtI_sxtb_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13218 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtb);
   
#line 24455 "ad_aarch64.cpp"
  }
}

void AddExtI_uxtbNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13233 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb);
   
#line 24475 "ad_aarch64.cpp"
  }
}

void AddExtI_uxtb_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13233 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtb);
   
#line 24495 "ad_aarch64.cpp"
  }
}

void AddExtL_sxthNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13248 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxth);
   
#line 24515 "ad_aarch64.cpp"
  }
}

void AddExtL_sxth_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13248 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxth);
   
#line 24535 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtwNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13263 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw);
   
#line 24555 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtw_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13263 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtw);
   
#line 24575 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtbNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13278 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtb);
   
#line 24595 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtb_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13278 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtb);
   
#line 24615 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtbNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13293 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb);
   
#line 24635 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtb_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13293 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtb);
   
#line 24655 "ad_aarch64.cpp"
  }
}

void AddExtI_uxtb_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13308 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb);
   
#line 24674 "ad_aarch64.cpp"
  }
}

void AddExtI_uxtb_and_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13308 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtb);
   
#line 24693 "ad_aarch64.cpp"
  }
}

void AddExtI_uxth_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13323 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth);
   
#line 24712 "ad_aarch64.cpp"
  }
}

void AddExtI_uxth_and_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13323 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxth);
   
#line 24731 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtb_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13338 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb);
   
#line 24750 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtb_and_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13338 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtb);
   
#line 24769 "ad_aarch64.cpp"
  }
}

void AddExtL_uxth_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13353 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth);
   
#line 24788 "ad_aarch64.cpp"
  }
}

void AddExtL_uxth_and_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13353 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxth);
   
#line 24807 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtw_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13368 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtw);
   
#line 24826 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtw_and_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13368 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtw);
   
#line 24845 "ad_aarch64.cpp"
  }
}

void SubExtI_uxtb_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13383 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb);
   
#line 24864 "ad_aarch64.cpp"
  }
}

void SubExtI_uxth_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13398 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth);
   
#line 24883 "ad_aarch64.cpp"
  }
}

void SubExtL_uxtb_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13413 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb);
   
#line 24902 "ad_aarch64.cpp"
  }
}

void SubExtL_uxth_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13428 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth);
   
#line 24921 "ad_aarch64.cpp"
  }
}

void SubExtL_uxtw_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13443 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtw);
   
#line 24940 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtb_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13459 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtb, (opnd_array(5)->constant()));
   
#line 24961 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtb_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13459 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(5)->reg(ra_,this,idx5)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtb, (opnd_array(4)->constant()));
   
#line 24982 "ad_aarch64.cpp"
  }
}

void AddExtL_sxth_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13474 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxth, (opnd_array(5)->constant()));
   
#line 25003 "ad_aarch64.cpp"
  }
}

void AddExtL_sxth_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13474 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(5)->reg(ra_,this,idx5)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxth, (opnd_array(4)->constant()));
   
#line 25024 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtw_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13489 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw, (opnd_array(5)->constant()));
   
#line 25045 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtw_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13489 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(5)->reg(ra_,this,idx5)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtw, (opnd_array(4)->constant()));
   
#line 25066 "ad_aarch64.cpp"
  }
}

void SubExtL_sxtb_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13504 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtb, (opnd_array(5)->constant()));
   
#line 25087 "ad_aarch64.cpp"
  }
}

void SubExtL_sxth_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13519 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxth, (opnd_array(5)->constant()));
   
#line 25108 "ad_aarch64.cpp"
  }
}

void SubExtL_sxtw_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13534 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw, (opnd_array(5)->constant()));
   
#line 25129 "ad_aarch64.cpp"
  }
}

void AddExtI_sxtb_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13549 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtb, (opnd_array(5)->constant()));
   
#line 25150 "ad_aarch64.cpp"
  }
}

void AddExtI_sxtb_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13549 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(5)->reg(ra_,this,idx5)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtb, (opnd_array(4)->constant()));
   
#line 25171 "ad_aarch64.cpp"
  }
}

void AddExtI_sxth_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13564 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxth, (opnd_array(5)->constant()));
   
#line 25192 "ad_aarch64.cpp"
  }
}

void AddExtI_sxth_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13564 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(5)->reg(ra_,this,idx5)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxth, (opnd_array(4)->constant()));
   
#line 25213 "ad_aarch64.cpp"
  }
}

void SubExtI_sxtb_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13579 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtb, (opnd_array(5)->constant()));
   
#line 25234 "ad_aarch64.cpp"
  }
}

void SubExtI_sxth_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13594 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxth, (opnd_array(5)->constant()));
   
#line 25255 "ad_aarch64.cpp"
  }
}

void AddExtI_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13609 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw, (opnd_array(3)->constant()));
   
#line 25274 "ad_aarch64.cpp"
  }
}

void AddExtI_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13609 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtw, (opnd_array(2)->constant()));
   
#line 25293 "ad_aarch64.cpp"
  }
}

void SubExtI_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13624 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw, (opnd_array(3)->constant()));
   
#line 25312 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtb_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13639 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb, (opnd_array(4)->constant()));
   
#line 25332 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtb_and_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13639 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtb, (opnd_array(3)->constant()));
   
#line 25352 "ad_aarch64.cpp"
  }
}

void AddExtL_uxth_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13654 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth, (opnd_array(4)->constant()));
   
#line 25372 "ad_aarch64.cpp"
  }
}

void AddExtL_uxth_and_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13654 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxth, (opnd_array(3)->constant()));
   
#line 25392 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtw_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13669 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtw, (opnd_array(4)->constant()));
   
#line 25412 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtw_and_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13669 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtw, (opnd_array(3)->constant()));
   
#line 25432 "ad_aarch64.cpp"
  }
}

void SubExtL_uxtb_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13684 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb, (opnd_array(4)->constant()));
   
#line 25452 "ad_aarch64.cpp"
  }
}

void SubExtL_uxth_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13699 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth, (opnd_array(4)->constant()));
   
#line 25472 "ad_aarch64.cpp"
  }
}

void SubExtL_uxtw_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13714 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtw, (opnd_array(4)->constant()));
   
#line 25492 "ad_aarch64.cpp"
  }
}

void AddExtI_uxtb_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13729 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb, (opnd_array(4)->constant()));
   
#line 25512 "ad_aarch64.cpp"
  }
}

void AddExtI_uxtb_and_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13729 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtb, (opnd_array(3)->constant()));
   
#line 25532 "ad_aarch64.cpp"
  }
}

void AddExtI_uxth_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13744 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth, (opnd_array(4)->constant()));
   
#line 25552 "ad_aarch64.cpp"
  }
}

void AddExtI_uxth_and_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13744 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxth, (opnd_array(3)->constant()));
   
#line 25572 "ad_aarch64.cpp"
  }
}

void SubExtI_uxtb_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13759 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb, (opnd_array(4)->constant()));
   
#line 25592 "ad_aarch64.cpp"
  }
}

void SubExtI_uxth_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13774 "src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth, (opnd_array(4)->constant()));
   
#line 25612 "ad_aarch64.cpp"
  }
}

void addF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13795 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fadds(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 25631 "ad_aarch64.cpp"
  }
}

void addD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13810 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ faddd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 25650 "ad_aarch64.cpp"
  }
}

void subF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13825 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fsubs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 25669 "ad_aarch64.cpp"
  }
}

void subD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13840 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fsubd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 25688 "ad_aarch64.cpp"
  }
}

void mulF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13855 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmuls(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 25707 "ad_aarch64.cpp"
  }
}

void mulD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13870 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmuld(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 25726 "ad_aarch64.cpp"
  }
}

void maddF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13886 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmadds(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 25747 "ad_aarch64.cpp"
  }
}

void maddD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13903 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmaddd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 25768 "ad_aarch64.cpp"
  }
}

void msubF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13921 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmsubs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 25789 "ad_aarch64.cpp"
  }
}

void msubF_reg_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13921 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmsubs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 25810 "ad_aarch64.cpp"
  }
}

void msubD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13939 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmsubd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 25831 "ad_aarch64.cpp"
  }
}

void msubD_reg_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13939 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmsubd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 25852 "ad_aarch64.cpp"
  }
}

void mnaddF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13957 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fnmadds(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 25873 "ad_aarch64.cpp"
  }
}

void mnaddF_reg_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13957 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fnmadds(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 25894 "ad_aarch64.cpp"
  }
}

void mnaddD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13975 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fnmaddd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 25915 "ad_aarch64.cpp"
  }
}

void mnaddD_reg_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13975 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fnmaddd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 25936 "ad_aarch64.cpp"
  }
}

void mnsubF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13992 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fnmsubs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 25957 "ad_aarch64.cpp"
  }
}

void mnsubD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14009 "src/hotspot/cpu/aarch64/aarch64.ad"

  // n.b. insn name should be fnmsubd
    __ fnmsub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 25979 "ad_aarch64.cpp"
  }
}

void maxF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14026 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmaxs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 25998 "ad_aarch64.cpp"
  }
}

void minF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14040 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmins(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 26017 "ad_aarch64.cpp"
  }
}

void maxD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14054 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmaxd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 26036 "ad_aarch64.cpp"
  }
}

void minD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14068 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmind(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 26055 "ad_aarch64.cpp"
  }
}

void divF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14084 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fdivs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 26074 "ad_aarch64.cpp"
  }
}

void divD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14099 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fdivd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 26093 "ad_aarch64.cpp"
  }
}

void negF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14114 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fnegs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26110 "ad_aarch64.cpp"
  }
}

void negD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14128 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fnegd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26127 "ad_aarch64.cpp"
  }
}

void absI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14146 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpw(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), zr);
    __ cnegw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), Assembler::LT);
  
#line 26144 "ad_aarch64.cpp"
  }
}

void absL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14163 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmp(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), zr);
    __ cneg(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), Assembler::LT);
  
#line 26161 "ad_aarch64.cpp"
  }
}

void absF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14175 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fabss(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26178 "ad_aarch64.cpp"
  }
}

void absD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14188 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fabsd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26195 "ad_aarch64.cpp"
  }
}

void absdF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14201 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fabds(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 26214 "ad_aarch64.cpp"
  }
}

void absdD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14215 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fabdd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 26233 "ad_aarch64.cpp"
  }
}

void sqrtD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14229 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fsqrtd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26250 "ad_aarch64.cpp"
  }
}

void sqrtF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14242 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fsqrts(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26267 "ad_aarch64.cpp"
  }
}

void roundD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rmode
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14254 "src/hotspot/cpu/aarch64/aarch64.ad"

    switch (opnd_array(2)->constant()) {
      case RoundDoubleModeNode::rmode_rint:
        __ frintnd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
                   as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
        break;
      case RoundDoubleModeNode::rmode_floor:
        __ frintmd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
                   as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
        break;
      case RoundDoubleModeNode::rmode_ceil:
        __ frintpd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
                   as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
        break;
    }
  
#line 26297 "ad_aarch64.cpp"
  }
}

void copySignD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14277 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst = as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */),
                  src1 = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
                  src2 = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                  zero = as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* zero */);
    __ fnegd(dst, zero);
    __ bsl(dst, __ T8B, src2, src1);
  
#line 26321 "ad_aarch64.cpp"
  }
}

void copySignF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14292 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst = as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
                  src1 = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
                  src2 = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    __ movi(dst, __ T2S, 0x80, 24);
    __ bsl(dst, __ T8B, src2, src1);
  
#line 26343 "ad_aarch64.cpp"
  }
}

void signumD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// one
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14306 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
                  dst = as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */),
                  zero = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* zero */),
                  one = as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* one */);
    __ facgtd(dst, src, zero); // dst=0 for +-0.0 and NaN. 0xFFF..F otherwise
    __ ushrd(dst, dst, 1);     // dst=0 for +-0.0 and NaN. 0x7FF..F otherwise
    // Bit selection instruction gets bit from "one" for each enabled bit in
    // "dst", otherwise gets a bit from "src". For "src" that contains +-0.0 or
    // NaN the whole "src" will be copied because "dst" is zero. For all other
    // "src" values dst is 0x7FF..F, which means only the sign bit is copied
    // from "src", and all other bits are copied from 1.0.
    __ bsl(dst, __ T8B, one, src);
  
#line 26373 "ad_aarch64.cpp"
  }
}

void signumF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// one
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14327 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
                  dst = as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */),
                  zero = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* zero */),
                  one = as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* one */);
    __ facgts(dst, src, zero);    // dst=0 for +-0.0 and NaN. 0xFFF..F otherwise
    __ ushr(dst, __ T2S, dst, 1); // dst=0 for +-0.0 and NaN. 0x7FF..F otherwise
    // Bit selection instruction gets bit from "one" for each enabled bit in
    // "dst", otherwise gets a bit from "src". For "src" that contains +-0.0 or
    // NaN the whole "src" will be copied because "dst" is zero. For all other
    // "src" values dst is 0x7FF..F, which means only the sign bit is copied
    // from "src", and all other bits are copied from 1.0.
    __ bsl(dst, __ T8B, one, src);
  
#line 26403 "ad_aarch64.cpp"
  }
}

void onspinwaitNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14350 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ spin_wait();
  
#line 26419 "ad_aarch64.cpp"
  }
}

void andI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14370 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 26438 "ad_aarch64.cpp"
  }
}

void andI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14385 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            (uint64_t)(opnd_array(2)->constant()));
  
#line 26457 "ad_aarch64.cpp"
  }
}

void orI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14402 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 26476 "ad_aarch64.cpp"
  }
}

void orI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14417 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            (uint64_t)(opnd_array(2)->constant()));
  
#line 26495 "ad_aarch64.cpp"
  }
}

void xorI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14434 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 26514 "ad_aarch64.cpp"
  }
}

void xorI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14449 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            (uint64_t)(opnd_array(2)->constant()));
  
#line 26533 "ad_aarch64.cpp"
  }
}

void andL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14467 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 26552 "ad_aarch64.cpp"
  }
}

void andL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14482 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            (uint64_t)(opnd_array(2)->constantL()));
  
#line 26571 "ad_aarch64.cpp"
  }
}

void orL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14499 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 26590 "ad_aarch64.cpp"
  }
}

void orL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14514 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           (uint64_t)(opnd_array(2)->constantL()));
  
#line 26609 "ad_aarch64.cpp"
  }
}

void xorL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14531 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 26628 "ad_aarch64.cpp"
  }
}

void xorL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14546 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           (uint64_t)(opnd_array(2)->constantL()));
  
#line 26647 "ad_aarch64.cpp"
  }
}

void convI2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14561 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ sbfm(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, 0, 31);
  
#line 26663 "ad_aarch64.cpp"
  }
}

void convUI2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14574 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ubfm(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, 0, 31);
  
#line 26680 "ad_aarch64.cpp"
  }
}

void convL2I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14587 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ movw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26696 "ad_aarch64.cpp"
  }
}

void convI2BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14604 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpw(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), zr);
    __ cset(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), Assembler::NE);
  
#line 26713 "ad_aarch64.cpp"
  }
}

void convP2BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14622 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmp(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), zr);
    __ cset(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), Assembler::NE);
  
#line 26730 "ad_aarch64.cpp"
  }
}

void convD2F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14636 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcvtd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26746 "ad_aarch64.cpp"
  }
}

void convF2D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14649 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcvts(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26762 "ad_aarch64.cpp"
  }
}

void convF2I_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14662 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcvtzsw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26778 "ad_aarch64.cpp"
  }
}

void convF2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14675 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcvtzs(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26794 "ad_aarch64.cpp"
  }
}

void convI2F_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14688 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ scvtfws(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26810 "ad_aarch64.cpp"
  }
}

void convL2F_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14701 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ scvtfs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26826 "ad_aarch64.cpp"
  }
}

void convD2I_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14714 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcvtzdw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26842 "ad_aarch64.cpp"
  }
}

void convD2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14727 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcvtzd(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26858 "ad_aarch64.cpp"
  }
}

void convI2D_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14740 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ scvtfwd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26874 "ad_aarch64.cpp"
  }
}

void convL2D_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14753 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ scvtfd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 26890 "ad_aarch64.cpp"
  }
}

void MoveF2I_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14772 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ldrw(opnd_array(0)->as_Register(ra_,this)/* dst */, Address(sp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 26906 "ad_aarch64.cpp"
  }
}

void MoveI2F_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14790 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ldrs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), Address(sp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 26922 "ad_aarch64.cpp"
  }
}

void MoveD2L_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14808 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ldr(opnd_array(0)->as_Register(ra_,this)/* dst */, Address(sp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 26938 "ad_aarch64.cpp"
  }
}

void MoveL2D_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14826 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ ldrd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), Address(sp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 26954 "ad_aarch64.cpp"
  }
}

void MoveF2I_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14844 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ strs(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), Address(sp, opnd_array(0)->disp(ra_,this,0)));
  
#line 26970 "ad_aarch64.cpp"
  }
}

void MoveI2F_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14862 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ strw(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, Address(sp, opnd_array(0)->disp(ra_,this,0)));
  
#line 26986 "ad_aarch64.cpp"
  }
}

void MoveD2L_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14880 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ strd(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), Address(sp, opnd_array(0)->disp(ra_,this,0)));
  
#line 27002 "ad_aarch64.cpp"
  }
}

void MoveL2D_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14898 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ str(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, Address(sp, opnd_array(0)->disp(ra_,this,0)));
  
#line 27018 "ad_aarch64.cpp"
  }
}

void MoveF2I_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14916 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmovs(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 27034 "ad_aarch64.cpp"
  }
}

void MoveI2F_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14934 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmovs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 27050 "ad_aarch64.cpp"
  }
}

void MoveD2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14952 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmovd(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 27066 "ad_aarch64.cpp"
  }
}

void MoveL2D_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14970 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmovd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 27082 "ad_aarch64.cpp"
  }
}

void clearArray_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// cnt
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// base
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14989 "src/hotspot/cpu/aarch64/aarch64.ad"

    address tpc = __ zero_words(opnd_array(2)->as_Register(ra_,this,idx2)/* base */, opnd_array(1)->as_Register(ra_,this,idx1)/* cnt */);
    if (tpc == NULL) {
      ciEnv::current()->record_failure("CodeCache is full");
      return;
    }
  
#line 27103 "ad_aarch64.cpp"
  }
}

void clearArray_imm_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// cnt
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// base
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15010 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ zero_words(opnd_array(2)->as_Register(ra_,this,idx2)/* base */, (uint64_t)opnd_array(1)->constantL());
  
#line 27120 "ad_aarch64.cpp"
  }
}

void overflowAddI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15026 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmnw(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 27137 "ad_aarch64.cpp"
  }
}

void overflowAddI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15039 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmnw(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constant());
  
#line 27154 "ad_aarch64.cpp"
  }
}

void overflowAddL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15052 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmn(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 27171 "ad_aarch64.cpp"
  }
}

void overflowAddL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15065 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmn(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constantL());
  
#line 27188 "ad_aarch64.cpp"
  }
}

void overflowSubI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15078 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpw(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 27205 "ad_aarch64.cpp"
  }
}

void overflowSubI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15091 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpw(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constant());
  
#line 27222 "ad_aarch64.cpp"
  }
}

void overflowSubL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15104 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmp(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 27239 "ad_aarch64.cpp"
  }
}

void overflowSubL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15117 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ subs(zr, opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constantL());
  
#line 27256 "ad_aarch64.cpp"
  }
}

void overflowNegI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15130 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpw(zr, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */);
  
#line 27273 "ad_aarch64.cpp"
  }
}

void overflowNegL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15143 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmp(zr, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */);
  
#line 27290 "ad_aarch64.cpp"
  }
}

void overflowMulI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15160 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ smull(rscratch1, opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
    __ subs(zr, rscratch1, rscratch1, ext::sxtw);      // NE => overflow
    __ movw(rscratch1, 0x80000000);                    // Develop 0 (EQ),
    __ cselw(rscratch1, rscratch1, zr, Assembler::NE); // or 0x80000000 (NE)
    __ cmpw(rscratch1, 1);                             // 0x80000000 - 1 => VS
  
#line 27311 "ad_aarch64.cpp"
  }
}

void overflowMulI_reg_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15182 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    __ smull(rscratch1, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* op2 */);
    __ subs(zr, rscratch1, rscratch1, ext::sxtw);      // NE => overflow
    __ br(cond == Assembler::VS ? Assembler::NE : Assembler::EQ, *L);
  
#line 27334 "ad_aarch64.cpp"
  }
}

void overflowMulL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15204 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ mul(rscratch1, opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);   // Result bits 0..63
    __ smulh(rscratch2, opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */); // Result bits 64..127
    __ cmp(rscratch2, rscratch1, Assembler::ASR, 63);    // Top is pure sign ext
    __ movw(rscratch1, 0x80000000);                    // Develop 0 (EQ),
    __ cselw(rscratch1, rscratch1, zr, Assembler::NE); // or 0x80000000 (NE)
    __ cmpw(rscratch1, 1);                             // 0x80000000 - 1 => VS
  
#line 27356 "ad_aarch64.cpp"
  }
}

void overflowMulL_reg_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15228 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    __ mul(rscratch1, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* op2 */);   // Result bits 0..63
    __ smulh(rscratch2, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* op2 */); // Result bits 64..127
    __ cmp(rscratch2, rscratch1, Assembler::ASR, 63);    // Top is pure sign ext
    __ br(cond == Assembler::VS ? Assembler::NE : Assembler::EQ, *L);
  
#line 27380 "ad_aarch64.cpp"
  }
}

void compI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3548 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    Register reg2 = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
    __ cmpw(reg1, reg2);
  
#line 27399 "ad_aarch64.cpp"
  }
}

void compI_reg_immI0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3555 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int32_t val = opnd_array(2)->constant();
    if (val >= 0) {
      __ subsw(zr, reg, val);
    } else {
      __ addsw(zr, reg, -val);
    }
  
#line 27422 "ad_aarch64.cpp"
  }
}

void compI_reg_immIAddSubNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3555 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int32_t val = opnd_array(2)->constant();
    if (val >= 0) {
      __ subsw(zr, reg, val);
    } else {
      __ addsw(zr, reg, -val);
    }
  
#line 27445 "ad_aarch64.cpp"
  }
}

void compI_reg_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3566 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    uint32_t val = (uint32_t)opnd_array(2)->constant();
    __ movw(rscratch1, val);
    __ cmpw(reg1, rscratch1);
  
#line 27465 "ad_aarch64.cpp"
  }
}

void compU_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3548 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    Register reg2 = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
    __ cmpw(reg1, reg2);
  
#line 27484 "ad_aarch64.cpp"
  }
}

void compU_reg_immI0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3555 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int32_t val = opnd_array(2)->constant();
    if (val >= 0) {
      __ subsw(zr, reg, val);
    } else {
      __ addsw(zr, reg, -val);
    }
  
#line 27507 "ad_aarch64.cpp"
  }
}

void compU_reg_immIAddSubNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3555 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int32_t val = opnd_array(2)->constant();
    if (val >= 0) {
      __ subsw(zr, reg, val);
    } else {
      __ addsw(zr, reg, -val);
    }
  
#line 27530 "ad_aarch64.cpp"
  }
}

void compU_reg_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3566 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    uint32_t val = (uint32_t)opnd_array(2)->constant();
    __ movw(rscratch1, val);
    __ cmpw(reg1, rscratch1);
  
#line 27550 "ad_aarch64.cpp"
  }
}

void compL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3574 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    Register reg2 = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
    __ cmp(reg1, reg2);
  
#line 27569 "ad_aarch64.cpp"
  }
}

void compL_reg_immL0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3581 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int64_t val = opnd_array(2)->constantL();
    if (val >= 0) {
      __ subs(zr, reg, val);
    } else if (val != -val) {
      __ adds(zr, reg, -val);
    } else {
    // aargh, Long.MIN_VALUE is a special case
      __ orr(rscratch1, zr, (uint64_t)val);
      __ subs(zr, reg, rscratch1);
    }
  
#line 27596 "ad_aarch64.cpp"
  }
}

void compL_reg_immLAddSubNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3581 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int64_t val = opnd_array(2)->constantL();
    if (val >= 0) {
      __ subs(zr, reg, val);
    } else if (val != -val) {
      __ adds(zr, reg, -val);
    } else {
    // aargh, Long.MIN_VALUE is a special case
      __ orr(rscratch1, zr, (uint64_t)val);
      __ subs(zr, reg, rscratch1);
    }
  
#line 27623 "ad_aarch64.cpp"
  }
}

void compL_reg_immLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3596 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    uint64_t val = (uint64_t)opnd_array(2)->constantL();
    __ mov(rscratch1, val);
    __ cmp(reg1, rscratch1);
  
#line 27643 "ad_aarch64.cpp"
  }
}

void compUL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3574 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    Register reg2 = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
    __ cmp(reg1, reg2);
  
#line 27662 "ad_aarch64.cpp"
  }
}

void compUL_reg_immL0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3581 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int64_t val = opnd_array(2)->constantL();
    if (val >= 0) {
      __ subs(zr, reg, val);
    } else if (val != -val) {
      __ adds(zr, reg, -val);
    } else {
    // aargh, Long.MIN_VALUE is a special case
      __ orr(rscratch1, zr, (uint64_t)val);
      __ subs(zr, reg, rscratch1);
    }
  
#line 27689 "ad_aarch64.cpp"
  }
}

void compUL_reg_immLAddSubNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3581 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int64_t val = opnd_array(2)->constantL();
    if (val >= 0) {
      __ subs(zr, reg, val);
    } else if (val != -val) {
      __ adds(zr, reg, -val);
    } else {
    // aargh, Long.MIN_VALUE is a special case
      __ orr(rscratch1, zr, (uint64_t)val);
      __ subs(zr, reg, rscratch1);
    }
  
#line 27716 "ad_aarch64.cpp"
  }
}

void compUL_reg_immLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3596 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    uint64_t val = (uint64_t)opnd_array(2)->constantL();
    __ mov(rscratch1, val);
    __ cmp(reg1, rscratch1);
  
#line 27736 "ad_aarch64.cpp"
  }
}

void compP_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3604 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    Register reg2 = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
    __ cmp(reg1, reg2);
  
#line 27755 "ad_aarch64.cpp"
  }
}

void compN_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3611 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    Register reg2 = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
    __ cmpw(reg1, reg2);
  
#line 27774 "ad_aarch64.cpp"
  }
}

void testP_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3618 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    __ cmp(reg, zr);
  
#line 27792 "ad_aarch64.cpp"
  }
}

void testN_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3624 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    __ cmpw(reg, zr);
  
#line 27810 "ad_aarch64.cpp"
  }
}

void compF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15539 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcmps(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27827 "ad_aarch64.cpp"
  }
}

void compF_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15553 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcmps(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), 0.0);
  
#line 27844 "ad_aarch64.cpp"
  }
}

void compD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15568 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcmpd(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 27861 "ad_aarch64.cpp"
  }
}

void compD_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15582 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcmpd(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), 0.0);
  
#line 27878 "ad_aarch64.cpp"
  }
}

void compF3_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15600 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label done;
    FloatRegister s1 = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    FloatRegister s2 = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    Register d = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ fcmps(s1, s2);
    // installs 0 if EQ else -1
    __ csinvw(d, zr, zr, Assembler::EQ);
    // keeps -1 if less or unordered else installs 1
    __ csnegw(d, d, d, Assembler::LT);
    __ bind(done);
  
#line 27904 "ad_aarch64.cpp"
  }
}

void compD3_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15628 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label done;
    FloatRegister s1 = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    FloatRegister s2 = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    Register d = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ fcmpd(s1, s2);
    // installs 0 if EQ else -1
    __ csinvw(d, zr, zr, Assembler::EQ);
    // keeps -1 if less or unordered else installs 1
    __ csnegw(d, d, d, Assembler::LT);
    __ bind(done);
  
#line 27930 "ad_aarch64.cpp"
  }
}

void compF3_reg_immF0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15655 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label done;
    FloatRegister s1 = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    Register d = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ fcmps(s1, 0.0);
    // installs 0 if EQ else -1
    __ csinvw(d, zr, zr, Assembler::EQ);
    // keeps -1 if less or unordered else installs 1
    __ csnegw(d, d, d, Assembler::LT);
    __ bind(done);
  
#line 27955 "ad_aarch64.cpp"
  }
}

void compD3_reg_immD0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15682 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label done;
    FloatRegister s1 = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    Register d = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ fcmpd(s1, 0.0);
    // installs 0 if EQ else -1
    __ csinvw(d, zr, zr, Assembler::EQ);
    // keeps -1 if less or unordered else installs 1
    __ csnegw(d, d, d, Assembler::LT);
    __ bind(done);
  
#line 27980 "ad_aarch64.cpp"
  }
}

void cmpLTMask_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// p
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// q
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15709 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpw(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* p */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* q */));
    __ csetw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), Assembler::LT);
    __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), zr, as_Register(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 27999 "ad_aarch64.cpp"
  }
}

void cmpLTMask_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15727 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ asrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), 31);
  
#line 28016 "ad_aarch64.cpp"
  }
}

void cmovI_reg_reg_ltNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15744 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
             Assembler::LT);
  
#line 28037 "ad_aarch64.cpp"
  }
}

void cmovI_reg_reg_gtNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15775 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
             Assembler::GT);
  
#line 28058 "ad_aarch64.cpp"
  }
}

void branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3630 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Label *L = opnd_array(1)->label();
    __ b(*L);
  
#line 28075 "ad_aarch64.cpp"
  }
}

void branchConNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lbl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {

#line 3636 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Label *L = opnd_array(3)->label();
    __ br ((Assembler::Condition)opnd_array(1)->ccode(), *L);
  
#line 28094 "ad_aarch64.cpp"
  }
}

void branchConUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lbl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {

#line 3642 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Label *L = opnd_array(3)->label();
    __ br ((Assembler::Condition)opnd_array(1)->ccode(), *L);
  
#line 28113 "ad_aarch64.cpp"
  }
}

void cmpI_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15866 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ)
      __ cbzw(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
    else
      __ cbnzw(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
  
#line 28137 "ad_aarch64.cpp"
  }
}

void cmpL_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15883 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ)
      __ cbz(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
    else
      __ cbnz(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
  
#line 28161 "ad_aarch64.cpp"
  }
}

void cmpP_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15900 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ)
      __ cbz(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
    else
      __ cbnz(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
  
#line 28185 "ad_aarch64.cpp"
  }
}

void cmpN_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15917 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ)
      __ cbzw(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
    else
      __ cbnzw(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
  
#line 28209 "ad_aarch64.cpp"
  }
}

void cmpP_narrowOop_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// oop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15934 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ)
      __ cbzw(opnd_array(2)->as_Register(ra_,this,idx2)/* oop */, *L);
    else
      __ cbnzw(opnd_array(2)->as_Register(ra_,this,idx2)/* oop */, *L);
  
#line 28233 "ad_aarch64.cpp"
  }
}

void cmpUI_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15951 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ || cond == Assembler::LS)
      __ cbzw(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
    else
      __ cbnzw(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
  
#line 28257 "ad_aarch64.cpp"
  }
}

void cmpUL_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15968 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ || cond == Assembler::LS)
      __ cbz(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
    else
      __ cbnz(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
  
#line 28281 "ad_aarch64.cpp"
  }
}

void cmpL_branch_signNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15988 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond =
      ((Assembler::Condition)opnd_array(1)->ccode()== Assembler::LT) ? Assembler::NE : Assembler::EQ;
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, 63, *L);
  
#line 28303 "ad_aarch64.cpp"
  }
}

void cmpI_branch_signNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16004 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond =
      ((Assembler::Condition)opnd_array(1)->ccode()== Assembler::LT) ? Assembler::NE : Assembler::EQ;
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, 31, *L);
  
#line 28325 "ad_aarch64.cpp"
  }
}

void cmpL_branch_bitNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// labl
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16021 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(5)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    int bit = exact_log2_long(opnd_array(3)->constantL());
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, bit, *L);
  
#line 28348 "ad_aarch64.cpp"
  }
}

void cmpI_branch_bitNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// labl
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16038 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(5)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    int bit = exact_log2((juint)opnd_array(3)->constant());
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, bit, *L);
  
#line 28371 "ad_aarch64.cpp"
  }
}

void far_cmpL_branch_signNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16055 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond =
      ((Assembler::Condition)opnd_array(1)->ccode()== Assembler::LT) ? Assembler::NE : Assembler::EQ;
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, 63, *L, /*far*/true);
  
#line 28393 "ad_aarch64.cpp"
  }
}

void far_cmpI_branch_signNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16070 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond =
      ((Assembler::Condition)opnd_array(1)->ccode()== Assembler::LT) ? Assembler::NE : Assembler::EQ;
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, 31, *L, /*far*/true);
  
#line 28415 "ad_aarch64.cpp"
  }
}

void far_cmpL_branch_bitNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// labl
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16086 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(5)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    int bit = exact_log2_long(opnd_array(3)->constantL());
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, bit, *L, /*far*/true);
  
#line 28438 "ad_aarch64.cpp"
  }
}

void far_cmpI_branch_bitNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// labl
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16102 "src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(5)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    int bit = exact_log2((juint)opnd_array(3)->constant());
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, bit, *L, /*far*/true);
  
#line 28461 "ad_aarch64.cpp"
  }
}

void cmpL_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16120 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ tst(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constantL());
  
#line 28479 "ad_aarch64.cpp"
  }
}

void cmpI_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16133 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ tstw(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constant());
  
#line 28497 "ad_aarch64.cpp"
  }
}

void cmpL_and_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16144 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ tst(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 28515 "ad_aarch64.cpp"
  }
}

void cmpI_and_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16155 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ tstw(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 28533 "ad_aarch64.cpp"
  }
}

void branchLoopEndNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lbl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {

#line 3636 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Label *L = opnd_array(3)->label();
    __ br ((Assembler::Condition)opnd_array(1)->ccode(), *L);
  
#line 28552 "ad_aarch64.cpp"
  }
}

void branchLoopEndUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lbl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {

#line 3642 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Label *L = opnd_array(3)->label();
    __ br ((Assembler::Condition)opnd_array(1)->ccode(), *L);
  
#line 28571 "ad_aarch64.cpp"
  }
}

void cmpFastLockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// object
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// box
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  {

#line 3782 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register oop = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* object */);
    Register box = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* box */);
    Register disp_hdr = as_Register(opnd_array(3)->reg(ra_,this,idx3)/* tmp */);
    Register tmp = as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp2 */);
    Label cont;
    Label object_has_monitor;
    Label cas_failed;

    assert_different_registers(oop, box, tmp, disp_hdr);

    // Load markWord from object into displaced_header.
    __ ldr(disp_hdr, Address(oop, oopDesc::mark_offset_in_bytes()));

    if (DiagnoseSyncOnValueBasedClasses != 0) {
      __ load_klass(tmp, oop);
      __ ldrw(tmp, Address(tmp, Klass::access_flags_offset()));
      __ tstw(tmp, JVM_ACC_IS_VALUE_BASED_CLASS);
      __ br(Assembler::NE, cont);
    }

    if (UseBiasedLocking && !UseOptoBiasInlining) {
      __ biased_locking_enter(box, oop, disp_hdr, tmp, true, cont);
    }

    // Check for existing monitor
    __ tbnz(disp_hdr, exact_log2(markWord::monitor_value), object_has_monitor);

    // Set tmp to be (markWord of object | UNLOCK_VALUE).
    __ orr(tmp, disp_hdr, markWord::unlocked_value);

    // Initialize the box. (Must happen before we update the object mark!)
    __ str(tmp, Address(box, BasicLock::displaced_header_offset_in_bytes()));

    // Compare object markWord with an unlocked value (tmp) and if
    // equal exchange the stack address of our box with object markWord.
    // On failure disp_hdr contains the possibly locked markWord.
    __ cmpxchg(oop, tmp, box, Assembler::xword, /*acquire*/ true,
               /*release*/ true, /*weak*/ false, disp_hdr);
    __ br(Assembler::EQ, cont);

    assert(oopDesc::mark_offset_in_bytes() == 0, "offset of _mark is not 0");

    // If the compare-and-exchange succeeded, then we found an unlocked
    // object, will have now locked it will continue at label cont

    __ bind(cas_failed);
    // We did not see an unlocked object so try the fast recursive case.

    // Check if the owner is self by comparing the value in the
    // markWord of object (disp_hdr) with the stack pointer.
    __ mov(rscratch1, sp);
    __ sub(disp_hdr, disp_hdr, rscratch1);
    __ mov(tmp, (address) (~(os::vm_page_size()-1) | markWord::lock_mask_in_place));
    // If condition is true we are cont and hence we can store 0 as the
    // displaced header in the box, which indicates that it is a recursive lock.
    __ ands(tmp/*==0?*/, disp_hdr, tmp);   // Sets flags for result
    __ str(tmp/*==0, perhaps*/, Address(box, BasicLock::displaced_header_offset_in_bytes()));

    __ b(cont);

    // Handle existing monitor.
    __ bind(object_has_monitor);

    // The object's monitor m is unlocked iff m->owner == NULL,
    // otherwise m->owner may contain a thread or a stack address.
    //
    // Try to CAS m->owner from NULL to current thread.
    __ add(tmp, disp_hdr, (ObjectMonitor::owner_offset_in_bytes()-markWord::monitor_value));
    __ cmpxchg(tmp, zr, rthread, Assembler::xword, /*acquire*/ true,
               /*release*/ true, /*weak*/ false, rscratch1); // Sets flags for result

    // Store a non-null value into the box to avoid looking like a re-entrant
    // lock. The fast-path monitor unlock code checks for
    // markWord::monitor_value so use markWord::unused_mark which has the
    // relevant bit set, and also matches ObjectSynchronizer::enter.
    __ mov(tmp, (address)markWord::unused_mark().value());
    __ str(tmp, Address(box, BasicLock::displaced_header_offset_in_bytes()));

    __ br(Assembler::EQ, cont); // CAS success means locking succeeded

    __ cmp(rscratch1, rthread);
    __ br(Assembler::NE, cont); // Check for recursive locking

    // Recursive lock case
    __ increment(Address(disp_hdr, ObjectMonitor::recursions_offset_in_bytes() - markWord::monitor_value), 1);
    // flag == EQ still from the cmp above, checking if this is a reentrant lock

    __ bind(cont);
    // flag == EQ indicates success
    // flag == NE indicates failure
  
#line 28679 "ad_aarch64.cpp"
  }
}

void cmpFastUnlockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// object
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// box
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  {

#line 3876 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register oop = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* object */);
    Register box = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* box */);
    Register disp_hdr = as_Register(opnd_array(3)->reg(ra_,this,idx3)/* tmp */);
    Register tmp = as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp2 */);
    Label cont;
    Label object_has_monitor;

    assert_different_registers(oop, box, tmp, disp_hdr);

    if (UseBiasedLocking && !UseOptoBiasInlining) {
      __ biased_locking_exit(oop, tmp, cont);
    }

    // Find the lock address and load the displaced header from the stack.
    __ ldr(disp_hdr, Address(box, BasicLock::displaced_header_offset_in_bytes()));

    // If the displaced header is 0, we have a recursive unlock.
    __ cmp(disp_hdr, zr);
    __ br(Assembler::EQ, cont);

    // Handle existing monitor.
    __ ldr(tmp, Address(oop, oopDesc::mark_offset_in_bytes()));
    __ tbnz(disp_hdr, exact_log2(markWord::monitor_value), object_has_monitor);

    // Check if it is still a light weight lock, this is is true if we
    // see the stack address of the basicLock in the markWord of the
    // object.

    __ cmpxchg(oop, box, disp_hdr, Assembler::xword, /*acquire*/ false,
               /*release*/ true, /*weak*/ false, tmp);
    __ b(cont);

    assert(oopDesc::mark_offset_in_bytes() == 0, "offset of _mark is not 0");

    // Handle existing monitor.
    __ bind(object_has_monitor);
    STATIC_ASSERT(markWord::monitor_value <= INT_MAX);
    __ add(tmp, tmp, -(int)markWord::monitor_value); // monitor
    __ ldr(rscratch1, Address(tmp, ObjectMonitor::owner_offset_in_bytes()));
    __ ldr(disp_hdr, Address(tmp, ObjectMonitor::recursions_offset_in_bytes()));

    Label notRecursive;
    __ cmp(rscratch1, rthread);
    __ br(Assembler::NE, cont);

    __ cbz(disp_hdr, notRecursive);

    // Recursive lock
    __ sub(disp_hdr, disp_hdr, 1u);
    __ str(disp_hdr, Address(tmp, ObjectMonitor::recursions_offset_in_bytes()));
    // flag == EQ was set in the ownership check above
    __ b(cont);

    __ bind(notRecursive);
    __ ldr(rscratch1, Address(tmp, ObjectMonitor::EntryList_offset_in_bytes()));
    __ ldr(disp_hdr, Address(tmp, ObjectMonitor::cxq_offset_in_bytes()));
    __ orr(rscratch1, rscratch1, disp_hdr); // Will be 0 if both are 0.
    __ cmp(rscratch1, zr); // Sets flags for result
    __ cbnz(rscratch1, cont);
    // need a release store here
    __ lea(tmp, Address(tmp, ObjectMonitor::owner_offset_in_bytes()));
    __ stlr(zr, tmp); // set unowned

    __ bind(cont);
    // flag == EQ indicates success
    // flag == NE indicates failure
  
#line 28763 "ad_aarch64.cpp"
  }
}

void safePointNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16250 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ read_polling_page(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* poll */), relocInfo::poll_type);
  
#line 28779 "ad_aarch64.cpp"
  }
}

void CallStaticJavaDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3666 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);

    address addr = (address)opnd_array(1)->method();
    address call;
    if (!_method) {
      // A call to a runtime wrapper, e.g. new, new_typeArray_Java, uncommon_trap.
      call = __ trampoline_call(Address(addr, relocInfo::runtime_call_type), &cbuf);
      if (call == NULL) {
        ciEnv::current()->record_failure("CodeCache is full");
        return;
      }
    } else {
      int method_index = resolved_method_index(cbuf);
      RelocationHolder rspec = _optimized_virtual ? opt_virtual_call_Relocation::spec(method_index)
                                                  : static_call_Relocation::spec(method_index);
      call = __ trampoline_call(Address(addr, rspec), &cbuf);
      if (call == NULL) {
        ciEnv::current()->record_failure("CodeCache is full");
        return;
      }
      // Emit stub for static call
      address stub = CompiledStaticCall::emit_to_interp_stub(cbuf);
      if (stub == NULL) {
        ciEnv::current()->record_failure("CodeCache is full");
        return;
      }
    }

    // Only non uncommon_trap calls need to reinitialize ptrue.
    if (Compile::current()->max_vector_size() >= 16 && uncommon_trap_request() == 0) {
      __ reinitialize_ptrue();
    }
  
#line 28825 "ad_aarch64.cpp"
  }
  {

#line 3713 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    if (VerifyStackAtCalls) {
      // Check that stack depth is unchanged: find majik cookie on stack
      __ call_Unimplemented();
    }
  
#line 28837 "ad_aarch64.cpp"
  }
}

void CallDynamicJavaDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3701 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    int method_index = resolved_method_index(cbuf);
    address call = __ ic_call((address)opnd_array(1)->method(), method_index);
    if (call == NULL) {
      ciEnv::current()->record_failure("CodeCache is full");
      return;
    } else if (Compile::current()->max_vector_size() >= 16) {
      __ reinitialize_ptrue();
    }
  
#line 28860 "ad_aarch64.cpp"
  }
  {

#line 3713 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    if (VerifyStackAtCalls) {
      // Check that stack depth is unchanged: find majik cookie on stack
      __ call_Unimplemented();
    }
  
#line 28872 "ad_aarch64.cpp"
  }
}

void CallRuntimeDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3721 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);

    // some calls to generated routines (arraycopy code) are scheduled
    // by C2 as runtime calls. if so we can call them using a br (they
    // will be in a reachable segment) otherwise we have to use a blr
    // which loads the absolute address into a register.
    address entry = (address)opnd_array(1)->method();
    CodeBlob *cb = CodeCache::find_blob(entry);
    if (cb) {
      address call = __ trampoline_call(Address(entry, relocInfo::runtime_call_type));
      if (call == NULL) {
        ciEnv::current()->record_failure("CodeCache is full");
        return;
      }
    } else {
      Label retaddr;
      __ adr(rscratch2, retaddr);
      __ lea(rscratch1, RuntimeAddress(entry));
      // Leave a breadcrumb for JavaFrameAnchor::capture_last_Java_pc()
      __ stp(zr, rscratch2, Address(__ pre(sp, -2 * wordSize)));
      __ blr(rscratch1);
      __ bind(retaddr);
      __ add(sp, sp, 2 * wordSize);
    }
    if (Compile::current()->max_vector_size() >= 16) {
      __ reinitialize_ptrue();
    }
  
#line 28913 "ad_aarch64.cpp"
  }
}

void CallLeafDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3721 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);

    // some calls to generated routines (arraycopy code) are scheduled
    // by C2 as runtime calls. if so we can call them using a br (they
    // will be in a reachable segment) otherwise we have to use a blr
    // which loads the absolute address into a register.
    address entry = (address)opnd_array(1)->method();
    CodeBlob *cb = CodeCache::find_blob(entry);
    if (cb) {
      address call = __ trampoline_call(Address(entry, relocInfo::runtime_call_type));
      if (call == NULL) {
        ciEnv::current()->record_failure("CodeCache is full");
        return;
      }
    } else {
      Label retaddr;
      __ adr(rscratch2, retaddr);
      __ lea(rscratch1, RuntimeAddress(entry));
      // Leave a breadcrumb for JavaFrameAnchor::capture_last_Java_pc()
      __ stp(zr, rscratch2, Address(__ pre(sp, -2 * wordSize)));
      __ blr(rscratch1);
      __ bind(retaddr);
      __ add(sp, sp, 2 * wordSize);
    }
    if (Compile::current()->max_vector_size() >= 16) {
      __ reinitialize_ptrue();
    }
  
#line 28954 "ad_aarch64.cpp"
  }
}

void CallLeafNoFPDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3721 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);

    // some calls to generated routines (arraycopy code) are scheduled
    // by C2 as runtime calls. if so we can call them using a br (they
    // will be in a reachable segment) otherwise we have to use a blr
    // which loads the absolute address into a register.
    address entry = (address)opnd_array(1)->method();
    CodeBlob *cb = CodeCache::find_blob(entry);
    if (cb) {
      address call = __ trampoline_call(Address(entry, relocInfo::runtime_call_type));
      if (call == NULL) {
        ciEnv::current()->record_failure("CodeCache is full");
        return;
      }
    } else {
      Label retaddr;
      __ adr(rscratch2, retaddr);
      __ lea(rscratch1, RuntimeAddress(entry));
      // Leave a breadcrumb for JavaFrameAnchor::capture_last_Java_pc()
      __ stp(zr, rscratch2, Address(__ pre(sp, -2 * wordSize)));
      __ blr(rscratch1);
      __ bind(retaddr);
      __ add(sp, sp, 2 * wordSize);
    }
    if (Compile::current()->max_vector_size() >= 16) {
      __ reinitialize_ptrue();
    }
  
#line 28995 "ad_aarch64.cpp"
  }
}

void CallNativeDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3721 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);

    // some calls to generated routines (arraycopy code) are scheduled
    // by C2 as runtime calls. if so we can call them using a br (they
    // will be in a reachable segment) otherwise we have to use a blr
    // which loads the absolute address into a register.
    address entry = (address)opnd_array(1)->method();
    CodeBlob *cb = CodeCache::find_blob(entry);
    if (cb) {
      address call = __ trampoline_call(Address(entry, relocInfo::runtime_call_type));
      if (call == NULL) {
        ciEnv::current()->record_failure("CodeCache is full");
        return;
      }
    } else {
      Label retaddr;
      __ adr(rscratch2, retaddr);
      __ lea(rscratch1, RuntimeAddress(entry));
      // Leave a breadcrumb for JavaFrameAnchor::capture_last_Java_pc()
      __ stp(zr, rscratch2, Address(__ pre(sp, -2 * wordSize)));
      __ blr(rscratch1);
      __ bind(retaddr);
      __ add(sp, sp, 2 * wordSize);
    }
    if (Compile::current()->max_vector_size() >= 16) {
      __ reinitialize_ptrue();
    }
  
#line 29036 "ad_aarch64.cpp"
  }
}

void TailCalljmpIndNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// method_ptr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// 
  {

#line 3766 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register target_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* jump_target */);
    __ br(target_reg);
  
#line 29054 "ad_aarch64.cpp"
  }
}

void TailjmpIndNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// ex_oop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// 
  {

#line 3772 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register target_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* jump_target */);
    // exception oop should be in r0
    // ret addr has been popped into lr
    // callee expects it in r3
    __ mov(r3, lr);
    __ br(target_reg);
  
#line 29076 "ad_aarch64.cpp"
  }
}

void CreateExceptionNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint CreateExceptionNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void RethrowExceptionNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// 
  {

#line 3751 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    __ far_jump(RuntimeAddress(OptoRuntime::rethrow_stub()));
  
#line 29105 "ad_aarch64.cpp"
  }
}

void RetNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// 
  {

#line 3756 "src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
#ifdef ASSERT
    if (Compile::current()->max_vector_size() >= 16) {
      __ verify_ptrue();
    }
#endif
    __ ret(lr);
  
#line 29126 "ad_aarch64.cpp"
  }
}

void ShouldNotReachHereNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16445 "src/hotspot/cpu/aarch64/aarch64.ad"

    if (is_reachable()) {
      __ stop(_halt_reason);
    }
  
#line 29144 "ad_aarch64.cpp"
  }
}

void partialSubtypeCheckNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// sub
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// super
  {

#line 3649 "src/hotspot/cpu/aarch64/aarch64.ad"

     Register sub_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* sub */);
     Register super_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* super */);
     Register temp_reg = as_Register(R2_enc);
     Register result_reg = as_Register(opnd_array(0)->reg(ra_,this)/* result */);

     Label miss;
     C2_MacroAssembler _masm(&cbuf);
     __ check_klass_subtype_slow_path(sub_reg, super_reg, temp_reg, result_reg,
                                     NULL, &miss,
                                     /*set_cond_codes:*/ true);
     if ((0x1 /*primary()*/)) {
       __ mov(result_reg, zr);
     }
     __ bind(miss);
  
#line 29173 "ad_aarch64.cpp"
  }
}

void partialSubtypeCheckVsZeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// sub
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// super
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  {

#line 3649 "src/hotspot/cpu/aarch64/aarch64.ad"

     Register sub_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* sub */);
     Register super_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* super */);
     Register temp_reg = as_Register(R2_enc);
     Register result_reg = as_Register(R5_enc);

     Label miss;
     C2_MacroAssembler _masm(&cbuf);
     __ check_klass_subtype_slow_path(sub_reg, super_reg, temp_reg, result_reg,
                                     NULL, &miss,
                                     /*set_cond_codes:*/ true);
     if ((0x0 /*primary()*/)) {
       __ mov(result_reg, zr);
     }
     __ bind(miss);
  
#line 29203 "ad_aarch64.cpp"
  }
}

void string_compareUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16500 "src/hotspot/cpu/aarch64/aarch64.ad"

    // Count is in 8-bit bytes; non-Compact chars are 16 bits.
    __ string_compare(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */, opnd_array(0)->as_Register(ra_,this)/* result */,
                      as_Register(R10_enc), as_Register(R11_enc),
                      fnoreg, fnoreg, fnoreg, StrIntrinsicNode::UU);
  
#line 29226 "ad_aarch64.cpp"
  }
}

void string_compareLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16518 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ string_compare(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */, opnd_array(0)->as_Register(ra_,this)/* result */,
                      as_Register(R10_enc), as_Register(R11_enc),
                      fnoreg, fnoreg, fnoreg, StrIntrinsicNode::LL);
  
#line 29248 "ad_aarch64.cpp"
  }
}

void string_compareULNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16537 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ string_compare(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */, opnd_array(0)->as_Register(ra_,this)/* result */,
                      as_Register(R10_enc), as_Register(R11_enc),
                      as_FloatRegister(V0_enc), as_FloatRegister(V1_enc),
                      as_FloatRegister(V2_enc), StrIntrinsicNode::UL);
  
#line 29271 "ad_aarch64.cpp"
  }
}

void string_compareLUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16557 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ string_compare(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */, opnd_array(0)->as_Register(ra_,this)/* result */,
                      as_Register(R10_enc), as_Register(R11_enc),
                      as_FloatRegister(V0_enc), as_FloatRegister(V1_enc),
                      as_FloatRegister(V2_enc),StrIntrinsicNode::LU);
  
#line 29294 "ad_aarch64.cpp"
  }
}

void string_indexofUUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp3
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// tmp4
  unsigned idx9 = idx8 + opnd_array(8)->num_edges(); 	// tmp5
  unsigned idx10 = idx9 + opnd_array(9)->num_edges(); 	// tmp6
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16577 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_Register(ra_,this,idx7)/* tmp3 */, opnd_array(8)->as_Register(ra_,this,idx8)/* tmp4 */,
                      opnd_array(9)->as_Register(ra_,this,idx9)/* tmp5 */, opnd_array(10)->as_Register(ra_,this,idx10)/* tmp6 */,
                      -1, opnd_array(0)->as_Register(ra_,this)/* result */, StrIntrinsicNode::UU);
  
#line 29324 "ad_aarch64.cpp"
  }
}

void string_indexofLLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp3
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// tmp4
  unsigned idx9 = idx8 + opnd_array(8)->num_edges(); 	// tmp5
  unsigned idx10 = idx9 + opnd_array(9)->num_edges(); 	// tmp6
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16598 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_Register(ra_,this,idx7)/* tmp3 */, opnd_array(8)->as_Register(ra_,this,idx8)/* tmp4 */,
                      opnd_array(9)->as_Register(ra_,this,idx9)/* tmp5 */, opnd_array(10)->as_Register(ra_,this,idx10)/* tmp6 */,
                      -1, opnd_array(0)->as_Register(ra_,this)/* result */, StrIntrinsicNode::LL);
  
#line 29354 "ad_aarch64.cpp"
  }
}

void string_indexofULNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp3
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// tmp4
  unsigned idx9 = idx8 + opnd_array(8)->num_edges(); 	// tmp5
  unsigned idx10 = idx9 + opnd_array(9)->num_edges(); 	// tmp6
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16619 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_Register(ra_,this,idx7)/* tmp3 */, opnd_array(8)->as_Register(ra_,this,idx8)/* tmp4 */,
                      opnd_array(9)->as_Register(ra_,this,idx9)/* tmp5 */, opnd_array(10)->as_Register(ra_,this,idx10)/* tmp6 */,
                      -1, opnd_array(0)->as_Register(ra_,this)/* result */, StrIntrinsicNode::UL);
  
#line 29384 "ad_aarch64.cpp"
  }
}

void string_indexof_conUUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// int_cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp3
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// tmp4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16640 "src/hotspot/cpu/aarch64/aarch64.ad"

    int icnt2 = (int)opnd_array(4)->constant();
    __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, zr,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_Register(ra_,this,idx7)/* tmp3 */, opnd_array(8)->as_Register(ra_,this,idx8)/* tmp4 */, zr, zr,
                      icnt2, opnd_array(0)->as_Register(ra_,this)/* result */, StrIntrinsicNode::UU);
  
#line 29412 "ad_aarch64.cpp"
  }
}

void string_indexof_conLLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// int_cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp3
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// tmp4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16661 "src/hotspot/cpu/aarch64/aarch64.ad"

    int icnt2 = (int)opnd_array(4)->constant();
    __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, zr,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_Register(ra_,this,idx7)/* tmp3 */, opnd_array(8)->as_Register(ra_,this,idx8)/* tmp4 */, zr, zr,
                      icnt2, opnd_array(0)->as_Register(ra_,this)/* result */, StrIntrinsicNode::LL);
  
#line 29440 "ad_aarch64.cpp"
  }
}

void string_indexof_conULNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// int_cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp3
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// tmp4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16682 "src/hotspot/cpu/aarch64/aarch64.ad"

    int icnt2 = (int)opnd_array(4)->constant();
    __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, zr,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_Register(ra_,this,idx7)/* tmp3 */, opnd_array(8)->as_Register(ra_,this,idx8)/* tmp4 */, zr, zr,
                      icnt2, opnd_array(0)->as_Register(ra_,this)/* result */, StrIntrinsicNode::UL);
  
#line 29468 "ad_aarch64.cpp"
  }
}

void string_indexof_charNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// ch
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16704 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ string_indexof_char(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* ch */,
                           opnd_array(0)->as_Register(ra_,this)/* result */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp1 */, opnd_array(5)->as_Register(ra_,this,idx5)/* tmp2 */,
                           opnd_array(6)->as_Register(ra_,this,idx6)/* tmp3 */);
  
#line 29491 "ad_aarch64.cpp"
  }
}

void stringL_indexof_charNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// ch
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16723 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ stringL_indexof_char(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* ch */,
                           opnd_array(0)->as_Register(ra_,this)/* result */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp1 */, opnd_array(5)->as_Register(ra_,this,idx5)/* tmp2 */,
                           opnd_array(6)->as_Register(ra_,this,idx6)/* tmp3 */);
  
#line 29514 "ad_aarch64.cpp"
  }
}

void string_equalsLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// str2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16739 "src/hotspot/cpu/aarch64/aarch64.ad"

    // Count is in 8-bit bytes; non-Compact chars are 16 bits.
    __ string_equals(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* str2 */,
                     opnd_array(0)->as_Register(ra_,this)/* result */, opnd_array(3)->as_Register(ra_,this,idx3)/* cnt */, 1);
  
#line 29534 "ad_aarch64.cpp"
  }
}

void string_equalsUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// str2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16755 "src/hotspot/cpu/aarch64/aarch64.ad"

    // Count is in 8-bit bytes; non-Compact chars are 16 bits.
    __ string_equals(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* str2 */,
                     opnd_array(0)->as_Register(ra_,this)/* result */, opnd_array(3)->as_Register(ra_,this,idx3)/* cnt */, 2);
  
#line 29554 "ad_aarch64.cpp"
  }
}

void array_equalsBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// ary1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// ary2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16772 "src/hotspot/cpu/aarch64/aarch64.ad"

    address tpc = __ arrays_equals(opnd_array(1)->as_Register(ra_,this,idx1)/* ary1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* ary2 */,
                                   opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */, opnd_array(5)->as_Register(ra_,this,idx5)/* tmp3 */,
                                   opnd_array(0)->as_Register(ra_,this)/* result */, as_Register(R10_enc), 1);
    if (tpc == NULL) {
      ciEnv::current()->record_failure("CodeCache is full");
      return;
    }
  
#line 29580 "ad_aarch64.cpp"
  }
}

void array_equalsCNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// ary1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// ary2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16793 "src/hotspot/cpu/aarch64/aarch64.ad"

    address tpc = __ arrays_equals(opnd_array(1)->as_Register(ra_,this,idx1)/* ary1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* ary2 */,
                                   opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */, opnd_array(5)->as_Register(ra_,this,idx5)/* tmp3 */,
                                   opnd_array(0)->as_Register(ra_,this)/* result */, as_Register(R10_enc), 2);
    if (tpc == NULL) {
      ciEnv::current()->record_failure("CodeCache is full");
      return;
    }
  
#line 29606 "ad_aarch64.cpp"
  }
}

void has_negativesNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// ary1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// len
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16810 "src/hotspot/cpu/aarch64/aarch64.ad"

    address tpc = __ has_negatives(opnd_array(1)->as_Register(ra_,this,idx1)/* ary1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* len */, opnd_array(0)->as_Register(ra_,this)/* result */);
    if (tpc == NULL) {
      ciEnv::current()->record_failure("CodeCache is full");
      return;
    }
  
#line 29627 "ad_aarch64.cpp"
  }
}

void string_compressNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// len
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp3
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16830 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ char_array_compress(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* len */,
                           opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp1 */, opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp2 */,
                           opnd_array(6)->as_FloatRegister(ra_,this,idx6)/* tmp3 */, opnd_array(7)->as_FloatRegister(ra_,this,idx7)/* tmp4 */,
                           opnd_array(0)->as_Register(ra_,this)/* result */);
  
#line 29652 "ad_aarch64.cpp"
  }
}

void string_inflateNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// len
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp3
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16847 "src/hotspot/cpu/aarch64/aarch64.ad"

    address tpc = __ byte_array_inflate(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* len */,
                                        opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp1 */, opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp2 */,
                                        opnd_array(6)->as_FloatRegister(ra_,this,idx6)/* tmp3 */, opnd_array(7)->as_Register(ra_,this,idx7)/* tmp4 */);
    if (tpc == NULL) {
      ciEnv::current()->record_failure("CodeCache is full");
      return;
    }
  
#line 29680 "ad_aarch64.cpp"
  }
}

void encode_iso_arrayNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// len
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16871 "src/hotspot/cpu/aarch64/aarch64.ad"

    __ encode_iso_array(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* len */,
         opnd_array(0)->as_Register(ra_,this)/* result */, as_FloatRegister(V0_enc),  as_FloatRegister(V1_enc),
         as_FloatRegister(V2_enc),  as_FloatRegister(V3_enc));
  
#line 29700 "ad_aarch64.cpp"
  }
}

void tlsLoadPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint tlsLoadPNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void loadV2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3053 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, MacroAssembler::H,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 29730 "ad_aarch64.cpp"
  }
}

void loadV4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3059 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, MacroAssembler::S,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 29747 "ad_aarch64.cpp"
  }
}

void loadV8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3065 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, MacroAssembler::D,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 29764 "ad_aarch64.cpp"
  }
}

void loadV16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3071 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, MacroAssembler::Q,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 29781 "ad_aarch64.cpp"
  }
}

void storeV2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3077 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, MacroAssembler::H,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 29799 "ad_aarch64.cpp"
  }
}

void storeV4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3083 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, MacroAssembler::S,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 29817 "ad_aarch64.cpp"
  }
}

void storeV8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3089 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, MacroAssembler::D,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 29835 "ad_aarch64.cpp"
  }
}

void storeV16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3095 "src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, MacroAssembler::Q,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 29853 "ad_aarch64.cpp"
  }
}

void reinterpretDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 128 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // empty
  
#line 29869 "ad_aarch64.cpp"
  }
}

void reinterpretXNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 141 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // empty
  
#line 29885 "ad_aarch64.cpp"
  }
}

void reinterpretD2XNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 154 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // If registers are the same, no register move is required - the
    // upper 64 bits of 'src' are expected to have been initialized
    // to zero.
    if (as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */) != as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */)) {
      __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    }
  
#line 29908 "ad_aarch64.cpp"
  }
}

void reinterpretX2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 174 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // Resize the vector from 128-bits to 64-bits. The higher 64-bits of
    // the "dst" register must be cleared to zero.
    __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 29928 "ad_aarch64.cpp"
  }
}

void vcvt4Bto4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 191 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8B);
  
#line 29944 "ad_aarch64.cpp"
  }
}

void vcvt8Bto8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 202 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8B);
  
#line 29960 "ad_aarch64.cpp"
  }
}

void vcvt4Sto4BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 213 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8H);
  
#line 29976 "ad_aarch64.cpp"
  }
}

void vcvt8Sto8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 224 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8H);
  
#line 29992 "ad_aarch64.cpp"
  }
}

void vcvt4Sto4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 235 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T4H);
  
#line 30008 "ad_aarch64.cpp"
  }
}

void vcvt4Ito4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 246 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T4S);
  
#line 30024 "ad_aarch64.cpp"
  }
}

void vcvt2Ito2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 257 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T2S);
  
#line 30040 "ad_aarch64.cpp"
  }
}

void vcvt2Lto2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 268 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T2D);
  
#line 30056 "ad_aarch64.cpp"
  }
}

void vcvt4Bto4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 281 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8B);
    __ sxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H);
  
#line 30073 "ad_aarch64.cpp"
  }
}

void vcvt4Ito4BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 295 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T4S);
    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H);
  
#line 30090 "ad_aarch64.cpp"
  }
}

void vcvt4Bto4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 310 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8B);
    __ sxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H);
    __ scvtfv(__ T4S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 30108 "ad_aarch64.cpp"
  }
}

void vcvt4Sto4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 325 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T4H);
    __ scvtfv(__ T4S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 30125 "ad_aarch64.cpp"
  }
}

void vcvt2Ito2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 339 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T2S);
    __ scvtfv(__ T2D, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 30142 "ad_aarch64.cpp"
  }
}

void vcvt2Ito2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 351 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ scvtfv(__ T2S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 30158 "ad_aarch64.cpp"
  }
}

void vcvt4Ito4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 362 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ scvtfv(__ T4S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 30174 "ad_aarch64.cpp"
  }
}

void vcvt2Lto2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 373 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ scvtfv(__ T2D, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 30190 "ad_aarch64.cpp"
  }
}

void vcvt2Fto2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 384 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fcvtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T2S);
  
#line 30206 "ad_aarch64.cpp"
  }
}

void vcvt2Dto2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 395 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fcvtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T2D);
  
#line 30222 "ad_aarch64.cpp"
  }
}

void vcvt2Lto2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 408 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ scvtfv(__ T2D, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ fcvtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D);
  
#line 30239 "ad_aarch64.cpp"
  }
}

void reduce_add8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 428 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T8B, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ smov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ B, 0);
    __ addw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ sxtb(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 30261 "ad_aarch64.cpp"
  }
}

void reduce_add16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 448 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T16B, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ smov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ B, 0);
    __ addw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ sxtb(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 30283 "ad_aarch64.cpp"
  }
}

void reduce_add4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 468 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T4H, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ smov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ H, 0);
    __ addw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ sxth(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 30305 "ad_aarch64.cpp"
  }
}

void reduce_add8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 488 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T8H, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ smov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ H, 0);
    __ addw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ sxth(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 30327 "ad_aarch64.cpp"
  }
}

void reduce_add2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 506 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addpd(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ D, 0);
    __ add(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 30348 "ad_aarch64.cpp"
  }
}

void reduce_mul8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// vtmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// itmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 531 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 1);
    __ mulv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), __ T8B,
            as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ ins(as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ H,
           as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), 0, 1);
    __ mulv(as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ T8B,
            as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */));
    __ umov(opnd_array(6)->as_Register(ra_,this,idx6)/* itmp */, as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ B, 0);
    __ mulw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(6)->as_Register(ra_,this,idx6)/* itmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ sxtb(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ umov(opnd_array(6)->as_Register(ra_,this,idx6)/* itmp */, as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ B, 1);
    __ mulw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(6)->as_Register(ra_,this,idx6)/* itmp */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxtb(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 30382 "ad_aarch64.cpp"
  }
}

void reduce_mul16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// vtmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// itmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 569 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), __ D,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 1);
    __ mulv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), __ T8B,
            as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ ins(as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ S,
           as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), 0, 1);
    __ mulv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), __ T8B,
            as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */));
    __ ins(as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ H,
           as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), 0, 1);
    __ mulv(as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ T8B,
            as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */));
    __ umov(opnd_array(6)->as_Register(ra_,this,idx6)/* itmp */, as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ B, 0);
    __ mulw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(6)->as_Register(ra_,this,idx6)/* itmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ sxtb(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ umov(opnd_array(6)->as_Register(ra_,this,idx6)/* itmp */, as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ B, 1);
    __ mulw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(6)->as_Register(ra_,this,idx6)/* itmp */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxtb(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 30420 "ad_aarch64.cpp"
  }
}

void reduce_mul4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// itmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 607 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 1);
    __ mulv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */), __ T4H,
            as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ umov(opnd_array(5)->as_Register(ra_,this,idx5)/* itmp */, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */), __ H, 0);
    __ mulw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(5)->as_Register(ra_,this,idx5)/* itmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ sxth(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ umov(opnd_array(5)->as_Register(ra_,this,idx5)/* itmp */, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */), __ H, 1);
    __ mulw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(5)->as_Register(ra_,this,idx5)/* itmp */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxth(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 30449 "ad_aarch64.cpp"
  }
}

void reduce_mul8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// vtmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// itmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 639 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), __ D,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 1);
    __ mulv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), __ T4H,
            as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ ins(as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ S,
           as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), 0, 1);
    __ mulv(as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ T4H,
            as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */));
    __ umov(opnd_array(6)->as_Register(ra_,this,idx6)/* itmp */, as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ H, 0);
    __ mulw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(6)->as_Register(ra_,this,idx6)/* itmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ sxth(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ umov(opnd_array(6)->as_Register(ra_,this,idx6)/* itmp */, as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ H, 1);
    __ mulw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(6)->as_Register(ra_,this,idx6)/* itmp */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxth(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 30483 "ad_aarch64.cpp"
  }
}

void reduce_mul2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 668 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ mul(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ mul(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
  
#line 30505 "ad_aarch64.cpp"
  }
}

void reduce_max8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 688 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ smaxv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T8B, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ smov(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ B, 0);
    __ cmpw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */));
    __ cselw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), Assembler::GT);
  
#line 30527 "ad_aarch64.cpp"
  }
}

void reduce_max16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 708 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ smaxv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T16B, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ smov(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ B, 0);
    __ cmpw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */));
    __ cselw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), Assembler::GT);
  
#line 30549 "ad_aarch64.cpp"
  }
}

void reduce_max4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 728 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ smaxv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T4H, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ smov(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ H, 0);
    __ cmpw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */));
    __ cselw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), Assembler::GT);
  
#line 30571 "ad_aarch64.cpp"
  }
}

void reduce_max8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 748 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ smaxv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T8H, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ smov(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ H, 0);
    __ cmpw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */));
    __ cselw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), Assembler::GT);
  
#line 30593 "ad_aarch64.cpp"
  }
}

void reduce_max4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 768 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ smaxv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T4S, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ umov(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S, 0);
    __ cmpw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */));
    __ cselw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), Assembler::GT);
  
#line 30615 "ad_aarch64.cpp"
  }
}

void reduce_min8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 788 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sminv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T8B, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ smov(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ B, 0);
    __ cmpw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */));
    __ cselw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), Assembler::LT);
  
#line 30637 "ad_aarch64.cpp"
  }
}

void reduce_min16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 808 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sminv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T16B, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ smov(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ B, 0);
    __ cmpw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */));
    __ cselw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), Assembler::LT);
  
#line 30659 "ad_aarch64.cpp"
  }
}

void reduce_min4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 828 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sminv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T4H, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ smov(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ H, 0);
    __ cmpw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */));
    __ cselw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), Assembler::LT);
  
#line 30681 "ad_aarch64.cpp"
  }
}

void reduce_min8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 848 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sminv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T8H, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ smov(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ H, 0);
    __ cmpw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */));
    __ cselw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), Assembler::LT);
  
#line 30703 "ad_aarch64.cpp"
  }
}

void reduce_min4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 868 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sminv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T4S, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ umov(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S, 0);
    __ cmpw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */));
    __ cselw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), Assembler::LT);
  
#line 30725 "ad_aarch64.cpp"
  }
}

void reduce_max2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 888 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ smaxp(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T2S, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ umov(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S, 0);
    __ cmpw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */));
    __ cselw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), Assembler::GT);
  
#line 30747 "ad_aarch64.cpp"
  }
}

void reduce_min2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 908 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sminp(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T2S, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ umov(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S, 0);
    __ cmpw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */));
    __ cselw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), Assembler::LT);
  
#line 30769 "ad_aarch64.cpp"
  }
}

void reduce_max2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 930 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ cmp(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
    __ csel(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), Assembler::GT);
    __ umov(as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ cmp(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
    __ csel(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), Assembler::GT);
  
#line 30793 "ad_aarch64.cpp"
  }
}

void reduce_min2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 954 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ cmp(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
    __ csel(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), Assembler::LT);
    __ umov(as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ cmp(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
    __ csel(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), Assembler::LT);
  
#line 30817 "ad_aarch64.cpp"
  }
}

void reduce_max2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// fsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 972 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmaxp(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S);
    __ fmaxs(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* fsrc */));
  
#line 30836 "ad_aarch64.cpp"
  }
}

void reduce_max4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// fsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 986 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmaxv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4S, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ fmaxs(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* fsrc */));
  
#line 30855 "ad_aarch64.cpp"
  }
}

void reduce_max2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1000 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmaxp(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D);
    __ fmaxd(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dsrc */));
  
#line 30874 "ad_aarch64.cpp"
  }
}

void reduce_min2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// fsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1014 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fminp(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S);
    __ fmins(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* fsrc */));
  
#line 30893 "ad_aarch64.cpp"
  }
}

void reduce_min4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// fsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1028 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fminv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4S, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ fmins(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* fsrc */));
  
#line 30912 "ad_aarch64.cpp"
  }
}

void reduce_min2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1042 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fminp(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D);
    __ fmind(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dsrc */));
  
#line 30931 "ad_aarch64.cpp"
  }
}

void reduce_and8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1063 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 1);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 16);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 8);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxtb(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 30956 "ad_aarch64.cpp"
  }
}

void reduce_orr8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1089 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 1);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 16);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 8);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxtb(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 30981 "ad_aarch64.cpp"
  }
}

void reduce_eor8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1115 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 1);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 16);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 8);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxtb(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 31006 "ad_aarch64.cpp"
  }
}

void reduce_and16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1142 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ andr(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ andr(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 32);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 16);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 8);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxtb(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 31032 "ad_aarch64.cpp"
  }
}

void reduce_orr16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1170 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ orr (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ orr (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 32);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 16);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 8);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxtb(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 31058 "ad_aarch64.cpp"
  }
}

void reduce_eor16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1198 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ eor (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ eor (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 32);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 16);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 8);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxtb(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 31084 "ad_aarch64.cpp"
  }
}

void reduce_and4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1224 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 1);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 16);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxth(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 31108 "ad_aarch64.cpp"
  }
}

void reduce_orr4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1248 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 1);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 16);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxth(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 31132 "ad_aarch64.cpp"
  }
}

void reduce_eor4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1272 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 1);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 16);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxth(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 31156 "ad_aarch64.cpp"
  }
}

void reduce_and8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1297 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ andr(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ andr(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 32);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 16);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxth(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 31181 "ad_aarch64.cpp"
  }
}

void reduce_orr8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1323 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ orr (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ orr (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 32);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 16);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxth(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 31206 "ad_aarch64.cpp"
  }
}

void reduce_eor8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1349 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ eor (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ eor (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 32);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 16);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxth(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 31231 "ad_aarch64.cpp"
  }
}

void reduce_and2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1372 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 0);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 1);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 31253 "ad_aarch64.cpp"
  }
}

void reduce_orr2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1392 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 0);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 1);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 31275 "ad_aarch64.cpp"
  }
}

void reduce_eor2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1412 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 0);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 1);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 31297 "ad_aarch64.cpp"
  }
}

void reduce_and4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1433 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ andr(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ andr(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 32);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 31320 "ad_aarch64.cpp"
  }
}

void reduce_orr4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1455 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ orr (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ orr (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 32);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 31343 "ad_aarch64.cpp"
  }
}

void reduce_eor4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1477 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ eor (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ eor (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 32);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 31366 "ad_aarch64.cpp"
  }
}

void reduce_and2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1498 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ andr(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ andr(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
  
#line 31388 "ad_aarch64.cpp"
  }
}

void reduce_orr2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1518 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ orr (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ orr (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
  
#line 31410 "ad_aarch64.cpp"
  }
}

void reduce_eor2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1538 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ eor (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ eor (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
  
#line 31432 "ad_aarch64.cpp"
  }
}

void insert8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1556 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    if (as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */) != as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */)) {
      __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    }
    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, opnd_array(3)->constant(), opnd_array(2)->as_Register(ra_,this,idx2)/* val */);
  
#line 31454 "ad_aarch64.cpp"
  }
}

void insert16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1573 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    if (as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */) != as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */)) {
      __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    }
    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B, opnd_array(3)->constant(), opnd_array(2)->as_Register(ra_,this,idx2)/* val */);
  
#line 31476 "ad_aarch64.cpp"
  }
}

void insert4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1590 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    if (as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */) != as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */)) {
      __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    }
    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H, opnd_array(3)->constant(), opnd_array(2)->as_Register(ra_,this,idx2)/* val */);
  
#line 31498 "ad_aarch64.cpp"
  }
}

void insert8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1607 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    if (as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */) != as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */)) {
      __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    }
    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, opnd_array(3)->constant(), opnd_array(2)->as_Register(ra_,this,idx2)/* val */);
  
#line 31520 "ad_aarch64.cpp"
  }
}

void insert2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1624 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    if (as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */) != as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */)) {
      __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    }
    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S, opnd_array(3)->constant(), opnd_array(2)->as_Register(ra_,this,idx2)/* val */);
  
#line 31542 "ad_aarch64.cpp"
  }
}

void insert4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1641 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    if (as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */) != as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */)) {
      __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    }
    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, opnd_array(3)->constant(), opnd_array(2)->as_Register(ra_,this,idx2)/* val */);
  
#line 31564 "ad_aarch64.cpp"
  }
}

void insert2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1658 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    if (as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */) != as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */)) {
      __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    }
    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, opnd_array(3)->constant(), opnd_array(2)->as_Register(ra_,this,idx2)/* val */);
  
#line 31586 "ad_aarch64.cpp"
  }
}

void insert2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1676 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ orr(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* val */), opnd_array(3)->constant(), 0);
  
#line 31608 "ad_aarch64.cpp"
  }
}

void insert4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1693 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ orr(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* val */), opnd_array(3)->constant(), 0);
  
#line 31630 "ad_aarch64.cpp"
  }
}

void insert2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1710 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ orr(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ D,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* val */), opnd_array(3)->constant(), 0);
  
#line 31652 "ad_aarch64.cpp"
  }
}

void extract8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1727 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ smov(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ B, opnd_array(2)->constant());
  
#line 31669 "ad_aarch64.cpp"
  }
}

void extract16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1739 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ smov(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ B, opnd_array(2)->constant());
  
#line 31686 "ad_aarch64.cpp"
  }
}

void extract4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1751 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ smov(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ H, opnd_array(2)->constant());
  
#line 31703 "ad_aarch64.cpp"
  }
}

void extract8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1763 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ smov(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ H, opnd_array(2)->constant());
  
#line 31720 "ad_aarch64.cpp"
  }
}

void extract2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1775 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ S, opnd_array(2)->constant());
  
#line 31737 "ad_aarch64.cpp"
  }
}

void extract4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1787 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ S, opnd_array(2)->constant());
  
#line 31754 "ad_aarch64.cpp"
  }
}

void extract2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1799 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ D, opnd_array(2)->constant());
  
#line 31771 "ad_aarch64.cpp"
  }
}

void extract2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1811 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ins(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), 0, opnd_array(2)->constant());
  
#line 31789 "ad_aarch64.cpp"
  }
}

void extract4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1824 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ins(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), 0, opnd_array(2)->constant());
  
#line 31807 "ad_aarch64.cpp"
  }
}

void extract2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1837 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ins(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), 0, opnd_array(2)->constant());
  
#line 31825 "ad_aarch64.cpp"
  }
}

void vcmpDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cond
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1852 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    BasicType bt = vector_element_basic_type(this);
    assert(type2aelembytes(bt) != 8, "not supported");
    __ neon_compare(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), bt, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
                    as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), (int)opnd_array(3)->constant(), /*isQ*/ false);
  
#line 31846 "ad_aarch64.cpp"
  }
}

void vcmpXNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cond
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1867 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    BasicType bt = vector_element_basic_type(this);
    __ neon_compare(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), bt, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
                    as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), (int)opnd_array(3)->constant(), /*isQ*/ true);
  
#line 31866 "ad_aarch64.cpp"
  }
}

void vmul2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1892 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), __ D, 0);
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), __ D, 0);
    __ mul(as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp2 */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp2 */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* tmp1 */));
    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, 0, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), __ D, 1);
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), __ D, 1);
    __ mul(as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp2 */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp2 */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* tmp1 */));
    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, 1, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */);
  
#line 31892 "ad_aarch64.cpp"
  }
}

void vnot2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1915 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 31910 "ad_aarch64.cpp"
  }
}

void vnot2I_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1915 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 31928 "ad_aarch64.cpp"
  }
}

void vnot2I_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1915 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 31946 "ad_aarch64.cpp"
  }
}

void vnot2I_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1915 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 31964 "ad_aarch64.cpp"
  }
}

void vnot2I_3Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1915 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 31982 "ad_aarch64.cpp"
  }
}

void vnot2I_4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1915 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 32000 "ad_aarch64.cpp"
  }
}

void vnot4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1930 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 32018 "ad_aarch64.cpp"
  }
}

void vnot4I_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1930 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 32036 "ad_aarch64.cpp"
  }
}

void vnot4I_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1930 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 32054 "ad_aarch64.cpp"
  }
}

void vnot4I_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1930 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 32072 "ad_aarch64.cpp"
  }
}

void vnot4I_3Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1930 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 32090 "ad_aarch64.cpp"
  }
}

void vnot4I_4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1930 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 32108 "ad_aarch64.cpp"
  }
}

void vnot2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1943 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 32126 "ad_aarch64.cpp"
  }
}

void vnot2L_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1943 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 32144 "ad_aarch64.cpp"
  }
}

void vand_not2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1960 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 32163 "ad_aarch64.cpp"
  }
}

void vand_not2I_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1960 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 32182 "ad_aarch64.cpp"
  }
}

void vand_not2I_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1960 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 32201 "ad_aarch64.cpp"
  }
}

void vand_not2I_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1960 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 32220 "ad_aarch64.cpp"
  }
}

void vand_not2I_3Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1960 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 32239 "ad_aarch64.cpp"
  }
}

void vand_not2I_5Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1960 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 32258 "ad_aarch64.cpp"
  }
}

void vand_not2I_4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1960 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 32277 "ad_aarch64.cpp"
  }
}

void vand_not2I_6Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1960 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 32296 "ad_aarch64.cpp"
  }
}

void vand_not2I_7Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1960 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 32315 "ad_aarch64.cpp"
  }
}

void vand_not2I_9Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1960 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 32334 "ad_aarch64.cpp"
  }
}

void vand_not2I_8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1960 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 32353 "ad_aarch64.cpp"
  }
}

void vand_not2I_10Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1960 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 32372 "ad_aarch64.cpp"
  }
}

void vand_not4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1975 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 32391 "ad_aarch64.cpp"
  }
}

void vand_not4I_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1975 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 32410 "ad_aarch64.cpp"
  }
}

void vand_not4I_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1975 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 32429 "ad_aarch64.cpp"
  }
}

void vand_not4I_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1975 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 32448 "ad_aarch64.cpp"
  }
}

void vand_not4I_3Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1975 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 32467 "ad_aarch64.cpp"
  }
}

void vand_not4I_5Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1975 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 32486 "ad_aarch64.cpp"
  }
}

void vand_not4I_4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1975 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 32505 "ad_aarch64.cpp"
  }
}

void vand_not4I_6Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1975 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 32524 "ad_aarch64.cpp"
  }
}

void vand_not4I_7Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1975 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 32543 "ad_aarch64.cpp"
  }
}

void vand_not4I_9Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1975 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 32562 "ad_aarch64.cpp"
  }
}

void vand_not4I_8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1975 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 32581 "ad_aarch64.cpp"
  }
}

void vand_not4I_10Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1975 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 32600 "ad_aarch64.cpp"
  }
}

void vand_not2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1988 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 32619 "ad_aarch64.cpp"
  }
}

void vand_not2L_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1988 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 32638 "ad_aarch64.cpp"
  }
}

void vand_not2L_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1988 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 32657 "ad_aarch64.cpp"
  }
}

void vand_not2L_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1988 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 32676 "ad_aarch64.cpp"
  }
}

void vmax8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2004 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ maxv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 32695 "ad_aarch64.cpp"
  }
}

void vmax16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2018 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ maxv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 32714 "ad_aarch64.cpp"
  }
}

void vmax4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2032 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ maxv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 32733 "ad_aarch64.cpp"
  }
}

void vmax8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2046 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ maxv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 32752 "ad_aarch64.cpp"
  }
}

void vmax2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2060 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ maxv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 32771 "ad_aarch64.cpp"
  }
}

void vmax4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2074 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ maxv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 32790 "ad_aarch64.cpp"
  }
}

void vmin8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2089 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ minv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 32809 "ad_aarch64.cpp"
  }
}

void vmin16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2103 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ minv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 32828 "ad_aarch64.cpp"
  }
}

void vmin4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2117 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ minv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 32847 "ad_aarch64.cpp"
  }
}

void vmin8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2131 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ minv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 32866 "ad_aarch64.cpp"
  }
}

void vmin2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2145 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ minv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 32885 "ad_aarch64.cpp"
  }
}

void vmin4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2159 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ minv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 32904 "ad_aarch64.cpp"
  }
}

void vmax2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2176 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ cmgt(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ bsl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 32925 "ad_aarch64.cpp"
  }
}

void vmin2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2193 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ cmgt(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ bsl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 32946 "ad_aarch64.cpp"
  }
}

void vbsl8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2210 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bsl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 32965 "ad_aarch64.cpp"
  }
}

void vbsl16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2223 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bsl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 32984 "ad_aarch64.cpp"
  }
}

void loadmask8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2238 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 33000 "ad_aarch64.cpp"
  }
}

void loadmask16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2250 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 33016 "ad_aarch64.cpp"
  }
}

void storemask8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// size
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2262 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 33033 "ad_aarch64.cpp"
  }
}

void storemask16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// size
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2274 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 33050 "ad_aarch64.cpp"
  }
}

void loadmask4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2287 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8B);
    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 33067 "ad_aarch64.cpp"
  }
}

void loadmask8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2301 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8B);
    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 33084 "ad_aarch64.cpp"
  }
}

void storemask4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// size
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2315 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8H);
    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 33102 "ad_aarch64.cpp"
  }
}

void storemask8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// size
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2329 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8H);
    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 33120 "ad_aarch64.cpp"
  }
}

void loadmask2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2346 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8B);
    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H);
    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 33138 "ad_aarch64.cpp"
  }
}

void loadmask4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2364 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8B);
    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H);
    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 33156 "ad_aarch64.cpp"
  }
}

void storemask2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// size
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2380 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T4S);
    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H);
    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 33175 "ad_aarch64.cpp"
  }
}

void storemask4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// size
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2396 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T4S);
    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H);
    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 33194 "ad_aarch64.cpp"
  }
}

void loadmask2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2415 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8B);
    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H);
    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S);
    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 33213 "ad_aarch64.cpp"
  }
}

void storemask2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// size
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2433 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T2D);
    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S);
    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H);
    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 33233 "ad_aarch64.cpp"
  }
}

void vmaskcastDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2452 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // empty
  
#line 33249 "ad_aarch64.cpp"
  }
}

void vmaskcastXNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2466 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // empty
  
#line 33265 "ad_aarch64.cpp"
  }
}

void loadcon8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2482 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ lea(rscratch1, ExternalAddress(StubRoutines::aarch64::vector_iota_indices()));
    __ ldrd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), rscratch1);
  
#line 33282 "ad_aarch64.cpp"
  }
}

void loadcon16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2495 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ lea(rscratch1, ExternalAddress(StubRoutines::aarch64::vector_iota_indices()));
    __ ldrq(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), rscratch1);
  
#line 33299 "ad_aarch64.cpp"
  }
}

void loadshuffle8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2511 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 33316 "ad_aarch64.cpp"
  }
}

void loadshuffle16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2525 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 33333 "ad_aarch64.cpp"
  }
}

void loadshuffle4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2539 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8B);
  
#line 33349 "ad_aarch64.cpp"
  }
}

void loadshuffle8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2552 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8B);
  
#line 33365 "ad_aarch64.cpp"
  }
}

void loadshuffle4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2567 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8B);
    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H);
  
#line 33382 "ad_aarch64.cpp"
  }
}

void rearrange8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shuffle
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2603 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ tbl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), 1, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shuffle */));
  
#line 33401 "ad_aarch64.cpp"
  }
}

void rearrange16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shuffle
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2618 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ tbl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), 1, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shuffle */));
  
#line 33420 "ad_aarch64.cpp"
  }
}

void rearrange4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shuffle
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp0
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2637 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mov(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp0 */), __ T8B, 0x02);
    __ mov(as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp1 */), __ T4H, 0x0100);
    __ mulv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shuffle */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp0 */));
    __ addv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp1 */));
    __ tbl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), 1, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */));
  
#line 33447 "ad_aarch64.cpp"
  }
}

void rearrange8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shuffle
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp0
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2662 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mov(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp0 */), __ T16B, 0x02);
    __ mov(as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp1 */), __ T8H, 0x0100);
    __ mulv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shuffle */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp0 */));
    __ addv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp1 */));
    __ tbl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), 1, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */));
  
#line 33474 "ad_aarch64.cpp"
  }
}

void rearrange4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shuffle
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp0
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2688 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mov(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp0 */), __ T16B, 0x04);
    __ mov(as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp1 */), __ T4S, 0x03020100);
    __ mulv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shuffle */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp0 */));
    __ addv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp1 */));
    __ tbl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), 1, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */));
  
#line 33501 "ad_aarch64.cpp"
  }
}

void anytrue_in_mask8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2713 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // No need to use src2.
    __ addv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T8B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
    __ umov(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ B, 0);
    __ cmpw(opnd_array(0)->as_Register(ra_,this)/* dst */, zr);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::NE);
  
#line 33523 "ad_aarch64.cpp"
  }
}

void anytrue_in_mask16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2733 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // No need to use src2.
    __ addv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
    __ umov(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ B, 0);
    __ cmpw(opnd_array(0)->as_Register(ra_,this)/* dst */, zr);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::NE);
  
#line 33545 "ad_aarch64.cpp"
  }
}

void alltrue_in_mask8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2753 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // No need to use src2.
    __ uminv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T8B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
    __ umov(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ B, 0);
    __ cmpw(opnd_array(0)->as_Register(ra_,this)/* dst */, 0xff);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::EQ);
  
#line 33567 "ad_aarch64.cpp"
  }
}

void alltrue_in_mask16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2773 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // No need to use src2.
    __ uminv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
    __ umov(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ B, 0);
    __ cmpw(opnd_array(0)->as_Register(ra_,this)/* dst */, 0xff);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::EQ);
  
#line 33589 "ad_aarch64.cpp"
  }
}

void vabs8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2791 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ absr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 33605 "ad_aarch64.cpp"
  }
}

void vabs16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2803 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ absr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 33621 "ad_aarch64.cpp"
  }
}

void vabs4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2815 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ absr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 33637 "ad_aarch64.cpp"
  }
}

void vabs8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2827 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ absr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 33653 "ad_aarch64.cpp"
  }
}

void vabs2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2839 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ absr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 33669 "ad_aarch64.cpp"
  }
}

void vabs4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2851 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ absr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 33685 "ad_aarch64.cpp"
  }
}

void vabs2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2863 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ absr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 33701 "ad_aarch64.cpp"
  }
}

void vabs2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2875 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fabs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 33717 "ad_aarch64.cpp"
  }
}

void vabs4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2887 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fabs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 33733 "ad_aarch64.cpp"
  }
}

void vabs2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2899 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fabs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 33749 "ad_aarch64.cpp"
  }
}

void vabd2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2913 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fabd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 33767 "ad_aarch64.cpp"
  }
}

void vabd4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2926 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fabd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 33785 "ad_aarch64.cpp"
  }
}

void vabd2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2939 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fabd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 33803 "ad_aarch64.cpp"
  }
}

void replicate8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2953 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 33819 "ad_aarch64.cpp"
  }
}

void replicate16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2965 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 33835 "ad_aarch64.cpp"
  }
}

void replicate8B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2978 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, opnd_array(1)->constant()& 0xff);
  
#line 33851 "ad_aarch64.cpp"
  }
}

void replicate16B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2990 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B, opnd_array(1)->constant()& 0xff);
  
#line 33867 "ad_aarch64.cpp"
  }
}

void replicate4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3003 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 33883 "ad_aarch64.cpp"
  }
}

void replicate8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3015 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 33899 "ad_aarch64.cpp"
  }
}

void replicate4S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3028 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H, opnd_array(1)->constant()& 0xffff);
  
#line 33915 "ad_aarch64.cpp"
  }
}

void replicate8S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3040 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, opnd_array(1)->constant()& 0xffff);
  
#line 33931 "ad_aarch64.cpp"
  }
}

void replicate2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3052 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 33947 "ad_aarch64.cpp"
  }
}

void replicate4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3064 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 33963 "ad_aarch64.cpp"
  }
}

void replicate2I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3076 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S, opnd_array(1)->constant());
  
#line 33979 "ad_aarch64.cpp"
  }
}

void replicate4I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3088 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, opnd_array(1)->constant());
  
#line 33995 "ad_aarch64.cpp"
  }
}

void replicate2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3100 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 34011 "ad_aarch64.cpp"
  }
}

void replicate2L_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3112 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
           as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 34029 "ad_aarch64.cpp"
  }
}

void replicate2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3126 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 34046 "ad_aarch64.cpp"
  }
}

void replicate4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3139 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 34063 "ad_aarch64.cpp"
  }
}

void replicate2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3152 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 34080 "ad_aarch64.cpp"
  }
}

void reduce_add2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// vtmp
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// itmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3171 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addpv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* vtmp */), __ T2S,
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* itmp */, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* vtmp */), __ S, 0);
    __ addw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* itmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
  
#line 34102 "ad_aarch64.cpp"
  }
}

void reduce_add4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// vtmp
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// itmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3190 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* vtmp */), __ T4S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* itmp */, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* vtmp */), __ S, 0);
    __ addw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* itmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
  
#line 34124 "ad_aarch64.cpp"
  }
}

void reduce_mul2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3210 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 0);
    __ mul(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 1);
    __ mul(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 34146 "ad_aarch64.cpp"
  }
}

void reduce_mul4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// itmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3232 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */), __ D,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 1);
    __ mulv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */), __ T2S,
            as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ umov(opnd_array(5)->as_Register(ra_,this,idx5)/* itmp */, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */), __ S, 0);
    __ mul(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(5)->as_Register(ra_,this,idx5)/* itmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ umov(opnd_array(5)->as_Register(ra_,this,idx5)/* itmp */, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */), __ S, 1);
    __ mul(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(5)->as_Register(ra_,this,idx5)/* itmp */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 34173 "ad_aarch64.cpp"
  }
}

void reduce_add2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// fsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3254 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fadds(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* fsrc */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 1);
    __ fadds(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 34197 "ad_aarch64.cpp"
  }
}

void reduce_add4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// fsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3278 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fadds(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* fsrc */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 1);
    __ fadds(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 2);
    __ fadds(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 3);
    __ fadds(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 34229 "ad_aarch64.cpp"
  }
}

void reduce_mul2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// fsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3306 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmuls(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* fsrc */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 1);
    __ fmuls(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 34253 "ad_aarch64.cpp"
  }
}

void reduce_mul4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// fsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3330 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmuls(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* fsrc */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 1);
    __ fmuls(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 2);
    __ fmuls(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 3);
    __ fmuls(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 34285 "ad_aarch64.cpp"
  }
}

void reduce_add2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3358 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ faddd(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dsrc */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ D,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 1);
    __ faddd(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 34309 "ad_aarch64.cpp"
  }
}

void reduce_mul2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3378 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmuld(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dsrc */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ D,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 1);
    __ fmuld(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 34333 "ad_aarch64.cpp"
  }
}

void vadd8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3400 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34352 "ad_aarch64.cpp"
  }
}

void vadd16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3414 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34371 "ad_aarch64.cpp"
  }
}

void vadd4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3429 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34390 "ad_aarch64.cpp"
  }
}

void vadd8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3443 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34409 "ad_aarch64.cpp"
  }
}

void vadd2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3457 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34428 "ad_aarch64.cpp"
  }
}

void vadd4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3471 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34447 "ad_aarch64.cpp"
  }
}

void vadd2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3485 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34466 "ad_aarch64.cpp"
  }
}

void vadd2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3499 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fadd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34485 "ad_aarch64.cpp"
  }
}

void vadd4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3513 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fadd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34504 "ad_aarch64.cpp"
  }
}

void vadd2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3526 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fadd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34523 "ad_aarch64.cpp"
  }
}

void vsub8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3543 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ subv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34542 "ad_aarch64.cpp"
  }
}

void vsub16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3557 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ subv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34561 "ad_aarch64.cpp"
  }
}

void vsub4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3572 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ subv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34580 "ad_aarch64.cpp"
  }
}

void vsub8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3586 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ subv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34599 "ad_aarch64.cpp"
  }
}

void vsub2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3600 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ subv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34618 "ad_aarch64.cpp"
  }
}

void vsub4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3614 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ subv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34637 "ad_aarch64.cpp"
  }
}

void vsub2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3628 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ subv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34656 "ad_aarch64.cpp"
  }
}

void vsub2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3642 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fsub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34675 "ad_aarch64.cpp"
  }
}

void vsub4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3656 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fsub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34694 "ad_aarch64.cpp"
  }
}

void vsub2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3670 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fsub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34713 "ad_aarch64.cpp"
  }
}

void vmul8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3687 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mulv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34732 "ad_aarch64.cpp"
  }
}

void vmul16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3701 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mulv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34751 "ad_aarch64.cpp"
  }
}

void vmul4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3716 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mulv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34770 "ad_aarch64.cpp"
  }
}

void vmul8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3730 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mulv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34789 "ad_aarch64.cpp"
  }
}

void vmul2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3744 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mulv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34808 "ad_aarch64.cpp"
  }
}

void vmul4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3758 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mulv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34827 "ad_aarch64.cpp"
  }
}

void vmul2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3772 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmul(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34846 "ad_aarch64.cpp"
  }
}

void vmul4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3786 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmul(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34865 "ad_aarch64.cpp"
  }
}

void vmul2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3800 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmul(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34884 "ad_aarch64.cpp"
  }
}

void vmla4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3817 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mlav(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 34904 "ad_aarch64.cpp"
  }
}

void vmla4S_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3817 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mlav(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34924 "ad_aarch64.cpp"
  }
}

void vmla8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3831 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mlav(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 34944 "ad_aarch64.cpp"
  }
}

void vmla8S_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3831 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mlav(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34964 "ad_aarch64.cpp"
  }
}

void vmla2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3845 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mlav(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 34984 "ad_aarch64.cpp"
  }
}

void vmla2I_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3845 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mlav(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 35004 "ad_aarch64.cpp"
  }
}

void vmla4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3859 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mlav(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 35024 "ad_aarch64.cpp"
  }
}

void vmla4I_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3859 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mlav(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 35044 "ad_aarch64.cpp"
  }
}

void vmla2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3874 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 35064 "ad_aarch64.cpp"
  }
}

void vmla4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3889 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 35084 "ad_aarch64.cpp"
  }
}

void vmla2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3904 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 35104 "ad_aarch64.cpp"
  }
}

void vmls4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3920 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mlsv(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 35124 "ad_aarch64.cpp"
  }
}

void vmls8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3933 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mlsv(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 35144 "ad_aarch64.cpp"
  }
}

void vmls2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3946 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mlsv(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 35164 "ad_aarch64.cpp"
  }
}

void vmls4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3959 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mlsv(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 35184 "ad_aarch64.cpp"
  }
}

void vmls2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3974 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 35204 "ad_aarch64.cpp"
  }
}

void vmls2F_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3974 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 35224 "ad_aarch64.cpp"
  }
}

void vmls4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3989 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 35244 "ad_aarch64.cpp"
  }
}

void vmls4F_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3989 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 35264 "ad_aarch64.cpp"
  }
}

void vmls2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4004 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 35284 "ad_aarch64.cpp"
  }
}

void vmls2D_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4004 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 35304 "ad_aarch64.cpp"
  }
}

void vmuladdS2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4022 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ smullv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T4H,
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ smullv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8H,
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ addpv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4S,
             as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */));
  
#line 35331 "ad_aarch64.cpp"
  }
}

void vdiv2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4044 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fdiv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 35350 "ad_aarch64.cpp"
  }
}

void vdiv4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4058 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fdiv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 35369 "ad_aarch64.cpp"
  }
}

void vdiv2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4072 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fdiv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 35388 "ad_aarch64.cpp"
  }
}

void vsqrt2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4087 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fsqrt(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 35404 "ad_aarch64.cpp"
  }
}

void vsqrt4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4098 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fsqrt(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 35420 "ad_aarch64.cpp"
  }
}

void vsqrt2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4109 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fsqrt(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 35436 "ad_aarch64.cpp"
  }
}

void vneg2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4123 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fneg(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 35453 "ad_aarch64.cpp"
  }
}

void vneg4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4136 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fneg(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 35470 "ad_aarch64.cpp"
  }
}

void vneg2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4149 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fneg(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 35487 "ad_aarch64.cpp"
  }
}

void vand8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4165 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ andr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 35506 "ad_aarch64.cpp"
  }
}

void vand16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4179 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ andr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 35525 "ad_aarch64.cpp"
  }
}

void vor8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4196 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 35544 "ad_aarch64.cpp"
  }
}

void vor16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4210 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 35563 "ad_aarch64.cpp"
  }
}

void vxor8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4227 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 35582 "ad_aarch64.cpp"
  }
}

void vxor16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4241 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 35601 "ad_aarch64.cpp"
  }
}

void vshiftcnt8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4257 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 35617 "ad_aarch64.cpp"
  }
}

void vshiftcnt8B_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4257 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 35633 "ad_aarch64.cpp"
  }
}

void vshiftcnt16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4268 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 35649 "ad_aarch64.cpp"
  }
}

void vshiftcnt16B_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4268 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 35665 "ad_aarch64.cpp"
  }
}

void vsll8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4280 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 35684 "ad_aarch64.cpp"
  }
}

void vsll16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4293 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 35703 "ad_aarch64.cpp"
  }
}

void vsra8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4330 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 35725 "ad_aarch64.cpp"
  }
}

void vsra16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4347 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 35747 "ad_aarch64.cpp"
  }
}

void vsrl8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4365 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ ushl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 35769 "ad_aarch64.cpp"
  }
}

void vsrl16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4382 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ ushl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 35791 "ad_aarch64.cpp"
  }
}

void vsll8B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4398 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 8) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ shl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 35816 "ad_aarch64.cpp"
  }
}

void vsll16B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4417 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 8) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ shl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 35841 "ad_aarch64.cpp"
  }
}

void vsra8B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4437 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 8) sh = 7;
    __ sshr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
  
#line 35861 "ad_aarch64.cpp"
  }
}

void vsra16B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4451 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 8) sh = 7;
    __ sshr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
  
#line 35881 "ad_aarch64.cpp"
  }
}

void vsrl8B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4466 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 8) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ ushr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 35906 "ad_aarch64.cpp"
  }
}

void vsrl16B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4485 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 8) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ ushr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 35931 "ad_aarch64.cpp"
  }
}

void vsll4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4505 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 35950 "ad_aarch64.cpp"
  }
}

void vsll8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4518 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 35969 "ad_aarch64.cpp"
  }
}

void vsra4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4534 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 35991 "ad_aarch64.cpp"
  }
}

void vsra8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4551 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 36013 "ad_aarch64.cpp"
  }
}

void vsrl4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4569 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ ushl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 36035 "ad_aarch64.cpp"
  }
}

void vsrl8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4586 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ ushl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 36057 "ad_aarch64.cpp"
  }
}

void vsll4S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4602 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 16) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ shl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 36082 "ad_aarch64.cpp"
  }
}

void vsll8S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4621 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 16) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ shl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 36107 "ad_aarch64.cpp"
  }
}

void vsra4S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4641 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 16) sh = 15;
    __ sshr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
  
#line 36127 "ad_aarch64.cpp"
  }
}

void vsra8S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4655 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 16) sh = 15;
    __ sshr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
  
#line 36147 "ad_aarch64.cpp"
  }
}

void vsrl4S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4670 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 16) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ ushr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 36172 "ad_aarch64.cpp"
  }
}

void vsrl8S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4689 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 16) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ ushr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 36197 "ad_aarch64.cpp"
  }
}

void vsll2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4708 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 36216 "ad_aarch64.cpp"
  }
}

void vsll4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4721 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 36235 "ad_aarch64.cpp"
  }
}

void vsra2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4736 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 36257 "ad_aarch64.cpp"
  }
}

void vsra4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4753 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 36279 "ad_aarch64.cpp"
  }
}

void vsrl2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4770 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ ushl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 36301 "ad_aarch64.cpp"
  }
}

void vsrl4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4787 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ ushl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 36323 "ad_aarch64.cpp"
  }
}

void vsll2I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4802 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ shl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           (int)opnd_array(2)->constant());
  
#line 36342 "ad_aarch64.cpp"
  }
}

void vsll4I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4815 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ shl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           (int)opnd_array(2)->constant());
  
#line 36361 "ad_aarch64.cpp"
  }
}

void vsra2I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4828 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sshr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 36380 "ad_aarch64.cpp"
  }
}

void vsra4I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4841 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sshr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 36399 "ad_aarch64.cpp"
  }
}

void vsrl2I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4854 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ushr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 36418 "ad_aarch64.cpp"
  }
}

void vsrl4I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4867 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ushr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 36437 "ad_aarch64.cpp"
  }
}

void vsll2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4880 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 36456 "ad_aarch64.cpp"
  }
}

void vsra2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4895 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 36478 "ad_aarch64.cpp"
  }
}

void vsrl2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4912 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ ushl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 36500 "ad_aarch64.cpp"
  }
}

void vsll2L_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4927 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ shl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           (int)opnd_array(2)->constant());
  
#line 36519 "ad_aarch64.cpp"
  }
}

void vsra2L_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4940 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sshr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 36538 "ad_aarch64.cpp"
  }
}

void vsrl2L_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4953 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ushr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 36557 "ad_aarch64.cpp"
  }
}

void vsraa8B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4966 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(3)->constant();
    if (sh >= 8) sh = 7;
    __ ssra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), sh);
  
#line 36578 "ad_aarch64.cpp"
  }
}

void vsraa8B_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4966 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 8) sh = 7;
    __ ssra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
  
#line 36599 "ad_aarch64.cpp"
  }
}

void vsraa16B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4980 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(3)->constant();
    if (sh >= 8) sh = 7;
    __ ssra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), sh);
  
#line 36620 "ad_aarch64.cpp"
  }
}

void vsraa16B_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4980 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 8) sh = 7;
    __ ssra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
  
#line 36641 "ad_aarch64.cpp"
  }
}

void vsraa4S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4994 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(3)->constant();
    if (sh >= 16) sh = 15;
    __ ssra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4H,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), sh);
  
#line 36662 "ad_aarch64.cpp"
  }
}

void vsraa4S_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4994 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 16) sh = 15;
    __ ssra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4H,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
  
#line 36683 "ad_aarch64.cpp"
  }
}

void vsraa8S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5008 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(3)->constant();
    if (sh >= 16) sh = 15;
    __ ssra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T8H,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), sh);
  
#line 36704 "ad_aarch64.cpp"
  }
}

void vsraa8S_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5008 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 16) sh = 15;
    __ ssra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8H,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
  
#line 36725 "ad_aarch64.cpp"
  }
}

void vsraa2I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5022 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ssra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */),
            (int)opnd_array(3)->constant());
  
#line 36745 "ad_aarch64.cpp"
  }
}

void vsraa2I_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5022 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ssra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 36765 "ad_aarch64.cpp"
  }
}

void vsraa4I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5035 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ssra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */),
            (int)opnd_array(3)->constant());
  
#line 36785 "ad_aarch64.cpp"
  }
}

void vsraa4I_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5035 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ssra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 36805 "ad_aarch64.cpp"
  }
}

void vsraa2L_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5048 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ssra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */),
            (int)opnd_array(3)->constant());
  
#line 36825 "ad_aarch64.cpp"
  }
}

void vsraa2L_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5048 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ssra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 36845 "ad_aarch64.cpp"
  }
}

void vsrla8B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5061 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(3)->constant();
    if (sh < 8) {
      __ usra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), sh);
    }
  
#line 36867 "ad_aarch64.cpp"
  }
}

void vsrla8B_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5061 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh < 8) {
      __ usra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 36889 "ad_aarch64.cpp"
  }
}

void vsrla16B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5076 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(3)->constant();
    if (sh < 8) {
      __ usra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), sh);
    }
  
#line 36911 "ad_aarch64.cpp"
  }
}

void vsrla16B_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5076 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh < 8) {
      __ usra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 36933 "ad_aarch64.cpp"
  }
}

void vsrla4S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5091 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(3)->constant();
    if (sh < 16) {
      __ usra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4H,
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), sh);
    }
  
#line 36955 "ad_aarch64.cpp"
  }
}

void vsrla4S_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5091 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh < 16) {
      __ usra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4H,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 36977 "ad_aarch64.cpp"
  }
}

void vsrla8S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5106 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(3)->constant();
    if (sh < 16) {
      __ usra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T8H,
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), sh);
    }
  
#line 36999 "ad_aarch64.cpp"
  }
}

void vsrla8S_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5106 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh < 16) {
      __ usra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8H,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 37021 "ad_aarch64.cpp"
  }
}

void vsrla2I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5121 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ usra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */),
            (int)opnd_array(3)->constant());
  
#line 37041 "ad_aarch64.cpp"
  }
}

void vsrla2I_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5121 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ usra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 37061 "ad_aarch64.cpp"
  }
}

void vsrla4I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5134 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ usra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */),
            (int)opnd_array(3)->constant());
  
#line 37081 "ad_aarch64.cpp"
  }
}

void vsrla4I_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5134 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ usra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 37101 "ad_aarch64.cpp"
  }
}

void vsrla2L_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5147 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ usra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */),
            (int)opnd_array(3)->constant());
  
#line 37121 "ad_aarch64.cpp"
  }
}

void vsrla2L_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5147 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ usra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 37141 "ad_aarch64.cpp"
  }
}

void vmax2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5161 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmax(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37160 "ad_aarch64.cpp"
  }
}

void vmax4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5175 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmax(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37179 "ad_aarch64.cpp"
  }
}

void vmax2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5189 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmax(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37198 "ad_aarch64.cpp"
  }
}

void vmin2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5203 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmin(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37217 "ad_aarch64.cpp"
  }
}

void vmin4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5217 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmin(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37236 "ad_aarch64.cpp"
  }
}

void vmin2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5231 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmin(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37255 "ad_aarch64.cpp"
  }
}

void vround2D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rmode
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5243 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    switch (opnd_array(2)->constant()) {
      case RoundDoubleModeNode::rmode_rint:
        __ frintn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
                  as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
        break;
      case RoundDoubleModeNode::rmode_floor:
        __ frintm(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
                  as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
        break;
      case RoundDoubleModeNode::rmode_ceil:
        __ frintp(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
                  as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
        break;
    }
  
#line 37285 "ad_aarch64.cpp"
  }
}

void vpopcount4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5270 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ cnt(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ uaddlp(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
              as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
    __ uaddlp(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
              as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 37306 "ad_aarch64.cpp"
  }
}

void vpopcount2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5289 "src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ cnt(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ uaddlp(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
              as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
    __ uaddlp(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
              as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 37327 "ad_aarch64.cpp"
  }
}

void loadVNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    C2_MacroAssembler _masm(&cbuf);

#line 228 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStoreA_predicate(C2_MacroAssembler(&cbuf), false, dst_reg, ptrue,
                         vector_element_basic_type(this), opnd_array(1)->opcode(),
                         as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 37346 "ad_aarch64.cpp"
  }
}

void storeVNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 242 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStoreA_predicate(C2_MacroAssembler(&cbuf), true, src_reg, ptrue,
                         vector_element_basic_type(this, opnd_array(2)), opnd_array(1)->opcode(),
                         as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 37366 "ad_aarch64.cpp"
  }
}

void vabsBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 259 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_abs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 37383 "ad_aarch64.cpp"
  }
}

void vabsSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 272 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_abs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 37400 "ad_aarch64.cpp"
  }
}

void vabsINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 285 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_abs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 37417 "ad_aarch64.cpp"
  }
}

void vabsLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 298 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_abs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 37434 "ad_aarch64.cpp"
  }
}

void vabsFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 311 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fabs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 37451 "ad_aarch64.cpp"
  }
}

void vabsDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 324 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fabs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 37468 "ad_aarch64.cpp"
  }
}

void vaddBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 338 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_add(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37487 "ad_aarch64.cpp"
  }
}

void vaddSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 351 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_add(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37506 "ad_aarch64.cpp"
  }
}

void vaddINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 364 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_add(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37525 "ad_aarch64.cpp"
  }
}

void vaddLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 377 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_add(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37544 "ad_aarch64.cpp"
  }
}

void vaddFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 390 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fadd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37563 "ad_aarch64.cpp"
  }
}

void vaddDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 403 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fadd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37582 "ad_aarch64.cpp"
  }
}

void vandNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 418 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_and(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37601 "ad_aarch64.cpp"
  }
}

void vorNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 433 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37620 "ad_aarch64.cpp"
  }
}

void vxorNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 448 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37639 "ad_aarch64.cpp"
  }
}

void vnotINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 465 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_not(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
               ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 37657 "ad_aarch64.cpp"
  }
}

void vnotI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 465 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_not(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
               ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 37675 "ad_aarch64.cpp"
  }
}

void vnotI_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 465 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_not(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
               ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 37693 "ad_aarch64.cpp"
  }
}

void vnotI_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 465 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_not(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
               ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 37711 "ad_aarch64.cpp"
  }
}

void vnotI_3Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 465 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_not(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
               ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 37729 "ad_aarch64.cpp"
  }
}

void vnotI_4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 465 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_not(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
               ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 37747 "ad_aarch64.cpp"
  }
}

void vnotLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 477 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_not(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
               ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 37765 "ad_aarch64.cpp"
  }
}

void vnotL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 477 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_not(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
               ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 37783 "ad_aarch64.cpp"
  }
}

void vand_notINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 494 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37803 "ad_aarch64.cpp"
  }
}

void vand_notI_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 494 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 37823 "ad_aarch64.cpp"
  }
}

void vand_notI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 494 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 37843 "ad_aarch64.cpp"
  }
}

void vand_notI_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 494 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37863 "ad_aarch64.cpp"
  }
}

void vand_notI_3Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 494 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37883 "ad_aarch64.cpp"
  }
}

void vand_notI_5Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 494 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 37903 "ad_aarch64.cpp"
  }
}

void vand_notI_4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 494 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 37923 "ad_aarch64.cpp"
  }
}

void vand_notI_6Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 494 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37943 "ad_aarch64.cpp"
  }
}

void vand_notI_7Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 494 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37963 "ad_aarch64.cpp"
  }
}

void vand_notI_9Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 494 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 37983 "ad_aarch64.cpp"
  }
}

void vand_notI_8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 494 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 38003 "ad_aarch64.cpp"
  }
}

void vand_notI_10Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 494 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 38023 "ad_aarch64.cpp"
  }
}

void vand_notLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 507 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 38043 "ad_aarch64.cpp"
  }
}

void vand_notL_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 507 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 38063 "ad_aarch64.cpp"
  }
}

void vand_notL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 507 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 38083 "ad_aarch64.cpp"
  }
}

void vand_notL_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 507 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 38103 "ad_aarch64.cpp"
  }
}

void vdivFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 523 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fdiv(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 38121 "ad_aarch64.cpp"
  }
}

void vdivDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 535 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fdiv(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 38139 "ad_aarch64.cpp"
  }
}

void vminNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 549 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = elemType_to_regVariant(bt);
    if (is_floating_point_type(bt)) {
      __ sve_fmin(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), size,
                  ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    } else {
      assert(is_integral_type(bt), "Unsupported type");
      __ sve_smin(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), size,
                  ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    }
  
#line 38165 "ad_aarch64.cpp"
  }
}

void vmaxNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 569 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = elemType_to_regVariant(bt);
    if (is_floating_point_type(bt)) {
      __ sve_fmax(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), size,
                  ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    } else {
      assert(is_integral_type(bt), "Unsupported type");
      __ sve_smax(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), size,
                  ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    }
  
#line 38191 "ad_aarch64.cpp"
  }
}

void vfmlaFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 592 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 38210 "ad_aarch64.cpp"
  }
}

void vfmlaDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 605 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 38229 "ad_aarch64.cpp"
  }
}

void vfmlsFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 622 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 38248 "ad_aarch64.cpp"
  }
}

void vfmlsF_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 622 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 38267 "ad_aarch64.cpp"
  }
}

void vfmlsDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 637 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 38286 "ad_aarch64.cpp"
  }
}

void vfmlsD_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 637 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 38305 "ad_aarch64.cpp"
  }
}

void vfnmlaFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 654 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fnmla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 38324 "ad_aarch64.cpp"
  }
}

void vfnmlaF_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 654 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fnmla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 38343 "ad_aarch64.cpp"
  }
}

void vfnmlaDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 669 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fnmla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 38362 "ad_aarch64.cpp"
  }
}

void vfnmlaD_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 669 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fnmla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 38381 "ad_aarch64.cpp"
  }
}

void vfnmlsFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 684 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fnmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 38400 "ad_aarch64.cpp"
  }
}

void vfnmlsDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 697 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fnmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 38419 "ad_aarch64.cpp"
  }
}

void vmlaBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 713 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ B,
      ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 38438 "ad_aarch64.cpp"
  }
}

void vmlaB_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst_src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 713 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mla(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst_src1 */), __ B,
      ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src3 */));
  
#line 38457 "ad_aarch64.cpp"
  }
}

void vmlaSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 727 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ H,
      ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 38476 "ad_aarch64.cpp"
  }
}

void vmlaS_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst_src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 727 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mla(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst_src1 */), __ H,
      ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src3 */));
  
#line 38495 "ad_aarch64.cpp"
  }
}

void vmlaINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 741 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
      ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 38514 "ad_aarch64.cpp"
  }
}

void vmlaI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst_src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 741 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mla(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst_src1 */), __ S,
      ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src3 */));
  
#line 38533 "ad_aarch64.cpp"
  }
}

void vmlaLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 755 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
      ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 38552 "ad_aarch64.cpp"
  }
}

void vmlaL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst_src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 755 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mla(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst_src1 */), __ D,
      ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src3 */));
  
#line 38571 "ad_aarch64.cpp"
  }
}

void vmlsBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 771 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ B,
      ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 38590 "ad_aarch64.cpp"
  }
}

void vmlsSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 785 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ H,
      ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 38609 "ad_aarch64.cpp"
  }
}

void vmlsINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 799 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
      ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 38628 "ad_aarch64.cpp"
  }
}

void vmlsLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 813 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
      ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 38647 "ad_aarch64.cpp"
  }
}

void vmulBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 828 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mul(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ B,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 38665 "ad_aarch64.cpp"
  }
}

void vmulSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 840 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mul(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ H,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 38683 "ad_aarch64.cpp"
  }
}

void vmulINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 852 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mul(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 38701 "ad_aarch64.cpp"
  }
}

void vmulLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 864 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mul(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 38719 "ad_aarch64.cpp"
  }
}

void vmulFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 876 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmul(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 38738 "ad_aarch64.cpp"
  }
}

void vmulDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 889 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmul(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 38757 "ad_aarch64.cpp"
  }
}

void vnegFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 904 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fneg(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 38774 "ad_aarch64.cpp"
  }
}

void vnegDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 916 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fneg(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 38791 "ad_aarch64.cpp"
  }
}

void vpopcountINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 929 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

     __ sve_cnt(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S, ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 38807 "ad_aarch64.cpp"
  }
}

void reduce_addBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 947 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_uaddv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ B,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ smov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ B, 0);
    __ addw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */);
    __ sxtb(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 38830 "ad_aarch64.cpp"
  }
}

void reduce_addSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 967 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_uaddv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ H,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ smov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ H, 0);
    __ addw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */);
    __ sxth(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 38853 "ad_aarch64.cpp"
  }
}

void reduce_addINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 986 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_uaddv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S, 0);
    __ addw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */);
  
#line 38875 "ad_aarch64.cpp"
  }
}

void reduce_addLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1004 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_uaddv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ D, 0);
    __ add(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */);
  
#line 38897 "ad_aarch64.cpp"
  }
}

void reduce_addFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1_dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1018 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fadda(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1_dst */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 38915 "ad_aarch64.cpp"
  }
}

void reduce_addDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1_dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1030 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fadda(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1_dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 38933 "ad_aarch64.cpp"
  }
}

void reduce_maxFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1047 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmaxv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ fmaxs(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 38953 "ad_aarch64.cpp"
  }
}

void reduce_maxDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1063 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmaxv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ fmaxd(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 38973 "ad_aarch64.cpp"
  }
}

void reduce_minFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1081 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fminv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ fmins(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 38993 "ad_aarch64.cpp"
  }
}

void reduce_minDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1097 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fminv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ fmind(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 39013 "ad_aarch64.cpp"
  }
}

void vroundDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rmode
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1112 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    switch (opnd_array(2)->constant()) {
      case RoundDoubleModeNode::rmode_rint:
        __ sve_frintn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
             ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
        break;
      case RoundDoubleModeNode::rmode_floor:
        __ sve_frintm(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
             ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
        break;
      case RoundDoubleModeNode::rmode_ceil:
        __ sve_frintp(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
             ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
        break;
    }
  
#line 39043 "ad_aarch64.cpp"
  }
}

void replicateBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1138 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 39059 "ad_aarch64.cpp"
  }
}

void replicateSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1149 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 39075 "ad_aarch64.cpp"
  }
}

void replicateINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1160 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 39091 "ad_aarch64.cpp"
  }
}

void replicateLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1171 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 39107 "ad_aarch64.cpp"
  }
}

void replicateB_imm8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1182 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B, opnd_array(1)->constant());
  
#line 39123 "ad_aarch64.cpp"
  }
}

void replicateS_imm8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1193 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H, opnd_array(1)->constant());
  
#line 39139 "ad_aarch64.cpp"
  }
}

void replicateI_imm8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1204 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S, opnd_array(1)->constant());
  
#line 39155 "ad_aarch64.cpp"
  }
}

void replicateL_imm8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1215 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, opnd_array(1)->constantL());
  
#line 39171 "ad_aarch64.cpp"
  }
}

void replicateFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1226 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_cpy(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 39188 "ad_aarch64.cpp"
  }
}

void replicateDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1238 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_cpy(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 39205 "ad_aarch64.cpp"
  }
}

void vasrBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1252 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_asr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ B,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 39223 "ad_aarch64.cpp"
  }
}

void vasrSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1264 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_asr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ H,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 39241 "ad_aarch64.cpp"
  }
}

void vasrINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1276 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_asr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 39259 "ad_aarch64.cpp"
  }
}

void vasrLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1288 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_asr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 39277 "ad_aarch64.cpp"
  }
}

void vlslBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1300 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsl(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ B,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 39295 "ad_aarch64.cpp"
  }
}

void vlslSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1312 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsl(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ H,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 39313 "ad_aarch64.cpp"
  }
}

void vlslINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1324 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsl(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 39331 "ad_aarch64.cpp"
  }
}

void vlslLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1336 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsl(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 39349 "ad_aarch64.cpp"
  }
}

void vlsrBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1348 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ B,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 39367 "ad_aarch64.cpp"
  }
}

void vlsrSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1360 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ H,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 39385 "ad_aarch64.cpp"
  }
}

void vlsrINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1372 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 39403 "ad_aarch64.cpp"
  }
}

void vlsrLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1384 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 39421 "ad_aarch64.cpp"
  }
}

void vasrB_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1396 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con == 0) {
      __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    if (con >= 8) con = 7;
    __ sve_asr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 39446 "ad_aarch64.cpp"
  }
}

void vasrS_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1415 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con == 0) {
      __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    if (con >= 16) con = 15;
    __ sve_asr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 39471 "ad_aarch64.cpp"
  }
}

void vasrI_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1434 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con == 0) {
      __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    __ sve_asr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 39495 "ad_aarch64.cpp"
  }
}

void vasrL_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1452 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con == 0) {
      __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    __ sve_asr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 39519 "ad_aarch64.cpp"
  }
}

void vlsrB_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1470 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con == 0) {
      __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    if (con >= 8) {
      __ sve_eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    __ sve_lsr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 39548 "ad_aarch64.cpp"
  }
}

void vlsrS_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1493 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con == 0) {
      __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    if (con >= 16) {
      __ sve_eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    __ sve_lsr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 39577 "ad_aarch64.cpp"
  }
}

void vlsrI_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1516 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con == 0) {
      __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    __ sve_lsr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 39601 "ad_aarch64.cpp"
  }
}

void vlsrL_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1534 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con == 0) {
      __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    __ sve_lsr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 39625 "ad_aarch64.cpp"
  }
}

void vlslB_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1552 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con >= 8) {
      __ sve_eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    __ sve_lsl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 39649 "ad_aarch64.cpp"
  }
}

void vlslS_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1570 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con >= 16) {
      __ sve_eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    __ sve_lsl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 39673 "ad_aarch64.cpp"
  }
}

void vlslI_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1588 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    __ sve_lsl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 39692 "ad_aarch64.cpp"
  }
}

void vlslL_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1601 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    __ sve_lsl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 39711 "ad_aarch64.cpp"
  }
}

void vshiftcntBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1615 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 39727 "ad_aarch64.cpp"
  }
}

void vshiftcntB_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1615 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 39743 "ad_aarch64.cpp"
  }
}

void vshiftcntSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1628 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 39759 "ad_aarch64.cpp"
  }
}

void vshiftcntS_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1628 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 39775 "ad_aarch64.cpp"
  }
}

void vshiftcntINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1640 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 39791 "ad_aarch64.cpp"
  }
}

void vshiftcntI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1640 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 39807 "ad_aarch64.cpp"
  }
}

void vshiftcntLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1652 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 39823 "ad_aarch64.cpp"
  }
}

void vshiftcntL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1652 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 39839 "ad_aarch64.cpp"
  }
}

void vsqrtFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1665 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fsqrt(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 39856 "ad_aarch64.cpp"
  }
}

void vsqrtDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1677 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fsqrt(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 39873 "ad_aarch64.cpp"
  }
}

void vsubBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1691 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_sub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 39892 "ad_aarch64.cpp"
  }
}

void vsubSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1704 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_sub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 39911 "ad_aarch64.cpp"
  }
}

void vsubINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1717 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_sub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 39930 "ad_aarch64.cpp"
  }
}

void vsubLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1730 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_sub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 39949 "ad_aarch64.cpp"
  }
}

void vsubFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1743 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fsub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 39968 "ad_aarch64.cpp"
  }
}

void vsubDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1756 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fsub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 39987 "ad_aarch64.cpp"
  }
}

void vmaskcastNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1772 "src/hotspot/cpu/aarch64/aarch64_sve.ad"

    // empty
  
#line 40003 "ad_aarch64.cpp"
  }
}

void compareAndSwapP_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {

#line 31 "src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    Register tmp = opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ false, /*release*/ true, /*is_cae*/ false, opnd_array(0)->as_Register(ra_,this)/* res */);
  
#line 40026 "ad_aarch64.cpp"
  }
}

void compareAndSwapN_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 77 "src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, /*acquire*/ false, /*release*/ true, /*is_cae*/ false, opnd_array(0)->as_Register(ra_,this)/* res */);
  
#line 40047 "ad_aarch64.cpp"
  }
}

void compareAndSwapPAcq_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {

#line 40 "src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    Register tmp = opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ true, /*release*/ true, /*is_cae*/ false, opnd_array(0)->as_Register(ra_,this)/* res */);
  
#line 40070 "ad_aarch64.cpp"
  }
}

void compareAndSwapNAcq_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 115 "src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, /*acquire*/ true, /*release*/ true, /*is_cae*/ false, opnd_array(0)->as_Register(ra_,this)/* res */);
  
#line 40091 "ad_aarch64.cpp"
  }
}

void compareAndExchangeN_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 131 "src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(5)->as_Register(ra_,this,idx5)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ false, /*release*/ true, /*is_cae*/ true, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 40114 "ad_aarch64.cpp"
  }
}

void compareAndExchangeP_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 147 "src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(5)->as_Register(ra_,this,idx5)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ false, /*release*/ true, /*is_cae*/ true, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 40137 "ad_aarch64.cpp"
  }
}

void compareAndExchangeNAcq_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 164 "src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(5)->as_Register(ra_,this,idx5)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ true, /*release*/ true, /*is_cae*/ true, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 40160 "ad_aarch64.cpp"
  }
}

void compareAndExchangePAcq_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 181 "src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(5)->as_Register(ra_,this,idx5)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ true, /*release*/ true, /*is_cae*/ true, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 40183 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapN_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 198 "src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    // Weak is not currently supported by ShenandoahBarrierSet::cmpxchg_oop
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ false, /*release*/ true, /*is_cae*/ false, opnd_array(0)->as_Register(ra_,this)/* res */);
  
#line 40206 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapP_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 215 "src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    // Weak is not currently supported by ShenandoahBarrierSet::cmpxchg_oop
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ false, /*release*/ true, /*is_cae*/ false, opnd_array(0)->as_Register(ra_,this)/* res */);
  
#line 40229 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapNAcq_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 234 "src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    // Weak is not currently supported by ShenandoahBarrierSet::cmpxchg_oop
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ true, /*release*/ true, /*is_cae*/ false, opnd_array(0)->as_Register(ra_,this)/* res */);
  
#line 40252 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapPAcq_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 253 "src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    // Weak is not currently supported by ShenandoahBarrierSet::cmpxchg_oop
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ true, /*release*/ true, /*is_cae*/ false, opnd_array(0)->as_Register(ra_,this)/* res */);
  
#line 40275 "ad_aarch64.cpp"
  }
}

void zLoadPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 64 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    const Address ref_addr = mem2address(opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
    __ ldr(opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, ref_addr);
    z_load_barrier(_masm, this, ref_addr, opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, rscratch2 /* tmp */, barrier_data());
  
#line 40294 "ad_aarch64.cpp"
  }
}

void zLoadPVolatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 84 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    __ ldar(opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */);
    z_load_barrier(_masm, this, Address(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */), opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, rscratch2 /* tmp */, barrier_data());
  
#line 40312 "ad_aarch64.cpp"
  }
}

void zCompareAndSwapPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 103 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    guarantee(opnd_array(1)->index(ra_,this,idx1)== -1 && opnd_array(1)->disp(ra_,this,idx1)== 0, "impossible encoding");
    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
               false /* acquire */, true /* release */, false /* weak */, rscratch2);
    __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
    if (barrier_data() != ZLoadBarrierElided) {
      Label good;
      __ ldr(rscratch1, Address(rthread, ZThreadLocalData::address_bad_mask_offset()));
      __ andr(rscratch1, rscratch1, rscratch2);
      __ cbz(rscratch1, good);
      z_load_barrier_slow_path(_masm, this, Address(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */), rscratch2 /* ref */, rscratch1 /* tmp */);
      __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
                 false /* acquire */, true /* release */, false /* weak */, rscratch2);
      __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
      __ bind(good);
    }
  
#line 40345 "ad_aarch64.cpp"
  }
}

void zCompareAndSwapP_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 103 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    guarantee(opnd_array(1)->index(ra_,this,idx1)== -1 && opnd_array(1)->disp(ra_,this,idx1)== 0, "impossible encoding");
    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
               false /* acquire */, true /* release */, false /* weak */, rscratch2);
    __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
    if (barrier_data() != ZLoadBarrierElided) {
      Label good;
      __ ldr(rscratch1, Address(rthread, ZThreadLocalData::address_bad_mask_offset()));
      __ andr(rscratch1, rscratch1, rscratch2);
      __ cbz(rscratch1, good);
      z_load_barrier_slow_path(_masm, this, Address(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */), rscratch2 /* ref */, rscratch1 /* tmp */);
      __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
                 false /* acquire */, true /* release */, false /* weak */, rscratch2);
      __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
      __ bind(good);
    }
  
#line 40378 "ad_aarch64.cpp"
  }
}

void zCompareAndSwapPAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 135 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    guarantee(opnd_array(1)->index(ra_,this,idx1)== -1 && opnd_array(1)->disp(ra_,this,idx1)== 0, "impossible encoding");
    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
               true /* acquire */, true /* release */, false /* weak */, rscratch2);
    __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
    if (barrier_data() != ZLoadBarrierElided) {
      Label good;
      __ ldr(rscratch1, Address(rthread, ZThreadLocalData::address_bad_mask_offset()));
      __ andr(rscratch1, rscratch1, rscratch2);
      __ cbz(rscratch1, good);
      z_load_barrier_slow_path(_masm, this, Address(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */), rscratch2 /* ref */, rscratch1 /* tmp */ );
      __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
                 true /* acquire */, true /* release */, false /* weak */, rscratch2);
      __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
      __ bind(good);
    }
  
#line 40411 "ad_aarch64.cpp"
  }
}

void zCompareAndSwapPAcq_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 135 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    guarantee(opnd_array(1)->index(ra_,this,idx1)== -1 && opnd_array(1)->disp(ra_,this,idx1)== 0, "impossible encoding");
    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
               true /* acquire */, true /* release */, false /* weak */, rscratch2);
    __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
    if (barrier_data() != ZLoadBarrierElided) {
      Label good;
      __ ldr(rscratch1, Address(rthread, ZThreadLocalData::address_bad_mask_offset()));
      __ andr(rscratch1, rscratch1, rscratch2);
      __ cbz(rscratch1, good);
      z_load_barrier_slow_path(_masm, this, Address(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */), rscratch2 /* ref */, rscratch1 /* tmp */ );
      __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
                 true /* acquire */, true /* release */, false /* weak */, rscratch2);
      __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
      __ bind(good);
    }
  
#line 40444 "ad_aarch64.cpp"
  }
}

void zCompareAndExchangePNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 165 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    guarantee(opnd_array(1)->index(ra_,this,idx1)== -1 && opnd_array(1)->disp(ra_,this,idx1)== 0, "impossible encoding");
    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
               false /* acquire */, true /* release */, false /* weak */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
    if (barrier_data() != ZLoadBarrierElided) {
      Label good;
      __ ldr(rscratch1, Address(rthread, ZThreadLocalData::address_bad_mask_offset()));
      __ andr(rscratch1, rscratch1, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
      __ cbz(rscratch1, good);
      z_load_barrier_slow_path(_masm, this, Address(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */), opnd_array(4)->as_Register(ra_,this,idx4)/* res */, rscratch1 /* tmp */);
      __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
                 false /* acquire */, true /* release */, false /* weak */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
      __ bind(good);
    }
  
#line 40475 "ad_aarch64.cpp"
  }
}

void zCompareAndExchangePAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 193 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    guarantee(opnd_array(1)->index(ra_,this,idx1)== -1 && opnd_array(1)->disp(ra_,this,idx1)== 0, "impossible encoding");
    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
               true /* acquire */, true /* release */, false /* weak */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
    if (barrier_data() != ZLoadBarrierElided) {
      Label good;
      __ ldr(rscratch1, Address(rthread, ZThreadLocalData::address_bad_mask_offset()));
      __ andr(rscratch1, rscratch1, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
      __ cbz(rscratch1, good);
      z_load_barrier_slow_path(_masm, this, Address(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */), opnd_array(4)->as_Register(ra_,this,idx4)/* res */, rscratch1 /* tmp */);
      __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
                 true /* acquire */, true /* release */, false /* weak */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
      __ bind(good);
    }
  
#line 40506 "ad_aarch64.cpp"
  }
}

void zGetAndSetPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// prev
  {
    C2_MacroAssembler _masm(&cbuf);

#line 221 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    __ atomic_xchg(opnd_array(3)->as_Register(ra_,this,idx3)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */);
    z_load_barrier(_masm, this, Address(noreg, 0), opnd_array(3)->as_Register(ra_,this,idx3)/* prev */, rscratch2 /* tmp */, barrier_data());
  
#line 40525 "ad_aarch64.cpp"
  }
}

void zGetAndSetPAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// prev
  {
    C2_MacroAssembler _masm(&cbuf);

#line 238 "src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    __ atomic_xchgal(opnd_array(3)->as_Register(ra_,this,idx3)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */);
    z_load_barrier(_masm, this, Address(noreg, 0), opnd_array(3)->as_Register(ra_,this,idx3)/* prev */, rscratch2 /* tmp */, barrier_data());
  
#line 40544 "ad_aarch64.cpp"
  }
}

const MachOper* loadBNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadB2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUBNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUB2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadSNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadS2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUSNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUS2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadINode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUI2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadLNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadRangeNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadPNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadNNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadKlassNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadNKlassNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadFNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadDNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmCM0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmCM0_orderedNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeBNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmB0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeCNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmC0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeINode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmI0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeLNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmL0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storePNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmP0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeNNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeImmN0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeFNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeDNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeNKlassNode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchallocNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadB_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadB2L_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUB_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUB2L_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadS_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUS_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUS2L_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadS2L_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUI2L_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadL_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadP_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadN_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadF_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadD_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeB_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeC_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeI_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeL_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeP_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeN_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeF_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeD_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* cacheWBNode::memory_operand() const { return _opnds[1]; }
const MachOper* popCountI_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* popCountL_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadPLockedNode::memory_operand() const { return _opnds[1]; }
const MachOper* storePConditionalNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeLConditionalNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeIConditionalNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapBNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapSNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapINode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapLNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapPNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapNNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapBAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapSAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapIAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapLAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapPAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapNAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeBNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeSNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeINode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeLNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeNNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangePNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeBAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeSAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeIAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeLAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeNAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangePAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapBNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapSNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapINode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapLNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapNNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapPNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapBAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapSAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapIAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapLAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapNAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapPAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setINode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setLNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setNNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setPNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setIAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setLAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setNAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setPAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addLNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addL_no_resNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addLiNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addLi_no_resNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addINode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addI_no_resNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addIiNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addIi_no_resNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addLAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addL_no_resAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addLiAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addLi_no_resAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addIAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addI_no_resAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addIiAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addIi_no_resAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadV2Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadV4Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadV8Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadV16Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeV2Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeV4Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeV8Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeV16Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadVNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeVNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapP_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapN_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapPAcq_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapNAcq_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeN_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeP_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeNAcq_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangePAcq_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapN_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapP_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapNAcq_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapPAcq_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* zLoadPNode::memory_operand() const { return _opnds[1]; }
const MachOper* zLoadPVolatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* zCompareAndSwapPNode::memory_operand() const { return _opnds[1]; }
const MachOper* zCompareAndSwapP_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* zCompareAndSwapPAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* zCompareAndSwapPAcq_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* zCompareAndExchangePNode::memory_operand() const { return _opnds[1]; }
const MachOper* zCompareAndExchangePAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* zGetAndSetPNode::memory_operand() const { return _opnds[1]; }
const MachOper* zGetAndSetPAcqNode::memory_operand() const { return _opnds[1]; }


const bool Matcher::has_match_rule(int opcode) {
  assert(_last_machine_leaf < opcode && opcode < _last_opcode, "opcode in range");
  return _hasMatchRule[opcode];
}

const bool Matcher::_hasMatchRule[_last_opcode] = {
    false,  // Node
    false,  // Set
    false,  // RegN
    false,  // RegI
    false,  // RegP
    false,  // RegF
    false,  // RegD
    false,  // RegL
    false,  // VecA
    false,  // VecS
    false,  // VecD
    false,  // VecX
    false,  // VecY
    false,  // VecZ
    false,  // RegVectMask
    false,  // RegFlags
    false,  // _last_machine_leaf
    true ,  // AbsD
    true ,  // AbsF
    true ,  // AbsI
    true ,  // AbsL
    true ,  // AddD
    true ,  // AddF
    true ,  // AddI
    true ,  // AddL
    true ,  // AddP
    false,  // Allocate
    false,  // AllocateArray
    true ,  // AndI
    true ,  // AndL
    false,  // ArrayCopy
    true ,  // AryEq
    false,  // AtanD
    true ,  // Binary
    false,  // Blackhole
    true ,  // Bool
    false,  // BoxLock
    true ,  // ReverseBytesI
    true ,  // ReverseBytesL
    true ,  // ReverseBytesUS
    true ,  // ReverseBytesS
    false,  // CProj
    true ,  // CacheWB
    true ,  // CacheWBPreSync
    true ,  // CacheWBPostSync
    true ,  // CallDynamicJava
    false,  // CallJava
    true ,  // CallLeaf
    true ,  // CallLeafNoFP
    false,  // CallLeafVector
    true ,  // CallRuntime
    true ,  // CallNative
    true ,  // CallStaticJava
    true ,  // CastDD
    true ,  // CastFF
    true ,  // CastII
    true ,  // CastLL
    true ,  // CastVV
    true ,  // CastX2P
    true ,  // CastP2X
    true ,  // CastPP
    false,  // Catch
    false,  // CatchProj
    true ,  // CheckCastPP
    true ,  // ClearArray
    false,  // ConstraintCast
    true ,  // CMoveD
    false,  // CMoveVD
    true ,  // CMoveF
    false,  // CMoveVF
    true ,  // CMoveI
    true ,  // CMoveL
    true ,  // CMoveP
    true ,  // CMoveN
    true ,  // CmpN
    true ,  // CmpD
    true ,  // CmpD3
    true ,  // CmpF
    true ,  // CmpF3
    true ,  // CmpI
    true ,  // CmpL
    true ,  // CmpL3
    true ,  // CmpLTMask
    true ,  // CmpP
    true ,  // CmpU
    true ,  // CmpUL
    true ,  // CompareAndSwapB
    true ,  // CompareAndSwapS
    true ,  // CompareAndSwapI
    true ,  // CompareAndSwapL
    true ,  // CompareAndSwapP
    true ,  // CompareAndSwapN
    true ,  // WeakCompareAndSwapB
    true ,  // WeakCompareAndSwapS
    true ,  // WeakCompareAndSwapI
    true ,  // WeakCompareAndSwapL
    true ,  // WeakCompareAndSwapP
    true ,  // WeakCompareAndSwapN
    true ,  // CompareAndExchangeB
    true ,  // CompareAndExchangeS
    true ,  // CompareAndExchangeI
    true ,  // CompareAndExchangeL
    true ,  // CompareAndExchangeP
    true ,  // CompareAndExchangeN
    false,  // GetAndAddB
    false,  // GetAndAddS
    true ,  // GetAndAddI
    true ,  // GetAndAddL
    false,  // GetAndSetB
    false,  // GetAndSetS
    true ,  // GetAndSetI
    true ,  // GetAndSetL
    true ,  // GetAndSetP
    true ,  // GetAndSetN
    false,  // Con
    true ,  // ConN
    true ,  // ConNKlass
    true ,  // ConD
    true ,  // ConF
    true ,  // ConI
    true ,  // ConL
    true ,  // ConP
    true ,  // Conv2B
    true ,  // ConvD2F
    true ,  // ConvD2I
    true ,  // ConvD2L
    true ,  // ConvF2D
    true ,  // ConvF2I
    true ,  // ConvF2L
    true ,  // ConvI2D
    true ,  // ConvI2F
    true ,  // ConvI2L
    true ,  // ConvL2D
    true ,  // ConvL2F
    true ,  // ConvL2I
    false,  // CountedLoop
    true ,  // CountedLoopEnd
    false,  // OuterStripMinedLoop
    false,  // OuterStripMinedLoopEnd
    false,  // LongCountedLoop
    false,  // LongCountedLoopEnd
    true ,  // CountLeadingZerosI
    true ,  // CountLeadingZerosL
    true ,  // CountTrailingZerosI
    true ,  // CountTrailingZerosL
    true ,  // CreateEx
    true ,  // DecodeN
    true ,  // DecodeNKlass
    true ,  // DivD
    true ,  // DivF
    true ,  // DivI
    true ,  // DivL
    false,  // DivMod
    false,  // DivModI
    false,  // DivModL
    true ,  // EncodeISOArray
    true ,  // EncodeP
    true ,  // EncodePKlass
    true ,  // FastLock
    true ,  // FastUnlock
    true ,  // FmaD
    true ,  // FmaF
    true ,  // Goto
    true ,  // Halt
    true ,  // HasNegatives
    true ,  // If
    false,  // RangeCheck
    false,  // IfFalse
    false,  // IfTrue
    false,  // Initialize
    false,  // JProj
    false,  // Jump
    false,  // JumpProj
    true ,  // LShiftI
    true ,  // LShiftL
    true ,  // LoadB
    true ,  // LoadUB
    true ,  // LoadUS
    true ,  // LoadD
    false,  // LoadD_unaligned
    true ,  // LoadF
    true ,  // LoadI
    true ,  // LoadKlass
    true ,  // LoadNKlass
    true ,  // LoadL
    false,  // LoadL_unaligned
    true ,  // LoadPLocked
    true ,  // LoadP
    true ,  // LoadN
    true ,  // LoadRange
    true ,  // LoadS
    false,  // Lock
    false,  // Loop
    false,  // LoopLimit
    false,  // Mach
    false,  // MachNullCheck
    false,  // MachProj
    true ,  // MulAddS2I
    true ,  // MaxI
    false,  // MaxL
    true ,  // MaxD
    true ,  // MaxF
    true ,  // MemBarAcquire
    true ,  // LoadFence
    false,  // SetVectMaskI
    true ,  // MemBarAcquireLock
    false,  // MemBarCPUOrder
    true ,  // MemBarRelease
    true ,  // StoreFence
    true ,  // MemBarReleaseLock
    true ,  // MemBarVolatile
    true ,  // MemBarStoreStore
    false,  // MergeMem
    true ,  // MinI
    false,  // MinL
    true ,  // MinF
    true ,  // MinD
    false,  // ModD
    false,  // ModF
    true ,  // ModI
    true ,  // ModL
    true ,  // MoveI2F
    true ,  // MoveF2I
    true ,  // MoveL2D
    true ,  // MoveD2L
    true ,  // MulD
    true ,  // MulF
    true ,  // MulHiL
    true ,  // MulI
    true ,  // MulL
    false,  // Multi
    false,  // NegI
    false,  // NegL
    true ,  // NegD
    true ,  // NegF
    false,  // NeverBranch
    true ,  // OnSpinWait
    false,  // Opaque1
    false,  // OpaqueLoopInit
    false,  // OpaqueLoopStride
    false,  // Opaque2
    false,  // Opaque3
    false,  // Opaque4
    false,  // ProfileBoolean
    true ,  // OrI
    true ,  // OrL
    true ,  // OverflowAddI
    true ,  // OverflowSubI
    true ,  // OverflowMulI
    true ,  // OverflowAddL
    true ,  // OverflowSubL
    true ,  // OverflowMulL
    false,  // PCTable
    false,  // Parm
    true ,  // PartialSubtypeCheck
    false,  // SubTypeCheck
    false,  // Phi
    true ,  // PopCountI
    true ,  // PopCountL
    true ,  // PopCountVI
    true ,  // PrefetchAllocation
    false,  // Proj
    true ,  // RShiftI
    true ,  // RShiftL
    false,  // Region
    true ,  // Rethrow
    true ,  // Return
    false,  // Root
    false,  // RoundDouble
    true ,  // RoundDoubleMode
    true ,  // RoundDoubleModeV
    false,  // RoundFloat
    true ,  // RotateLeft
    false,  // RotateLeftV
    true ,  // RotateRight
    false,  // RotateRightV
    true ,  // SafePoint
    false,  // SafePointScalarObject
    true ,  // ShenandoahCompareAndExchangeP
    true ,  // ShenandoahCompareAndExchangeN
    true ,  // ShenandoahCompareAndSwapN
    true ,  // ShenandoahCompareAndSwapP
    true ,  // ShenandoahWeakCompareAndSwapN
    true ,  // ShenandoahWeakCompareAndSwapP
    false,  // ShenandoahIUBarrier
    false,  // ShenandoahLoadReferenceBarrier
    false,  // SCMemProj
    true ,  // CopySignD
    true ,  // CopySignF
    true ,  // SignumD
    true ,  // SignumF
    true ,  // SqrtD
    true ,  // SqrtF
    false,  // Start
    false,  // StartOSR
    true ,  // StoreB
    true ,  // StoreC
    true ,  // StoreCM
    true ,  // StorePConditional
    true ,  // StoreIConditional
    true ,  // StoreLConditional
    true ,  // StoreD
    true ,  // StoreF
    true ,  // StoreI
    true ,  // StoreL
    true ,  // StoreP
    true ,  // StoreN
    true ,  // StoreNKlass
    true ,  // StrComp
    true ,  // StrCompressedCopy
    true ,  // StrEquals
    true ,  // StrIndexOf
    true ,  // StrIndexOfChar
    true ,  // StrInflatedCopy
    true ,  // SubD
    true ,  // SubF
    true ,  // SubI
    true ,  // SubL
    true ,  // TailCall
    true ,  // TailJump
    false,  // MacroLogicV
    true ,  // ThreadLocal
    false,  // Unlock
    false,  // URShiftB
    false,  // URShiftS
    true ,  // URShiftI
    true ,  // URShiftL
    true ,  // XorI
    true ,  // XorL
    false,  // Vector
    true ,  // AddVB
    true ,  // AddVS
    true ,  // AddVI
    true ,  // AddReductionVI
    true ,  // AddVL
    true ,  // AddReductionVL
    true ,  // AddVF
    true ,  // AddReductionVF
    true ,  // AddVD
    true ,  // AddReductionVD
    true ,  // SubVB
    true ,  // SubVS
    true ,  // SubVI
    true ,  // SubVL
    true ,  // SubVF
    true ,  // SubVD
    true ,  // MulVB
    true ,  // MulVS
    true ,  // MulVI
    true ,  // MulReductionVI
    true ,  // MulVL
    true ,  // MulReductionVL
    true ,  // MulVF
    true ,  // MulReductionVF
    true ,  // MulVD
    true ,  // MulReductionVD
    true ,  // MulAddVS2VI
    true ,  // FmaVD
    true ,  // FmaVF
    true ,  // DivVF
    true ,  // DivVD
    true ,  // AbsVB
    true ,  // AbsVS
    true ,  // AbsVI
    true ,  // AbsVL
    true ,  // AbsVF
    true ,  // AbsVD
    false,  // NegVI
    true ,  // NegVF
    true ,  // NegVD
    true ,  // SqrtVD
    true ,  // SqrtVF
    true ,  // LShiftCntV
    true ,  // RShiftCntV
    true ,  // LShiftVB
    true ,  // LShiftVS
    true ,  // LShiftVI
    true ,  // LShiftVL
    true ,  // RShiftVB
    true ,  // RShiftVS
    true ,  // RShiftVI
    true ,  // RShiftVL
    true ,  // URShiftVB
    true ,  // URShiftVS
    true ,  // URShiftVI
    true ,  // URShiftVL
    true ,  // AndV
    true ,  // AndReductionV
    true ,  // OrV
    true ,  // OrReductionV
    true ,  // XorV
    true ,  // XorReductionV
    true ,  // MinV
    true ,  // MaxV
    true ,  // MinReductionV
    true ,  // MaxReductionV
    true ,  // LoadVector
    false,  // LoadVectorGather
    true ,  // StoreVector
    false,  // StoreVectorScatter
    false,  // LoadVectorMasked
    false,  // StoreVectorMasked
    false,  // VectorCmpMasked
    false,  // VectorMaskGen
    false,  // VectorMaskOp
    false,  // VectorMaskTrueCount
    false,  // VectorMaskFirstTrue
    false,  // VectorMaskLastTrue
    false,  // Pack
    false,  // PackB
    false,  // PackS
    false,  // PackI
    false,  // PackL
    false,  // PackF
    false,  // PackD
    false,  // Pack2L
    false,  // Pack2D
    true ,  // ReplicateB
    true ,  // ReplicateS
    true ,  // ReplicateI
    true ,  // ReplicateL
    true ,  // ReplicateF
    true ,  // ReplicateD
    false,  // Extract
    true ,  // ExtractB
    false,  // ExtractUB
    false,  // ExtractC
    true ,  // ExtractS
    true ,  // ExtractI
    true ,  // ExtractL
    true ,  // ExtractF
    true ,  // ExtractD
    false,  // Digit
    false,  // LowerCase
    false,  // UpperCase
    false,  // Whitespace
    false,  // VectorBox
    false,  // VectorBoxAllocate
    false,  // VectorUnbox
    false,  // VectorMaskWrapper
    true ,  // VectorMaskCmp
    true ,  // VectorMaskCast
    true ,  // VectorTest
    true ,  // VectorBlend
    true ,  // VectorRearrange
    true ,  // VectorLoadMask
    true ,  // VectorLoadShuffle
    true ,  // VectorLoadConst
    true ,  // VectorStoreMask
    true ,  // VectorReinterpret
    false,  // VectorCast
    true ,  // VectorCastB2X
    true ,  // VectorCastS2X
    true ,  // VectorCastI2X
    true ,  // VectorCastL2X
    true ,  // VectorCastF2X
    true ,  // VectorCastD2X
    true    // VectorInsert
};


int Compile::sync_stack_slots() const { return 2; }

uint Matcher::stack_alignment_in_bytes() { return StackAlignmentInBytes; }

OptoReg::Name Matcher::return_addr() const { return OptoReg::stack2reg(- 2 +
              align_up((Compile::current()->in_preserve_stack_slots() +
                        Compile::current()->fixed_slots()),
                       stack_alignment_in_slots())); }

uint Compile::varargs_C_out_slots_killed() const { return frame::arg_reg_save_area_bytes/BytesPerInt; }

OptoRegPair Matcher::return_value(uint ideal_reg) {

#line 4047 "src/hotspot/cpu/aarch64/aarch64.ad"

    // TODO do we allow ideal_reg == Op_RegN???
    assert(ideal_reg >= Op_RegI && ideal_reg <= Op_RegL,
           "only return normal values");

    static const int lo[Op_RegL + 1] = { // enum name
      0,                                 // Op_Node
      0,                                 // Op_Set
      R0_num,                            // Op_RegN
      R0_num,                            // Op_RegI
      R0_num,                            // Op_RegP
      V0_num,                            // Op_RegF
      V0_num,                            // Op_RegD
      R0_num                             // Op_RegL
    };

    static const int hi[Op_RegL + 1] = { // enum name
      0,                                 // Op_Node
      0,                                 // Op_Set
      OptoReg::Bad,                      // Op_RegN
      OptoReg::Bad,                      // Op_RegI
      R0_H_num,                          // Op_RegP
      OptoReg::Bad,                      // Op_RegF
      V0_H_num,                          // Op_RegD
      R0_H_num                           // Op_RegL
    };

    return OptoRegPair(hi[ideal_reg], lo[ideal_reg]);
  
#line 41219 "ad_aarch64.cpp"

}

OptoRegPair Matcher::c_return_value(uint ideal_reg) {

#line 4047 "src/hotspot/cpu/aarch64/aarch64.ad"

    // TODO do we allow ideal_reg == Op_RegN???
    assert(ideal_reg >= Op_RegI && ideal_reg <= Op_RegL,
           "only return normal values");

    static const int lo[Op_RegL + 1] = { // enum name
      0,                                 // Op_Node
      0,                                 // Op_Set
      R0_num,                            // Op_RegN
      R0_num,                            // Op_RegI
      R0_num,                            // Op_RegP
      V0_num,                            // Op_RegF
      V0_num,                            // Op_RegD
      R0_num                             // Op_RegL
    };

    static const int hi[Op_RegL + 1] = { // enum name
      0,                                 // Op_Node
      0,                                 // Op_Set
      OptoReg::Bad,                      // Op_RegN
      OptoReg::Bad,                      // Op_RegI
      R0_H_num,                          // Op_RegP
      OptoReg::Bad,                      // Op_RegF
      V0_H_num,                          // Op_RegD
      R0_H_num                           // Op_RegL
    };

    return OptoRegPair(hi[ideal_reg], lo[ideal_reg]);
  
#line 41255 "ad_aarch64.cpp"

}

OptoReg::Name Matcher::inline_cache_reg() { return OptoReg::Name(R12_num); }

int Matcher::inline_cache_reg_encode() { return _regEncode[inline_cache_reg()]; }

OptoReg::Name Matcher::interpreter_frame_pointer_reg() { return OptoReg::Name(R29_num); }

OptoReg::Name Matcher::c_frame_pointer() const { return OptoReg::Name(R31_num); }

// Number of callee-save + always-save registers
int  Matcher::number_of_saved_registers() {
  return 0;
};

bool Compile::needs_deep_clone_jvms() { return false; }

// Check consistency of C++ compilation with ADLC options:
// Check adlc -DLINUX=1
#ifndef LINUX
#  error "LINUX must be defined"
#endif // LINUX
// Check adlc -D_GNU_SOURCE=1
#ifndef _GNU_SOURCE
#  error "_GNU_SOURCE must be defined"
#endif // _GNU_SOURCE
// Check adlc -DAARCH64=1
#ifndef AARCH64
#  error "AARCH64 must be defined"
#endif // AARCH64
// Check adlc -D_LP64=1
#ifndef _LP64
#  error "_LP64 must be defined"
#endif // _LP64
